@@ -32,7 +32,6 @@ enum map_handler_type
 	AMH_NOP,
 	AMH_UNMAP,
 	AMH_DEVICE_DELEGATE,
-	AMH_LEGACY_SPACE_HANDLER,
 	AMH_PORT,
 	AMH_BANK,
 	AMH_DEVICE_SUBMAP
@@ -83,7 +82,7 @@ public:
 	void set_read_type(map_handler_type _type) { m_read.m_type = _type; }
 	void set_write_type(map_handler_type _type) { m_write.m_type = _type; }
 	void set_region(const char *tag, offs_t offset) { m_region = tag; m_rgnoffs = offset; }
-	void set_share(const char *tag) { assert(m_share == NULL); m_share = tag; }
+	void set_share(device_t &device, const char *tag) { assert(m_sharetag == NULL); m_sharebase = &device; m_sharetag = tag; }
 
 	// mask setting
 	void set_mask(offs_t _mask);
@@ -117,7 +116,8 @@ public:
 	map_handler_data        m_read;                 // data for read handler
 	map_handler_data        m_write;                // data for write handler
 	map_handler_data        m_setoffsethd;          // data for setoffset handler
-	const char *            m_share;                // tag of a shared memory block
+	device_t *              m_sharebase;            // pointer to the base device for the share tag
+	const char *            m_sharetag;             // tag of a shared memory block
 	const char *            m_region;               // tag of region containing the memory backing this entry
 	offs_t                  m_rgnoffs;              // offset within the region
 
@@ -126,18 +126,10 @@ public:
 	read16_delegate         m_rproto16;             // 16-bit read proto-delegate
 	read32_delegate         m_rproto32;             // 32-bit read proto-delegate
 	read64_delegate         m_rproto64;             // 64-bit read proto-delegate
-	read8_space_func        m_rspace8;              // 8-bit legacy address space handler
-	read16_space_func       m_rspace16;             // 16-bit legacy address space handler
-	read32_space_func       m_rspace32;             // 32-bit legacy address space handler
-	read64_space_func       m_rspace64;             // 64-bit legacy address space handler
 	write8_delegate         m_wproto8;              // 8-bit write proto-delegate
 	write16_delegate        m_wproto16;             // 16-bit write proto-delegate
 	write32_delegate        m_wproto32;             // 32-bit write proto-delegate
 	write64_delegate        m_wproto64;             // 64-bit write proto-delegate
-	write8_space_func       m_wspace8;              // 8-bit legacy address space handler
-	write16_space_func      m_wspace16;             // 16-bit legacy address space handler
-	write32_space_func      m_wspace32;             // 32-bit legacy address space handler
-	write64_space_func      m_wspace64;             // 64-bit legacy address space handler
 
 	setoffset_delegate       m_soproto;              // set offset proto-delegate
 	address_map_delegate    m_submap_delegate;
@@ -152,33 +144,21 @@ public:
 
 protected:
 	// internal handler setters for 8-bit functions
-	void internal_set_handler(read8_space_func func, const char *string, UINT64 mask);
-	void internal_set_handler(write8_space_func func, const char *string, UINT64 mask);
-	void internal_set_handler(read8_space_func rfunc, const char *rstring, write8_space_func wfunc,  const char *wstring, UINT64 mask);
 	void internal_set_handler(device_t &device, read8_delegate func, UINT64 mask);
 	void internal_set_handler(device_t &device, write8_delegate func, UINT64 mask);
 	void internal_set_handler(device_t &device, read8_delegate rfunc, write8_delegate wfunc, UINT64 mask);
 
 	// internal handler setters for 16-bit functions
-	void internal_set_handler(read16_space_func func, const char *string, UINT64 mask);
-	void internal_set_handler(write16_space_func func, const char *string, UINT64 mask);
-	void internal_set_handler(read16_space_func rfunc, const char *rstring, write16_space_func wfunc, const char *wstring, UINT64 mask);
 	void internal_set_handler(device_t &device, read16_delegate func, UINT64 mask);
 	void internal_set_handler(device_t &device, write16_delegate func, UINT64 mask);
 	void internal_set_handler(device_t &device, read16_delegate rfunc, write16_delegate wfunc, UINT64 mask);
 
 	// internal handler setters for 32-bit functions
-	void internal_set_handler(read32_space_func func, const char *string, UINT64 mask);
-	void internal_set_handler(write32_space_func func, const char *string, UINT64 mask);
-	void internal_set_handler(read32_space_func rfunc, const char *rstring, write32_space_func wfunc, const char *wstring, UINT64 mask);
 	void internal_set_handler(device_t &device, read32_delegate func, UINT64 mask);
 	void internal_set_handler(device_t &device, write32_delegate func, UINT64 mask);
 	void internal_set_handler(device_t &device, read32_delegate rfunc, write32_delegate wfunc, UINT64 mask);
 
 	// internal handler setters for 64-bit functions
-	void internal_set_handler(read64_space_func func, const char *string, UINT64 mask);
-	void internal_set_handler(write64_space_func func, const char *string, UINT64 mask);
-	void internal_set_handler(read64_space_func rfunc, const char *rstring, write64_space_func wfunc, const char *wstring, UINT64 mask);
 	void internal_set_handler(device_t &device, read64_delegate func, UINT64 mask);
 	void internal_set_handler(device_t &device, write64_delegate func, UINT64 mask);
 	void internal_set_handler(device_t &device, read64_delegate rfunc, write64_delegate wfunc, UINT64 mask);
@@ -198,9 +178,6 @@ public:
 	address_map_entry8(address_map &map, offs_t start, offs_t end);
 
 	// native-size handlers
-	void set_handler(read8_space_func func, const char *string) { internal_set_handler(func, string, 0); }
-	void set_handler(write8_space_func func, const char *string) { internal_set_handler(func, string, 0); }
-	void set_handler(read8_space_func rfunc, const char *rstring, write8_space_func wfunc, const char *wstring) { internal_set_handler(rfunc, rstring, wfunc, wstring, 0); }
 	void set_handler(device_t &device, read8_delegate func) { internal_set_handler(device, func, 0); }
 	void set_handler(device_t &device, write8_delegate func) { internal_set_handler(device, func, 0); }
 	void set_handler(device_t &device, read8_delegate rfunc, write8_delegate wfunc) { internal_set_handler(device, rfunc, wfunc, 0); }
@@ -216,17 +193,11 @@ public:
 	address_map_entry16(address_map &map, offs_t start, offs_t end);
 
 	// native-size handlers
-	void set_handler(read16_space_func func, const char *string) { internal_set_handler(func, string, 0); }
-	void set_handler(write16_space_func func, const char *string) { internal_set_handler(func, string, 0); }
-	void set_handler(read16_space_func rfunc, const char *rstring, write16_space_func wfunc, const char *wstring) { internal_set_handler(rfunc, rstring, wfunc, wstring, 0); }
 	void set_handler(device_t &device, read16_delegate func) { internal_set_handler(device, func, 0); }
 	void set_handler(device_t &device, write16_delegate func) { internal_set_handler(device, func, 0); }
 	void set_handler(device_t &device, read16_delegate rfunc, write16_delegate wfunc) { internal_set_handler(device, rfunc, wfunc, 0); }
 
 	// 8-bit handlers
-	void set_handler(read8_space_func func, const char *string, UINT16 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(write8_space_func func, const char *string, UINT16 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(read8_space_func rfunc, const char *rstring, write8_space_func wfunc, const char *wstring, UINT16 mask) { internal_set_handler(rfunc, rstring, wfunc, wstring, mask); }
 	void set_handler(device_t &device, read8_delegate func, UINT16 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, write8_delegate func, UINT16 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, read8_delegate rfunc, write8_delegate wfunc, UINT16 mask) { internal_set_handler(device, rfunc, wfunc, mask); }
@@ -242,25 +213,16 @@ public:
 	address_map_entry32(address_map &map, offs_t start, offs_t end);
 
 	// native-size handlers
-	void set_handler(read32_space_func func, const char *string) { internal_set_handler(func, string, 0); }
-	void set_handler(write32_space_func func, const char *string) { internal_set_handler(func, string, 0); }
-	void set_handler(read32_space_func rfunc, const char *rstring, write32_space_func wfunc, const char *wstring) { internal_set_handler(rfunc, rstring, wfunc, wstring, 0); }
 	void set_handler(device_t &device, read32_delegate func) { internal_set_handler(device, func, 0); }
 	void set_handler(device_t &device, write32_delegate func) { internal_set_handler(device, func, 0); }
 	void set_handler(device_t &device, read32_delegate rfunc, write32_delegate wfunc) { internal_set_handler(device, rfunc, wfunc, 0); }
 
 	// 16-bit handlers
-	void set_handler(read16_space_func func, const char *string, UINT32 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(write16_space_func func, const char *string, UINT32 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(read16_space_func rfunc, const char *rstring, write16_space_func wfunc, const char *wstring, UINT32 mask) { internal_set_handler(rfunc, rstring, wfunc, wstring, mask); }
 	void set_handler(device_t &device, read16_delegate func, UINT32 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, write16_delegate func, UINT32 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, read16_delegate rfunc, write16_delegate wfunc, UINT32 mask) { internal_set_handler(device, rfunc, wfunc, mask); }
 
 	// 8-bit handlers
-	void set_handler(read8_space_func func, const char *string, UINT32 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(write8_space_func func, const char *string, UINT32 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(read8_space_func rfunc, const char *rstring, write8_space_func wfunc, const char *wstring, UINT32 mask) { internal_set_handler(rfunc, rstring, wfunc, wstring, mask); }
 	void set_handler(device_t &device, read8_delegate func, UINT32 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, write8_delegate func, UINT32 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, read8_delegate rfunc, write8_delegate wfunc, UINT32 mask) { internal_set_handler(device, rfunc, wfunc, mask); }
@@ -276,33 +238,21 @@ public:
 	address_map_entry64(address_map &map, offs_t start, offs_t end);
 
 	// native-size handlers
-	void set_handler(read64_space_func func, const char *string) { internal_set_handler(func, string, 0); }
-	void set_handler(write64_space_func func, const char *string) { internal_set_handler(func, string, 0); }
-	void set_handler(read64_space_func rfunc, const char *rstring, write64_space_func wfunc, const char *wstring) { internal_set_handler(rfunc, rstring, wfunc, wstring, 0); }
 	void set_handler(device_t &device, read64_delegate func) { internal_set_handler(device, func, 0); }
 	void set_handler(device_t &device, write64_delegate func) { internal_set_handler(device, func, 0); }
 	void set_handler(device_t &device, read64_delegate rfunc, write64_delegate wfunc) { internal_set_handler(device, rfunc, wfunc, 0); }
 
 	// 32-bit handlers
-	void set_handler(read32_space_func func, const char *string, UINT64 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(write32_space_func func, const char *string, UINT64 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(read32_space_func rfunc, const char *rstring, write32_space_func wfunc, const char *wstring, UINT64 mask) { internal_set_handler(rfunc, rstring, wfunc, wstring, mask); }
 	void set_handler(device_t &device, read32_delegate func, UINT64 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, write32_delegate func, UINT64 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, read32_delegate rfunc, write32_delegate wfunc, UINT64 mask) { internal_set_handler(device, rfunc, wfunc, mask); }
 
 	// 16-bit handlers
-	void set_handler(read16_space_func func, const char *string, UINT64 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(write16_space_func func, const char *string, UINT64 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(read16_space_func rfunc, const char *rstring, write16_space_func wfunc, const char *wstring, UINT64 mask) { internal_set_handler(rfunc, rstring, wfunc, wstring, mask); }
 	void set_handler(device_t &device, read16_delegate func, UINT64 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, write16_delegate func, UINT64 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, read16_delegate rfunc, write16_delegate wfunc, UINT64 mask) { internal_set_handler(device, rfunc, wfunc, mask); }
 
 	// 8-bit handlers
-	void set_handler(read8_space_func func, const char *string, UINT64 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(write8_space_func func, const char *string, UINT64 mask) { internal_set_handler(func, string, mask); }
-	void set_handler(read8_space_func rfunc, const char *rstring, write8_space_func wfunc, const char *wstring, UINT64 mask) { internal_set_handler(rfunc, rstring, wfunc, wstring, mask); }
 	void set_handler(device_t &device, read8_delegate func, UINT64 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, write8_delegate func, UINT64 mask) { internal_set_handler(device, func, mask); }
 	void set_handler(device_t &device, read8_delegate rfunc, write8_delegate wfunc, UINT64 mask) { internal_set_handler(device, rfunc, wfunc, mask); }
@@ -409,38 +359,6 @@ void _class :: _name(::address_map &map, device_t &device) \
 #define AM_MIRROR(_mirror) \
 	curentry->set_mirror(_mirror);
 
-// legacy space reads
-#define AM_READ_LEGACY(_handler) \
-	curentry->set_handler(_handler, #_handler);
-
-// legacy space writes
-#define AM_WRITE_LEGACY(_handler) \
-	curentry->set_handler(_handler, #_handler);
-
-// legacy space reads/writes
-#define AM_READWRITE_LEGACY(_rhandler, _whandler) \
-	curentry->set_handler(_rhandler, #_rhandler, _whandler, #_whandler);
-#define AM_READWRITE8_LEGACY(_rhandler, _whandler, _unitmask) \
-	curentry->set_handler(_rhandler, #_rhandler, _whandler, #_whandler, _unitmask);
-#define AM_READWRITE32_LEGACY(_rhandler, _whandler, _unitmask) \
-	curentry->set_handler(_rhandler, #_rhandler, _whandler, #_whandler, _unitmask);
-
-// legacy device reads
-#define AM_DEVREAD_LEGACY(_tag, _handler) \
-	curentry->set_handler(device, read_delegate(&_handler, #_handler, _tag, (device_t *)0));
-
-// legacy device writes
-#define AM_DEVWRITE_LEGACY(_tag, _handler) \
-	curentry->set_handler(device, write_delegate(&_handler, #_handler, _tag, (device_t *)0));
-
-// legacy device reads/writes
-#define AM_DEVREADWRITE_LEGACY(_tag, _rhandler, _whandler) \
-	curentry->set_handler(device, read_delegate(&_rhandler, #_rhandler, _tag, (device_t *)0), write_delegate(&_whandler, #_whandler, _tag, (device_t *)0));
-#define AM_DEVREADWRITE8_LEGACY(_tag, _rhandler, _whandler, _unitmask) \
-	curentry->set_handler(device, read8_delegate(&_rhandler, #_rhandler, _tag, (device_t *)0), write8_delegate(&_whandler, #_whandler, _tag, (device_t *)0), _unitmask);
-#define AM_DEVREADWRITE16_LEGACY(_tag, _rhandler, _whandler, _unitmask) \
-	curentry->set_handler(device, read16_delegate(&_rhandler, #_rhandler, _tag, (device_t *)0), write16_delegate(&_whandler, #_whandler, _tag, (device_t *)0), _unitmask);
-
 // driver data reads
 #define AM_READ(_handler) \
 	curentry->set_handler(device, read_delegate(&drivdata_class::_handler, "driver_data::" #_handler, DEVICE_SELF, (drivdata_class *)0));
@@ -566,7 +484,7 @@ void _class :: _name(::address_map &map, device_t &device) \
 #define AM_REGION(_tag, _offs) \
 	curentry->set_region(_tag, _offs);
 #define AM_SHARE(_tag) \
-	curentry->set_share(_tag);
+	curentry->set_share(device, _tag);
 
 // common shortcuts
 #define AM_ROMBANK(_bank)                   AM_READ_BANK(_bank)
