@@ -140,6 +140,7 @@
 */
 
 #include "c1541.h"
+#include "bus/centronics/ctronics.h"
 
 
 
@@ -506,10 +507,6 @@ static ADDRESS_MAP_START( c1541pdc_mem, AS_PROGRAM, 8, c1541_prologic_dos_classi
 ADDRESS_MAP_END
 
 
-//-------------------------------------------------
-//  via6522_interface via0_intf
-//-------------------------------------------------
-
 WRITE_LINE_MEMBER( base_c1541_device::via0_irq_w )
 {
 	m_via0_irq = state;
@@ -592,11 +589,6 @@ WRITE8_MEMBER( base_c1541_device::via0_pb_w )
 	m_bus->clk_w(this, !BIT(data, 3));
 }
 
-READ_LINE_MEMBER( base_c1541_device::atn_in_r )
-{
-	return !m_bus->atn_r();
-}
-
 WRITE_LINE_MEMBER( base_c1541_device::via0_ca2_w )
 {
 	if (m_other != NULL)
@@ -605,30 +597,6 @@ WRITE_LINE_MEMBER( base_c1541_device::via0_ca2_w )
 	}
 }
 
-static const via6522_interface c1541_via0_intf =
-{
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via0_pa_r),
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via0_pb_r),
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, atn_in_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via0_pa_w),
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via0_pb_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via0_ca2_w),
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via0_irq_w)
-};
-
-
-//-------------------------------------------------
-//  via6522_interface c1541c_via0_intf
-//-------------------------------------------------
-
 READ8_MEMBER( c1541c_device::via0_pa_r )
 {
 	/*
@@ -646,32 +614,9 @@ READ8_MEMBER( c1541c_device::via0_pa_r )
 
 	*/
 
-	return !floppy_tk00_r(m_image);
+	return !m_floppy->trk00_r();
 }
 
-static const via6522_interface c1541c_via0_intf =
-{
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, c1541c_device, via0_pa_r),
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via0_pb_r),
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, atn_in_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_NULL,
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via0_pb_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via0_irq_w)
-};
-
-
-//-------------------------------------------------
-//  via6522_interface via1_intf
-//-------------------------------------------------
 
 WRITE_LINE_MEMBER( base_c1541_device::via1_irq_w )
 {
@@ -700,7 +645,7 @@ READ8_MEMBER( base_c1541_device::via1_pb_r )
 	UINT8 data = 0;
 
 	// write protect sense
-	data |= !floppy_wpt_r(m_image) << 4;
+	data |= !m_floppy->wpt_r() << 4;
 
 	// SYNC detect line
 	data |= m_ga->sync_r() << 7;
@@ -738,25 +683,6 @@ WRITE8_MEMBER( base_c1541_device::via1_pb_w )
 	m_ga->ds_w((data >> 5) & 0x03);
 }
 
-static const via6522_interface c1541_via1_intf =
-{
-	DEVCB_DEVICE_MEMBER(C64H156_TAG, c64h156_device, yb_r),
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via1_pb_r),
-	DEVCB_DEVICE_LINE_MEMBER(C64H156_TAG, c64h156_device, byte_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_MEMBER(C64H156_TAG, c64h156_device, yb_w),
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via1_pb_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DEVICE_LINE_MEMBER(C64H156_TAG, c64h156_device, soe_w),
-	DEVCB_DEVICE_LINE_MEMBER(C64H156_TAG, c64h156_device, oe_w),
-
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, via1_irq_w)
-};
-
 
 //-------------------------------------------------
 //  C64H156_INTERFACE( ga_intf )
@@ -774,46 +700,26 @@ WRITE_LINE_MEMBER( base_c1541_device::byte_w )
 	m_via1->write_ca1(state);
 }
 
-static C64H156_INTERFACE( ga_intf )
-{
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, atn_w),
-	DEVCB_NULL,
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, base_c1541_device, byte_w)
-};
+
+//-------------------------------------------------
+//  SLOT_INTERFACE( c1540_floppies )
+//-------------------------------------------------
+
+static SLOT_INTERFACE_START( c1540_floppies )
+	SLOT_INTERFACE( "525ssqd", ALPS_3255190x )
+SLOT_INTERFACE_END
 
 
 //-------------------------------------------------
-//  LEGACY_FLOPPY_OPTIONS( c1541 )
+//  FLOPPY_FORMATS( floppy_formats )
 //-------------------------------------------------
 
-static LEGACY_FLOPPY_OPTIONS_START( c1541 )
-	LEGACY_FLOPPY_OPTION( c1541, "g64", "Commodore 1541 GCR Disk Image", g64_dsk_identify, g64_dsk_construct, NULL, NULL )
-	LEGACY_FLOPPY_OPTION( c1541, "d64", "Commodore 1541 Disk Image", d64_dsk_identify, d64_dsk_construct, NULL, NULL )
-LEGACY_FLOPPY_OPTIONS_END
+FLOPPY_FORMATS_MEMBER( base_c1541_device::floppy_formats )
+	FLOPPY_D64_FORMAT,
+	FLOPPY_G64_FORMAT
+FLOPPY_FORMATS_END
 
 
-//-------------------------------------------------
-//  floppy_interface c1541_floppy_interface
-//-------------------------------------------------
-
-static const floppy_interface c1541_floppy_interface =
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	FLOPPY_STANDARD_5_25_SSDD,
-	LEGACY_FLOPPY_OPTIONS_NAME(c1541),
-	"floppy_5_25",
-	NULL
-};
-
-
-//-------------------------------------------------
-//  pia6821_interface pia0_intf
-//-------------------------------------------------
-
 READ8_MEMBER( c1541_prologic_dos_classic_device::pia_r )
 {
 	return m_pia->read(space, (offset >> 2) & 0x03);
@@ -851,26 +757,9 @@ WRITE8_MEMBER( c1541_prologic_dos_classic_device::pia_pb_w )
 {
 	m_parallel_data = data;
 
-	m_centronics->write(space, 0, data);
+	m_cent_data_out->write(space, 0, data);
 }
 
-static const pia6821_interface pia_intf =
-{
-	DEVCB_NULL,
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, c1541_prologic_dos_classic_device, pia_pb_r),
-	DEVCB_DEVICE_LINE_MEMBER(CENTRONICS_TAG, centronics_device, ack_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, c1541_prologic_dos_classic_device, pia_pa_w),
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, c1541_prologic_dos_classic_device, pia_pb_w),
-	DEVCB_DEVICE_LINE_MEMBER(CENTRONICS_TAG, centronics_device, strobe_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
 
 //-------------------------------------------------
 //  MACHINE_DRIVER( c1541 )
@@ -881,11 +770,27 @@ static MACHINE_CONFIG_FRAGMENT( c1541 )
 	MCFG_CPU_PROGRAM_MAP(c1541_mem)
 	MCFG_QUANTUM_PERFECT_CPU(M6502_TAG)
 
-	MCFG_VIA6522_ADD(M6522_0_TAG, XTAL_16MHz/16, c1541_via0_intf)
-	MCFG_VIA6522_ADD(M6522_1_TAG, XTAL_16MHz/16, c1541_via1_intf)
+	MCFG_DEVICE_ADD(M6522_0_TAG, VIA6522, XTAL_16MHz/16)
+	MCFG_VIA6522_READPA_HANDLER(READ8(base_c1541_device, via0_pa_r))
+	MCFG_VIA6522_READPB_HANDLER(READ8(base_c1541_device, via0_pb_r))
+	MCFG_VIA6522_WRITEPA_HANDLER(WRITE8(base_c1541_device, via0_pa_w))
+	MCFG_VIA6522_WRITEPB_HANDLER(WRITE8(base_c1541_device, via0_pb_w))
+	MCFG_VIA6522_CB2_HANDLER(WRITELINE(base_c1541_device, via0_ca2_w))
+	MCFG_VIA6522_IRQ_HANDLER(WRITELINE(base_c1541_device, via0_irq_w))
 
-	MCFG_LEGACY_FLOPPY_DRIVE_ADD(FLOPPY_0, c1541_floppy_interface)
-	MCFG_64H156_ADD(C64H156_TAG, XTAL_16MHz, ga_intf)
+	MCFG_DEVICE_ADD(M6522_1_TAG, VIA6522, XTAL_16MHz/16)
+	MCFG_VIA6522_READPA_HANDLER(DEVREAD8(C64H156_TAG, c64h156_device, yb_r))
+	MCFG_VIA6522_READPB_HANDLER(READ8(base_c1541_device, via1_pb_r))
+	MCFG_VIA6522_WRITEPA_HANDLER(DEVWRITE8(C64H156_TAG, c64h156_device, yb_w))
+	MCFG_VIA6522_WRITEPB_HANDLER(WRITE8(base_c1541_device, via1_pb_w))
+	MCFG_VIA6522_CA2_HANDLER(DEVWRITELINE(C64H156_TAG, c64h156_device, soe_w))
+	MCFG_VIA6522_CB2_HANDLER(DEVWRITELINE(C64H156_TAG, c64h156_device, oe_w))
+	MCFG_VIA6522_IRQ_HANDLER(WRITELINE(base_c1541_device, via1_irq_w))
+
+	MCFG_DEVICE_ADD(C64H156_TAG, C64H156, XTAL_16MHz)
+	MCFG_64H156_ATN_CALLBACK(WRITELINE(base_c1541_device, atn_w))
+	MCFG_64H156_BYTE_CALLBACK(WRITELINE(base_c1541_device, byte_w))
+	MCFG_FLOPPY_DRIVE_ADD(C64H156_TAG":0", c1540_floppies, "525ssqd", base_c1541_device::floppy_formats)
 MACHINE_CONFIG_END
 
 
@@ -906,9 +811,6 @@ machine_config_constructor base_c1541_device::device_mconfig_additions() const
 
 static MACHINE_CONFIG_FRAGMENT( c1541c )
 	MCFG_FRAGMENT_ADD(c1541)
-
-	MCFG_DEVICE_MODIFY(M6522_0_TAG)
-	MCFG_DEVICE_CONFIG(c1541c_via0_intf)
 MACHINE_CONFIG_END
 
 
@@ -979,8 +881,15 @@ static MACHINE_CONFIG_FRAGMENT( c1541pdc )
 	MCFG_CPU_MODIFY(M6502_TAG)
 	MCFG_CPU_PROGRAM_MAP(c1541pdc_mem)
 
-	MCFG_PIA6821_ADD(MC6821_TAG, pia_intf)
-	MCFG_CENTRONICS_PRINTER_ADD(CENTRONICS_TAG, standard_centronics)
+	MCFG_DEVICE_ADD(MC6821_TAG, PIA6821, 0)
+	MCFG_PIA_READPB_HANDLER(READ8(c1541_prologic_dos_classic_device, pia_pb_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(c1541_prologic_dos_classic_device, pia_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(c1541_prologic_dos_classic_device, pia_pb_w))
+	MCFG_PIA_CA2_HANDLER(DEVWRITELINE(CENTRONICS_TAG, centronics_device, write_strobe))
+
+	MCFG_CENTRONICS_ADD(CENTRONICS_TAG, centronics_printers, "printer")
+	MCFG_CENTRONICS_ACK_HANDLER(DEVWRITELINE(MC6821_TAG, pia6821_device, ca1_w))
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", "centronics")
 MACHINE_CONFIG_END
 
 
@@ -1053,7 +962,7 @@ base_c1541_device:: base_c1541_device(const machine_config &mconfig, device_type
 		m_via0(*this, M6522_0_TAG),
 		m_via1(*this, M6522_1_TAG),
 		m_ga(*this, C64H156_TAG),
-		m_image(*this, FLOPPY_0),
+		m_floppy(*this, C64H156_TAG":0:525ssqd"),
 		m_address(*this, "ADDRESS"),
 		m_data_out(1),
 		m_via0_irq(CLEAR_LINE),
@@ -1141,7 +1050,7 @@ c1541_professional_dos_v1_device::c1541_professional_dos_v1_device(const machine
 c1541_prologic_dos_classic_device::c1541_prologic_dos_classic_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
 	: base_c1541_device(mconfig, C1541_PROLOGIC_DOS_CLASSIC, "C1541 ProLogic-DOS Classic", tag, owner, clock, "c1541pdc", __FILE__),
 		m_pia(*this, MC6821_TAG),
-		m_centronics(*this, CENTRONICS_TAG),
+		m_cent_data_out(*this, "cent_data_out"),
 		m_mmu_rom(*this, "mmu")
 {
 }
@@ -1154,7 +1063,7 @@ c1541_prologic_dos_classic_device::c1541_prologic_dos_classic_device(const machi
 void base_c1541_device::device_start()
 {
 	// install image callbacks
-	m_ga->set_floppy(m_image);
+	m_ga->set_floppy(m_floppy);
 
 	// register for state saving
 	save_item(NAME(m_data_out));
