@@ -55,9 +55,7 @@
 */
 
 #include "e01.h"
-#include "machine/scsibus.h"
-#include "machine/scsicb.h"
-#include "machine/scsihd.h"
+#include "bus/scsi/scsihd.h"
 
 
 
@@ -159,20 +157,6 @@ WRITE_LINE_MEMBER( e01_device::econet_data_w )
 	m_econet->data_w(this, state);
 }
 
-static const mc6854_interface adlc_intf =
-{
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, e01_device, adlc_irq_w),
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, e01_device, econet_data_w),
-	NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
-//-------------------------------------------------
-//  via6522_interface via_intf
-//-------------------------------------------------
-
 WRITE_LINE_MEMBER( e01_device::via_irq_w )
 {
 	m_via_irq = state;
@@ -185,42 +169,18 @@ WRITE_LINE_MEMBER( e01_device::clk_en_w )
 	m_clk_en = state;
 }
 
-static const via6522_interface via_intf =
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_MEMBER(CENTRONICS_TAG, centronics_device, write),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, e01_device, via_irq_w)
-};
-
-
-//-------------------------------------------------
-//  wd17xx_interface fdc_intf
-//-------------------------------------------------
-
 static SLOT_INTERFACE_START( e01_floppies )
 	SLOT_INTERFACE( "35dd", FLOPPY_35_DD ) // NEC FD1036 A
 SLOT_INTERFACE_END
 
-void e01_device::fdc_irq_w(bool state)
+WRITE_LINE_MEMBER( e01_device::fdc_irq_w )
 {
 	m_fdc_irq = state;
 
 	update_interrupts();
 }
 
-void e01_device::fdc_drq_w(bool state)
+WRITE_LINE_MEMBER( e01_device::fdc_drq_w )
 {
 	m_fdc_drq = state;
 
@@ -229,17 +189,21 @@ void e01_device::fdc_drq_w(bool state)
 
 WRITE_LINE_MEMBER( e01_device::scsi_bsy_w )
 {
+	m_scsi_ctrl_in->write_bit1(state);
+
 	if (state)
 	{
-		m_scsibus->scsi_sel_w(0);
+		m_scsibus->write_sel(0);
 	}
 }
 
 WRITE_LINE_MEMBER( e01_device::scsi_req_w )
 {
+	m_scsi_ctrl_in->write_bit5(state);
+
 	if (!state)
 	{
-		m_scsibus->scsi_ack_w(0);
+		m_scsibus->write_ack(0);
 	}
 
 	m_hdc_irq = !state;
@@ -247,18 +211,6 @@ WRITE_LINE_MEMBER( e01_device::scsi_req_w )
 }
 
 
-//-------------------------------------------------
-//  centronics_interface e01_centronics_intf
-//-------------------------------------------------
-
-static centronics_interface e01_centronics_intf =
-{
-	DEVCB_DEVICE_LINE_MEMBER(R6522_TAG, via6522_device, write_ca1),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
 //-------------------------------------------------
 //  ADDRESS_MAP( e01_mem )
 //-------------------------------------------------
@@ -275,7 +227,7 @@ static ADDRESS_MAP_START( e01_mem, AS_PROGRAM, 8, e01_device )
 	AM_RANGE(0xfc28, 0xfc28) AM_MIRROR(0x00c3) AM_READWRITE(network_irq_enable_r, network_irq_enable_w)
 	AM_RANGE(0xfc2c, 0xfc2c) AM_MIRROR(0x00c3) AM_READ_PORT("FLAP")
 	AM_RANGE(0xfc30, 0xfc30) AM_MIRROR(0x00c0) AM_READWRITE(hdc_data_r, hdc_data_w)
-	AM_RANGE(0xfc31, 0xfc31) AM_MIRROR(0x00c0) AM_READ(hdc_status_r)
+	AM_RANGE(0xfc31, 0xfc31) AM_MIRROR(0x00c0) AM_DEVREAD("scsi_ctrl_in", input_buffer_device, read)
 	AM_RANGE(0xfc32, 0xfc32) AM_MIRROR(0x00c0) AM_WRITE(hdc_select_w)
 	AM_RANGE(0xfc33, 0xfc33) AM_MIRROR(0x00c0) AM_WRITE(hdc_irq_enable_w)
 ADDRESS_MAP_END
@@ -294,18 +246,39 @@ static MACHINE_CONFIG_FRAGMENT( e01 )
 	MCFG_MC146818_IRQ_HANDLER(WRITELINE(e01_device, rtc_irq_w))
 
 	// devices
-	MCFG_VIA6522_ADD(R6522_TAG, XTAL_8MHz/4, via_intf)
-	MCFG_MC6854_ADD(MC6854_TAG, adlc_intf)
+	MCFG_DEVICE_ADD(R6522_TAG, VIA6522, XTAL_8MHz/4)
+	MCFG_VIA6522_WRITEPA_HANDLER(DEVWRITE8("cent_data_out", output_latch_device, write))
+	MCFG_VIA6522_IRQ_HANDLER(WRITELINE(e01_device, via_irq_w))
+
+	MCFG_DEVICE_ADD(MC6854_TAG, MC6854, 0)
+	MCFG_MC6854_OUT_IRQ_CB(WRITELINE(e01_device, adlc_irq_w))
+	MCFG_MC6854_OUT_TXD_CB(WRITELINE(e01_device, econet_data_w))
 	MCFG_WD2793x_ADD(WD2793_TAG, XTAL_8MHz/4)
+	MCFG_WD_FDC_INTRQ_CALLBACK(WRITELINE(e01_device, fdc_irq_w))
+	MCFG_WD_FDC_DRQ_CALLBACK(WRITELINE(e01_device, fdc_drq_w))
 	MCFG_FLOPPY_DRIVE_ADD(WD2793_TAG":0", e01_floppies, "35dd", floppy_image_device::default_floppy_formats)
 	MCFG_FLOPPY_DRIVE_ADD(WD2793_TAG":1", e01_floppies, "35dd", floppy_image_device::default_floppy_formats)
-	MCFG_CENTRONICS_PRINTER_ADD(CENTRONICS_TAG, e01_centronics_intf)
 
-	MCFG_SCSIBUS_ADD(SCSIBUS_TAG)
-	MCFG_SCSIDEV_ADD(SCSIBUS_TAG ":harddisk0", SCSIHD, SCSI_ID_0)
-	MCFG_SCSICB_ADD(SCSIBUS_TAG ":host")
-	MCFG_SCSICB_BSY_HANDLER(DEVWRITELINE(DEVICE_SELF_OWNER, e01_device, scsi_bsy_w))
-	MCFG_SCSICB_REQ_HANDLER(DEVWRITELINE(DEVICE_SELF_OWNER, e01_device, scsi_req_w))
+	MCFG_CENTRONICS_ADD(CENTRONICS_TAG, centronics_printers, "printer")
+	MCFG_CENTRONICS_ACK_HANDLER(DEVWRITELINE(R6522_TAG, via6522_device, write_ca1))
+
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", CENTRONICS_TAG)
+
+	MCFG_DEVICE_ADD(SCSIBUS_TAG, SCSI_PORT, 0)
+	MCFG_SCSI_DATA_INPUT_BUFFER("scsi_data_in")
+	MCFG_SCSI_MSG_HANDLER(DEVWRITELINE("scsi_ctrl_in", input_buffer_device, write_bit0))
+	MCFG_SCSI_BSY_HANDLER(WRITELINE(e01_device, scsi_bsy_w)) // bit1
+	// bit 2 0
+	// bit 3 0
+	// bit 4 NIRQ
+	MCFG_SCSI_REQ_HANDLER(WRITELINE(e01_device, scsi_req_w)) // bit5
+	MCFG_SCSI_IO_HANDLER(DEVWRITELINE("scsi_ctrl_in", input_buffer_device, write_bit6))
+	MCFG_SCSI_CD_HANDLER(DEVWRITELINE("scsi_ctrl_in", input_buffer_device, write_bit7))
+	MCFG_SCSIDEV_ADD(SCSIBUS_TAG ":" SCSI_PORT_DEVICE1, "harddisk", SCSIHD, SCSI_ID_0)
+
+	MCFG_SCSI_OUTPUT_LATCH_ADD("scsi_data_out", SCSIBUS_TAG)
+	MCFG_DEVICE_ADD("scsi_data_in", INPUT_BUFFER, 0)
+	MCFG_DEVICE_ADD("scsi_ctrl_in", INPUT_BUFFER, 0)
 
 	// internal ram
 	MCFG_RAM_ADD(RAM_TAG)
@@ -410,10 +383,14 @@ e01_device::e01_device(const machine_config &mconfig, const char *tag, device_t
 		m_adlc(*this, MC6854_TAG),
 		m_rtc(*this, HD146818_TAG),
 		m_ram(*this, RAM_TAG),
-		m_scsibus(*this, SCSIBUS_TAG ":host"),
+		m_scsibus(*this, SCSIBUS_TAG),
+		m_scsi_data_out(*this, "scsi_data_out"),
+		m_scsi_data_in(*this, "scsi_data_in"),
+		m_scsi_ctrl_in(*this, "scsi_ctrl_in"),
 		m_floppy0(*this, WD2793_TAG":0"),
 		m_floppy1(*this, WD2793_TAG":1"),
 		m_rom(*this, R65C102_TAG),
+		m_centronics(*this, CENTRONICS_TAG),
 		m_adlc_ie(0),
 		m_hdc_ie(0),
 		m_rtc_irq(CLEAR_LINE),
@@ -435,10 +412,14 @@ e01_device::e01_device(const machine_config &mconfig, device_type type, const ch
 		m_adlc(*this, MC6854_TAG),
 		m_rtc(*this, HD146818_TAG),
 		m_ram(*this, RAM_TAG),
-		m_scsibus(*this, SCSIBUS_TAG ":host"),
+		m_scsibus(*this, SCSIBUS_TAG),
+		m_scsi_data_out(*this, "scsi_data_out"),
+		m_scsi_data_in(*this, "scsi_data_in"),
+		m_scsi_ctrl_in(*this, "scsi_ctrl_in"),
 		m_floppy0(*this, WD2793_TAG":0"),
 		m_floppy1(*this, WD2793_TAG":1"),
 		m_rom(*this, R65C102_TAG),
+		m_centronics(*this, CENTRONICS_TAG),
 		m_adlc_ie(0),
 		m_hdc_ie(0),
 		m_rtc_irq(CLEAR_LINE),
@@ -457,10 +438,6 @@ e01_device::e01_device(const machine_config &mconfig, device_type type, const ch
 
 void e01_device::device_start()
 {
-	// floppy callbacks
-	m_fdc->setup_intrq_cb(wd2793_t::line_cb(FUNC(e01_device::fdc_irq_w), this));
-	m_fdc->setup_drq_cb(wd2793_t::line_cb(FUNC(e01_device::fdc_drq_w), this));
-
 	// allocate timers
 	m_clk_timer = timer_alloc();
 
@@ -641,9 +618,9 @@ WRITE8_MEMBER( e01_device::network_irq_enable_w )
 
 READ8_MEMBER( e01_device::hdc_data_r )
 {
-	UINT8 data = m_scsibus->scsi_data_r(space, 0);
+	UINT8 data = m_scsi_data_in->read();
 
-	m_scsibus->scsi_ack_w(1);
+	m_scsibus->write_ack(1);
 
 	return data;
 }
@@ -655,45 +632,9 @@ READ8_MEMBER( e01_device::hdc_data_r )
 
 WRITE8_MEMBER( e01_device::hdc_data_w )
 {
-	m_scsibus->scsi_data_w(space, 0, data);
+	m_scsi_data_out->write(data);
 
-	m_scsibus->scsi_ack_w(1);
-}
-
-
-//-------------------------------------------------
-//  hdc_status_r -
-//-------------------------------------------------
-
-READ8_MEMBER( e01_device::hdc_status_r )
-{
-	/*
-
-	    bit     description
-
-	    0       MSG
-	    1       BSY
-	    2       0
-	    3       0
-	    4       NIRQ
-	    5       REQ
-	    6       I/O
-	    7       C/D
-
-	*/
-
-	UINT8 data = 0;
-
-	// SCSI bus
-	data |= m_scsibus->scsi_msg_r();
-	data |= m_scsibus->scsi_bsy_r() << 1;
-	data |= m_scsibus->scsi_req_r() << 5;
-	data |= m_scsibus->scsi_io_r() << 6;
-	data |= m_scsibus->scsi_cd_r() << 7;
-
-	// TODO NIRQ
-
-	return data;
+	m_scsibus->write_ack(1);
 }
 
 
@@ -703,7 +644,7 @@ READ8_MEMBER( e01_device::hdc_status_r )
 
 WRITE8_MEMBER( e01_device::hdc_select_w )
 {
-	m_scsibus->scsi_sel_w(1);
+	m_scsibus->write_sel(1);
 }
 
 
