@@ -154,7 +154,10 @@ adsp21xx_device::adsp21xx_device(const machine_config &mconfig, device_type type
 		m_icount(0),
 		m_mstat_mask((m_chip_type >= CHIP_TYPE_ADSP2101) ? 0x7f : 0x0f),
 		m_imask_mask((m_chip_type >= CHIP_TYPE_ADSP2181) ? 0x3ff :
-					(m_chip_type >= CHIP_TYPE_ADSP2101) ? 0x3f : 0x0f)
+					(m_chip_type >= CHIP_TYPE_ADSP2101) ? 0x3f : 0x0f),
+		m_sport_rx_cb(*this),
+		m_sport_tx_cb(*this),
+		m_timer_fired_cb(*this)
 {
 	// initialize remaining state
 	memset(&m_core, 0, sizeof(m_core));
@@ -171,10 +174,6 @@ adsp21xx_device::adsp21xx_device(const machine_config &mconfig, device_type type
 	memset(&m_irq_state, 0, sizeof(m_irq_state));
 	memset(&m_irq_latch, 0, sizeof(m_irq_latch));
 
-	m_sport_rx_callback = NULL;
-	m_sport_tx_callback = NULL;
-	m_timer_fired = NULL;
-
 	// create the tables
 	create_tables();
 
@@ -295,18 +294,6 @@ adsp21xx_device::~adsp21xx_device()
 }
 
 
-//-------------------------------------------------
-//  static_set_config - set the configuration
-//  structure
-//-------------------------------------------------
-
-void adsp21xx_device::static_set_config(device_t &device, const adsp21xx_config &config)
-{
-	adsp21xx_device &adsp = downcast<adsp21xx_device &>(device);
-	static_cast<adsp21xx_config &>(adsp) = config;
-}
-
-
 //-------------------------------------------------
 //  load_boot_data - load the boot data from an
 //  8-bit ROM
@@ -415,6 +402,10 @@ UINT16 adsp2181_device::idma_data_r()
 
 void adsp21xx_device::device_start()
 {
+	m_sport_rx_cb.resolve();
+	m_sport_tx_cb.resolve();
+	m_timer_fired_cb.resolve();
+
 	// get our address spaces
 	m_program = &space(AS_PROGRAM);
 	m_direct = &m_program->direct();
@@ -829,7 +820,7 @@ inline UINT32 adsp21xx_device::opcode_read()
     IMPORT CORE UTILITIES
 ***************************************************************************/
 
-#include "2100ops.c"
+#include "2100ops.inc"
 
 
 
