@@ -230,7 +230,9 @@ arm_cpu_device::arm_cpu_device(const machine_config &mconfig, const char *tag, d
 	: cpu_device(mconfig, ARM, "ARM", tag, owner, clock, "arm", __FILE__)
 	, m_program_config("program", ENDIANNESS_LITTLE, 32, 26, 0)
 	, m_endian(ENDIANNESS_LITTLE)
+	, m_copro_type(ARM_COPRO_TYPE_UNKNOWN_CP15)
 {
+	memset(m_sArmRegister, 0x00, sizeof(m_sArmRegister));
 }
 
 
@@ -238,7 +240,9 @@ arm_cpu_device::arm_cpu_device(const machine_config &mconfig, device_type type,
 	: cpu_device(mconfig, type, name, tag, owner, clock, shortname, source)
 	, m_program_config("program", endianness, 32, 26, 0)
 	, m_endian(endianness)
+	, m_copro_type(ARM_COPRO_TYPE_UNKNOWN_CP15)
 {
+	memset(m_sArmRegister, 0x00, sizeof(m_sArmRegister));
 }
 
 
@@ -248,6 +252,7 @@ arm_be_cpu_device::arm_be_cpu_device(const machine_config &mconfig, const char *
 }
 
 
+
 void arm_cpu_device::cpu_write32( int addr, UINT32 data )
 {
 	/* Unaligned writes are treated as normal writes */
@@ -413,7 +418,11 @@ void arm_cpu_device::execute_run()
 		}
 		else if ((insn & 0x0f000000u) == 0x0e000000u)   /* Coprocessor */
 		{
-			HandleCoPro(insn);
+			if (m_copro_type == ARM_COPRO_TYPE_VL86C020)
+				HandleCoProVL86C020(insn);
+			else
+				HandleCoPro(insn);
+
 			R15 += 4;
 		}
 		else if ((insn & 0x0f000000u) == 0x0f000000u)   /* Software interrupt */
@@ -1363,6 +1372,45 @@ UINT32 arm_cpu_device::DecimalToBCD(UINT32 value)
 	return accumulator;
 }
 
+void arm_cpu_device::HandleCoProVL86C020( UINT32 insn )
+{
+	UINT32 rn=(insn>>12)&0xf;
+	UINT32 crn=(insn>>16)&0xf;
+
+	m_icount -= S_CYCLE;
+
+	/* MRC - transfer copro register to main register */
+	if( (insn&0x0f100010)==0x0e100010 )
+	{
+		if(crn == 0) // ID, read only
+		{
+			/*
+			0x41<<24 <- Designer code, Acorn Computer Ltd.
+			0x56<<16 <- Manufacturer code, VLSI Technology Inc.
+			0x03<<8 <- Part type, VLC86C020
+			0x00<<0 <- Revision number, 0
+			*/
+			SetRegister(rn, 0x41560300);
+			//debugger_break(machine());
+		}
+		else
+			SetRegister(rn, m_coproRegister[crn]);
+
+	}
+	/* MCR - transfer main register to copro register */
+	else if( (insn&0x0f100010)==0x0e000010 )
+	{
+		if(crn != 0)
+			m_coproRegister[crn]=GetRegister(rn);
+
+		//printf("%08x:  VL86C020 copro instruction write %08x %d %d\n", R15 & 0x3ffffff, insn,rn,crn);
+	}
+	else
+	{
+		printf("%08x:  Unimplemented VL86C020 copro instruction %08x %d %d\n", R15 & 0x3ffffff, insn,rn,crn);
+		debugger_break(machine());
+	}
+}
 
 void arm_cpu_device::HandleCoPro( UINT32 insn )
 {
