@@ -31,7 +31,7 @@
        It can be used as is, or used to demonstrate how to utilize the arm7 core to create a cpu
        that uses the core, since there are numerous different mcu packages that incorporate an arm7 core.
 
-       See the notes in the arm7core.c file itself regarding issues/limitations of the arm7 core.
+       See the notes in the arm7core.inc file itself regarding issues/limitations of the arm7 core.
     **
 
 TODO:
@@ -71,7 +71,9 @@ arm7_cpu_device::arm7_cpu_device(const machine_config &mconfig, const char *tag,
 	, m_archRev(4)  // ARMv4
 	, m_archFlags(eARM_ARCHFLAGS_T)  // has Thumb
 	, m_copro_id(0x41 | (1 << 23) | (7 << 12))  // <-- where did this come from?
+	, m_pc(0)
 {
+	memset(m_r, 0x00, sizeof(m_r));
 }
 
 
@@ -82,7 +84,9 @@ arm7_cpu_device::arm7_cpu_device(const machine_config &mconfig, device_type type
 	, m_archRev(archRev)
 	, m_archFlags(archFlags)
 	, m_copro_id(0x41 | (1 << 23) | (7 << 12))  // <-- where did this come from?
+	, m_pc(0)
 {
+	memset(m_r, 0x00, sizeof(m_r));
 }
 
 
@@ -493,7 +497,7 @@ bool arm7_cpu_device::memory_translate(address_spacenum spacenum, int intention,
 
 
 /* include the arm7 core */
-#include "arm7core.c"
+#include "arm7core.inc"
 
 /***************************************************************************
  * CPU SPECIFIC IMPLEMENTATIONS
@@ -514,7 +518,8 @@ void arm7_cpu_device::device_start()
 
 	m_icountptr = &m_icount;
 
-	state_add(STATE_GENPC, "curpc", m_pc).callexport().formatstr("%08X");
+	state_add( ARM7_PC,    "PC", m_pc).callexport().formatstr("%08X");
+	state_add(STATE_GENPC, "GENPC", m_pc).callexport().noshow();
 	/* registers shared by all operating modes */
 	state_add( ARM7_R0,    "R0",   m_r[ 0]).formatstr("%08X");
 	state_add( ARM7_R1,    "R1",   m_r[ 1]).formatstr("%08X");
@@ -1221,4 +1226,4 @@ UINT8 arm7_cpu_device::arm7_cpu_read8(UINT32 addr)
 	return m_program->read_byte(addr);
 }
 
-#include "arm7drc.c"
+#include "arm7drc.inc"
