@@ -24,7 +24,7 @@
 
     In addition, there are several optimizations enabled which make
     assumptions about the code which may not be valid for other
-    applications. Check dsp32ops.c for details.
+    applications. Check dsp32ops.inc for details.
 
 ***************************************************************************/
 
@@ -174,33 +174,21 @@ dsp32c_device::dsp32c_device(const machine_config &mconfig, const char *tag, dev
 		m_lastpins(0),
 		m_ppc(0),
 		m_program(NULL),
-		m_direct(NULL)
+		m_direct(NULL),
+		m_output_pins_changed(*this)
 {
-	m_output_pins_changed = NULL;
-
 	// set our instruction counter
 	m_icountptr = &m_icount;
 }
 
-
-//-------------------------------------------------
-//  static_set_config - set the configuration
-//  structure
-//-------------------------------------------------
-
-void dsp32c_device::static_set_config(device_t &device, const dsp32_config &config)
-{
-	dsp32c_device &dsp = downcast<dsp32c_device &>(device);
-	static_cast<dsp32_config &>(dsp) = config;
-}
-
-
 //-------------------------------------------------
 //  device_start - start up the device
 //-------------------------------------------------
 
 void dsp32c_device::device_start()
 {
+	m_output_pins_changed.resolve_safe();
+
 	// get our address spaces
 	m_program = &space(AS_PROGRAM);
 	m_direct = &m_program->direct();
@@ -297,8 +285,7 @@ void dsp32c_device::device_reset()
 	m_emr = 0xffff;
 
 	// clear the output pins
-	if (m_output_pins_changed != NULL)
-		(*m_output_pins_changed)(*this, 0);
+	m_output_pins_changed(0);
 
 	// initialize fixed registers
 	R0 = R0_ALT = 0;
@@ -540,21 +527,18 @@ void dsp32c_device::update_pins(void)
 {
 	if (m_pcr & PCR_ENI)
 	{
-		if (m_output_pins_changed != NULL)
+		UINT16 newoutput = 0;
+
+		if (m_pcr & PCR_PIFs)
+			newoutput |= DSP32_OUTPUT_PIF;
+
+		if (m_pcr & PCR_PDFs)
+			newoutput |= DSP32_OUTPUT_PDF;
+
+		if (newoutput != m_lastpins)
 		{
-			UINT16 newoutput = 0;
-
-			if (m_pcr & PCR_PIFs)
-				newoutput |= DSP32_OUTPUT_PIF;
-
-			if (m_pcr & PCR_PDFs)
-				newoutput |= DSP32_OUTPUT_PDF;
-
-			if (newoutput != m_lastpins)
-			{
-				m_lastpins = newoutput;
-				(*m_output_pins_changed)(*this, newoutput);
-			}
+			m_lastpins = newoutput;
+			m_output_pins_changed(newoutput);
 		}
 	}
 }
@@ -565,7 +549,7 @@ void dsp32c_device::update_pins(void)
 //  CORE INCLUDE
 //**************************************************************************
 
-#include "dsp32ops.c"
+#include "dsp32ops.inc"
 
 
 
