@@ -55,6 +55,7 @@
 #include "debugger.h"
 #include "m37710.h"
 #include "m37710cm.h"
+#include "m37710il.h"
 
 #define M37710_DEBUG    (0) // enables verbose logging for peripherals, etc.
 
@@ -704,30 +705,6 @@ const m37710_cpu_device::execute_func m37710_cpu_device::m37710i_execute[4] =
 
 /* internal functions */
 
-void m37710_cpu_device::m37710i_push_8(UINT32 value)
-{
-	m37710_write_8(REG_S, value);
-	REG_S = MAKE_UINT_16(REG_S-1);
-}
-
-void m37710_cpu_device::m37710i_push_16(UINT32 value)
-{
-	m37710i_push_8(value>>8);
-	m37710i_push_8(value&0xff);
-}
-
-UINT32 m37710_cpu_device::m37710i_get_reg_p()
-{
-	return  (FLAG_N&0x80)       |
-			((FLAG_V>>1)&0x40)  |
-			FLAG_M              |
-			FLAG_X              |
-			FLAG_D              |
-			FLAG_I              |
-			((!FLAG_Z)<<1)      |
-			((FLAG_C>>8)&1);
-}
-
 void m37710_cpu_device::m37710i_update_irqs()
 {
 	int curirq, pending = LINE_IRQ;
@@ -775,7 +752,7 @@ void m37710_cpu_device::m37710i_update_irqs()
 		// let's do it...
 		// push PB, then PC, then status
 		CLK(13);
-//      mame_printf_debug("taking IRQ %d: PC = %06x, SP = %04x, IPL %d\n", wantedIRQ, REG_PB | REG_PC, REG_S, m_ipl);
+//      osd_printf_debug("taking IRQ %d: PC = %06x, SP = %04x, IPL %d\n", wantedIRQ, REG_PB | REG_PC, REG_S, m_ipl);
 		m37710i_push_8(REG_PB>>16);
 		m37710i_push_16(REG_PC);
 		m37710i_push_8(m_ipl);
@@ -786,10 +763,8 @@ void m37710_cpu_device::m37710i_update_irqs()
 		m_ipl = curpri;
 		// then PB=0, PC=(vector)
 		REG_PB = 0;
-		REG_PC = m37710_read_8(m37710_irq_vectors[wantedIRQ]) |
-				m37710_read_8(m37710_irq_vectors[wantedIRQ]+1)<<8;
+		REG_PC = m37710_read_16(m37710_irq_vectors[wantedIRQ]);
 //      logerror("IRQ @ %06x\n", REG_PB | REG_PC);
-		m37710i_jumping(REG_PB | REG_PC);
 	}
 }
 
@@ -876,8 +851,7 @@ void m37710_cpu_device::device_reset()
 	m37710i_set_execution_mode(EXECUTION_MODE_M0X0);
 
 	/* Fetch the reset vector */
-	REG_PC = m37710_read_8(0xfffe) | (m37710_read_8(0xffff)<<8);
-	m37710i_jumping(REG_PB | REG_PC);
+	REG_PC = m37710_read_16(0xfffe);
 }
 
 /* Execute some instructions */
@@ -894,7 +868,6 @@ void m37710_cpu_device::execute_run()
 void m37710_cpu_device::m37710_set_pc(unsigned val)
 {
 	REG_PC = MAKE_UINT_16(val);
-	m37710_jumping(REG_PB | REG_PC);
 }
 
 /* Get the current Stack Pointer */
@@ -947,9 +920,6 @@ void m37710_cpu_device::m37710_restore_state()
 {
 	// restore proper function pointers
 	m37710i_set_execution_mode((FLAG_M>>4) | (FLAG_X>>4));
-
-	// make sure the memory system can keep up
-	m37710i_jumping(REG_PB | REG_PC);
 }
 
 void m37710_cpu_device::device_start()
@@ -990,6 +960,7 @@ void m37710_cpu_device::device_start()
 	memset(m_m37710_regs, 0, sizeof(m_m37710_regs));
 
 	m_program = &space(AS_PROGRAM);
+	m_direct = &m_program->direct();
 	m_io = &space(AS_IO);
 
 	m_ICount = 0;
@@ -1188,196 +1159,6 @@ void m37710_cpu_device::m37710i_set_execution_mode(UINT32 mode)
 }
 
 
-/* ======================================================================== */
-/* ================================= MEMORY =============================== */
-/* ======================================================================== */
-
-#define ADDRESS_37710(A) ((A)&0xffffff)
-
-UINT32 m37710_cpu_device::m37710i_read_8_normal(UINT32 address)
-{
-	address = ADDRESS_37710(address);
-	return m37710_read_8(address);
-}
-
-UINT32 m37710_cpu_device::m37710i_read_8_immediate(UINT32 address)
-{
-	address = ADDRESS_37710(address);
-	return m37710_read_8_immediate(address);
-}
-
-UINT32 m37710_cpu_device::m37710i_read_8_direct(UINT32 address)
-{
-	address = ADDRESS_37710(address);
-	return m37710_read_8(address);
-}
-
-void m37710_cpu_device::m37710i_write_8_normal(UINT32 address, UINT32 value)
-{
-	address = ADDRESS_37710(address);
-	m37710_write_8(address, MAKE_UINT_8(value));
-}
-
-void m37710_cpu_device::m37710i_write_8_direct(UINT32 address, UINT32 value)
-{
-	address = ADDRESS_37710(address);
-	m37710_write_8(address, MAKE_UINT_8(value));
-}
-
-UINT32 m37710_cpu_device::m37710i_read_16_normal(UINT32 address)
-{
-	address = ADDRESS_37710(address);
-	if (address & 1)
-		return m37710i_read_8_normal(address) | m37710i_read_8_normal(address+1)<<8;
-	else
-		return m37710_read_16(address);
-}
-
-UINT32 m37710_cpu_device::m37710i_read_16_immediate(UINT32 address)
-{
-	address = ADDRESS_37710(address);
-	if (address & 1)
-		return m37710_read_8_immediate(address) | m37710_read_8_immediate(address+1)<<8;
-	else
-		return m37710_read_16(address);
-}
-
-UINT32 m37710_cpu_device::m37710i_read_16_direct(UINT32 address)
-{
-	address = ADDRESS_37710(address);
-	if (address & 1)
-		return m37710_read_8(address) | m37710_read_8((address)+1)<<8;
-	else
-		return m37710_read_16(address);
-}
-
-void m37710_cpu_device::m37710i_write_16_normal(UINT32 address, UINT32 value)
-{
-	address = ADDRESS_37710(address);
-	if (address & 1)
-	{
-		m37710_write_8(address, value);
-		m37710_write_8(address+1, value>>8);
-	}
-	else
-		m37710_write_16(address, value);
-}
-
-void m37710_cpu_device::m37710i_write_16_direct(UINT32 address, UINT32 value)
-{
-	address = ADDRESS_37710(address);
-	if (address & 1)
-	{
-		m37710_write_8(address, value);
-		m37710_write_8(address+1, value>>8);
-	}
-	else
-		m37710_write_16(address, value);
-}
-
-UINT32 m37710_cpu_device::m37710i_read_24_normal(UINT32 address)
-{
-	return   m37710i_read_16_normal(address)       |
-			(m37710i_read_8_normal(address+2)<<16);
-}
-
-UINT32 m37710_cpu_device::m37710i_read_24_immediate(UINT32 address)
-{
-	return   m37710i_read_16_immediate(address)       |
-			(m37710i_read_8_immediate(address+2)<<16);
-}
-
-UINT32 m37710_cpu_device::m37710i_read_24_direct(UINT32 address)
-{
-	return   m37710i_read_16_direct(address)         |
-			(m37710i_read_8_direct(address+2)<<16);
-}
-
-
-
-/* ======================================================================== */
-/* ================================= STACK ================================ */
-/* ======================================================================== */
-
-UINT32 m37710_cpu_device::m37710i_pull_8()
-{
-	REG_S = MAKE_UINT_16(REG_S+1);
-	return m37710i_read_8_normal(REG_S);
-}
-
-UINT32 m37710_cpu_device::m37710i_pull_16()
-{
-	UINT32 res = m37710i_pull_8();
-	return res | (m37710i_pull_8() << 8);
-}
-
-void m37710_cpu_device::m37710i_push_24(UINT32 value)
-{
-	m37710i_push_8(value>>16);
-	m37710i_push_8((value>>8)&0xff);
-	m37710i_push_8(value&0xff);
-}
-
-UINT32 m37710_cpu_device::m37710i_pull_24()
-{
-	UINT32 res = m37710i_pull_8();
-	res |= m37710i_pull_8() << 8;
-	return res | (m37710i_pull_8() << 16);
-}
-
-
-/* ======================================================================== */
-/* ============================ PROGRAM COUNTER =========================== */
-/* ======================================================================== */
-
-void m37710_cpu_device::m37710i_jump_16(UINT32 address)
-{
-	REG_PC = MAKE_UINT_16(address);
-	m37710i_jumping(REG_PC);
-}
-
-void m37710_cpu_device::m37710i_jump_24(UINT32 address)
-{
-	REG_PB = address&0xff0000;
-	REG_PC = MAKE_UINT_16(address);
-	m37710i_jumping(REG_PC);
-}
-
-void m37710_cpu_device::m37710i_branch_8(UINT32 offset)
-{
-	REG_PC = MAKE_UINT_16(REG_PC + MAKE_INT_8(offset));
-	m37710i_branching(REG_PC);
-}
-
-void m37710_cpu_device::m37710i_branch_16(UINT32 offset)
-{
-	REG_PC = MAKE_UINT_16(REG_PC + offset);
-	m37710i_branching(REG_PC);
-}
-
-
-/* ======================================================================== */
-/* ============================ STATUS REGISTER =========================== */
-/* ======================================================================== */
-
-void m37710_cpu_device::m37710i_set_flag_i(UINT32 value)
-{
-	value &= FLAGPOS_I;
-	if(!FLAG_I || value)
-	{
-		FLAG_I = value;
-		return;
-	}
-	FLAG_I = value;
-}
-
-
-void m37710_cpu_device::m37710i_set_reg_ipl(UINT32 value)
-{
-	m_ipl = value & 7;
-}
-
-
 /* ======================================================================== */
 /* =============================== INTERRUPTS ============================= */
 /* ======================================================================== */
@@ -1389,33 +1170,12 @@ void m37710_cpu_device::m37710i_interrupt_software(UINT32 vector)
 	m37710i_push_16(REG_PC);
 	m37710i_push_8(m_ipl);
 	m37710i_push_8(m37710i_get_reg_p());
-	m37710i_set_flag_i(IFLAG_SET);
+	FLAG_I = IFLAG_SET;
 	REG_PB = 0;
-	m37710i_jump_16(m37710i_read_16_normal(vector));
+	REG_PC = m37710_read_16(vector);
 }
 
 
-UINT32 m37710_cpu_device::EA_IMM8()  {REG_PC += 1; return REG_PB | MAKE_UINT_16(REG_PC-1);}
-UINT32 m37710_cpu_device::EA_IMM16() {REG_PC += 2; return REG_PB | MAKE_UINT_16(REG_PC-2);}
-UINT32 m37710_cpu_device::EA_IMM24() {REG_PC += 3; return REG_PB | MAKE_UINT_16(REG_PC-3);}
-UINT32 m37710_cpu_device::EA_D()     {if(MAKE_UINT_8(REG_D)) CLK(1); return MAKE_UINT_16(REG_D + OPER_8_IMM());}
-UINT32 m37710_cpu_device::EA_A()     {return REG_DB | OPER_16_IMM();}
-UINT32 m37710_cpu_device::EA_AL()    {return OPER_24_IMM();}
-UINT32 m37710_cpu_device::EA_DX()    {return MAKE_UINT_16(REG_D + OPER_8_IMM() + REG_X);}
-UINT32 m37710_cpu_device::EA_DY()    {return MAKE_UINT_16(REG_D + OPER_8_IMM() + REG_Y);}
-UINT32 m37710_cpu_device::EA_AX()    {UINT32 tmp = EA_A(); if((tmp^(tmp+REG_X))&0xff00) CLK(1); return tmp + REG_X;}
-UINT32 m37710_cpu_device::EA_ALX()   {return EA_AL() + REG_X;}
-UINT32 m37710_cpu_device::EA_AY()    {UINT32 tmp = EA_A(); if((tmp^(tmp+REG_X))&0xff00) CLK(1); return tmp + REG_Y;}
-UINT32 m37710_cpu_device::EA_DI()    {return REG_DB | OPER_16_D();}
-UINT32 m37710_cpu_device::EA_DLI()   {return OPER_24_D();}
-UINT32 m37710_cpu_device::EA_AI()    {return read_16_A(OPER_16_IMM());}
-UINT32 m37710_cpu_device::EA_ALI()   {return OPER_24_A();}
-UINT32 m37710_cpu_device::EA_DXI()   {return REG_DB | OPER_16_DX();}
-UINT32 m37710_cpu_device::EA_DIY()   {UINT32 tmp = REG_DB | OPER_16_D(); if((tmp^(tmp+REG_X))&0xff00) CLK(1); return tmp + REG_Y;}
-UINT32 m37710_cpu_device::EA_DLIY()  {return OPER_24_D() + REG_Y;}
-UINT32 m37710_cpu_device::EA_AXI()   {return read_16_AXI(MAKE_UINT_16(OPER_16_IMM() + REG_X));}
-UINT32 m37710_cpu_device::EA_S()     {return MAKE_UINT_16(REG_S + OPER_8_IMM());}
-UINT32 m37710_cpu_device::EA_SIY()   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()) + REG_Y) | REG_DB;}
 
 /* ======================================================================== */
 /* ============================== END OF FILE ============================= */
