@@ -16,13 +16,13 @@ CPU_DISASSEMBLE( rsp );
 #define SAVE_DMEM                       0
 #define RSP_TEST_SYNC                   0
 
-#define PRINT_VECREG(x)     mame_printf_debug("V%d: %04X|%04X|%04X|%04X|%04X|%04X|%04X|%04X\n", (x), \
+#define PRINT_VECREG(x)     osd_printf_debug("V%d: %04X|%04X|%04X|%04X|%04X|%04X|%04X|%04X\n", (x), \
 							(UINT16)VREG_S((x),0), (UINT16)VREG_S((x),1), \
 							(UINT16)VREG_S((x),2), (UINT16)VREG_S((x),3), \
 							(UINT16)VREG_S((x),4), (UINT16)VREG_S((x),5), \
 							(UINT16)VREG_S((x),6), (UINT16)VREG_S((x),7))
 
-#define PRINT_ACCUM(x)     mame_printf_debug("A%d: %08X|%08X\n", (x), \
+#define PRINT_ACCUM(x)     osd_printf_debug("A%d: %08X|%08X\n", (x), \
 							(UINT32)( ( ACCUM(x) >> 32 ) & 0x00000000ffffffff ),    \
 							(UINT32)(   ACCUM(x)         & 0x00000000ffffffff ))
 
@@ -103,7 +103,7 @@ INLINE UINT8 READ8(rsp_state *rsp, UINT32 address)
 	UINT8 ret;
 	address = 0x04000000 | (address & 0xfff);
 	ret = rsp->program->read_byte(address);
-	printf("%04xr%02x\n", address & 0x0000ffff, ret);
+	//printf("%04xr%02x\n", address & 0x0000ffff, ret);
 	return ret;
 }
 
@@ -121,7 +121,7 @@ INLINE UINT16 READ16(rsp_state *rsp, UINT32 address)
 		ret = rsp->program->read_word(address);
 	}
 
-	printf("%04xr%04x\n", address & 0x0000ffff, ret);
+	//printf("%04xr%04x\n", address & 0x0000ffff, ret);
 
 	return ret;
 }
@@ -143,21 +143,21 @@ INLINE UINT32 READ32(rsp_state *rsp, UINT32 address)
 		ret = rsp->program->read_dword(address);
 	}
 
-	printf("%04xr%08x\n", address & 0x0000ffff, ret);
+	//printf("%04xr%08x\n", address & 0x0000ffff, ret);
 	return ret;
 }
 
 INLINE void WRITE8(rsp_state *rsp, UINT32 address, UINT8 data)
 {
 	address = 0x04000000 | (address & 0xfff);
-	printf("%04x:%02x\n", address & 0x0000ffff, data);
+	//printf("%04x:%02x\n", address & 0x0000ffff, data);
 	rsp->program->write_byte(address, data);
 }
 
 INLINE void WRITE16(rsp_state *rsp, UINT32 address, UINT16 data)
 {
 	address = 0x04000000 | (address & 0xfff);
-	printf("%04x:%04x\n", address & 0x0000ffff, data);
+	//printf("%04x:%04x\n", address & 0x0000ffff, data);
 
 	if(address & 1)
 	{
@@ -172,7 +172,7 @@ INLINE void WRITE16(rsp_state *rsp, UINT32 address, UINT16 data)
 INLINE void WRITE32(rsp_state *rsp, UINT32 address, UINT32 data)
 {
 	address = 0x04000000 | (address & 0xfff);
-	printf("%04x:%08x\n", address & 0x0000ffff, data);
+	//printf("%04x:%08x\n", address & 0x0000ffff, data);
 
 	if(address & 3)
 	{
@@ -193,11 +193,11 @@ static UINT32 get_cop0_reg(rsp_state *rsp, int reg)
 	reg &= 0xf;
 	if (reg < 8)
 	{
-		return (rsp->sp_reg_r_func)(reg, 0x00000000);
+		return (rsp->device->sp_reg_r_func)(reg, 0xffffffff);
 	}
 	else if (reg >= 8 && reg < 16)
 	{
-		return (rsp->dp_reg_r_func)(reg - 8, 0x00000000);
+		return (rsp->device->dp_reg_r_func)(reg - 8, 0xffffffff);
 	}
 
 	return 0;
@@ -208,11 +208,11 @@ static void set_cop0_reg(rsp_state *rsp, int reg, UINT32 data)
 	reg &= 0xf;
 	if (reg < 8)
 	{
-		(rsp->sp_reg_w_func)(reg, data, 0x00000000);
+		(rsp->device->sp_reg_w_func)(reg, data, 0xffffffff);
 	}
 	else if (reg >= 8 && reg < 16)
 	{
-		(rsp->dp_reg_w_func)(reg - 8, data, 0x00000000);
+		(rsp->device->dp_reg_w_func)(reg - 8, data, 0xffffffff);
 	}
 }
 
@@ -222,7 +222,7 @@ static void unimplemented_opcode(rsp_state *rsp, UINT32 op)
 	{
 		char string[200];
 		rsp_dasm_one(string, rsp->ppc, op);
-		mame_printf_debug("%08X: %s\n", rsp->ppc, string);
+		osd_printf_debug("%08X: %s\n", rsp->ppc, string);
 	}
 
 #if SAVE_DISASM
@@ -280,26 +280,29 @@ static const int vector_elements[16][8] =
 	{ 7, 7, 7, 7, 7, 7, 7, 7 },     // 7
 };
 
+void rsp_cpu_device::resolve_cb()
+{
+	dp_reg_r_func.resolve();
+	dp_reg_w_func.resolve();
+	sp_reg_r_func.resolve();
+	sp_reg_w_func.resolve();
+	sp_set_status_func.resolve();
+}
+
 static CPU_INIT( rsp )
 {
 	rsp_state *rsp = get_safe_token(device);
 	int regIdx;
 	int accumIdx;
-	const rsp_config *config = (const rsp_config *)device->static_config();
-	// resolve callbacks
-	rsp->dp_reg_r_func.resolve(config->dp_reg_r_cb, *device);
-	rsp->dp_reg_w_func.resolve(config->dp_reg_w_cb, *device);
-	rsp->sp_reg_r_func.resolve(config->sp_reg_r_cb, *device);
-	rsp->sp_reg_w_func.resolve(config->sp_reg_w_cb, *device);
-	rsp->sp_set_status_func.resolve(config->sp_set_status_cb, *device);
 
 	if (LOG_INSTRUCTION_EXECUTION)
 		rsp->exec_output = fopen("rsp_execute.txt", "wt");
 
 	rsp->irq_callback = irqcallback;
-	rsp->device = device;
+	rsp->device = downcast<rsp_cpu_device *>(device);
 	rsp->program = &device->space(AS_PROGRAM);
 	rsp->direct = &rsp->program->direct();
+	rsp->device->resolve_cb();
 
 #if 1
 	// Inaccurate.  RSP registers power on to a random state...
@@ -869,7 +872,7 @@ static void handle_swc2(rsp_state *rsp, UINT32 op)
 
 			// FIXME: only works for index 0 and index 8
 
-			if (index & 0x7)    mame_printf_debug("RSP: SFV: index = %d at %08X\n", index, rsp->ppc);
+			if (index & 0x7)    osd_printf_debug("RSP: SFV: index = %d at %08X\n", index, rsp->ppc);
 
 			ea = (base) ? rsp->r[base] + (offset * 16) : (offset * 16);
 
@@ -2742,7 +2745,7 @@ static CPU_EXECUTE( rsp )
 					case 0x09:  /* JALR */      JUMP_PC_L(RSVAL, RDREG); break;
 					case 0x0d:  /* BREAK */
 					{
-						(rsp->sp_set_status_func)(0, 0x3);
+						(rsp->device->sp_set_status_func)(0, 0x3, 0xffffffff);
 						rsp->icount = MIN(rsp->icount, 1);
 
 						if (LOG_INSTRUCTION_EXECUTION) fprintf(rsp->exec_output, "\n---------- break ----------\n\n");
@@ -3254,6 +3257,21 @@ CPU_GET_INFO( rsp_int )
 	}
 }
 
-DEFINE_LEGACY_CPU_DEVICE(RSP_INT, rsp_int);
+rsp_cpu_device::rsp_cpu_device(const machine_config &mconfig, device_type type, const char *tag, device_t *owner, UINT32 clock, cpu_get_info_func get_info)
+	: legacy_cpu_device(mconfig, type, tag, owner, clock, get_info),
+		dp_reg_r_func(*this),
+		dp_reg_w_func(*this),
+		sp_reg_r_func(*this),
+		sp_reg_w_func(*this),
+		sp_set_status_func(*this)
+{
+}
+
+rsp_int_device::rsp_int_device(const machine_config &mconfig, device_type type, const char *tag, device_t *owner, UINT32 clock)
+	: rsp_cpu_device(mconfig, type, tag, owner, clock, CPU_GET_INFO_NAME(rsp_int))
+{
+}
+
+const device_type RSP_INT = &legacy_device_creator<rsp_drc_device>;
 
 const device_type RSP = &legacy_device_creator_drc<rsp_int_device, rsp_drc_device>;
