@@ -285,6 +285,21 @@ void tlcs900h_device::device_start()
 {
 	m_program = &space( AS_PROGRAM );
 
+	m_pc.d = 0;
+	memset(m_xwa, 0x00, sizeof(m_xwa));
+	memset(m_xbc, 0x00, sizeof(m_xbc));
+	memset(m_xde, 0x00, sizeof(m_xde));
+	memset(m_xhl, 0x00, sizeof(m_xhl));
+	m_xix.d = 0;
+	m_xiy.d = 0;
+	m_xiz.d = 0;
+	m_xnsp.d = 0;
+	m_xssp.d = 0;
+	memset(m_dmas, 0x00, sizeof(m_dmas));
+	memset(m_dmad, 0x00, sizeof(m_dmad));
+	memset(m_dmac, 0x00, sizeof(m_dmac));
+	memset(m_dmam, 0x00, sizeof(m_dmam));
+
 	save_item( NAME(m_xwa) );
 	save_item( NAME(m_xbc) );
 	save_item( NAME(m_xde) );
@@ -431,6 +446,8 @@ void tmp95c061_device::device_reset()
 	m_timer_change[2] = 0;
 	m_timer_change[3] = 0;
 
+	memset(m_reg, 0x00, sizeof(m_reg));
+
 	m_reg[TMP95C061_P1] = 0x00;
 	m_reg[TMP95C061_P1CR] = 0x00;
 	m_reg[TMP95C061_P2] = 0xff;
@@ -498,7 +515,7 @@ void tmp95c061_device::device_reset()
 }
 
 
-#include "900tbl.c"
+#include "900tbl.inc"
 
 
 #define TMP95C061_NUM_MASKABLE_IRQS   22
@@ -1835,6 +1852,7 @@ void tmp95c063_device::device_reset()
 	{
 		m_level[i] = CLEAR_LINE;
 	}
+	m_prefetch_clear = true;
 }
 
 READ8_MEMBER( tmp95c063_device::internal_r )
@@ -2155,6 +2173,18 @@ void tmp95c063_device::execute_set_input(int input, int level)
 		m_level[TLCS900_INT5] = level;
 		break;
 
+	case TLCS900_INT6:
+		if (m_level[TLCS900_INT6] == CLEAR_LINE && level == ASSERT_LINE)
+		{
+			m_reg[TMP95C063_INTE56] |= 0x80;
+		}
+		else if (m_level[TLCS900_INT6] == ASSERT_LINE && level == CLEAR_LINE)
+		{
+			m_reg[TMP95C063_INTE56] &= ~0x80;
+		}
+		m_level[TLCS900_INT6] = level;
+		break;
+
 	case TLCS900_TIO:   /* External timer input for timer 0 */
 		if ( ( m_reg[TMP95C063_T8RUN] & 0x01 ) && ( m_reg[TMP95C063_T01MOD] & 0x03 ) == 0x00 )
 		{
