@@ -87,7 +87,6 @@ device_t::device_t(const machine_config &mconfig, device_type type, const char *
 		m_clock_scale(1.0),
 		m_attoseconds_per_clock((clock == 0) ? 0 : HZ_TO_ATTOSECONDS(clock)),
 
-		m_debug(NULL),
 		m_region(NULL),
 		m_machine_config(mconfig),
 		m_static_config(NULL),
@@ -275,7 +274,7 @@ void device_t::set_unscaled_clock(UINT32 clock)
 {
 	m_unscaled_clock = clock;
 	m_clock = m_unscaled_clock * m_clock_scale;
-	m_attoseconds_per_clock = HZ_TO_ATTOSECONDS(m_clock);
+	m_attoseconds_per_clock = (m_clock == 0) ? 0 : HZ_TO_ATTOSECONDS(m_clock);
 	notify_clock_changed();
 }
 
@@ -289,7 +288,7 @@ void device_t::set_clock_scale(double clockscale)
 {
 	m_clock_scale = clockscale;
 	m_clock = m_unscaled_clock * m_clock_scale;
-	m_attoseconds_per_clock = HZ_TO_ATTOSECONDS(m_clock);
+	m_attoseconds_per_clock = (m_clock == 0) ? 0 : HZ_TO_ATTOSECONDS(m_clock);
 	notify_clock_changed();
 }
 
@@ -317,7 +316,7 @@ attotime device_t::clocks_to_attotime(UINT64 numclocks) const
 //  attotime to CPU clock ticks
 //-------------------------------------------------
 
-UINT64 device_t::attotime_to_clocks(attotime duration) const
+UINT64 device_t::attotime_to_clocks(const attotime &duration) const
 {
 	return mulu_32x32(duration.seconds, m_clock) + (UINT64)duration.attoseconds / (UINT64)m_attoseconds_per_clock;
 }
@@ -339,7 +338,7 @@ emu_timer *device_t::timer_alloc(device_timer_id id, void *ptr)
 //  call our device callback
 //-------------------------------------------------
 
-void device_t::timer_set(attotime duration, device_timer_id id, int param, void *ptr)
+void device_t::timer_set(const attotime &duration, device_timer_id id, int param, void *ptr)
 {
 	machine().scheduler().timer_set(duration, *this, id, param, ptr);
 }
@@ -361,7 +360,7 @@ void device_t::set_machine(running_machine &machine)
 //  list and return status
 //-------------------------------------------------
 
-bool device_t::findit(bool isvalidation)
+bool device_t::findit(bool isvalidation) const
 {
 	bool allfound = true;
 	for (finder_base *autodev = m_auto_finder_list; autodev != NULL; autodev = autodev->m_next)
@@ -413,7 +412,7 @@ void device_t::start()
 	// if we're debugging, create a device_debug object
 	if ((machine().debug_flags & DEBUG_FLAG_ENABLED) != 0)
 	{
-		m_debug = auto_alloc(machine(), device_debug(*this));
+		m_debug.reset(global_alloc(device_debug(*this)));
 		debug_setup();
 	}
 
@@ -445,7 +444,7 @@ void device_t::stop()
 		intf->interface_post_stop();
 
 	// free any debugging info
-	auto_free(machine(), m_debug);
+	m_debug.reset();
 
 	// we're now officially stopped, and the machine is off-limits
 	m_started = false;
