@@ -40,10 +40,6 @@
 #define MCFG_DEVICE_INPUT_DEFAULTS(_config) \
 	device_t::static_set_input_default(*device, DEVICE_INPUT_DEFAULTS_NAME(_config));
 
-// macros for defining read_line/write_line functions
-#define READ_LINE_DEVICE_HANDLER(name)      int  name(ATTR_UNUSED device_t *device)
-#define WRITE_LINE_DEVICE_HANDLER(name)     void name(ATTR_UNUSED device_t *device, ATTR_UNUSED int state)
-
 #define DECLARE_READ_LINE_MEMBER(name)      int  name()
 #define READ_LINE_MEMBER(name)              int  name()
 #define DECLARE_WRITE_LINE_MEMBER(name)     void name(ATTR_UNUSED int state)
@@ -90,12 +86,6 @@ device_t *device_creator(const machine_config &mconfig, const char *tag, device_
 // timer IDs for devices
 typedef UINT32 device_timer_id;
 
-
-// read/write types for I/O lines (similar to read/write handlers but no offset)
-typedef int (*read_line_device_func)(device_t *device);
-typedef void (*write_line_device_func)(device_t *device, int state);
-
-
 // ======================> device_t
 
 // device_t represents a device
@@ -116,11 +106,11 @@ class device_t : public delegate_late_bind
 protected:
 	// construction/destruction
 	device_t(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, const char *shortname, const char *source);
+public:
 	virtual ~device_t();
 
-public:
 	// getters
-	running_machine &machine() const { assert(m_machine != NULL); return *m_machine; }
+	running_machine &machine() const { /*assert(m_machine != NULL);*/ return *m_machine; }
 	const char *tag() const { return m_tag; }
 	const char *basetag() const { return m_basetag; }
 	device_type type() const { return m_type; }
@@ -190,11 +180,11 @@ public:
 	double clock_scale() const { return m_clock_scale; }
 	void set_clock_scale(double clockscale);
 	attotime clocks_to_attotime(UINT64 clocks) const;
-	UINT64 attotime_to_clocks(attotime duration) const;
+	UINT64 attotime_to_clocks(const attotime &duration) const;
 
 	// timer interfaces
 	emu_timer *timer_alloc(device_timer_id id = 0, void *ptr = NULL);
-	void timer_set(attotime duration, device_timer_id id = 0, int param = 0, void *ptr = NULL);
+	void timer_set(const attotime &duration, device_timer_id id = 0, int param = 0, void *ptr = NULL);
 	void synchronize(device_timer_id id = 0, int param = 0, void *ptr = NULL) { timer_set(attotime::zero, id, param, ptr); }
 	void timer_expired(emu_timer &timer, device_timer_id id, int param, void *ptr) { device_timer(timer, id, param, ptr); }
 
@@ -211,7 +201,7 @@ public:
 
 	void set_default_bios(UINT8 bios) { m_default_bios = bios; }
 	void set_system_bios(UINT8 bios) { m_system_bios = bios; }
-	bool findit(bool isvalidation = false);
+	bool findit(bool isvalidation = false) const;
 
 protected:
 	// miscellaneous helpers
@@ -270,7 +260,7 @@ protected:
 	double                  m_clock_scale;          // clock scale factor
 	attoseconds_t           m_attoseconds_per_clock;// period in attoseconds
 
-	device_debug *          m_debug;
+	auto_pointer<device_debug> m_debug;
 	memory_region *         m_region;               // our device-local region
 	const machine_config &  m_machine_config;       // reference to the machine's configuration
 	const void *            m_static_config;        // static device configuration
@@ -322,6 +312,10 @@ public:
 	template<class _InterfaceClass> bool next(_InterfaceClass *&intf) const { return m_device.next(intf); }
 
 	// optional operation overrides
+	//
+	// WARNING: interface_pre_start must be callable multiple times in
+	// case another interface throws a missing dependency.  In
+	// particular, state saving registrations should be done in post.
 	virtual void interface_config_complete();
 	virtual void interface_validity_check(validity_checker &valid) const;
 	virtual void interface_pre_start();
