@@ -11,10 +11,11 @@
 #include "emu.h"
 #include "emuopts.h"
 #include "drivenum.h"
-#include "ui.h"
+#include "ui/ui.h"
 #include "zippath.h"
-#include "uiimage.h"
-#include "uiswlist.h"
+#include "ui/filesel.h"
+#include "ui/swlist.h"
+#include "ui/imgcntrl.h"
 
 //**************************************************************************
 //  DEVICE CONFIG IMAGE INTERFACE
@@ -55,13 +56,10 @@ device_image_interface::device_image_interface(const machine_config &mconfig, de
 	: device_interface(device),
 		m_file(NULL),
 		m_mame_file(NULL),
-		m_full_software_name(NULL),
 		m_software_info_ptr(NULL),
 		m_software_part_ptr(NULL),
-		m_software_list_name(NULL),
 		m_readonly(false),
 		m_created(false),
-		m_formatlist(NULL),
 		m_is_loading(FALSE)
 {
 }
@@ -73,15 +71,6 @@ device_image_interface::device_image_interface(const machine_config &mconfig, de
 
 device_image_interface::~device_image_interface()
 {
-	image_device_format **formatptr = &m_formatlist;
-
-	/* free all entries */
-	while (*formatptr != NULL)
-	{
-		image_device_format *entry = *formatptr;
-		*formatptr = entry->m_next;
-		global_free(entry);
-	}
 }
 
 //-------------------------------------------------
@@ -130,7 +119,7 @@ iodevice_t device_image_interface::device_typeid(const char *name)
 	int i;
 	for (i = 0; i < ARRAY_LENGTH(device_image_interface::m_device_info_array); i++)
 	{
-		if (!mame_stricmp(name, m_device_info_array[i].m_name) || !mame_stricmp(name, m_device_info_array[i].m_shortname))
+		if (!core_stricmp(name, m_device_info_array[i].m_name) || !core_stricmp(name, m_device_info_array[i].m_shortname))
 			return m_device_info_array[i].m_type;
 	}
 	return (iodevice_t)-1;
@@ -195,22 +184,6 @@ image_error_t device_image_interface::set_image_filename(const char *filename)
     CREATION FORMATS
 ****************************************************************************/
 
-/*-------------------------------------------------
-    device_get_indexed_creatable_format -
-    accesses a specific image format available for
-    image creation by index
--------------------------------------------------*/
-
-const image_device_format *device_image_interface::device_get_indexed_creatable_format(int index)
-{
-	const image_device_format *format = device_get_creatable_formats();
-	while(index-- && (format != NULL))
-		format = format->m_next;
-	return format;
-}
-
-
-
 /*-------------------------------------------------
     device_get_named_creatable_format -
     accesses a specific image format available for
@@ -219,10 +192,10 @@ const image_device_format *device_image_interface::device_get_indexed_creatable_
 
 const image_device_format *device_image_interface::device_get_named_creatable_format(const char *format_name)
 {
-	const image_device_format *format = device_get_creatable_formats();
-	while((format != NULL) && strcmp(format->m_name, format_name))
-		format = format->m_next;
-	return format;
+	for (const image_device_format *format = m_formatlist.first(); format != NULL; format = format->next())
+		if (strcmp(format->name(), format_name) == 0)
+			return format;
+	return NULL;
 }
 
 /****************************************************************************
@@ -300,7 +273,7 @@ void device_image_interface::message(const char *format, ...)
 	va_end(args);
 
 	/* display the popup for a standard amount of time */
-	ui_popup_time(5, "%s: %s",
+	device().machine().ui().popup_time(5, "%s: %s",
 		basename(),
 		buffer);
 }
@@ -327,7 +300,7 @@ bool device_image_interface::try_change_working_directory(const char *subdir)
 	{
 		while(!done && (entry = osd_readdir(directory)) != NULL)
 		{
-			if (!mame_stricmp(subdir, entry->name))
+			if (!core_stricmp(subdir, entry->name))
 			{
 				done = TRUE;
 				success = entry->type == ENTTYPE_DIR;
@@ -420,18 +393,7 @@ UINT32 device_image_interface::get_software_region_length(const char *tag)
 
 const char *device_image_interface::get_feature(const char *feature_name)
 {
-	feature_list *feature;
-
-	if ( ! m_software_part_ptr->featurelist )
-		return NULL;
-
-	for ( feature = m_software_part_ptr->featurelist; feature; feature = feature->next )
-	{
-		if ( ! strcmp( feature->name, feature_name ) )
-			return feature->value;
-	}
-
-	return NULL;
+	return (m_software_part_ptr == NULL) ? NULL : m_software_part_ptr->feature(feature_name);
 }
 
 
@@ -464,13 +426,12 @@ void device_image_interface::run_hash(void (*partialhash)(hash_collection &, con
 	hash_collection &hashes, const char *types)
 {
 	UINT32 size;
-	UINT8 *buf = NULL;
+	dynamic_buffer buf;
 
 	hashes.reset();
 	size = (UINT32) length();
 
-	buf = (UINT8*)malloc(size);
-	memset(buf,0,size);
+	buf.resize_and_clear(size);
 
 	/* read the file */
 	fseek(0, SEEK_SET);
@@ -482,7 +443,6 @@ void device_image_interface::run_hash(void (*partialhash)(hash_collection &, con
 		hashes.compute(buf, size, types);
 
 	/* cleanup */
-	free(buf);
 	fseek(0, SEEK_SET);
 }
 
@@ -540,10 +500,15 @@ UINT32 device_image_interface::crc()
 void device_image_interface::battery_load(void *buffer, int length, int fill)
 {
 	astring fname(device().machine().system().name, PATH_SEPARATOR, m_basename_noext, ".nv");
-
 	image_battery_load_by_name(device().machine().options(), fname, buffer, length, fill);
 }
 
+void device_image_interface::battery_load(void *buffer, int length, void *def_buffer)
+{
+	astring fname(device().machine().system().name, PATH_SEPARATOR, m_basename_noext, ".nv");
+	image_battery_load_by_name(device().machine().options(), fname, buffer, length, def_buffer);
+}
+
 /*-------------------------------------------------
     battery_save - stores the battery
     backed RAM for an image. The file name is
@@ -574,7 +539,7 @@ bool device_image_interface::uses_file_extension(const char *file_extension) con
 	char *ext = strtok((char*)extensions.cstr(),",");
 	while (ext != NULL)
 	{
-		if (!mame_stricmp(ext, file_extension))
+		if (!core_stricmp(ext, file_extension))
 		{
 			result = TRUE;
 			break;
@@ -738,8 +703,8 @@ void device_image_interface::determine_open_plan(int is_create, UINT32 *open_pla
 static void dump_wrong_and_correct_checksums(const hash_collection &hashes, const hash_collection &acthashes)
 {
 	astring tempstr;
-	mame_printf_error("    EXPECTED: %s\n", hashes.macro_string(tempstr));
-	mame_printf_error("       FOUND: %s\n", acthashes.macro_string(tempstr));
+	osd_printf_error("    EXPECTED: %s\n", hashes.macro_string(tempstr));
+	osd_printf_error("       FOUND: %s\n", acthashes.macro_string(tempstr));
 }
 
 /*-------------------------------------------------
@@ -756,7 +721,7 @@ static int verify_length_and_hash(emu_file *file, const char *name, UINT32 exple
 	UINT32 actlength = file->size();
 	if (explength != actlength)
 	{
-		mame_printf_error("%s WRONG LENGTH (expected: %d found: %d)\n", name, explength, actlength);
+		osd_printf_error("%s WRONG LENGTH (expected: %d found: %d)\n", name, explength, actlength);
 		retVal++;
 	}
 
@@ -765,20 +730,20 @@ static int verify_length_and_hash(emu_file *file, const char *name, UINT32 exple
 	hash_collection &acthashes = file->hashes(hashes.hash_types(tempstr));
 	if (hashes.flag(hash_collection::FLAG_NO_DUMP))
 	{
-		mame_printf_error("%s NO GOOD DUMP KNOWN\n", name);
+		osd_printf_error("%s NO GOOD DUMP KNOWN\n", name);
 	}
 	/* verify checksums */
 	else if (hashes != acthashes)
 	{
 		/* otherwise, it's just bad */
-		mame_printf_error("%s WRONG CHECKSUMS:\n", name);
+		osd_printf_error("%s WRONG CHECKSUMS:\n", name);
 		dump_wrong_and_correct_checksums(hashes, acthashes);
 		retVal++;
 	}
 	/* If it matches, but it is actually a bad dump, write it */
 	else if (hashes.flag(hash_collection::FLAG_BAD_DUMP))
 	{
-		mame_printf_error("%s NEEDS REDUMP\n",name);
+		osd_printf_error("%s NEEDS REDUMP\n",name);
 	}
 	return retVal;
 }
@@ -786,7 +751,8 @@ static int verify_length_and_hash(emu_file *file, const char *name, UINT32 exple
 /*-------------------------------------------------
     load_software - software image loading
 -------------------------------------------------*/
-bool device_image_interface::load_software(char *swlist, char *swname, rom_entry *start)
+
+bool device_image_interface::load_software(software_list_device &swlist, const char *swname, const rom_entry *start)
 {
 	astring locationtag, breakstr("%");
 	const rom_entry *region;
@@ -807,38 +773,29 @@ bool device_image_interface::load_software(char *swlist, char *swname, rom_entry
 				UINT32 crc = 0;
 				bool has_crc = hash_collection(ROM_GETHASHDATA(romp)).crc(crc);
 
+				software_info *swinfo = swlist.find(swname);
+				if (swinfo == NULL)
+					return false;
+
+				UINT32 supported = swinfo->supported();
+				if (supported == SOFTWARE_SUPPORTED_PARTIAL)
+					osd_printf_error("WARNING: support for software %s (in list %s) is only partial\n", swname, swlist.list_name());
+				if (supported == SOFTWARE_SUPPORTED_NO)
+					osd_printf_error("WARNING: support for software %s (in list %s) is only preliminary\n", swname, swlist.list_name());
+
 				// attempt reading up the chain through the parents and create a locationtag astring in the format
 				// " swlist % clonename % parentname "
 				// below, we have the code to split the elements and to create paths to load from
 
-				software_list *software_list_ptr = software_list_open(device().machine().options(), swlist, FALSE, NULL);
-				if (software_list_ptr)
+				while (swinfo != NULL)
 				{
-					for (software_info *swinfo = software_list_find(software_list_ptr, swname, NULL); swinfo != NULL; )
-					{
-						{
-							astring tmp(swinfo->shortname);
-							locationtag.cat(tmp);
-							locationtag.cat(breakstr);
-							//printf("%s\n", locationtag.cstr());
-						}
-
-						const char *parentname = software_get_clone(device().machine().options(), swlist, swinfo->shortname);
-						if (parentname != NULL)
-							swinfo = software_list_find(software_list_ptr, parentname, NULL);
-						else
-							swinfo = NULL;
-					}
-					// strip the final '%'
-					locationtag.del(locationtag.len() - 1, 1);
-					software_list_close(software_list_ptr);
+					locationtag.cat(swinfo->shortname()).cat(breakstr);
+					const char *parentname = swinfo->parentname();
+					swinfo = (parentname != NULL) ? swlist.find(parentname) : NULL;
 				}
+				// strip the final '%'
+				locationtag.del(locationtag.len() - 1, 1);
 
-				if (software_get_support(device().machine().options(), swlist, swname) == SOFTWARE_SUPPORTED_PARTIAL)
-					mame_printf_error("WARNING: support for software %s (in list %s) is only partial\n", swname, swlist);
-
-				if (software_get_support(device().machine().options(), swlist, swname) == SOFTWARE_SUPPORTED_NO)
-					mame_printf_error("WARNING: support for software %s (in list %s) is only preliminary\n", swname, swlist);
 
 				// check if locationtag actually contains two locations separated by '%'
 				// (i.e. check if we are dealing with a clone in softwarelist)
@@ -852,10 +809,10 @@ bool device_image_interface::load_software(char *swlist, char *swname, rom_entry
 				}
 
 				// prepare locations where we have to load from: list/parentname & list/clonename
-				astring tag1(swlist);
+				astring tag1(swlist.list_name());
 				tag1.cat(PATH_SEPARATOR);
 				tag2.cpy(tag1.cat(tag4));
-				tag1.cpy(swlist);
+				tag1.cpy(swlist.list_name());
 				tag1.cat(PATH_SEPARATOR);
 				tag3.cpy(tag1.cat(tag5));
 
@@ -893,7 +850,7 @@ bool device_image_interface::load_software(char *swlist, char *swname, rom_entry
 	}
 	if (warningcount > 0)
 	{
-		mame_printf_error("WARNING: the software item might not run correctly.\n");
+		osd_printf_error("WARNING: the software item might not run correctly.\n");
 	}
 	return retVal;
 }
@@ -933,13 +890,26 @@ bool device_image_interface::load_internal(const char *path, bool is_create, int
 		/* Check if there's a software list defined for this device and use that if we're not creating an image */
 		if (!filename_has_period && !just_load)
 		{
-			softload = load_software_part( device().machine().options(), this, path, &m_software_info_ptr, &m_software_part_ptr, &m_full_software_name, &m_software_list_name );
-			// if we had launched from softlist with a specified part, e.g. "shortname:part"
-			// we would have recorded the wrong name, so record it again based on software_info
-			if (m_software_info_ptr && m_full_software_name)
-				m_err = set_image_filename(m_full_software_name);
+			softload = load_software_part(path, m_software_part_ptr);
+			if (softload)
+			{
+				m_software_info_ptr = &m_software_part_ptr->info();
+				m_software_list_name.cpy(m_software_info_ptr->list().list_name());
+				m_full_software_name.cpy(m_software_part_ptr->info().shortname());
 
-			m_from_swlist = TRUE;
+				// if we had launched from softlist with a specified part, e.g. "shortname:part"
+				// we would have recorded the wrong name, so record it again based on software_info
+				if (m_software_info_ptr && m_full_software_name)
+					m_err = set_image_filename(m_full_software_name);
+
+				// check if image should be read-only
+				const char *read_only = get_feature("read_only");
+				if (read_only && !strcmp(read_only, "true")) {
+					make_readonly();
+				}
+
+				m_from_swlist = TRUE;
+			}
 		}
 
 		if (is_create || filename_has_period)
@@ -961,14 +931,14 @@ bool device_image_interface::load_internal(const char *path, bool is_create, int
 		if ( m_software_info_ptr )
 		{
 			// sanitize
-			if (!m_software_info_ptr->longname || !m_software_info_ptr->publisher || !m_software_info_ptr->year)
+			if (m_software_info_ptr->longname() == NULL || m_software_info_ptr->publisher() == NULL || m_software_info_ptr->year() == NULL)
 				fatalerror("Each entry in an XML list must have all of the following fields: description, publisher, year!\n");
 
 			// store
-			m_longname = m_software_info_ptr->longname;
-			m_manufacturer = m_software_info_ptr->publisher;
-			m_year = m_software_info_ptr->year;
-			//m_playable = m_software_info_ptr->supported;
+			m_longname = m_software_info_ptr->longname();
+			m_manufacturer = m_software_info_ptr->publisher();
+			m_year = m_software_info_ptr->year();
+			//m_playable = m_software_info_ptr->supported();
 		}
 
 		/* did we fail to find the file? */
@@ -999,9 +969,9 @@ done:
 		if (!m_init_phase)
 		{
 			if (device().machine().phase() == MACHINE_PHASE_RUNNING)
-				popmessage("Error: Unable to %s image '%s': %s\n", is_create ? "create" : "load", path, error());
+				popmessage("Error: Unable to %s image '%s': %s", is_create ? "create" : "load", path, error());
 			else
-				mame_printf_error("Error: Unable to %s image '%s': %s", is_create ? "create" : "load", path, error());
+				osd_printf_error("Error: Unable to %s image '%s': %s\n", is_create ? "create" : "load", path, error());
 		}
 		clear();
 	}
@@ -1016,7 +986,7 @@ done:
 				if (device().machine().phase() == MACHINE_PHASE_RUNNING)
 					popmessage("Image '%s' was successfully %s.", path, is_create ? "created" : "loaded");
 				else
-					mame_printf_info("Image '%s' was successfully %s.\n", path, is_create ? "created" : "loaded");
+					osd_printf_info("Image '%s' was successfully %s.\n", path, is_create ? "created" : "loaded");
 			}
 		}
 	}
@@ -1065,9 +1035,6 @@ bool device_image_interface::finish_load()
 	{
 		image_checkhash();
 
-		if (m_from_swlist)
-			call_display_info();
-
 		if (has_been_created())
 		{
 			err = call_create(m_create_format, m_create_args);
@@ -1101,7 +1068,7 @@ bool device_image_interface::finish_load()
 
 bool device_image_interface::create(const char *path, const image_device_format *create_format, option_resolution *create_args)
 {
-	int format_index = (create_format != NULL) ? create_format->m_index : 0;
+	int format_index = (create_format != NULL) ? m_formatlist.indexof(*create_format) : 0;
 	return load_internal(path, TRUE, format_index, create_args, FALSE);
 }
 
@@ -1137,10 +1104,10 @@ void device_image_interface::clear()
 	m_basename_noext.reset();
 	m_filetype.reset();
 
-	m_full_software_name = NULL;
+	m_full_software_name.reset();
 	m_software_info_ptr = NULL;
 	m_software_part_ptr = NULL;
-	m_software_list_name = NULL;
+	m_software_list_name.reset();
 }
 
 /*-------------------------------------------------
@@ -1187,6 +1154,173 @@ void device_image_interface::update_names(const device_type device_type, const c
 	}
 }
 
+//-------------------------------------------------
+//  software_name_split - helper that splits a
+//  software_list:software:part string into
+//  separate software_list, software, and part
+//  strings.
+//
+//  str1:str2:str3  => swlist_name - str1, swname - str2, swpart - str3
+//  str1:str2       => swlist_name - NULL, swname - str1, swpart - str2
+//  str1            => swlist_name - NULL, swname - str1, swpart - NULL
+//-------------------------------------------------
+
+void device_image_interface::software_name_split(const char *swlist_swname, astring &swlist_name, astring &swname, astring &swpart)
+{
+	// reset all output parameters
+	swlist_name.reset();
+	swname.reset();
+	swpart.reset();
+
+	// if no colon, this is the swname by itself
+	const char *split1 = strchr(swlist_swname, ':');
+	if (split1 == NULL)
+	{
+		swname.cpy(swlist_swname);
+		return;
+	}
+
+	// if one colon, it is the swname and swpart alone
+	const char *split2 = strchr(split1 + 1, ':');
+	if (split2 == NULL)
+	{
+		swname.cpy(swlist_swname, split1 - swlist_swname);
+		swpart.cpy(split1 + 1);
+		return;
+	}
+
+	// if two colons present, split into 3 parts
+	swlist_name.cpy(swlist_swname, split1 - swlist_swname);
+	swname.cpy(split1 + 1, split2 - (split1 + 1));
+	swpart.cpy(split2 + 1);
+}
+
+
+software_part *device_image_interface::find_software_item(const char *path, bool restrict_to_interface)
+{
+	//
+	// Note: old code would explicitly load swlist_name if it was specified, rather than
+	// searching the devices.
+	//
+	// Also if not found, old code would attempt to open <drivername>.xml and even
+	// <swinfo_name>.xml. Hopefully removing this won't break anything.
+	//
+
+	// split full software name into software list name and short software name
+	astring swlist_name, swinfo_name, swpart_name;
+	software_name_split(path, swlist_name, swinfo_name, swpart_name);
+	bool explicit_name = (swlist_name.len() > 0);
+
+	// determine interface
+	const char *interface = NULL;
+	if (restrict_to_interface)
+		interface = image_interface();
+
+	// find the software list if explicitly specified
+	software_list_device_iterator deviter(device().mconfig().root_device());
+	for (software_list_device *swlistdev = deviter.first(); swlistdev != NULL; swlistdev = deviter.next())
+		if (!explicit_name || swlist_name == swlistdev->list_name())
+		{
+			software_info *info = swlistdev->find(swinfo_name);
+			if (info != NULL)
+			{
+				software_part *part = info->find_part(swpart_name, interface);
+				if (part != NULL)
+					return part;
+			}
+		}
+
+	// if explicitly specified and not found, just error here
+	return NULL;
+}
+
+
+//-------------------------------------------------
+//  load_software_part
+//
+//  Load a software part for a device. The part to
+//  load is determined by the "path", software lists
+//  configured for a driver, and the interface
+//  supported by the device.
+//
+//  returns true if the software could be loaded,
+//  false otherwise. If the software could be loaded
+//  sw_info and sw_part are also set.
+//-------------------------------------------------
+
+bool device_image_interface::load_software_part(const char *path, software_part *&swpart)
+{
+	// if no match has been found, we suggest similar shortnames
+	swpart = find_software_item(path, true);
+	if (swpart == NULL)
+	{
+		software_list_device::display_matches(device().machine().config(), image_interface(), path);
+		return false;
+	}
+
+	// Load the software part
+	bool result = call_softlist_load(swpart->info().list(), swpart->info().shortname(), swpart->romdata());
+
+	// Tell the world which part we actually loaded
+	astring full_sw_name;
+	full_sw_name.printf("%s:%s:%s", swpart->info().list().list_name(), swpart->info().shortname(), swpart->name());
+
+	// check compatibility
+	if (!swpart->is_compatible(swpart->info().list()))
+		osd_printf_warning("WARNING! the set %s might not work on this system due to missing filter(s) '%s'\n", swpart->info().shortname(), swpart->info().list().filter());
+
+	// check requirements and load those images
+	const char *requirement = swpart->feature("requirement");
+	if (requirement != NULL)
+	{
+		software_part *req_swpart = find_software_item(requirement, false);
+		if (req_swpart != NULL)
+		{
+			image_interface_iterator imgiter(device().machine().root_device());
+			for (device_image_interface *req_image = imgiter.first(); req_image != NULL; req_image = imgiter.next())
+			{
+				const char *interface = req_image->image_interface();
+				if (interface != NULL)
+				{
+					if (req_swpart->matches_interface(interface))
+					{
+						const char *option = device().mconfig().options().value(req_image->brief_instance_name());
+						// mount only if not already mounted
+						if (strlen(option) == 0 && !req_image->filename())
+						{
+							req_image->set_init_phase();
+							req_image->load(requirement);
+						}
+						break;
+					}
+				}
+			}
+		}
+	}
+	return result;
+}
+
+//-------------------------------------------------
+//  software_get_default_slot
+//-------------------------------------------------
+
+void device_image_interface::software_get_default_slot(astring &result, const char *default_card_slot)
+{
+	const char *path = device().mconfig().options().value(instance_name());
+	result.reset();
+	if (strlen(path) > 0)
+	{
+		result.cpy(default_card_slot);
+		software_part *swpart = find_software_item(path, true);
+		if (swpart != NULL)
+		{
+			const char *slot = swpart->feature("slot");
+			if (slot != NULL)
+				result.cpy(slot);
+		}
+	}
+}
+
 /*-------------------------------------------------
     get_selection_menu - create the menu stack
     for ui-level image selection
@@ -1196,270 +1330,3 @@ ui_menu *device_image_interface::get_selection_menu(running_machine &machine, re
 {
 	return auto_alloc_clear(machine, ui_menu_control_device_image(machine, container, this));
 }
-
-ui_menu_control_device_image::ui_menu_control_device_image(running_machine &machine, render_container *container, device_image_interface *_image) : ui_menu(machine, container)
-{
-	image = _image;
-
-	sld = 0;
-	if (image->software_list_name()) {
-		software_list_device_iterator iter(machine.config().root_device());
-		for (const software_list_device *swlist = iter.first(); swlist != NULL; swlist = iter.next())
-		{
-			if (strcmp(swlist->list_name(),image->software_list_name())==0) sld = swlist;
-		}
-	}
-	swi = image->software_entry();
-	swp = image->part_entry();
-
-	if(swi)
-	{
-		state = START_OTHER_PART;
-		current_directory.cpy(image->working_directory());
-	}
-	else
-	{
-		state = START_FILE;
-
-		/* if the image exists, set the working directory to the parent directory */
-		if (image->exists())
-		{
-			current_file.cpy(image->filename());
-			zippath_parent(current_directory, current_file);
-		} else
-			current_directory.cpy(image->working_directory());
-
-		/* check to see if the path exists; if not clear it */
-		if (zippath_opendir(current_directory, NULL) != FILERR_NONE)
-			current_directory.reset();
-	}
-}
-
-ui_menu_control_device_image::~ui_menu_control_device_image()
-{
-}
-
-
-
-
-/*-------------------------------------------------
-    create_new_image - creates a new disk image
--------------------------------------------------*/
-
-void ui_menu_control_device_image::test_create(bool &can_create, bool &need_confirm)
-{
-	astring path;
-	osd_directory_entry *entry;
-	osd_dir_entry_type file_type;
-
-	/* assemble the full path */
-	zippath_combine(path, current_directory, current_file);
-
-	/* does a file or a directory exist at the path */
-	entry = osd_stat(path);
-	file_type = (entry != NULL) ? entry->type : ENTTYPE_NONE;
-
-	switch(file_type)
-	{
-		case ENTTYPE_NONE:
-			/* no file/dir here - always create */
-			can_create = true;
-			need_confirm = false;
-			break;
-
-		case ENTTYPE_FILE:
-			/* a file exists here - ask for permission from the user */
-			can_create = true;
-			need_confirm = true;
-			break;
-
-		case ENTTYPE_DIR:
-			/* a directory exists here - we can't save over it */
-			ui_popup_time(5, "Cannot save over directory");
-			can_create = false;
-			need_confirm = false;
-			break;
-
-		default:
-			fatalerror("Unexpected\n");
-			can_create = false;
-			need_confirm = false;
-			break;
-	}
-}
-
-void ui_menu_control_device_image::load_software_part()
-{
-	astring temp_name(sld->list_name());
-	temp_name.cat(":");
-	temp_name.cat(swi->shortname);
-	temp_name.cat(":");
-	temp_name.cat(swp->name);
-	hook_load(temp_name, true);
-}
-
-void ui_menu_control_device_image::hook_load(astring name, bool softlist)
-{
-	image->load(name);
-	ui_menu::stack_pop(machine());
-}
-
-void ui_menu_control_device_image::populate()
-{
-}
-
-void ui_menu_control_device_image::handle()
-{
-	switch(state) {
-	case START_FILE: {
-		bool can_create = false;
-		if(image->is_creatable()) {
-			zippath_directory *directory = NULL;
-			file_error err = zippath_opendir(current_directory, &directory);
-			can_create = err == FILERR_NONE && !zippath_is_zip(directory);
-			if(directory)
-				zippath_closedir(directory);
-		}
-		submenu_result = -1;
-		ui_menu::stack_push(auto_alloc_clear(machine(), ui_menu_file_selector(machine(), container, image, current_directory, current_file, true, image->image_interface()!=NULL, can_create, &submenu_result)));
-		state = SELECT_FILE;
-		break;
-	}
-
-	case START_SOFTLIST:
-		sld = 0;
-		ui_menu::stack_push(auto_alloc_clear(machine(), ui_menu_software(machine(), container, image->image_interface(), &sld)));
-		state = SELECT_SOFTLIST;
-		break;
-
-	case START_OTHER_PART: {
-		submenu_result = -1;
-		ui_menu::stack_push(auto_alloc_clear(machine(), ui_menu_software_parts(machine(), container, swi, swp->interface_, &swp, true, &submenu_result)));
-		state = SELECT_OTHER_PART;
-		break;
-	}
-
-	case SELECT_SOFTLIST:
-		if(!sld) {
-			ui_menu::stack_pop(machine());
-			break;
-		}
-		software_info_name = "";
-		ui_menu::stack_push(auto_alloc_clear(machine(), ui_menu_software_list(machine(), container, sld, image->image_interface(), software_info_name)));
-		state = SELECT_PARTLIST;
-		break;
-
-	case SELECT_PARTLIST:
-		swl = software_list_open(machine().options(), sld->list_name(), false, NULL);
-		swi = software_list_find(swl, software_info_name, NULL);
-		if(swinfo_has_multiple_parts(swi, image->image_interface())) {
-			submenu_result = -1;
-			swp = 0;
-			ui_menu::stack_push(auto_alloc_clear(machine(), ui_menu_software_parts(machine(), container, swi, image->image_interface(), &swp, false, &submenu_result)));
-			state = SELECT_ONE_PART;
-		} else {
-			swp = software_find_part(swi, NULL, NULL);
-			load_software_part();
-			software_list_close(swl);
-			ui_menu::stack_pop(machine());
-		}
-		break;
-
-	case SELECT_ONE_PART:
-		switch(submenu_result) {
-		case ui_menu_software_parts::T_ENTRY: {
-			load_software_part();
-			software_list_close(swl);
-			ui_menu::stack_pop(machine());
-			break;
-		}
-
-		case -1: // return to list
-			software_list_close(swl);
-			state = SELECT_SOFTLIST;
-			break;
-
-		}
-		break;
-
-	case SELECT_OTHER_PART:
-		switch(submenu_result) {
-		case ui_menu_software_parts::T_ENTRY: {
-			load_software_part();
-			break;
-		}
-
-		case ui_menu_software_parts::T_FMGR:
-			state = START_FILE;
-			handle();
-			break;
-
-		case -1: // return to system
-			ui_menu::stack_pop(machine());
-			break;
-
-		}
-		break;
-
-	case SELECT_FILE:
-		switch(submenu_result) {
-		case ui_menu_file_selector::R_EMPTY:
-			image->unload();
-			ui_menu::stack_pop(machine());
-			break;
-
-		case ui_menu_file_selector::R_FILE:
-			hook_load(current_file, false);
-			break;
-
-		case ui_menu_file_selector::R_CREATE:
-			ui_menu::stack_push(auto_alloc_clear(machine(), ui_menu_file_create(machine(), container, image, current_directory, current_file)));
-			state = CREATE_FILE;
-			break;
-
-		case ui_menu_file_selector::R_SOFTLIST:
-			state = START_SOFTLIST;
-			handle();
-			break;
-
-		case -1: // return to system
-			ui_menu::stack_pop(machine());
-			break;
-		}
-		break;
-
-	case CREATE_FILE: {
-		bool can_create, need_confirm;
-		test_create(can_create, need_confirm);
-		if(can_create) {
-			if(need_confirm) {
-				ui_menu::stack_push(auto_alloc_clear(machine(), ui_menu_confirm_save_as(machine(), container, &create_confirmed)));
-				state = CREATE_CONFIRM;
-			} else {
-				state = DO_CREATE;
-				handle();
-			}
-		} else {
-			state = START_FILE;
-			handle();
-		}
-		break;
-	}
-
-	case CREATE_CONFIRM: {
-		state = create_confirmed ? DO_CREATE : START_FILE;
-		handle();
-		break;
-	}
-
-	case DO_CREATE: {
-		astring path;
-		zippath_combine(path, current_directory, current_file);
-		int err = image->create(path, 0, NULL);
-		if (err != 0)
-			popmessage("Error: %s", image->error());
-		ui_menu::stack_pop(machine());
-		break;
-	}
-	}
-}
