@@ -5,7 +5,6 @@ device_network_interface::device_network_interface(const machine_config &mconfig
 	: device_interface(device)
 {
 	m_promisc = false;
-	m_dev = NULL;
 	m_bandwidth = bandwidth;
 	set_mac("\0\0\0\0\0\0");
 	m_intf = 0;
@@ -13,7 +12,6 @@ device_network_interface::device_network_interface(const machine_config &mconfig
 
 device_network_interface::~device_network_interface()
 {
-	if(m_dev) global_free(m_dev);
 }
 
 int device_network_interface::send(UINT8 *buf, int len)
@@ -40,7 +38,7 @@ void device_network_interface::set_mac(const char *mac)
 
 void device_network_interface::set_interface(int id)
 {
-	m_dev = open_netdev(id, this, (int)(m_bandwidth*1000000/8.0/1500));
+	m_dev.reset(open_netdev(id, this, (int)(m_bandwidth*1000000/8.0/1500)));
 	if(!m_dev) {
 		logerror("Network interface %d not found\n", id);
 		id = -1;
