@@ -22,7 +22,6 @@
 
 // core emulator headers -- must be first
 #include "emucore.h"
-#include "emutempl.h"
 #include "eminline.h"
 #include "profiler.h"
 
@@ -57,7 +56,7 @@ typedef device_t * (*machine_config_constructor)(machine_config &config, device_
 #include "output.h"
 
 // diimage requires uimenu
-#include "uimenu.h"
+#include "ui/menu.h"
 
 // devices and callbacks
 #include "device.h"
@@ -66,7 +65,9 @@ typedef device_t * (*machine_config_constructor)(machine_config &config, device_
 #include "dimemory.h"
 #include "diexec.h"
 #include "opresolv.h"
+#include "digfx.h"
 #include "diimage.h"
+#include "dioutput.h"
 #include "diserial.h"
 #include "dislot.h"
 #include "disound.h"
@@ -96,9 +97,9 @@ typedef device_t * (*machine_config_constructor)(machine_config &config, device_
 #include "luaengine.h"
 
 // the running machine
+#include "mame.h"
 #include "machine.h"
 #include "driver.h"
-#include "mame.h"
 
 // video-related
 #include "drawgfx.h"
@@ -113,7 +114,7 @@ typedef device_t * (*machine_config_constructor)(machine_config &config, device_
 
 // generic helpers
 #include "devcb.h"
-#include "devcb2.h"
+#include "dispatch.h"
 #include "drivers/xtal.h"
 #include "machine/generic.h"
 #include "video/generic.h"
