@@ -47,7 +47,6 @@ const options_entry emu_options::s_option_entries[] =
 	{ NULL,                                              NULL,        OPTION_HEADER,     "CORE OUTPUT DIRECTORY OPTIONS" },
 	{ OPTION_CFG_DIRECTORY,                              "cfg",       OPTION_STRING,     "directory to save configurations" },
 	{ OPTION_NVRAM_DIRECTORY,                            "nvram",     OPTION_STRING,     "directory to save nvram contents" },
-	{ OPTION_MEMCARD_DIRECTORY,                          "memcard",   OPTION_STRING,     "directory to save memory card contents" },
 	{ OPTION_INPUT_DIRECTORY,                            "inp",       OPTION_STRING,     "directory to save input device logs" },
 	{ OPTION_STATE_DIRECTORY,                            "sta",       OPTION_STRING,     "directory to save states" },
 	{ OPTION_SNAPSHOT_DIRECTORY,                         "snap",      OPTION_STRING,     "directory to save screenshots" },
@@ -114,7 +113,6 @@ const options_entry emu_options::s_option_entries[] =
 
 	// sound options
 	{ NULL,                                              NULL,        OPTION_HEADER,     "CORE SOUND OPTIONS" },
-	{ OPTION_SOUND,                                      "1",         OPTION_BOOLEAN,    "enable sound output" },
 	{ OPTION_SAMPLERATE ";sr(1000-1000000)",             "48000",     OPTION_INTEGER,    "set sound output sample rate" },
 	{ OPTION_SAMPLES,                                    "1",         OPTION_BOOLEAN,    "enable the use of external samples if available" },
 	{ OPTION_VOLUME ";vol",                              "0",         OPTION_INTEGER,    "sound volume in decibels (-32 min, 0 max)" },
@@ -151,12 +149,8 @@ const options_entry emu_options::s_option_entries[] =
 
 	// debugging options
 	{ NULL,                                              NULL,        OPTION_HEADER,     "CORE DEBUGGING OPTIONS" },
-	{ OPTION_LOG,                                        "0",         OPTION_BOOLEAN,    "generate an error.log file" },
-	{ OPTION_VERBOSE ";v",                               "0",         OPTION_BOOLEAN,    "display additional diagnostic information" },
 	{ OPTION_UPDATEINPAUSE,                              "0",         OPTION_BOOLEAN,    "keep calling video updates while in pause" },
-	{ OPTION_DEBUG ";d",                                 "0",         OPTION_BOOLEAN,    "enable/disable debugger" },
 	{ OPTION_DEBUGSCRIPT,                                NULL,        OPTION_STRING,     "script for debugger" },
-	{ OPTION_DEBUG_INTERNAL ";di",                       "0",         OPTION_BOOLEAN,    "use the internal debugger for debugging" },
 
 	// misc options
 	{ NULL,                                              NULL,        OPTION_HEADER,     "CORE MISC OPTIONS" },
@@ -175,6 +169,7 @@ const options_entry emu_options::s_option_entries[] =
 	{ OPTION_HTTP,                                       "0",         OPTION_BOOLEAN,    "enable local http server" },
 	{ OPTION_HTTP_PORT,                                  "8080",      OPTION_STRING,     "http server listener port" },
 	{ OPTION_HTTP_PATH,                                  "web",       OPTION_STRING,     "path to web files" },
+	{ OPTION_CONSOLE,                                    "0",         OPTION_BOOLEAN,    "enable emulator LUA console" },
 	{ NULL }
 };
 
@@ -191,6 +186,7 @@ const options_entry emu_options::s_option_entries[] =
 emu_options::emu_options()
 {
 	add_entries(s_option_entries);
+	add_osd_options();
 }
 
 
@@ -199,57 +195,51 @@ emu_options::emu_options()
 //  options for the configured system
 //-------------------------------------------------
 
-bool emu_options::add_slot_options(bool isfirst)
+bool emu_options::add_slot_options(bool isfirstpass)
 {
 	// look up the system configured by name; if no match, do nothing
 	const game_driver *cursystem = system();
 	if (cursystem == NULL)
 		return false;
+	machine_config config(*cursystem, *this);
 
 	// iterate through all slot devices
-	options_entry entry[2] = { { 0 }, { 0 } };
 	bool first = true;
+
 	// create the configuration
-	machine_config config(*cursystem, *this);
-	bool added = false;
+	int starting_count = options_count();
 	slot_interface_iterator iter(config.root_device());
 	for (const device_slot_interface *slot = iter.first(); slot != NULL; slot = iter.next())
 	{
-		if (slot->fixed()) continue;
+		// skip fixed slots
+		if (slot->fixed())
+			continue;
+
 		// first device? add the header as to be pretty
-		if (first && isfirst)
-		{
-			entry[0].name = NULL;
-			entry[0].description = "SLOT DEVICES";
-			entry[0].flags = OPTION_HEADER | OPTION_FLAG_DEVICE;
-			entry[0].defvalue = NULL;
-			add_entries(entry);
-		}
+		if (isfirstpass && first)
+			add_entry(NULL, "SLOT DEVICES", OPTION_HEADER | OPTION_FLAG_DEVICE);
 		first = false;
 
 		// retrieve info about the device instance
-		if (!exists(slot->device().tag() + 1)) {
+		const char *name = slot->device().tag() + 1;
+		if (!exists(name))
+		{
 			// add the option
-			entry[0].name = slot->device().tag() + 1;
-			entry[0].description = NULL;
-			entry[0].flags = OPTION_STRING | OPTION_FLAG_DEVICE;
-			entry[0].defvalue = slot->default_option();
-			if ( entry[0].defvalue )
+			UINT32 flags = OPTION_STRING | OPTION_FLAG_DEVICE;
+			const char *defvalue = slot->default_option();
+			if (defvalue != NULL)
 			{
-				const device_slot_option *option = slot->option(entry[0].defvalue);
-				if (option && !option->selectable())
-				{
-					entry[0].flags |= OPTION_FLAG_INTERNAL;
-				}
+				const device_slot_option *option = slot->option(defvalue);
+				if (option != NULL && !option->selectable())
+					flags |= OPTION_FLAG_INTERNAL;
 			}
-			add_entries(entry, true);
-
-			added = true;
+			add_entry(name, NULL, flags, defvalue, true);
 		}
 	}
-	return added;
+	return (options_count() != starting_count);
 }
 
+
 //-------------------------------------------------
 //  update_slot_options - update slot values
 //  depending of image mounted
@@ -261,72 +251,61 @@ void emu_options::update_slot_options()
 	const game_driver *cursystem = system();
 	if (cursystem == NULL)
 		return;
+	machine_config config(*cursystem, *this);
 
 	// iterate through all slot devices
-	// create the configuration
-	machine_config config(*cursystem, *this);
 	slot_interface_iterator iter(config.root_device());
 	for (device_slot_interface *slot = iter.first(); slot != NULL; slot = iter.next())
 	{
 		// retrieve info about the device instance
-		if (exists(slot->device().tag()+1)) {
-			if (slot->first_option() != NULL) {
-				const char *def = slot->get_default_card_software(config,*this);
-				if (def)
-				{
-					set_default_value(slot->device().tag()+1,def);
-					const device_slot_option *option = slot->option( def );
-					set_flag(slot->device().tag()+1, ~OPTION_FLAG_INTERNAL, option && !option->selectable() ? OPTION_FLAG_INTERNAL : 0 );
-				}
+		const char *name = slot->device().tag() + 1;
+		if (exists(name) && slot->first_option() != NULL)
+		{
+			astring defvalue;
+			slot->get_default_card_software(defvalue);
+			if (defvalue.len() > 0)
+			{
+				set_default_value(name, defvalue);
+				const device_slot_option *option = slot->option(defvalue);
+				set_flag(name, ~OPTION_FLAG_INTERNAL, (option != NULL && !option->selectable()) ? OPTION_FLAG_INTERNAL : 0);
 			}
 		}
 	}
 }
+
+
 //-------------------------------------------------
 //  add_device_options - add all of the device
 //  options for the configured system
 //-------------------------------------------------
 
-void emu_options::add_device_options(bool isfirst)
+void emu_options::add_device_options(bool isfirstpass)
 {
 	// look up the system configured by name; if no match, do nothing
 	const game_driver *cursystem = system();
 	if (cursystem == NULL)
 		return;
-
-	// iterate through all slot devices
-	options_entry entry[2] = { { 0 }, { 0 } };
-	bool first = true;
-	// iterate through all image devices
 	machine_config config(*cursystem, *this);
+
+	// iterate through all image devices
+	bool first = true;
 	image_interface_iterator iter(config.root_device());
 	for (const device_image_interface *image = iter.first(); image != NULL; image = iter.next())
 	{
 		// first device? add the header as to be pretty
-		if (first && isfirst)
-		{
-			entry[0].name = NULL;
-			entry[0].description = "IMAGE DEVICES";
-			entry[0].flags = OPTION_HEADER | OPTION_FLAG_DEVICE;
-			entry[0].defvalue = NULL;
-			add_entries(entry);
-		}
+		if (first && isfirstpass)
+			add_entry(NULL, "IMAGE DEVICES", OPTION_HEADER | OPTION_FLAG_DEVICE);
 		first = false;
 
 		// retrieve info about the device instance
 		astring option_name;
 		option_name.printf("%s;%s", image->instance_name(), image->brief_instance_name());
-		if (strcmp(image->device_typename(image->image_type()),image->instance_name())==0){
-			option_name.printf("%s;%s;%s1;%s1", image->instance_name(), image->brief_instance_name(), image->instance_name(), image->brief_instance_name());
-		}
+		if (strcmp(image->device_typename(image->image_type()), image->instance_name()) == 0)
+			option_name.catprintf(";%s1;%s1", image->instance_name(), image->brief_instance_name());
+
 		// add the option
-		if (!exists(image->instance_name())) {
-			entry[0].name = option_name;
-			entry[0].description = NULL;
-			entry[0].flags = OPTION_STRING | OPTION_FLAG_DEVICE;
-			entry[0].defvalue = NULL;
-			add_entries(entry, true);
-		}
+		if (!exists(image->instance_name()))
+			add_entry(option_name, NULL, OPTION_STRING | OPTION_FLAG_DEVICE, NULL, true);
 	}
 }
 
@@ -358,16 +337,21 @@ void emu_options::remove_device_options()
 
 bool emu_options::parse_slot_devices(int argc, char *argv[], astring &error_string, const char *name, const char *value)
 {
-	bool isfirst = true;
+	// an initial parse to capture the initial set of values
 	bool result = core_options::parse_command_line(argc, argv, OPTION_PRIORITY_CMDLINE, error_string);
-	while (add_slot_options(isfirst)) {
+
+	// keep adding slot options until we stop seeing new stuff
+	bool isfirstpass = true;
+	while (add_slot_options(isfirstpass))
+	{
 		result = core_options::parse_command_line(argc, argv, OPTION_PRIORITY_CMDLINE, error_string);
-		isfirst = false;
+		isfirstpass = false;
 	}
+
+	// add device options and reparse
 	add_device_options(true);
-	if (name && exists(name)) {
+	if (name != NULL && exists(name))
 		set_value(name, value, OPTION_PRIORITY_CMDLINE, error_string);
-	}
 	result = core_options::parse_command_line(argc, argv, OPTION_PRIORITY_CMDLINE, error_string);
 
 	int num = 0;
@@ -377,11 +361,12 @@ bool emu_options::parse_slot_devices(int argc, char *argv[], astring &error_stri
 		while (add_slot_options(false));
 		add_device_options(false);
 		result = core_options::parse_command_line(argc, argv, OPTION_PRIORITY_CMDLINE, error_string);
-	} while(num != options_count());
+	} while (num != options_count());
 
 	return result;
 }
 
+
 //-------------------------------------------------
 //  parse_command_line - parse the command line
 //  and update the devices
@@ -389,22 +374,9 @@ bool emu_options::parse_slot_devices(int argc, char *argv[], astring &error_stri
 
 bool emu_options::parse_command_line(int argc, char *argv[], astring &error_string)
 {
-	// remember the original system name
-	astring old_system_name(system_name());
-
 	// parse as normal
-	bool result = core_options::parse_command_line(argc, argv, OPTION_PRIORITY_CMDLINE, error_string);
-
-	// if the system name changed, fix up the device options
-	if (old_system_name != system_name())
-	{
-		// remove any existing device options
-		remove_device_options();
-		result = parse_slot_devices(argc, argv, error_string, NULL, NULL);
-		if (exists(OPTION_RAMSIZE) && old_system_name.len()!=0)
-			set_value(OPTION_RAMSIZE, "", OPTION_PRIORITY_CMDLINE, error_string);
-	}
-	return result;
+	core_options::parse_command_line(argc, argv, OPTION_PRIORITY_CMDLINE, error_string);
+	return parse_slot_devices(argc, argv, error_string, NULL, NULL);
 }
 
 
@@ -438,6 +410,15 @@ void emu_options::parse_standard_inis(astring &error_string)
 	else
 		parse_one_ini("horizont", OPTION_PRIORITY_ORIENTATION_INI, &error_string);
 
+	if (cursystem->flags & GAME_TYPE_ARCADE)
+		parse_one_ini("arcade", OPTION_PRIORITY_SYSTYPE_INI, &error_string);
+	else if (cursystem->flags & GAME_TYPE_CONSOLE)
+		parse_one_ini("console", OPTION_PRIORITY_SYSTYPE_INI, &error_string);
+	else if (cursystem->flags & GAME_TYPE_COMPUTER)
+		parse_one_ini("computer", OPTION_PRIORITY_SYSTYPE_INI, &error_string);
+	else if (cursystem->flags & GAME_TYPE_OTHER)
+		parse_one_ini("othersys", OPTION_PRIORITY_SYSTYPE_INI, &error_string);
+
 	// parse "vector.ini" for vector games
 	{
 		machine_config config(*cursystem, *this);
@@ -502,13 +483,12 @@ void emu_options::set_system_name(const char *name)
 		astring error;
 		set_value(OPTION_SYSTEMNAME, name, OPTION_PRIORITY_CMDLINE, error);
 		assert(!error);
-		// remove any existing device options
-		remove_device_options();
 
-		bool isfirst = true;
-		while (add_slot_options(isfirst)) {
-			isfirst = false;
-		}
+		// remove any existing device options and then add them afresh
+		remove_device_options();
+		if (add_slot_options(true))
+			while (add_slot_options(false)) { }
+
 		// then add the options
 		add_device_options(true);
 		int num = 0;
@@ -550,7 +530,7 @@ bool emu_options::parse_one_ini(const char *basename, int priority, astring *err
 		return false;
 
 	// parse the file
-	mame_printf_verbose("Parsing %s.ini\n", basename);
+	osd_printf_verbose("Parsing %s.ini\n", basename);
 	astring error;
 	bool result = parse_ini_file(file, priority, OPTION_PRIORITY_DRIVER_INI, error);
 
@@ -565,26 +545,25 @@ bool emu_options::parse_one_ini(const char *basename, int priority, astring *err
 const char *emu_options::main_value(astring &buffer, const char *name) const
 {
 	buffer = value(name);
-	int pos = buffer.chr(0,',');
-	if (pos!=-1) {
-		buffer = buffer.substr(0,pos);
-	}
+	int pos = buffer.chr(0, ',');
+	if (pos != -1)
+		buffer = buffer.substr(0, pos);
 	return buffer.cstr();
 }
 
 const char *emu_options::sub_value(astring &buffer, const char *name, const char *subname) const
 {
-	astring tmp = ",";
-	tmp.cat(subname);
-	tmp.cat("=");
+	astring tmp(",", subname, "=");
 	buffer = value(name);
-	int pos = buffer.find(0,tmp);
-	if (pos!=-1) {
-		int endpos = buffer.chr(pos+1,',');
-		if(endpos==-1) endpos = buffer.len();
-		buffer = buffer.substr(pos+tmp.len(),endpos-pos-tmp.len());
-	} else {
-		buffer ="";
+	int pos = buffer.find(0, tmp);
+	if (pos != -1)
+	{
+		int endpos = buffer.chr(pos + 1, ',');
+		if (endpos == -1)
+			endpos = buffer.len();
+		buffer = buffer.substr(pos + tmp.len(), endpos - pos - tmp.len());
 	}
+	else
+		buffer.reset();
 	return buffer.cstr();
 }
