@@ -35,11 +35,18 @@ public:
 	cartslot_image_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
 	virtual ~cartslot_image_device();
 
+	static void static_set_device_load(device_t &device, device_image_load_delegate callback) { downcast<cartslot_image_device &>(device).m_device_image_load = callback; }
+	static void static_set_device_unload(device_t &device, device_image_func_delegate callback) { downcast<cartslot_image_device &>(device).m_device_image_unload = callback; }
+	static void static_set_partialhash(device_t &device, device_image_partialhash_func callback) { downcast<cartslot_image_device &>(device).m_device_image_partialhash = callback; }
+
+	static void static_set_extensions(device_t &device, const char *_extensions) { downcast<cartslot_image_device &>(device).m_extensions = _extensions; }
+	static void static_set_interface(device_t &device, const char *_interface) { downcast<cartslot_image_device &>(device).m_interface = _interface; }
+	static void static_set_must_be_loaded(device_t &device, bool _must_be_loaded) { downcast<cartslot_image_device &>(device).m_must_be_loaded = _must_be_loaded; }
+
 	// image-level overrides
 	virtual bool call_load();
 	virtual void call_unload();
-	virtual void call_display_info() { if (!m_device_image_displayinfo.isnull()) m_device_image_displayinfo(*this); }
-	virtual bool call_softlist_load(char *swlist, char *swname, rom_entry *start_entry) {   load_software_part_region( this, swlist, swname, start_entry ); return TRUE; }
+	virtual bool call_softlist_load(software_list_device &swlist, const char *swname, const rom_entry *start_entry) {   load_software_part_region( *this, swlist, swname, start_entry ); return TRUE; }
 	virtual device_image_partialhash_func get_partial_hash() const { return m_device_image_partialhash; }
 
 	virtual iodevice_t image_type() const { return IO_CARTSLOT; }
@@ -53,14 +60,6 @@ public:
 	virtual const char *file_extensions() const { return m_extensions; }
 	virtual const option_guide *create_option_guide() const { return NULL; }
 
-	void set_extensions(const char *_extensions) { m_extensions = _extensions; }
-	void set_interface(const char *_interface) { m_interface = _interface; }
-	void set_must_be_loaded(bool _must_be_loaded) { m_must_be_loaded = _must_be_loaded; }
-	void set_device_load(device_image_load_delegate _load) { m_device_image_load = _load; }
-	void set_device_unload(device_image_func_delegate _unload) { m_device_image_unload = _unload; }
-	void set_partialhash(device_image_partialhash_func _partialhash) { m_device_image_partialhash = _partialhash; }
-	void set_displayinfo(device_image_func_delegate _displayinfo) { m_device_image_displayinfo = _displayinfo; }
-
 protected:
 	// device-level overrides
 	virtual void device_config_complete();
@@ -76,7 +75,6 @@ protected:
 	device_image_load_delegate      m_device_image_load;
 	device_image_func_delegate      m_device_image_unload;
 	device_image_partialhash_func   m_device_image_partialhash;
-	device_image_func_delegate      m_device_image_displayinfo;
 };
 
 // device type definition
@@ -90,28 +88,26 @@ extern const device_type CARTSLOT;
 	MCFG_DEVICE_ADD(_tag, CARTSLOT, 0)
 #define MCFG_CARTSLOT_MODIFY(_tag)                                      \
 	MCFG_DEVICE_MODIFY(_tag)
+
 #define MCFG_CARTSLOT_EXTENSION_LIST(_extensions)                       \
-	static_cast<cartslot_image_device *>(device)->set_extensions(_extensions);
+	cartslot_image_device::static_set_extensions(*device, _extensions);
 
 #define MCFG_CARTSLOT_INTERFACE(_interface)                         \
-	static_cast<cartslot_image_device *>(device)->set_interface(_interface);
+	cartslot_image_device::static_set_interface(*device, _interface);
 
 #define MCFG_CARTSLOT_NOT_MANDATORY                                     \
-	static_cast<cartslot_image_device *>(device)->set_must_be_loaded(FALSE);
+	cartslot_image_device::static_set_must_be_loaded(*device, FALSE);
 
 #define MCFG_CARTSLOT_MANDATORY                                         \
-	static_cast<cartslot_image_device *>(device)->set_must_be_loaded(TRUE);
+	cartslot_image_device::static_set_must_be_loaded(*device, TRUE);
 
-#define MCFG_CARTSLOT_LOAD(_class,_load)                                \
-	static_cast<cartslot_image_device *>(device)->set_device_load( DEVICE_IMAGE_LOAD_DELEGATE(_class,_load));
+#define MCFG_CARTSLOT_LOAD(_class,_method)                                \
+	cartslot_image_device::static_set_device_load(*device, device_image_load_delegate(&DEVICE_IMAGE_LOAD_NAME(_class,_method), #_class "::device_image_load_" #_method, downcast<_class *>(owner)));
 
-#define MCFG_CARTSLOT_UNLOAD(_class,_unload)                            \
-	static_cast<cartslot_image_device *>(device)->set_device_unload( DEVICE_IMAGE_UNLOAD_DELEGATE(_class,_unload));
+#define MCFG_CARTSLOT_UNLOAD(_class,_method)                            \
+	cartslot_image_device::static_set_device_unload(*device, device_image_func_delegate(&DEVICE_IMAGE_UNLOAD_NAME(_class,_method), #_class "::device_image_unload_" #_method, downcast<_class *>(owner)));
 
 #define MCFG_CARTSLOT_PARTIALHASH(_partialhash)                  \
-	static_cast<cartslot_image_device *>(device)->set_partialhash(_partialhash);
-
-#define MCFG_CARTSLOT_DISPLAY_INFO(_class,_displayinfo)                 \
-	static_cast<cartslot_image_device *>(device)->set_displayinfo(&DEVICE_IMAGE_DISPLAY_INFO_NAME(_class,_displayinfo));
+	cartslot_image_device::static_set_partialhash(*device, _partialhash);
 
 #endif /* __CARTSLOT_H__ */
