@@ -91,7 +91,13 @@ const device_type PC16552D = &device_creator<pc16552_device>;
 
 ins8250_uart_device::ins8250_uart_device(const machine_config &mconfig, device_type type, const char* name, const char *tag, device_t *owner, UINT32 clock, const char *shortname)
 		: device_t(mconfig, type, name, tag, owner, clock, shortname, __FILE__),
-			device_serial_interface(mconfig, *this)
+			device_serial_interface(mconfig, *this),
+			m_out_tx_cb(*this),
+			m_out_dtr_cb(*this),
+			m_out_rts_cb(*this),
+			m_out_int_cb(*this),
+			m_out_out1_cb(*this),
+			m_out_out2_cb(*this)
 {
 }
 
@@ -172,7 +178,7 @@ void ins8250_uart_device::update_interrupt()
 	}
 
 	/* set or clear the int */
-	m_out_int_func(state);
+	m_out_int_cb(state);
 }
 
 /* set pending bit and trigger int */
@@ -239,26 +245,44 @@ WRITE8_MEMBER( ins8250_uart_device::ins8250_w )
 			break;
 		case 3:
 			m_regs.lcr = data;
+
+			{
+			int data_bit_count = (m_regs.lcr & 3) + 5;
+			parity_t parity;
+			stop_bits_t stop_bits;
+
 			switch ((m_regs.lcr>>3) & 7)
 			{
 			case 1:
-				tmp = PARITY_ODD;
+				parity = PARITY_ODD;
 				break;
+
 			case 3:
-				tmp = PARITY_EVEN;
+				parity = PARITY_EVEN;
 				break;
+
 			case 5:
-				tmp = PARITY_MARK;
+				parity = PARITY_MARK;
 				break;
+
 			case 7:
-				tmp = PARITY_SPACE;
+				parity = PARITY_SPACE;
 				break;
+
 			default:
-				tmp = PARITY_NONE;
+				parity = PARITY_NONE;
 				break;
 			}
-			// if 5 data bits and stb = 1, stop bits is supposed to be 1.5
-			set_data_frame((m_regs.lcr & 3) + 5, (m_regs.lcr & 4)?2:1, tmp, false);
+
+			if (!(m_regs.lcr & 4))
+				stop_bits = STOP_BITS_1;
+			else if (data_bit_count == 5)
+				stop_bits = STOP_BITS_1_5;
+			else
+				stop_bits = STOP_BITS_2;
+
+			set_data_frame(1, data_bit_count, parity, stop_bits);
+			}
 			break;
 		case 4:
 			if ( ( m_regs.mcr & 0x1f ) != ( data & 0x1f ) )
@@ -280,10 +304,10 @@ WRITE8_MEMBER( ins8250_uart_device::ins8250_w )
 				}
 				else
 				{
-					m_out_dtr_func(m_regs.mcr & 1);
-					m_out_rts_func(m_regs.mcr & 2);
-					m_out_out1_func(m_regs.mcr & 4);
-					m_out_out2_func(m_regs.mcr & 8);
+					m_out_dtr_cb((m_regs.mcr & 1) ? 1 : 0);
+					m_out_rts_cb((m_regs.mcr & 2) ? 1 : 0);
+					m_out_out1_cb((m_regs.mcr & 4) ? 1 : 0);
+					m_out_out2_cb((m_regs.mcr & 8) ? 1 : 0);
 				}
 			}
 			break;
@@ -458,7 +482,7 @@ void ins8250_uart_device::tra_complete()
 
 void ins8250_uart_device::tra_callback()
 {
-	m_out_tx_func(transmit_register_get_data_bit());
+	m_out_tx_cb(transmit_register_get_data_bit());
 }
 
 void ins8250_uart_device::update_msr(int bit, UINT8 state)
@@ -493,19 +517,20 @@ WRITE_LINE_MEMBER(ins8250_uart_device::cts_w)
 
 void ins8250_uart_device::device_start()
 {
-	m_out_tx_func.resolve(m_out_tx_cb, *this);
-	m_out_dtr_func.resolve(m_out_dtr_cb, *this);
-	m_out_rts_func.resolve(m_out_rts_cb, *this);
-	m_out_int_func.resolve(m_out_int_cb, *this);
-	m_out_out1_func.resolve(m_out_out1_cb, *this);
-	m_out_out2_func.resolve(m_out_out2_cb, *this);
+	m_out_tx_cb.resolve_safe();
+	m_out_dtr_cb.resolve_safe();
+	m_out_rts_cb.resolve_safe();
+	m_out_int_cb.resolve_safe();
+	m_out_out1_cb.resolve_safe();
+	m_out_out2_cb.resolve_safe();
 	set_tra_rate(0);
 	set_rcv_rate(0);
+	memset(&m_regs, 0x00, sizeof(m_regs));
 }
 
 void ins8250_uart_device::device_reset()
 {
-	memset(&m_regs, '\0', sizeof(m_regs));
+	memset(&m_regs, 0x00, sizeof(m_regs));
 	m_regs.ier = 0;
 	m_regs.iir = 1;
 	m_regs.lcr = 0;
@@ -514,29 +539,11 @@ void ins8250_uart_device::device_reset()
 	m_int_pending = 0;
 	receive_register_reset();
 	transmit_register_reset();
-	m_out_rts_func(0);
-	m_out_dtr_func(0);
-	m_out_out1_func(0);
-	m_out_out2_func(0);
-	m_out_tx_func(1);
-}
-
-void ins8250_uart_device::device_config_complete()
-{
-	const ins8250_interface *intf = reinterpret_cast<const ins8250_interface *>(static_config());
-	if(intf != NULL)
-	{
-		*static_cast<ins8250_interface *>(this) = *intf;
-	}
-	else
-	{
-		memset(&m_out_tx_cb, 0, sizeof(m_out_tx_cb));
-		memset(&m_out_dtr_cb, 0, sizeof(m_out_dtr_cb));
-		memset(&m_out_rts_cb, 0, sizeof(m_out_rts_cb));
-		memset(&m_out_int_cb, 0, sizeof(m_out_int_cb));
-		memset(&m_out_out1_cb, 0, sizeof(m_out_out1_cb));
-		memset(&m_out_out2_cb, 0, sizeof(m_out_out2_cb));
-	}
+	m_out_rts_cb(0);
+	m_out_dtr_cb(0);
+	m_out_out1_cb(0);
+	m_out_out2_cb(0);
+	m_out_tx_cb(1);
 }
 
 void ins8250_uart_device::device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr)
