@@ -82,9 +82,10 @@ const device_type ATMEL_29C010 = &device_creator<atmel_29c010_device>;
 const device_type AMD_29F010 = &device_creator<amd_29f010_device>;
 const device_type AMD_29F040 = &device_creator<amd_29f040_device>;
 const device_type AMD_29F080 = &device_creator<amd_29f080_device>;
+const device_type AMD_29LV200T = &device_creator<amd_29lv200t_device>;
 const device_type FUJITSU_29F016A = &device_creator<fujitsu_29f016a_device>;
 const device_type FUJITSU_29DL16X = &device_creator<fujitsu_29dl16x_device>;
-const device_type INTEL_E28F400 = &device_creator<intel_e28f400_device>;
+const device_type INTEL_E28F400B = &device_creator<intel_e28f400b_device>;
 const device_type MACRONIX_29L001MC = &device_creator<macronix_29l001mc_device>;
 const device_type MACRONIX_29LV160TMC = &device_creator<macronix_29lv160tmc_device>;
 
@@ -210,6 +211,13 @@ intelfsh_device::intelfsh_device(const machine_config &mconfig, device_type type
 		m_device_id = 0xd5;
 		map = ADDRESS_MAP_NAME( memory_map8_8Mb );
 		break;
+	case FLASH_AMD_29LV200T:
+		m_bits = 8;
+		m_size = 0x40000;
+		m_maker_id = MFG_AMD;
+		m_device_id = 0x3b;
+		map = ADDRESS_MAP_NAME( memory_map8_2Mb );
+		break;
 	case FLASH_INTEL_28F320J3D:
 		m_bits = 16;
 		m_size = 0x400000;
@@ -235,13 +243,19 @@ intelfsh_device::intelfsh_device(const machine_config &mconfig, device_type type
 		map = ADDRESS_MAP_NAME( memory_map16_4Mb );
 		break;
 	case FLASH_SHARP_LH28F400:
-	case FLASH_INTEL_E28F400:
 		m_bits = 16;
 		m_size = 0x80000;
 		m_maker_id = MFG_SHARP;
 		m_device_id = 0xed;
 		map = ADDRESS_MAP_NAME( memory_map16_4Mb );
 		break;
+	case FLASH_INTEL_E28F400B:
+		m_bits = 16;
+		m_size = 0x80000;
+		m_maker_id = MFG_INTEL;
+		m_device_id = 0x4471;
+		map = ADDRESS_MAP_NAME( memory_map16_4Mb );
+		break;
 	case FLASH_FUJITSU_29F016A:
 		m_bits = 8;
 		m_size = 0x200000;
@@ -356,6 +370,9 @@ amd_29f040_device::amd_29f040_device(const machine_config &mconfig, const char *
 amd_29f080_device::amd_29f080_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
 	: intelfsh8_device(mconfig, AMD_29F080, "AMD 29F080 Flash", tag, owner, clock, FLASH_AMD_29F080, "amd_29f080", __FILE__) { }
 
+amd_29lv200t_device::amd_29lv200t_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh8_device(mconfig, AMD_29LV200T, "AMD 29LV200T Flash", tag, owner, clock, FLASH_AMD_29LV200T, "amd_29lv200t", __FILE__) { }
+
 intel_e28f008sa_device::intel_e28f008sa_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
 	: intelfsh8_device(mconfig, INTEL_E28F008SA, "Intel E28F008SA Flash", tag, owner, clock, FLASH_INTEL_E28F008SA, "intel_e28f008sa", __FILE__) { }
 
@@ -383,8 +400,8 @@ sharp_lh28f400_device::sharp_lh28f400_device(const machine_config &mconfig, cons
 intel_te28f160_device::intel_te28f160_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
 	: intelfsh16_device(mconfig, INTEL_TE28F160, "Intel TE28F160 Flash", tag, owner, clock, FLASH_INTEL_TE28F160, "intel_te28f160", __FILE__) { }
 
-intel_e28f400_device::intel_e28f400_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: intelfsh16_device(mconfig, INTEL_E28F400, "Intel E28F400 Flash", tag, owner, clock, FLASH_INTEL_E28F400, "intel_e28f400", __FILE__) { }
+intel_e28f400b_device::intel_e28f400b_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: intelfsh16_device(mconfig, INTEL_E28F400B, "Intel E28F400B Flash", tag, owner, clock, FLASH_INTEL_E28F400B, "intel_e28f400b", __FILE__) { }
 
 sharp_unk128mbit_device::sharp_unk128mbit_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
 	: intelfsh16_device(mconfig, SHARP_UNK128MBIT, "Sharp Unknown 128Mbit Flash", tag, owner, clock, FLASH_SHARP_UNK128MBIT, "sharp_unk128mbit", __FILE__) { }
@@ -479,11 +496,10 @@ void intelfsh_device::nvram_default()
 
 void intelfsh_device::nvram_read(emu_file &file)
 {
-	UINT8 *buffer = global_alloc_array(UINT8, m_size);
+	dynamic_buffer buffer(m_size);
 	file.read(buffer, m_size);
 	for (int byte = 0; byte < m_size; byte++)
 		m_addrspace[0]->write_byte(byte, buffer[byte]);
-	global_free(buffer);
 }
 
 
@@ -494,11 +510,10 @@ void intelfsh_device::nvram_read(emu_file &file)
 
 void intelfsh_device::nvram_write(emu_file &file)
 {
-	UINT8 *buffer = global_alloc_array(UINT8, m_size);
+	dynamic_buffer buffer(m_size);
 	for (int byte = 0; byte < m_size; byte++)
 		buffer[byte] = m_addrspace[0]->read_byte(byte);
 	file.write(buffer, m_size);
-	global_free(buffer);
 }
 
 
@@ -533,9 +548,10 @@ UINT32 intelfsh_device::read_full(UINT32 address)
 		data = m_status;
 		break;
 	case FM_READAMDID3:
-		if (m_maker_id == MFG_FUJITSU && m_device_id == 0x35)
+		if ((m_maker_id == MFG_FUJITSU && m_device_id == 0x35) || (m_maker_id == MFG_AMD && m_device_id == 0x3b))
 		{
-			//used in Fujitsu 29DL16X 8bits mode
+			// used in Fujitsu 29DL16X 8bits mode
+			// used in AMD 29LV200 8bits mode
 			switch (address)
 			{
 				case 0: data = m_maker_id; break;
@@ -952,6 +968,49 @@ void intelfsh_device::write_full(UINT32 address, UINT32 data)
 
 				m_timer->adjust( attotime::from_msec( 4 ) );
 			}
+			else if (m_type == FLASH_INTEL_E28F400B)
+			{
+				// 00000-03fff -  16KB boot block (may be write protected via external pins)
+				// 04000-05fff -   8KB parameter block
+				// 06000-07fff -   8KB parameter block
+				// 08000-1ffff -  96KB main block
+				// 20000-3ffff - 128KB main block
+				// 40000-5ffff - 128KB main block
+				// 60000-7ffff - 128KB main block
+				// erase duration is 0.3s for boot and parameter blocks, and 0.6s for main blocks
+				UINT32 base = (address & 0x3ffff) * 2;
+				int size, duration;
+				if (base < 0x4000)
+				{
+					base = 0;
+					size = 0x4000;
+					duration = 300;
+				}
+				else if (base < 0x8000)
+				{
+					base &= 0x6000;
+					size = 0x2000;
+					duration = 300;
+				}
+				else if (base < 0x20000)
+				{
+					base = 0x8000;
+					size = 0x18000;
+					duration = 600;
+				}
+				else
+				{
+					base &= 0x60000;
+					size = 0x20000;
+					duration = 600;
+				}
+
+				// clear the block containing the current address to all 0xffffs
+				for (offs_t offs = 0; offs < size / 2; offs += 2)
+					m_addrspace[0]->write_word(base | offs, 0xffff);
+
+				m_timer->adjust( attotime::from_msec( duration ) );
+			}
 			else
 			{
 				// clear the 64k block containing the current address to all 0xffs
