@@ -52,15 +52,6 @@ enum
 #define MODE_STOP_BITS      ((m_mr[0] >> 6) & 0x03)
 
 
-enum
-{
-	STOP_BITS_INVALID = 0,
-	STOP_BITS_1,
-	STOP_BITS_1_5,
-	STOP_BITS_2
-};
-
-
 #define SYN1            m_sync[0]
 #define SYN2            m_sync[1]
 #define DLE             m_sync[2]
@@ -106,41 +97,24 @@ enum
 //  mc2661_device - constructor
 //-------------------------------------------------
 
-mc2661_device::mc2661_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: device_t(mconfig, MC2661, "MC2661", tag, owner, clock, "mc2661", __FILE__),
-		device_serial_interface(mconfig, *this)
+mc2661_device::mc2661_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock) :
+	device_t(mconfig, MC2661, "MC2661", tag, owner, clock, "mc2661", __FILE__),
+	device_serial_interface(mconfig, *this),
+	m_write_txd(*this),
+	m_write_rxrdy(*this),
+	m_write_txrdy(*this),
+	m_write_rts(*this),
+	m_write_dtr(*this),
+	m_write_txemt_dschg(*this),
+	m_write_bkdet(*this),
+	m_write_xsync(*this),
+	m_rxc(0),
+	m_txc(0),
+	m_sr(0)
 {
 }
 
 
-//-------------------------------------------------
-//  device_config_complete - perform any
-//  operations now that the configuration is
-//  complete
-//-------------------------------------------------
-
-void mc2661_device::device_config_complete()
-{
-	// inherit a copy of the static data
-	const mc2661_interface *intf = reinterpret_cast<const mc2661_interface *>(static_config());
-	if (intf != NULL)
-		*static_cast<mc2661_interface *>(this) = *intf;
-
-	// or initialize to defaults if none provided
-	else
-	{
-		memset(&m_out_txd_cb, 0, sizeof(m_out_txd_cb));
-		memset(&m_out_rxrdy_cb, 0, sizeof(m_out_rxrdy_cb));
-		memset(&m_out_txrdy_cb, 0, sizeof(m_out_txrdy_cb));
-		memset(&m_out_rts_cb, 0, sizeof(m_out_rts_cb));
-		memset(&m_out_dtr_cb, 0, sizeof(m_out_dtr_cb));
-		memset(&m_out_txemt_dschg_cb, 0, sizeof(m_out_txemt_dschg_cb));
-		memset(&m_out_bkdet_cb, 0, sizeof(m_out_bkdet_cb));
-		memset(&m_out_xsync_cb, 0, sizeof(m_out_xsync_cb));
-	}
-}
-
-
 //-------------------------------------------------
 //  device_start - device-specific startup
 //-------------------------------------------------
@@ -148,14 +122,14 @@ void mc2661_device::device_config_complete()
 void mc2661_device::device_start()
 {
 	// resolve callbacks
-	m_out_txd_func.resolve(m_out_txd_cb, *this);
-	m_out_rxrdy_func.resolve(m_out_rxrdy_cb, *this);
-	m_out_txrdy_func.resolve(m_out_txrdy_cb, *this);
-	m_out_rts_func.resolve(m_out_rts_cb, *this);
-	m_out_dtr_func.resolve(m_out_dtr_cb, *this);
-	m_out_txemt_dschg_func.resolve(m_out_txemt_dschg_cb, *this);
-	m_out_bkdet_func.resolve(m_out_bkdet_cb, *this);
-	m_out_xsync_func.resolve(m_out_xsync_cb, *this);
+	m_write_txd.resolve_safe();
+	m_write_rxrdy.resolve_safe();
+	m_write_txrdy.resolve_safe();
+	m_write_rts.resolve_safe();
+	m_write_dtr.resolve_safe();
+	m_write_txemt_dschg.resolve_safe();
+	m_write_bkdet.resolve_safe();
+	m_write_xsync.resolve_safe();
 
 	// create the timers
 	if (m_rxc > 0)
@@ -196,16 +170,15 @@ void mc2661_device::device_reset()
 
 	m_mode_index = 0;
 	m_sync_index = 0;
-	m_signal = 0;
 
-	m_out_txd_func(1);
-	m_out_rxrdy_func(CLEAR_LINE);
-	m_out_txrdy_func(CLEAR_LINE);
-	m_out_rts_func(1);
-	m_out_dtr_func(1);
-	m_out_txemt_dschg_func(CLEAR_LINE);
-	m_out_bkdet_func(0);
-	m_out_xsync_func(0);
+	m_write_txd(1);
+	m_write_rxrdy(CLEAR_LINE);
+	m_write_txrdy(CLEAR_LINE);
+	m_write_rts(1);
+	m_write_dtr(1);
+	m_write_txemt_dschg(CLEAR_LINE);
+	m_write_bkdet(0);
+	m_write_xsync(0);
 }
 
 
@@ -215,10 +188,7 @@ void mc2661_device::device_reset()
 
 void mc2661_device::tra_callback()
 {
-	if (m_out_txd_func.isnull())
-		transmit_register_send_bit();
-	else
-		m_out_txd_func(transmit_register_get_data_bit());
+	m_write_txd(transmit_register_get_data_bit());
 }
 
 
@@ -230,17 +200,7 @@ void mc2661_device::tra_complete()
 {
 	// TODO
 	m_sr |= STATUS_TXRDY;
-	m_out_txrdy_func(ASSERT_LINE);
-}
-
-
-//-------------------------------------------------
-//  rcv_callback -
-//-------------------------------------------------
-
-void mc2661_device::rcv_callback()
-{
-	receive_register_update_bit(m_signal);
+	m_write_txrdy(ASSERT_LINE);
 }
 
 
@@ -254,17 +214,7 @@ void mc2661_device::rcv_complete()
 	receive_register_extract();
 	m_rhr = get_received_char();
 	m_sr |= STATUS_RXRDY;
-	m_out_rxrdy_func(ASSERT_LINE);
-}
-
-
-//-------------------------------------------------
-//  input_callback -
-//-------------------------------------------------
-
-void mc2661_device::input_callback(UINT8 state)
-{
-	m_input_state = state;
+	m_write_rxrdy(ASSERT_LINE);
 }
 
 
@@ -281,7 +231,7 @@ READ8_MEMBER( mc2661_device::read )
 	case REGISTER_HOLDING:
 		data = m_rhr;
 		m_sr &= ~STATUS_RXRDY;
-		m_out_rxrdy_func(CLEAR_LINE);
+		m_write_rxrdy(CLEAR_LINE);
 		break;
 
 	case REGISTER_STATUS:
@@ -325,7 +275,7 @@ WRITE8_MEMBER( mc2661_device::write )
 			if(COMMAND_MODE != 0x02)
 				transmit_register_setup(m_thr);
 			m_sr &= ~STATUS_TXRDY;
-			m_out_txrdy_func(CLEAR_LINE);
+			m_write_txrdy(CLEAR_LINE);
 		}
 		if(COMMAND_MODE == 0x02)  // loopback - the Wicat will set this after enabling the transmitter
 			m_rhr = data;
@@ -347,22 +297,36 @@ WRITE8_MEMBER( mc2661_device::write )
 
 		if (m_mode_index == 0)
 		{
-			int word_length = 5 + MODE_CHARACTER;
-			float stop_bits = 0;
-			int parity_code;
+			int data_bit_count = 5 + MODE_CHARACTER;
+			parity_t parity;
+
+			if (!MODE_PARITY) parity = PARITY_NONE;
+			else if (MODE_PARITY_EVEN) parity = PARITY_EVEN;
+			else parity = PARITY_ODD;
+
+			stop_bits_t stop_bits;
 
 			switch (MODE_STOP_BITS)
 			{
-			case STOP_BITS_1:   stop_bits = 1;      break;
-			case STOP_BITS_1_5: stop_bits = 1.5;    break;
-			case STOP_BITS_2:   stop_bits = 2;      break;
+			case 0:
+			default:
+				stop_bits = STOP_BITS_0;
+				break;
+
+			case 1:
+				stop_bits = STOP_BITS_1;
+				break;
+
+			case 2:
+				stop_bits = STOP_BITS_1_5;
+				break;
+
+			case 3:
+				stop_bits = STOP_BITS_2;
+				break;
 			}
 
-			if (!MODE_PARITY) parity_code = PARITY_NONE;
-			else if (MODE_PARITY_EVEN) parity_code = PARITY_EVEN;
-			else parity_code = PARITY_ODD;
-
-			set_data_frame(word_length, stop_bits, parity_code, false);
+			set_data_frame(1, data_bit_count, parity, stop_bits);
 		}
 		if(m_mode_index == 1)
 		{
@@ -422,8 +386,8 @@ WRITE8_MEMBER( mc2661_device::write )
 
 		m_cr = data & 0xef;
 
-		m_out_dtr_func(!COMMAND_DTR);
-		m_out_rts_func(!COMMAND_RTS);
+		m_write_dtr(!COMMAND_DTR);
+		m_write_rts(!COMMAND_RTS);
 
 		if (COMMAND_MODE == 0x02)  // local loopback
 		{
@@ -432,7 +396,7 @@ WRITE8_MEMBER( mc2661_device::write )
 				// probably much more to it that this, but this is enough for the Wicat to be happy
 				m_rhr = m_thr;
 				m_sr |= STATUS_RXRDY;
-				m_out_rxrdy_func(ASSERT_LINE);
+				m_write_rxrdy(ASSERT_LINE);
 				return;
 			}
 		}
@@ -440,17 +404,17 @@ WRITE8_MEMBER( mc2661_device::write )
 		if (COMMAND_TXEN)
 		{
 			m_sr |= STATUS_TXRDY;
-			m_out_txrdy_func(ASSERT_LINE);
+			m_write_txrdy(ASSERT_LINE);
 		}
 		else
 		{
 			m_sr &= ~STATUS_TXRDY;
-			m_out_txrdy_func(CLEAR_LINE);
+			m_write_txrdy(CLEAR_LINE);
 		}
 		if (!COMMAND_RXEN)
 		{
 			m_sr &= ~STATUS_RXRDY;
-			m_out_rxrdy_func(CLEAR_LINE);
+			m_write_rxrdy(CLEAR_LINE);
 		}
 		if (COMMAND_RESET)
 		{
