@@ -131,7 +131,7 @@ const device_type MOS5710 = &device_creator<mos5710_device>;
 
 inline void mos6526_device::update_pa()
 {
-	UINT8 pa = m_pra | ~m_ddra;
+	UINT8 pa = m_pra | (m_pa_in & ~m_ddra);
 
 	if (m_pa != pa)
 	{
@@ -147,7 +147,7 @@ inline void mos6526_device::update_pa()
 
 inline void mos6526_device::update_pb()
 {
-	UINT8 pb = m_prb | ~m_ddrb;
+	UINT8 pb = m_prb | (m_pb_in & ~m_ddrb);
 
 	if (CRA_PBON)
 	{
@@ -184,6 +184,14 @@ inline void mos6526_device::set_cra(UINT8 data)
 		m_ta_pb6 = 1;
 	}
 
+	// switching to serial output mode with a one-shot timer causes a pulse?
+	if (!CRA_SPMODE && BIT(data, 6) && CRA_RUNMODE)
+		m_write_sp(1);
+
+	// lower sp again when switching back to input?
+	if (CRA_SPMODE && !BIT(data, 6) && CRA_RUNMODE)
+		m_write_sp(0);
+
 	m_cra = data;
 	update_pb();
 }
@@ -329,20 +337,17 @@ inline void mos6526_device::write_tod(int offset, UINT8 data)
 
 inline void mos6526_device::serial_input()
 {
-	if (m_count_a0 && !CRA_SPMODE)
+	m_shift <<= 1;
+	m_bits++;
+
+	m_shift |= m_sp;
+
+	if (m_bits == 8)
 	{
-		m_shift <<= 1;
-		m_bits++;
+		m_sdr = m_shift;
+		m_bits = 0;
 
-		m_shift |= m_sp;
-
-		if (m_bits == 8)
-		{
-			m_sdr = m_shift;
-			m_bits = 0;
-
-			m_icr |= ICR_SP;
-		}
+		m_icr |= ICR_SP;
 	}
 }
 
@@ -494,16 +499,8 @@ inline void mos6526_device::clock_pipeline()
 	// timer A pipeline
 	m_count_a3 = m_count_a2;
 
-	switch (CRA_INMODE)
-	{
-	case CRA_INMODE_PHI2:
+	if (CRA_INMODE == CRA_INMODE_PHI2)
 		m_count_a2 = 1;
-		break;
-
-	case CRA_INMODE_CNT:
-		m_count_a2 = m_count_a1;
-		break;
-	}
 
 	m_count_a2 &= CRA_STARTED;
 	m_count_a1 = m_count_a0;
@@ -525,10 +522,6 @@ inline void mos6526_device::clock_pipeline()
 		m_count_b2 = 1;
 		break;
 
-	case CRB_INMODE_CNT:
-		m_count_b2 = m_count_b1;
-		break;
-
 	case CRB_INMODE_TA:
 		m_count_b2 = m_ta_out;
 		break;
@@ -567,8 +560,6 @@ inline void mos6526_device::synchronize()
 		m_write_pc(m_pc);
 	}
 
-	serial_input();
-
 	clock_ta();
 
 	serial_output();
@@ -597,6 +588,7 @@ mos6526_device::mos6526_device(const machine_config &mconfig, device_type type,
 		device_execute_interface(mconfig, *this),
 		m_icount(0),
 		m_variant(variant),
+		m_tod_clock(0),
 		m_write_irq(*this),
 		m_write_pc(*this),
 		m_write_cnt(*this),
@@ -613,6 +605,7 @@ mos6526_device::mos6526_device(const machine_config &mconfig, const char *tag, d
 		device_execute_interface(mconfig, *this),
 		m_icount(0),
 		m_variant(TYPE_6526),
+		m_tod_clock(0),
 		m_write_irq(*this),
 		m_write_pc(*this),
 		m_write_cnt(*this),
@@ -722,6 +715,8 @@ void mos6526_device::device_reset()
 	m_ddrb = 0;
 	m_pa = 0xff;
 	m_pb = 0xff;
+	m_pa_in = 0;
+	m_pb_in = 0;
 
 	m_sp = 1;
 	m_cnt = 1;
@@ -777,15 +772,8 @@ void mos6526_device::device_reset()
 
 void mos6526_device::device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr)
 {
-	if (!m_tod_stopped)
-	{
-		clock_tod();
-
-		if (m_tod == m_alarm)
-		{
-			m_icr |= ICR_ALARM;
-		}
-	}
+	tod_w(1);
+	tod_w(0);
 }
 
 
@@ -810,16 +798,21 @@ void mos6526_device::execute_run()
 
 READ8_MEMBER( mos6526_device::read )
 {
+	if (space.debugger_access())
+		return 0xff;
+
 	UINT8 data = 0;
 
-	switch (offset)
+	switch (offset & 0x0f)
 	{
 	case PRA:
 		data = (m_read_pa(0) & ~m_ddra) | (m_pra & m_ddra);
+		m_pa_in = data;
 		break;
 
 	case PRB:
 		data = (m_read_pb(0) & ~m_ddrb) | (m_prb & m_ddrb);
+		m_pb_in = data;
 
 		if (CRA_PBON)
 		{
@@ -921,7 +914,7 @@ READ8_MEMBER( mos8520_device::read )
 {
 	UINT8 data = 0;
 
-	switch (offset)
+	switch (offset & 0x0f)
 	{
 	case TOD_MIN:
 		if (!m_tod_latched)
@@ -950,7 +943,7 @@ READ8_MEMBER( mos8520_device::read )
 
 WRITE8_MEMBER( mos6526_device::write )
 {
-	switch (offset)
+	switch (offset & 0x0f)
 	{
 	case PRA:
 		m_pra = data;
@@ -992,6 +985,12 @@ WRITE8_MEMBER( mos6526_device::write )
 			m_load_a0 = 1;
 		}
 
+		if (CRA_RUNMODE)
+		{
+			m_ta = m_ta_latch;
+			set_cra(m_cra | CRA_START);
+		}
+
 		if (m_load_a2)
 		{
 			m_ta = (data << 8) | (m_ta & 0xff);
@@ -1015,6 +1014,12 @@ WRITE8_MEMBER( mos6526_device::write )
 			m_load_b0 = 1;
 		}
 
+		if (CRB_RUNMODE)
+		{
+			m_tb = m_tb_latch;
+			set_crb(m_crb | CRB_START);
+		}
+
 		if (m_load_b2)
 		{
 			m_tb = (data << 8) | (m_tb & 0xff);
@@ -1080,7 +1085,7 @@ WRITE8_MEMBER( mos6526_device::write )
 
 WRITE8_MEMBER( mos8520_device::write )
 {
-	switch (offset)
+	switch (offset & 0x0f)
 	{
 	default:
 		mos6526_device::write(space, offset, data);
@@ -1098,46 +1103,6 @@ WRITE8_MEMBER( mos8520_device::write )
 }
 
 
-//-------------------------------------------------
-//  pa_r - port A read
-//-------------------------------------------------
-
-UINT8 mos6526_device::pa_r()
-{
-	return m_pa;
-}
-
-READ8_MEMBER( mos6526_device::pa_r )
-{
-	return pa_r();
-}
-
-
-//-------------------------------------------------
-//  pb_r - port B read
-//-------------------------------------------------
-
-UINT8 mos6526_device::pb_r()
-{
-	return m_pb;
-}
-
-READ8_MEMBER( mos6526_device::pb_r )
-{
-	return pb_r();
-}
-
-
-//-------------------------------------------------
-//  sp_r - serial port read
-//-------------------------------------------------
-
-READ_LINE_MEMBER( mos6526_device::sp_r )
-{
-	return m_sp;
-}
-
-
 //-------------------------------------------------
 //  sp_w - serial port write
 //-------------------------------------------------
@@ -1148,16 +1113,6 @@ WRITE_LINE_MEMBER( mos6526_device::sp_w )
 }
 
 
-//-------------------------------------------------
-//  cnt_r - serial counter read
-//-------------------------------------------------
-
-READ_LINE_MEMBER( mos6526_device::cnt_r )
-{
-	return m_cnt;
-}
-
-
 //-------------------------------------------------
 //  cnt_w - serial counter write
 //-------------------------------------------------
@@ -1168,8 +1123,13 @@ WRITE_LINE_MEMBER( mos6526_device::cnt_w )
 
 	if (!m_cnt && state)
 	{
-		m_count_a0 = 1;
-		m_count_b0 = 1;
+		serial_input();
+
+		if (CRA_INMODE == CRA_INMODE_CNT)
+			m_ta--;
+
+		if (CRB_INMODE == CRB_INMODE_CNT)
+			m_tb--;
 	}
 
 	m_cnt = state;
@@ -1189,3 +1149,21 @@ WRITE_LINE_MEMBER( mos6526_device::flag_w )
 
 	m_flag = state;
 }
+
+
+//-------------------------------------------------
+//  tod_w - time-of-day clock write
+//-------------------------------------------------
+
+WRITE_LINE_MEMBER( mos6526_device::tod_w )
+{
+	if (state && !m_tod_stopped)
+	{
+		clock_tod();
+
+		if (m_tod == m_alarm)
+		{
+			m_icr |= ICR_ALARM;
+		}
+	}
+}
