@@ -204,7 +204,7 @@ void saturn_state::cd_exec_command( void )
 					break;
 
 				default:
-					mame_printf_error("CD: Unknown request to Get Session Info %x\n", cr1 & 0xff);
+					osd_printf_error("CD: Unknown request to Get Session Info %x\n", cr1 & 0xff);
 					cr1 = cd_stat;
 					cr2 = 0;
 					cr3 = 0;
@@ -1429,9 +1429,7 @@ void saturn_state::stvcd_reset( void )
 	cd_stat |= CD_STAT_PERI;
 	cur_track = 0xff;
 
-	if (curdir != (direntryT *)NULL)
-		auto_free(machine(), curdir);
-	curdir = (direntryT *)NULL;     // no directory yet
+	curdir.reset();
 
 	xfertype = XFERTYPE_INVALID;
 	xfertype32 = XFERTYPE32_INVALID;
@@ -1993,7 +1991,7 @@ READ32_MEMBER( saturn_state::stvcd_r )
 			}
 			else
 			{
-				mame_printf_error("CD: Unknown data buffer read @ mask = %08x\n", mem_mask);
+				osd_printf_error("CD: Unknown data buffer read @ mask = %08x\n", mem_mask);
 			}
 
 			break;
@@ -2117,7 +2115,7 @@ void saturn_state::read_new_dir(UINT32 fileno)
 			// easy to fix, but make sure we *need* to first
 			if (curroot.length > MAX_DIR_SIZE)
 			{
-				mame_printf_error("ERROR: root directory too big (%d)\n", curroot.length);
+				osd_printf_error("ERROR: root directory too big (%d)\n", curroot.length);
 			}
 
 			// done with all that, read the root directory now
@@ -2128,7 +2126,7 @@ void saturn_state::read_new_dir(UINT32 fileno)
 	{
 		if (curdir[fileno].length > MAX_DIR_SIZE)
 		{
-			mame_printf_error("ERROR: new directory too big (%d)!\n", curdir[fileno].length);
+			osd_printf_error("ERROR: new directory too big (%d)!\n", curdir[fileno].length);
 		}
 		make_dir_current(curdir[fileno].firstfad);
 	}
@@ -2139,10 +2137,9 @@ void saturn_state::make_dir_current(UINT32 fad)
 {
 	int i;
 	UINT32 nextent, numentries;
-	UINT8 *sect;
+	dynamic_buffer sect(MAX_DIR_SIZE);
 	direntryT *curentry;
 
-	sect = (UINT8 *)malloc(MAX_DIR_SIZE);
 	memset(sect, 0, MAX_DIR_SIZE);
 	if(sectlenin != 2048)
 		popmessage("Sector Length %d, contact MAMEdev (1)",sectlenin);
@@ -2167,12 +2164,7 @@ void saturn_state::make_dir_current(UINT32 fad)
 		}
 	}
 
-	if (curdir != (direntryT *)NULL)
-	{
-		auto_free(machine(), curdir);
-	}
-
-	curdir = auto_alloc_array(machine(), direntryT, numentries);
+	curdir.resize(numentries);
 	curentry = curdir;
 	numfiles = numentries;
 
@@ -2237,17 +2229,11 @@ void saturn_state::make_dir_current(UINT32 fad)
 			i = numfiles;
 		}
 	}
-
-	free(sect);
 }
 
 void saturn_state::stvcd_exit( void )
 {
-	if (curdir != (direntryT *)NULL)
-	{
-		auto_free(machine(), curdir);
-		curdir = (direntryT *)NULL;
-	}
+	curdir.reset();
 
 	if (cdrom)
 	{
