@@ -22,7 +22,6 @@
 
     TODO:
 
-    - devcb2
     - i8274 DMA scheme
     - break detection
     - wr0 reset tx interrupt pending
@@ -95,6 +94,25 @@ z80dart_device::z80dart_device(const machine_config &mconfig, device_type type,
 		device_z80daisy_interface(mconfig, *this),
 		m_chanA(*this, CHANA_TAG),
 		m_chanB(*this, CHANB_TAG),
+		m_rxca(0),
+		m_txca(0),
+		m_rxcb(0),
+		m_txcb(0),
+		m_out_txda_cb(*this),
+		m_out_dtra_cb(*this),
+		m_out_rtsa_cb(*this),
+		m_out_wrdya_cb(*this),
+		m_out_synca_cb(*this),
+		m_out_txdb_cb(*this),
+		m_out_dtrb_cb(*this),
+		m_out_rtsb_cb(*this),
+		m_out_wrdyb_cb(*this),
+		m_out_syncb_cb(*this),
+		m_out_int_cb(*this),
+		m_out_rxdrqa_cb(*this),
+		m_out_txdrqa_cb(*this),
+		m_out_rxdrqb_cb(*this),
+		m_out_txdrqb_cb(*this),
 		m_variant(variant)
 {
 	for (int i = 0; i < 8; i++)
@@ -106,6 +124,25 @@ z80dart_device::z80dart_device(const machine_config &mconfig, const char *tag, d
 		device_z80daisy_interface(mconfig, *this),
 		m_chanA(*this, CHANA_TAG),
 		m_chanB(*this, CHANB_TAG),
+		m_rxca(0),
+		m_txca(0),
+		m_rxcb(0),
+		m_txcb(0),
+		m_out_txda_cb(*this),
+		m_out_dtra_cb(*this),
+		m_out_rtsa_cb(*this),
+		m_out_wrdya_cb(*this),
+		m_out_synca_cb(*this),
+		m_out_txdb_cb(*this),
+		m_out_dtrb_cb(*this),
+		m_out_rtsb_cb(*this),
+		m_out_wrdyb_cb(*this),
+		m_out_syncb_cb(*this),
+		m_out_int_cb(*this),
+		m_out_rxdrqa_cb(*this),
+		m_out_txdrqa_cb(*this),
+		m_out_rxdrqb_cb(*this),
+		m_out_txdrqb_cb(*this),
 		m_variant(TYPE_DART)
 {
 	for (int i = 0; i < 8; i++)
@@ -148,43 +185,6 @@ upd7201_device::upd7201_device(const machine_config &mconfig, const char *tag, d
 }
 
 
-//-------------------------------------------------
-//  device_config_complete - perform any
-//  operations now that the configuration is
-//  complete
-//-------------------------------------------------
-
-void z80dart_device::device_config_complete()
-{
-	// inherit a copy of the static data
-	const z80dart_interface *intf = reinterpret_cast<const z80dart_interface *>(static_config());
-	if (intf != NULL)
-		*static_cast<z80dart_interface *>(this) = *intf;
-
-	// or initialize to defaults if none provided
-	else
-	{
-		m_rxca = m_txca = m_rxcb = m_txcb = 0;
-
-		memset(&m_out_txda_cb, 0, sizeof(m_out_txda_cb));
-		memset(&m_out_dtra_cb, 0, sizeof(m_out_dtra_cb));
-		memset(&m_out_rtsa_cb, 0, sizeof(m_out_rtsa_cb));
-		memset(&m_out_wrdya_cb, 0, sizeof(m_out_wrdya_cb));
-		memset(&m_out_synca_cb, 0, sizeof(m_out_synca_cb));
-		memset(&m_out_txdb_cb, 0, sizeof(m_out_txdb_cb));
-		memset(&m_out_dtrb_cb, 0, sizeof(m_out_dtrb_cb));
-		memset(&m_out_rtsb_cb, 0, sizeof(m_out_rtsb_cb));
-		memset(&m_out_wrdyb_cb, 0, sizeof(m_out_wrdyb_cb));
-		memset(&m_out_syncb_cb, 0, sizeof(m_out_syncb_cb));
-		memset(&m_out_int_cb, 0, sizeof(m_out_int_cb));
-		memset(&m_out_rxdrqa_cb, 0, sizeof(m_out_rxdrqa_cb));
-		memset(&m_out_txdrqa_cb, 0, sizeof(m_out_txdrqa_cb));
-		memset(&m_out_rxdrqb_cb, 0, sizeof(m_out_rxdrqb_cb));
-		memset(&m_out_txdrqb_cb, 0, sizeof(m_out_txdrqb_cb));
-	}
-}
-
-
 //-------------------------------------------------
 //  device_start - device-specific startup
 //-------------------------------------------------
@@ -192,32 +192,30 @@ void z80dart_device::device_config_complete()
 void z80dart_device::device_start()
 {
 	// resolve callbacks
-	m_out_int_func.resolve(m_out_int_cb, *this);
+	m_out_txda_cb.resolve_safe();
+	m_out_dtra_cb.resolve_safe();
+	m_out_rtsa_cb.resolve_safe();
+	m_out_wrdya_cb.resolve_safe();
+	m_out_synca_cb.resolve_safe();
+	m_out_txdb_cb.resolve_safe();
+	m_out_dtrb_cb.resolve_safe();
+	m_out_rtsb_cb.resolve_safe();
+	m_out_wrdyb_cb.resolve_safe();
+	m_out_syncb_cb.resolve_safe();
+	m_out_int_cb.resolve_safe();
+	m_out_rxdrqa_cb.resolve_safe();
+	m_out_txdrqa_cb.resolve_safe();
+	m_out_rxdrqb_cb.resolve_safe();
+	m_out_txdrqb_cb.resolve_safe();
 
 	// configure channel A
 	m_chanA->m_rxc = m_rxca;
 	m_chanA->m_txc = m_txca;
 
-	m_chanA->m_out_txd_cb = m_out_txda_cb;
-	m_chanA->m_out_dtr_cb = m_out_dtra_cb;
-	m_chanA->m_out_rts_cb = m_out_rtsa_cb;
-	m_chanA->m_out_wrdy_cb = m_out_wrdya_cb;
-	m_chanA->m_out_sync_cb = m_out_synca_cb;
-	m_chanA->m_out_rxdrq_cb = m_out_rxdrqa_cb;
-	m_chanA->m_out_txdrq_cb = m_out_txdrqa_cb;
-
 	// configure channel B
 	m_chanB->m_rxc = m_rxcb;
 	m_chanB->m_txc = m_txcb;
 
-	m_chanB->m_out_txd_cb = m_out_txdb_cb;
-	m_chanB->m_out_dtr_cb = m_out_dtrb_cb;
-	m_chanB->m_out_rts_cb = m_out_rtsb_cb;
-	m_chanB->m_out_wrdy_cb = m_out_wrdyb_cb;
-	m_chanB->m_out_sync_cb = m_out_syncb_cb;
-	m_chanB->m_out_rxdrq_cb = m_out_rxdrqb_cb;
-	m_chanB->m_out_txdrq_cb = m_out_txdrqb_cb;
-
 	// state saving
 	save_item(NAME(m_int_state));
 }
@@ -333,7 +331,7 @@ void z80dart_device::z80daisy_irq_reti()
 void z80dart_device::check_interrupts()
 {
 	int state = (z80daisy_irq_state() & Z80_DAISY_INT) ? ASSERT_LINE : CLEAR_LINE;
-	m_out_int_func(state);
+	m_out_int_cb(state);
 }
 
 
@@ -359,16 +357,58 @@ void z80dart_device::reset_interrupts()
 void z80dart_device::trigger_interrupt(int index, int state)
 {
 	UINT8 vector = m_chanB->m_wr[2];
-	int priority = (index << 2) | state;
+	int priority;
+
+	if((m_variant == TYPE_I8274) || (m_variant == TYPE_UPD7201))
+	{
+		int prio_level = 0;
+		switch(state)
+		{
+			case z80dart_channel::INT_TRANSMIT:
+				prio_level = 1;
+				break;
+			case z80dart_channel::INT_RECEIVE:
+			case z80dart_channel::INT_SPECIAL:
+				prio_level = 0;
+				break;
+			case z80dart_channel::INT_EXTERNAL:
+				prio_level = 2;
+				break;
+		}
+
+		if(m_chanA->m_wr[2] & z80dart_channel::WR2_PRIORITY)
+		{
+			priority = (prio_level * 2) + index;
+		}
+		else
+		{
+			priority = (prio_level == 2) ? index + 4 : ((index * 2) + prio_level);
+		}
+		if (m_chanB->m_wr[1] & z80dart_channel::WR1_STATUS_VECTOR)
+		{
+			vector = (!index << 2) | state;
+			if((m_chanA->m_wr[1] & 0x18) == z80dart_channel::WR2_MODE_8086_8088)
+			{
+				vector = (m_chanB->m_wr[2] & 0xf8) | vector;
+			}
+			else
+			{
+				vector = (m_chanB->m_wr[2] & 0xe3) | (vector << 2);
+			}
+		}
+	}
+	else
+	{
+		priority = (index << 2) | state;
+		if (m_chanB->m_wr[1] & z80dart_channel::WR1_STATUS_VECTOR)
+		{
+			// status affects vector
+			vector = (m_chanB->m_wr[2] & 0xf1) | (!index << 3) | (state << 1);
+		}
+	}
 
 	LOG(("Z80DART \"%s\" Channel %c : Interrupt Request %u\n", tag(), 'A' + index, state));
 
-	if ((index == CHANNEL_B) && (m_chanB->m_wr[1] & z80dart_channel::WR1_STATUS_VECTOR))
-	{
-		// status affects vector
-		vector = (m_chanB->m_wr[2] & 0xf1) | (!index << 3) | (state << 1);
-	}
-
 	// update vector register
 	m_chanB->m_rr[2] = vector;
 
@@ -471,6 +511,7 @@ z80dart_channel::z80dart_channel(const machine_config &mconfig, const char *tag,
 		m_rx_first(0),
 		m_rx_break(0),
 		m_rx_rr0_latch(0),
+		m_rxd(0),
 		m_ri(0),
 		m_cts(0),
 		m_dcd(0),
@@ -503,15 +544,6 @@ void z80dart_channel::device_start()
 	m_uart = downcast<z80dart_device *>(owner());
 	m_index = m_uart->get_channel_index(this);
 
-	// resolve callbacks
-	m_out_txd_func.resolve(m_out_txd_cb, *m_uart);
-	m_out_dtr_func.resolve(m_out_dtr_cb, *m_uart);
-	m_out_rts_func.resolve(m_out_rts_cb, *m_uart);
-	m_out_wrdy_func.resolve(m_out_wrdy_cb, *m_uart);
-	m_out_sync_func.resolve(m_out_sync_cb, *m_uart);
-	m_out_rxdrq_func.resolve(m_out_rxdrq_cb, *m_uart);
-	m_out_txdrq_func.resolve(m_out_txdrq_cb, *m_uart);
-
 	// state saving
 	save_item(NAME(m_rr));
 	save_item(NAME(m_wr));
@@ -549,6 +581,7 @@ void z80dart_channel::device_reset()
 	// disable transmitter
 	m_wr[5] &= ~WR5_TX_ENABLE;
 	m_rr[0] |= RR0_TX_BUFFER_EMPTY;
+	m_rr[1] |= RR1_ALL_SENT;
 
 	// reset external lines
 	set_rts(1);
@@ -576,22 +609,26 @@ void z80dart_channel::tra_callback()
 	if (!(m_wr[5] & WR5_TX_ENABLE))
 	{
 		// transmit mark
-		m_out_txd_func(1);
-		set_out_data_bit(1);
+		if (m_index == z80dart_device::CHANNEL_A)
+			m_uart->m_out_txda_cb(1);
+		else
+			m_uart->m_out_txdb_cb(1);
 	}
 	else if (m_wr[5] & WR5_SEND_BREAK)
 	{
 		// transmit break
-		m_out_txd_func(0);
-		set_out_data_bit(0);
+		if (m_index == z80dart_device::CHANNEL_A)
+			m_uart->m_out_txda_cb(0);
+		else
+			m_uart->m_out_txdb_cb(0);
 	}
 	else if (!is_transmit_register_empty())
 	{
 		// transmit data
-		if (m_out_txd_func.isnull())
-			transmit_register_send_bit();
+		if (m_index == z80dart_device::CHANNEL_A)
+			m_uart->m_out_txda_cb(transmit_register_get_data_bit());
 		else
-			m_out_txd_func(transmit_register_get_data_bit());
+			m_uart->m_out_txdb_cb(transmit_register_get_data_bit());
 	}
 }
 
@@ -617,14 +654,18 @@ void z80dart_channel::tra_complete()
 	else if (m_wr[5] & WR5_SEND_BREAK)
 	{
 		// transmit break
-		m_out_txd_func(0);
-		set_out_data_bit(0);
+		if (m_index == z80dart_device::CHANNEL_A)
+			m_uart->m_out_txda_cb(0);
+		else
+			m_uart->m_out_txdb_cb(0);
 	}
 	else
 	{
 		// transmit mark
-		m_out_txd_func(1);
-		set_out_data_bit(1);
+		if (m_index == z80dart_device::CHANNEL_A)
+			m_uart->m_out_txda_cb(1);
+		else
+			m_uart->m_out_txdb_cb(1);
 	}
 
 	// if transmit buffer is empty
@@ -648,7 +689,7 @@ void z80dart_channel::rcv_callback()
 {
 	if (m_wr[3] & WR3_RX_ENABLE)
 	{
-		receive_register_update_bit(get_in_data_bit());
+		receive_register_update_bit(m_rxd);
 	}
 }
 
@@ -664,23 +705,6 @@ void z80dart_channel::rcv_complete()
 }
 
 
-//-------------------------------------------------
-//  input_callback -
-//-------------------------------------------------
-
-void z80dart_channel::input_callback(UINT8 state)
-{
-	UINT8 changed = m_input_state ^ state;
-
-	m_input_state = state;
-
-	if (changed & CTS)
-	{
-		cts_w(state);
-	}
-}
-
-
 //-------------------------------------------------
 //  get_clock_mode - get clock divisor
 //-------------------------------------------------
@@ -705,18 +729,16 @@ int z80dart_channel::get_clock_mode()
 //  get_stop_bits - get number of stop bits
 //-------------------------------------------------
 
-float z80dart_channel::get_stop_bits()
+device_serial_interface::stop_bits_t z80dart_channel::get_stop_bits()
 {
-	float bits = 1;
-
 	switch (m_wr[4] & WR4_STOP_BITS_MASK)
 	{
-	case WR4_STOP_BITS_1:       bits = 1;       break;
-	case WR4_STOP_BITS_1_5:     bits = 1.5;     break;
-	case WR4_STOP_BITS_2:       bits = 2;       break;
+	case WR4_STOP_BITS_1: return STOP_BITS_1;
+	case WR4_STOP_BITS_1_5: return STOP_BITS_1_5;
+	case WR4_STOP_BITS_2: return STOP_BITS_2;
 	}
 
-	return bits;
+	return STOP_BITS_0;
 }
 
 
@@ -807,7 +829,8 @@ void z80dart_channel::control_write(UINT8 data)
 	LOG(("Z80DART \"%s\" Channel %c : Control Register Write '%02x'\n", m_owner->tag(), 'A' + m_index, data));
 
 	// write data to selected register
-	m_wr[reg] = data;
+	if (reg < 6)
+		m_wr[reg] = data;
 
 	if (reg != 0)
 	{
@@ -907,8 +930,12 @@ void z80dart_channel::control_write(UINT8 data)
 	case 2:
 		// interrupt vector
 		if (m_index == z80dart_device::CHANNEL_B)
-			m_rr[2] = ( m_rr[2] & 0x0e ) | ( m_wr[2] & 0xF1);;
-
+		{
+			if(m_wr[1] & z80dart_channel::WR1_STATUS_VECTOR)
+				m_rr[2] = ( m_rr[2] & 0x0e ) | ( m_wr[2] & 0xF1);
+			else
+				m_rr[2] = m_wr[2];
+		}
 		m_uart->check_interrupts();
 		LOG(("Z80DART \"%s\" Channel %c : Interrupt Vector %02x\n", m_owner->tag(), 'A' + m_index, data));
 		break;
@@ -924,7 +951,7 @@ void z80dart_channel::control_write(UINT8 data)
 	case 4:
 		LOG(("Z80DART \"%s\" Channel %c : Parity Enable %u\n", m_owner->tag(), 'A' + m_index, (data & WR4_PARITY_ENABLE) ? 1 : 0));
 		LOG(("Z80DART \"%s\" Channel %c : Parity %s\n", m_owner->tag(), 'A' + m_index, (data & WR4_PARITY_EVEN) ? "Even" : "Odd"));
-		LOG(("Z80DART \"%s\" Channel %c : Stop Bits %f\n", m_owner->tag(), 'A' + m_index, get_stop_bits()));
+		LOG(("Z80DART \"%s\" Channel %c : Stop Bits %s\n", m_owner->tag(), 'A' + m_index, stop_bits_tostring(get_stop_bits())));
 		LOG(("Z80DART \"%s\" Channel %c : Clock Mode %uX\n", m_owner->tag(), 'A' + m_index, get_clock_mode()));
 
 		update_serial();
@@ -981,8 +1008,8 @@ UINT8 z80dart_channel::data_read()
 		// load data from the FIFO
 		data = m_rx_data_fifo[m_rx_fifo];
 
-		// load error status from the FIFO, retain overrun and parity errors
-		m_rr[1] = (m_rr[1] & (RR1_RX_OVERRUN_ERROR | RR1_PARITY_ERROR)) | m_rx_error_fifo[m_rx_fifo];
+		// load error status from the FIFO
+		m_rr[1] = (m_rr[1] & ~(RR1_CRC_FRAMING_ERROR | RR1_RX_OVERRUN_ERROR | RR1_PARITY_ERROR)) | m_rx_error_fifo[m_rx_fifo];
 
 		// decrease FIFO pointer
 		m_rx_fifo--;
@@ -1260,6 +1287,22 @@ WRITE_LINE_MEMBER( z80dart_channel::txc_w )
 
 void z80dart_channel::update_serial()
 {
+	int data_bit_count = get_rx_word_length();
+	stop_bits_t stop_bits = get_stop_bits();
+
+	parity_t parity;
+	if (m_wr[4] & WR4_PARITY_ENABLE)
+	{
+		if (m_wr[4] & WR4_PARITY_EVEN)
+			parity = PARITY_EVEN;
+		else
+			parity = PARITY_ODD;
+	}
+	else
+		parity = PARITY_NONE;
+
+	set_data_frame(1, data_bit_count, parity, stop_bits);
+
 	int clocks = get_clock_mode();
 
 	if (m_rxc > 0)
@@ -1271,20 +1314,7 @@ void z80dart_channel::update_serial()
 	{
 		set_tra_rate(m_txc / clocks);
 	}
-
-	int num_data_bits = get_rx_word_length();
-	int stop_bit_count = get_stop_bits();
-	int parity_code = PARITY_NONE;
-
-	if (m_wr[1] & WR4_PARITY_ENABLE)
-	{
-		if (m_wr[1] & WR4_PARITY_EVEN)
-			parity_code = PARITY_EVEN;
-		else
-			parity_code = PARITY_ODD;
-	}
-
-	set_data_frame(num_data_bits, stop_bit_count, parity_code, false);
+	receive_register_reset(); // if stop bits is changed from 0, receive register has to be reset
 }
 
 
@@ -1296,14 +1326,10 @@ void z80dart_channel::set_dtr(int state)
 {
 	m_dtr = state;
 
-	m_out_dtr_func(m_dtr);
-
-	if (state)
-		m_connection_state &= ~DTR;
+	if (m_index == z80dart_device::CHANNEL_A)
+		m_uart->m_out_dtra_cb(m_dtr);
 	else
-		m_connection_state |= DTR;
-
-	serial_connection_out();
+		m_uart->m_out_dtrb_cb(m_dtr);
 }
 
 
@@ -1313,14 +1339,10 @@ void z80dart_channel::set_dtr(int state)
 
 void z80dart_channel::set_rts(int state)
 {
-	m_out_rts_func(state);
-
-	if (state)
-		m_connection_state &= ~RTS;
+	if (m_index == z80dart_device::CHANNEL_A)
+		m_uart->m_out_rtsa_cb(state);
 	else
-		m_connection_state |= RTS;
-
-	serial_connection_out();
+		m_uart->m_out_rtsb_cb(state);
 }
 
 
@@ -1330,12 +1352,8 @@ void z80dart_channel::set_rts(int state)
 
 WRITE_LINE_MEMBER(z80dart_channel::write_rx)
 {
-	if (state)
-	{
-		input_callback(m_input_state | RX);
-	}
-	else
-	{
-		input_callback(m_input_state & ~RX);
-	}
+	m_rxd = state;
+	//only use rx_w when self-clocked
+	if(m_rxc)
+		device_serial_interface::rx_w(state);
 }
