@@ -145,39 +145,19 @@ const device_type Z80DMA = &device_creator<z80dma_device>;
 //-------------------------------------------------
 
 z80dma_device::z80dma_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: device_t(mconfig, Z80DMA, "Z8410", tag, owner, clock, "z80dma", __FILE__),
-		device_z80daisy_interface(mconfig, *this)
+	: device_t(mconfig, Z80DMA, "Z8410 DMA", tag, owner, clock, "z80dma", __FILE__),
+		device_z80daisy_interface(mconfig, *this),
+		m_out_busreq_cb(*this),
+		m_out_int_cb(*this),
+		m_out_bao_cb(*this),
+		m_in_mreq_cb(*this),
+		m_out_mreq_cb(*this),
+		m_in_iorq_cb(*this),
+		m_out_iorq_cb(*this)
 {
 }
 
 
-//-------------------------------------------------
-//  device_config_complete - perform any
-//  operations now that the configuration is
-//  complete
-//-------------------------------------------------
-
-void z80dma_device::device_config_complete()
-{
-	// inherit a copy of the static data
-	const z80dma_interface *intf = reinterpret_cast<const z80dma_interface *>(static_config());
-	if (intf != NULL)
-		*static_cast<z80dma_interface *>(this) = *intf;
-
-	// or initialize to defaults if none provided
-	else
-	{
-		memset(&m_out_busreq_cb, 0, sizeof(m_out_busreq_cb));
-		memset(&m_out_int_cb, 0, sizeof(m_out_int_cb));
-		memset(&m_out_bao_cb, 0, sizeof(m_out_bao_cb));
-		memset(&m_in_mreq_cb, 0, sizeof(m_in_mreq_cb));
-		memset(&m_out_mreq_cb, 0, sizeof(m_out_mreq_cb));
-		memset(&m_in_iorq_cb, 0, sizeof(m_in_iorq_cb));
-		memset(&m_out_iorq_cb, 0, sizeof(m_out_iorq_cb));
-	}
-}
-
-
 //-------------------------------------------------
 //  device_start - device-specific startup
 //-------------------------------------------------
@@ -185,13 +165,13 @@ void z80dma_device::device_config_complete()
 void z80dma_device::device_start()
 {
 	// resolve callbacks
-	m_out_busreq_func.resolve(m_out_busreq_cb, *this);
-	m_out_int_func.resolve(m_out_int_cb, *this);
-	m_out_bao_func.resolve(m_out_bao_cb, *this);
-	m_in_mreq_func.resolve(m_in_mreq_cb, *this);
-	m_out_mreq_func.resolve(m_out_mreq_cb, *this);
-	m_in_iorq_func.resolve(m_in_iorq_cb, *this);
-	m_out_iorq_func.resolve(m_out_iorq_cb, *this);
+	m_out_busreq_cb.resolve_safe();
+	m_out_int_cb.resolve_safe();
+	m_out_bao_cb.resolve_safe();
+	m_in_mreq_cb.resolve_safe(0);
+	m_out_mreq_cb.resolve_safe();
+	m_in_iorq_cb.resolve_safe(0);
+	m_out_iorq_cb.resolve_safe();
 
 	// allocate timer
 	m_timer = machine().scheduler().timer_alloc(FUNC(static_timerproc), (void *)this);
@@ -345,7 +325,7 @@ int z80dma_device::is_ready()
 
 void z80dma_device::interrupt_check()
 {
-	m_out_int_func(m_ip ? ASSERT_LINE : CLEAR_LINE);
+	m_out_int_cb(m_ip ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -395,18 +375,18 @@ void z80dma_device::do_read()
 			if (PORTA_IS_SOURCE)
 			{
 				if (PORTA_MEMORY)
-					m_latch = m_in_mreq_func(m_addressA);
+					m_latch = m_in_mreq_cb(m_addressA);
 				else
-					m_latch = m_in_iorq_func(m_addressA);
+					m_latch = m_in_iorq_cb(m_addressA);
 
 				if (DMA_LOG) logerror("Z80DMA '%s' A src: %04x %s -> data: %02x\n", tag(), m_addressA, PORTA_MEMORY ? "mem" : "i/o", m_latch);
 			}
 			else
 			{
 				if (PORTB_MEMORY)
-					m_latch = m_in_mreq_func(m_addressB);
+					m_latch = m_in_mreq_cb(m_addressB);
 				else
-					m_latch = m_in_iorq_func(m_addressB);
+					m_latch = m_in_iorq_cb(m_addressB);
 
 				if (DMA_LOG) logerror("Z80DMA '%s' B src: %04x %s -> data: %02x\n", tag(), m_addressB, PORTB_MEMORY ? "mem" : "i/o", m_latch);
 			}
@@ -427,18 +407,18 @@ void z80dma_device::do_transfer_write()
 	if (PORTA_IS_SOURCE)
 	{
 		if (PORTB_MEMORY)
-			m_out_mreq_func(m_addressB, m_latch);
+			m_out_mreq_cb((offs_t)m_addressB, m_latch);
 		else
-			m_out_iorq_func(m_addressB, m_latch);
+			m_out_iorq_cb((offs_t)m_addressB, m_latch);
 
 		if (DMA_LOG) logerror("Z80DMA '%s' B dst: %04x %s\n", tag(), m_addressB, PORTB_MEMORY ? "mem" : "i/o");
 	}
 	else
 	{
 		if (PORTA_MEMORY)
-			m_out_mreq_func(m_addressA, m_latch);
+			m_out_mreq_cb((offs_t)m_addressA, m_latch);
 		else
-			m_out_iorq_func(m_addressA, m_latch);
+			m_out_iorq_cb((offs_t)m_addressA, m_latch);
 
 		if (DMA_LOG) logerror("Z80DMA '%s' A dst: %04x %s\n", tag(), m_addressA, PORTA_MEMORY ? "mem" : "i/o");
 	}
@@ -596,7 +576,7 @@ void z80dma_device::update_status()
 	}
 
 	// set the busreq line
-	m_out_busreq_func(pending_transfer ? ASSERT_LINE : CLEAR_LINE);
+	m_out_busreq_cb(pending_transfer ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -874,7 +854,7 @@ void z80dma_device::rdy_write_callback(int state)
 //  rdy_w - ready input
 //-------------------------------------------------
 
-void z80dma_device::rdy_w(int state)
+WRITE_LINE_MEMBER(z80dma_device::rdy_w)
 {
 	if (LOG) logerror("Z80DMA '%s' RDY: %d Active High: %d\n", tag(), state, READY_ACTIVE_HIGH);
 	machine().scheduler().synchronize(FUNC(static_rdy_write_callback), state, (void *)this);
@@ -885,7 +865,7 @@ void z80dma_device::rdy_w(int state)
 //  wait_w - wait input
 //-------------------------------------------------
 
-void z80dma_device::wait_w(int state)
+WRITE_LINE_MEMBER(z80dma_device::wait_w)
 {
 }
 
@@ -894,19 +874,6 @@ void z80dma_device::wait_w(int state)
 //  bai_w - bus acknowledge input
 //-------------------------------------------------
 
-void z80dma_device::bai_w(int state)
+WRITE_LINE_MEMBER(z80dma_device::bai_w)
 {
 }
-
-
-
-//**************************************************************************
-//  GLOBAL STUBS
-//**************************************************************************
-
-READ8_DEVICE_HANDLER( z80dma_r ) { return downcast<z80dma_device *>(device)->read(); }
-WRITE8_DEVICE_HANDLER( z80dma_w ) { downcast<z80dma_device *>(device)->write(data); }
-
-WRITE_LINE_DEVICE_HANDLER( z80dma_rdy_w ) { downcast<z80dma_device *>(device)->rdy_w(state); }
-WRITE_LINE_DEVICE_HANDLER( z80dma_wait_w ) { downcast<z80dma_device *>(device)->wait_w(state); }
-WRITE_LINE_DEVICE_HANDLER( z80dma_bai_w ) { downcast<z80dma_device *>(device)->bai_w(state); }
