@@ -9,19 +9,20 @@
 #include "nl_setup.h"
 #include "nl_parser.h"
 #include "nl_util.h"
+#include "devices/net_lib.h"
 #include "devices/nld_system.h"
-#include "devices/nld_solver.h"
+#include "analog/nld_solver.h"
+#include "analog/nld_twoterm.h"
 
 static NETLIST_START(base)
-	NETDEV_TTL_CONST(ttlhigh, 1)
-	NETDEV_TTL_CONST(ttllow, 0)
-	NETDEV_ANALOG_CONST(NC, NETLIST_HIGHIMP_V)
+	TTL_INPUT(ttlhigh, 1)
+	TTL_INPUT(ttllow, 0)
+	NET_REGISTER_DEV(gnd, GND)
 
-	NET_MODEL(".model 1N914 D(Is=2.52n Rs=.568 N=1.752 Cjo=4p M=.4 tt=20n Iave=200m Vpk=75 mfg=OnSemi type=silicon)")
-	NET_MODEL(".model 1N4148 D(Is=2.52n Rs=.568 N=1.752 Cjo=4p M=.4 tt=20n Iave=200m Vpk=75 mfg=OnSemi type=silicon)")
-	NET_MODEL(".MODEL BC237B NPN(IS=1.8E-14 ISE=5.0E-14 ISC=1.72E-13 XTI=3 BF=400 BR=35.5 IKF=0.14 IKR=0.03 XTB=1.5 VAF=80 VAR=12.5 VJE=0.58 VJC=0.54 RE=0.6 RC=0.25 RB=0.56 CJE=13E-12 CJC=4E-12 XCJC=0.75 FC=0.5 NF=0.9955 NR=1.005 NE=1.46 NC=1.27 MJE=0.33 MJC=0.33 TF=0.64E-9 TR=50.72E-9 EG=1.11 KF=0 AF=1 VCEO=45V ICRATING=100M MFG=ZETEX)")
+	INCLUDE(diode_models);
+	INCLUDE(bjt_models);
 
-NETLIST_END
+NETLIST_END()
 
 
 // ----------------------------------------------------------------------------------------
@@ -44,39 +45,61 @@ void netlist_setup_t::init()
 
 netlist_setup_t::~netlist_setup_t()
 {
-	m_links.reset();
-	m_alias.reset();
-	m_params.reset();
-	m_terminals.reset();
-	m_params_temp.reset();
+	m_links.clear();
+	m_alias.clear();
+	m_params.clear();
+	m_terminals.clear();
+	m_params_temp.clear();
 
 	netlist().set_setup(NULL);
 
 	pstring::resetmem();
 }
 
-// FIXME: Move to netlist ...
+ATTR_COLD pstring netlist_setup_t::build_fqn(const pstring &obj_name) const
+{
+	if (m_stack.empty())
+		return netlist().name() + "." + obj_name;
+	else
+		return m_stack.peek() + "." + obj_name;
+}
+
+void netlist_setup_t::namespace_push(const pstring &aname)
+{
+	if (m_stack.empty())
+		m_stack.push(netlist().name() + "." + aname);
+	else
+		m_stack.push(m_stack.peek() + "." + aname);
+}
+
+void netlist_setup_t::namespace_pop()
+{
+	m_stack.pop();
+}
+
+
 netlist_device_t *netlist_setup_t::register_dev(netlist_device_t *dev, const pstring &name)
 {
-	if (!(netlist().m_devices.add(name, dev, false)==TMERR_NONE))
-		netlist().xfatalerror("Error adding %s to device list\n", name.cstr());
+	pstring fqn = build_fqn(name);
+
+	dev->init(netlist(), fqn);
+
+	if (!(netlist().m_devices.add(dev, false)==true))
+		netlist().error("Error adding %s to device list\n", name.cstr());
 	return dev;
 }
 
 template <class T>
 static void remove_start_with(T &hm, pstring &sw)
 {
-	typename T::entry_t *entry = hm.first();
-	while (entry != NULL)
+	for (int i = hm.count() - 1; i >= 0; i++)
 	{
-		typename T::entry_t *next = hm.next(entry);
-		pstring x = entry->tag().cstr();
+		pstring x = hm[i]->name();
 		if (sw.equals(x.substr(0, sw.len())))
 		{
-			NL_VERBOSE_OUT(("removing %s\n", entry->tag().cstr()));
-			hm.remove(entry->object());
+			NL_VERBOSE_OUT(("removing %s\n", hm[i]->name().cstr()));
+			hm.remove(hm[i]);
 		}
-		entry = next;
 	}
 }
 
@@ -85,21 +108,20 @@ void netlist_setup_t::remove_dev(const pstring &name)
 	netlist_device_t *dev = netlist().m_devices.find(name);
 	pstring temp = name + ".";
 	if (dev == NULL)
-		netlist().xfatalerror("Device %s does not exist\n", name.cstr());
+		netlist().error("Device %s does not exist\n", name.cstr());
 
-	//remove_start_with<tagmap_input_t>(m_inputs, temp);
 	remove_start_with<tagmap_terminal_t>(m_terminals, temp);
 	remove_start_with<tagmap_param_t>(m_params, temp);
 
-	tagmap_link_t::entry_t *p = m_links.first();
+	const link_t *p = m_links.first();
 	while (p != NULL)
 	{
-		tagmap_link_t::entry_t *n = m_links.next(p);
-		if (temp.equals(p->object().e1.substr(0,temp.len())) || temp.equals(p->object().e2.substr(0,temp.len())))
-			m_links.remove(p->object());
+		const link_t *n = m_links.next(p);
+		if (temp.equals(p->e1.substr(0,temp.len())) || temp.equals(p->e2.substr(0,temp.len())))
+			m_links.remove(*p);
 		p = n;
 	}
-	netlist().m_devices.remove(name);
+	netlist().m_devices.remove_by_name(name);
 }
 
 void netlist_setup_t::register_model(const pstring &model)
@@ -107,14 +129,20 @@ void netlist_setup_t::register_model(const pstring &model)
 	m_models.add(model);
 }
 
-void netlist_setup_t::register_alias(const pstring &alias, const pstring &out)
+void netlist_setup_t::register_alias_nofqn(const pstring &alias, const pstring &out)
 {
-	//if (!(m_alias.add(alias, new nstring(out), false)==TMERR_NONE))
-	if (!(m_alias.add(alias, out, false)==TMERR_NONE))
-		netlist().xfatalerror("Error adding alias %s to alias list\n", alias.cstr());
+	if (!(m_alias.add(link_t(alias, out), false)==true))
+		netlist().error("Error adding alias %s to alias list\n", alias.cstr());
 }
 
-pstring netlist_setup_t::objtype_as_astr(netlist_object_t &in)
+void netlist_setup_t::register_alias(const pstring &alias, const pstring &out)
+{
+	pstring alias_fqn = build_fqn(alias);
+	pstring out_fqn = build_fqn(out);
+	register_alias_nofqn(alias_fqn, out_fqn);
+}
+
+pstring netlist_setup_t::objtype_as_astr(netlist_object_t &in) const
 {
 	switch (in.type())
 	{
@@ -139,13 +167,16 @@ pstring netlist_setup_t::objtype_as_astr(netlist_object_t &in)
 		case netlist_terminal_t::NETLIST:
 			return "NETLIST";
 			break;
+		case netlist_terminal_t::QUEUE:
+			return "QUEUE";
+			break;
 	}
 	// FIXME: noreturn
-	netlist().xfatalerror("Unknown object type %d\n", in.type());
+	netlist().error("Unknown object type %d\n", in.type());
 	return "Error";
 }
 
-void netlist_setup_t::register_object(netlist_device_t &dev, netlist_core_device_t &upd_dev, const pstring &name, netlist_object_t &obj, const netlist_input_t::state_e state)
+void netlist_setup_t::register_object(netlist_device_t &dev, const pstring &name, netlist_object_t &obj)
 {
 	switch (obj.type())
 	{
@@ -155,12 +186,12 @@ void netlist_setup_t::register_object(netlist_device_t &dev, netlist_core_device
 			{
 				netlist_core_terminal_t &term = dynamic_cast<netlist_core_terminal_t &>(obj);
 				if (obj.isType(netlist_terminal_t::OUTPUT))
-					dynamic_cast<netlist_output_t &>(term).init_object(upd_dev, dev.name() + "." + name);
+					dynamic_cast<netlist_output_t &>(term).init_object(dev, dev.name() + "." + name);
 				else
-					term.init_object(upd_dev, dev.name() + "." + name, state);
+					term.init_object(dev, dev.name() + "." + name);
 
-				if (!(m_terminals.add(term.name(), &term, false)==TMERR_NONE))
-					netlist().xfatalerror("Error adding %s %s to terminal list\n", objtype_as_astr(term).cstr(), term.name().cstr());
+				if (!(m_terminals.add(&term, false)==true))
+					netlist().error("Error adding %s %s to terminal list\n", objtype_as_astr(term).cstr(), term.name().cstr());
 				NL_VERBOSE_OUT(("%s %s\n", objtype_as_astr(term).cstr(), name.cstr()));
 			}
 			break;
@@ -169,28 +200,29 @@ void netlist_setup_t::register_object(netlist_device_t &dev, netlist_core_device
 		case netlist_terminal_t::PARAM:
 			{
 				netlist_param_t &param = dynamic_cast<netlist_param_t &>(obj);
-				const pstring val = m_params_temp.find(name);
+				//printf("name: %s\n", name.cstr());
+				const pstring val = m_params_temp.find(name).e2;
 				if (val != "")
 				{
 					switch (param.param_type())
 					{
 						case netlist_param_t::DOUBLE:
 						{
-							NL_VERBOSE_OUT(("Found parameter ... %s : %s\n", temp.cstr(), val->cstr()));
+							NL_VERBOSE_OUT(("Found parameter ... %s : %s\n", name.cstr(), val.cstr()));
 							double vald = 0;
 							if (sscanf(val.cstr(), "%lf", &vald) != 1)
-								netlist().xfatalerror("Invalid number conversion %s : %s\n", name.cstr(), val.cstr());
+								netlist().error("Invalid number conversion %s : %s\n", name.cstr(), val.cstr());
 							dynamic_cast<netlist_param_double_t &>(param).initial(vald);
 						}
 						break;
 						case netlist_param_t::INTEGER:
 						case netlist_param_t::LOGIC:
 						{
-							NL_VERBOSE_OUT(("Found parameter ... %s : %s\n", name.cstr(), val->cstr()));
-							int vald = 0;
-							if (sscanf(val.cstr(), "%d", &vald) != 1)
-								netlist().xfatalerror("Invalid number conversion %s : %s\n", name.cstr(), val.cstr());
-							dynamic_cast<netlist_param_int_t &>(param).initial(vald);
+							NL_VERBOSE_OUT(("Found parameter ... %s : %s\n", name.cstr(), val.cstr()));
+							double vald = 0;
+							if (sscanf(val.cstr(), "%lf", &vald) != 1)
+								netlist().error("Invalid number conversion %s : %s\n", name.cstr(), val.cstr());
+							dynamic_cast<netlist_param_int_t &>(param).initial((int) vald);
 						}
 						break;
 						case netlist_param_t::STRING:
@@ -206,37 +238,55 @@ void netlist_setup_t::register_object(netlist_device_t &dev, netlist_core_device
 							{
 								if (m_models[i].ucase().startsWith(search))
 								{
-									int pl=m_models[i].find("(");
-									int pr=m_models[i].find("(");
-									dynamic_cast<netlist_param_model_t &>(param).initial(m_models[i].substr(pl+1,pr-pl-1));
+									//int pl=m_models[i].find("(");
+									//int pr=m_models[i].find(")");
+									//dynamic_cast<netlist_param_model_t &>(param).initial(m_models[i].substr(pl+1,pr-pl-1));
+									dynamic_cast<netlist_param_model_t &>(param).initial(m_models[i]);
 									found = true;
 									break;
 								}
 							}
 							if (!found)
-								netlist().xfatalerror("Model %s not found\n", val.cstr());
+								netlist().error("Model %s not found\n", val.cstr());
 						}
 						break;
 						default:
-							netlist().xfatalerror("Parameter is not supported %s : %s\n", name.cstr(), val.cstr());
+							netlist().error("Parameter is not supported %s : %s\n", name.cstr(), val.cstr());
 					}
 				}
-				if (!(m_params.add(name, &param, false)==TMERR_NONE))
-					netlist().xfatalerror("Error adding parameter %s to parameter list\n", name.cstr());
+				if (!(m_params.add(&param, false)==true))
+					netlist().error("Error adding parameter %s to parameter list\n", name.cstr());
 			}
 			break;
 		case netlist_terminal_t::DEVICE:
-			netlist().xfatalerror("Device registration not yet supported - \n", name.cstr());
+			netlist().error("Device registration not yet supported - %s\n", name.cstr());
 			break;
 		case netlist_terminal_t::NETLIST:
-			netlist().xfatalerror("Netlist registration not yet supported - \n", name.cstr());
+			netlist().error("Netlist registration not yet supported - %s\n", name.cstr());
+			break;
+		case netlist_terminal_t::QUEUE:
+			netlist().error("QUEUE registration not yet supported - %s\n", name.cstr());
 			break;
 	}
 }
 
+void netlist_setup_t::register_link_arr(const pstring &terms)
+{
+	nl_util::pstring_list list = nl_util::split(terms,", ");
+	if (list.count() < 2)
+		netlist().error("You must pass at least 2 terminals to NET_C");
+	pstring last = list[0];
+	for (int i = 1; i < list.count(); i++)
+	{
+		register_link(last, list[i]);
+		last = list[i];
+	}
+}
+
+
 void netlist_setup_t::register_link(const pstring &sin, const pstring &sout)
 {
-	link_t temp = link_t(sin, sout);
+	link_t temp = link_t(build_fqn(sin), build_fqn(sout));
 	NL_VERBOSE_OUT(("link %s <== %s\n", sin.cstr(), sout.cstr()));
 	m_links.add(temp);
 	//if (!(m_links.add(sin + "." + sout, temp, false)==TMERR_NONE))
@@ -251,9 +301,10 @@ void netlist_setup_t::register_param(const pstring &param, const double value)
 
 void netlist_setup_t::register_param(const pstring &param, const pstring &value)
 {
-	//if (!(m_params_temp.add(param, new nstring(value), false)==TMERR_NONE))
-	if (!(m_params_temp.add(param, value, false)==TMERR_NONE))
-		netlist().xfatalerror("Error adding parameter %s to parameter list\n", param.cstr());
+	pstring fqn = build_fqn(param);
+
+	if (!(m_params_temp.add(link_t(fqn, value), false)==true))
+		netlist().error("Error adding parameter %s to parameter list\n", param.cstr());
 }
 
 const pstring netlist_setup_t::resolve_alias(const pstring &name) const
@@ -264,25 +315,9 @@ const pstring netlist_setup_t::resolve_alias(const pstring &name) const
 	/* FIXME: Detect endless loop */
 	do {
 		ret = temp;
-		temp = m_alias.find(ret);
+		temp = m_alias.find(ret).e2;
 	} while (temp != "");
 
-	int p = ret.find(".[");
-	if (p > 0)
-	{
-		pstring dname = ret;
-		netlist_device_t *dev = netlist().m_devices.find(dname.substr(0,p));
-		if (dev == NULL)
-			netlist().xfatalerror("Device for %s not found\n", name.cstr());
-		int c = atoi(ret.substr(p+2,ret.len()-p-3));
-		temp = dev->name() + "." + dev->m_terminals[c];
-		// reresolve ....
-		do {
-			ret = temp;
-			temp = m_alias.find(ret);
-		} while (temp != "");
-	}
-
 	NL_VERBOSE_OUT(("%s==>%s\n", name.cstr(), ret.cstr()));
 	return ret;
 }
@@ -301,7 +336,7 @@ netlist_core_terminal_t *netlist_setup_t::find_terminal(const pstring &terminal_
 		ret = m_terminals.find(s);
 	}
 	if (ret == NULL && required)
-		netlist().xfatalerror("terminal %s(%s) not found!\n", terminal_in.cstr(), tname.cstr());
+		netlist().error("terminal %s(%s) not found!\n", terminal_in.cstr(), tname.cstr());
 	if (ret != NULL)
 		NL_VERBOSE_OUT(("Found input %s\n", tname.cstr()));
 	return ret;
@@ -321,11 +356,11 @@ netlist_core_terminal_t *netlist_setup_t::find_terminal(const pstring &terminal_
 		ret = m_terminals.find(s);
 	}
 	if (ret == NULL && required)
-		netlist().xfatalerror("terminal %s(%s) not found!\n", terminal_in.cstr(), tname.cstr());
+		netlist().error("terminal %s(%s) not found!\n", terminal_in.cstr(), tname.cstr());
 	if (ret != NULL && ret->type() != atype)
 	{
 		if (required)
-			netlist().xfatalerror("object %s(%s) found but wrong type\n", terminal_in.cstr(), tname.cstr());
+			netlist().error("object %s(%s) found but wrong type\n", terminal_in.cstr(), tname.cstr());
 		else
 			ret = NULL;
 	}
@@ -336,28 +371,65 @@ netlist_core_terminal_t *netlist_setup_t::find_terminal(const pstring &terminal_
 
 netlist_param_t *netlist_setup_t::find_param(const pstring &param_in, bool required)
 {
-	const pstring &outname = resolve_alias(param_in);
+	const pstring param_in_fqn = build_fqn(param_in);
+
+	const pstring &outname = resolve_alias(param_in_fqn);
 	netlist_param_t *ret;
 
 	ret = m_params.find(outname);
 	if (ret == NULL && required)
-		netlist().xfatalerror("parameter %s(%s) not found!\n", param_in.cstr(), outname.cstr());
+		netlist().error("parameter %s(%s) not found!\n", param_in_fqn.cstr(), outname.cstr());
 	if (ret != NULL)
 		NL_VERBOSE_OUT(("Found parameter %s\n", outname.cstr()));
 	return ret;
 }
 
+nld_base_d_to_a_proxy *netlist_setup_t::get_d_a_proxy(netlist_output_t &out)
+{
+	assert(out.isFamily(netlist_terminal_t::LOGIC));
+
+	//printf("proxy for %s\n", out.name().cstr());;
+	netlist_logic_output_t &out_cast = dynamic_cast<netlist_logic_output_t &>(out);
+	nld_base_d_to_a_proxy *proxy = out_cast.get_proxy();
+
+	if (proxy == NULL)
+	{
+		// create a new one ...
+		proxy = new nld_d_to_a_proxy(out);
+		pstring x = pstring::sprintf("proxy_da_%s_%d", out.name().cstr(), m_proxy_cnt);
+		m_proxy_cnt++;
+
+		register_dev(proxy, x);
+		proxy->start_dev();
+
+#if 1
+		/* connect all existing terminals to new net */
+
+		for (int i = 0; i < out.net().m_core_terms.count(); i++)
+		{
+			netlist_core_terminal_t *p = out.net().m_core_terms[i];
+			p->clear_net(); // de-link from all nets ...
+			connect(proxy->out(), *p);
+		}
+		out.net().m_core_terms.clear(); // clear the list
+#endif
+		out.net().register_con(proxy->m_I);
+		out_cast.set_proxy(proxy);
+
+	}
+	return proxy;
+}
 
 void netlist_setup_t::connect_input_output(netlist_input_t &in, netlist_output_t &out)
 {
 	if (out.isFamily(netlist_terminal_t::ANALOG) && in.isFamily(netlist_terminal_t::LOGIC))
 	{
 		nld_a_to_d_proxy *proxy = new nld_a_to_d_proxy(in);
-		pstring x = pstring::sprintf("proxy_ad_%d", m_proxy_cnt);
+		pstring x = pstring::sprintf("proxy_ad_%s_%d", in.name().cstr(), m_proxy_cnt);
 		m_proxy_cnt++;
 
-		proxy->init(netlist(), x);
 		register_dev(proxy, x);
+		proxy->start_dev();
 
 		proxy->m_Q.net().register_con(in);
 		out.net().register_con(proxy->m_I);
@@ -365,19 +437,17 @@ void netlist_setup_t::connect_input_output(netlist_input_t &in, netlist_output_t
 	}
 	else if (out.isFamily(netlist_terminal_t::LOGIC) && in.isFamily(netlist_terminal_t::ANALOG))
 	{
-		nld_d_to_a_proxy *proxy = new nld_d_to_a_proxy(out);
-		pstring x = pstring::sprintf("proxy_da_%d", m_proxy_cnt);
-		m_proxy_cnt++;
+		nld_base_d_to_a_proxy *proxy = get_d_a_proxy(out);
 
-		proxy->init(netlist(), x);
-		register_dev(proxy, x);
-
-		proxy->m_Q.net().register_con(in);
-		out.net().register_con(proxy->m_I);
+		connect_terminals(proxy->out(), in);
+		//proxy->out().net().register_con(in);
 	}
 	else
 	{
-		out.net().register_con(in);
+		if (in.has_net())
+			out.net().merge_net(&in.net());
+		else
+			out.net().register_con(in);
 	}
 }
 
@@ -391,11 +461,11 @@ void netlist_setup_t::connect_terminal_input(netlist_terminal_t &term, netlist_i
 	{
 		NL_VERBOSE_OUT(("connect_terminal_input: connecting proxy\n"));
 		nld_a_to_d_proxy *proxy = new nld_a_to_d_proxy(inp);
-		pstring x = pstring::sprintf("proxy_da_%d", m_proxy_cnt);
+		pstring x = pstring::sprintf("proxy_ad_%s_%d", inp.name().cstr(), m_proxy_cnt);
 		m_proxy_cnt++;
 
-		proxy->init(netlist(), x);
 		register_dev(proxy, x);
+		proxy->start_dev();
 
 		connect_terminals(term, proxy->m_I);
 
@@ -407,42 +477,31 @@ void netlist_setup_t::connect_terminal_input(netlist_terminal_t &term, netlist_i
 	}
 	else
 	{
-		netlist().xfatalerror("Netlist: Severe Error");
+		netlist().error("Netlist: Severe Error");
 	}
 }
 
-// FIXME: optimize code  ...
 void netlist_setup_t::connect_terminal_output(netlist_terminal_t &in, netlist_output_t &out)
 {
 	if (out.isFamily(netlist_terminal_t::ANALOG))
 	{
+		NL_VERBOSE_OUT(("connect_terminal_output: %s %s\n", in.name().cstr(), out.name().cstr()));
 		/* no proxy needed, just merge existing terminal net */
 		if (in.has_net())
 			out.net().merge_net(&in.net());
 		else
 			out.net().register_con(in);
-
 	}
 	else if (out.isFamily(netlist_terminal_t::LOGIC))
 	{
 		NL_VERBOSE_OUT(("connect_terminal_output: connecting proxy\n"));
-		nld_d_to_a_proxy *proxy = new nld_d_to_a_proxy(out);
-		pstring x = pstring::sprintf("proxy_da_%d", m_proxy_cnt);
-		m_proxy_cnt++;
+		nld_base_d_to_a_proxy *proxy = get_d_a_proxy(out);
 
-		proxy->init(netlist(), x);
-		register_dev(proxy, x);
-
-		out.net().register_con(proxy->m_I);
-
-		if (in.has_net())
-			proxy->m_Q.net().merge_net(&in.net());
-		else
-			proxy->m_Q.net().register_con(in);
+		connect_terminals(proxy->out(), in);
 	}
 	else
 	{
-		netlist().xfatalerror("Netlist: Severe Error");
+		netlist().error("Netlist: Severe Error");
 	}
 }
 
@@ -469,7 +528,7 @@ void netlist_setup_t::connect_terminals(netlist_core_terminal_t &t1, netlist_cor
 	else
 	{
 		NL_VERBOSE_OUT(("adding net ...\n"));
-		netlist_net_t *anet =  new netlist_net_t(netlist_object_t::NET, netlist_object_t::ANALOG);
+		netlist_analog_net_t *anet =  new netlist_analog_net_t();
 		t1.set_net(*anet);
 		//m_netlist.solver()->m_nets.add(anet);
 		// FIXME: Nets should have a unique name
@@ -479,21 +538,33 @@ void netlist_setup_t::connect_terminals(netlist_core_terminal_t &t1, netlist_cor
 	}
 }
 
-void netlist_setup_t::connect(netlist_core_terminal_t &t1, netlist_core_terminal_t &t2)
+static netlist_core_terminal_t &resolve_proxy(netlist_core_terminal_t &term)
 {
-	NL_VERBOSE_OUT(("Connecting %s to %s\n", t1.name().cstr(), t2.name().cstr()));
-	// FIXME: amend device design so that warnings can be turned into errors
-	//        Only variable inputs have this issue
+	if (term.isType(netlist_core_terminal_t::OUTPUT) && term.isFamily(netlist_core_terminal_t::LOGIC))
+	{
+		netlist_logic_output_t &out = dynamic_cast<netlist_logic_output_t &>(term);
+		if (out.has_proxy())
+			return out.get_proxy()->out();
+	}
+	return term;
+}
+
+void netlist_setup_t::connect(netlist_core_terminal_t &t1_in, netlist_core_terminal_t &t2_in)
+{
+	NL_VERBOSE_OUT(("Connecting %s to %s\n", t1_in.name().cstr(), t2_in.name().cstr()));
+	netlist_core_terminal_t &t1 = resolve_proxy(t1_in);
+	netlist_core_terminal_t &t2 = resolve_proxy(t2_in);
+
 	if (t1.isType(netlist_core_terminal_t::OUTPUT) && t2.isType(netlist_core_terminal_t::INPUT))
 	{
-		if (t2.has_net())
-			NL_VERBOSE_OUT(("Input %s already connected\n", t2.name().cstr()));
+		if (t2.has_net() && t2.net().isRailNet())
+			netlist().error("Input %s already connected\n", t2.name().cstr());
 		connect_input_output(dynamic_cast<netlist_input_t &>(t2), dynamic_cast<netlist_output_t &>(t1));
 	}
 	else if (t1.isType(netlist_core_terminal_t::INPUT) && t2.isType(netlist_core_terminal_t::OUTPUT))
 	{
-		if (t1.has_net())
-			NL_VERBOSE_OUT(("Input %s already connected\n", t1.name().cstr()));
+		if (t1.has_net()  && t1.net().isRailNet())
+			netlist().error("Input %s already connected\n", t1.name().cstr());
 		connect_input_output(dynamic_cast<netlist_input_t &>(t1), dynamic_cast<netlist_output_t &>(t2));
 	}
 	else if (t1.isType(netlist_core_terminal_t::OUTPUT) && t2.isType(netlist_core_terminal_t::TERMINAL))
@@ -517,50 +588,104 @@ void netlist_setup_t::connect(netlist_core_terminal_t &t1, netlist_core_terminal
 		connect_terminals(dynamic_cast<netlist_terminal_t &>(t1), dynamic_cast<netlist_terminal_t &>(t2));
 	}
 	else
-		netlist().xfatalerror("Connecting %s to %s not supported!\n", t1.name().cstr(), t2.name().cstr());
+		netlist().error("Connecting %s to %s not supported!\n", t1.name().cstr(), t2.name().cstr());
 }
 
 void netlist_setup_t::resolve_inputs()
 {
-	NL_VERBOSE_OUT(("Resolving ...\n"));
-	for (tagmap_link_t::entry_t *entry = m_links.first(); entry != NULL; entry = m_links.next(entry))
+	bool has_twoterms = false;
+
+	netlist().log("Resolving inputs ...");
+
+	for (const link_t *entry = m_links.first(); entry != NULL; entry = m_links.next(entry))
 	{
-		const pstring t1s = entry->object().e1;
-		const pstring t2s = entry->object().e2;
+		const pstring t1s = entry->e1;
+		const pstring t2s = entry->e2;
 		netlist_core_terminal_t *t1 = find_terminal(t1s);
 		netlist_core_terminal_t *t2 = find_terminal(t2s);
 
 		connect(*t1, *t2);
 	}
 
+	//netlist().log("printing outputs ...");
 	/* print all outputs */
-	for (tagmap_terminal_t::entry_t *entry = m_terminals.first(); entry != NULL; entry = m_terminals.next(entry))
+	for (int i = 0; i < m_terminals.count(); i++)
 	{
-		ATTR_UNUSED netlist_output_t *out = dynamic_cast<netlist_output_t *>(entry->object());
+		ATTR_UNUSED netlist_output_t *out = dynamic_cast<netlist_output_t *>(m_terminals[i]);
 		//if (out != NULL)
 			//VERBOSE_OUT(("%s %d\n", out->netdev()->name(), *out->Q_ptr()));
 	}
 
-#if 0
-	NL_VERBOSE_OUT(("deleting empty nets ...\n"));
+	netlist().log("deleting empty nets ...");
 
-	// delete empty nets ...
-	for (netlist_net_t::list_t::entry_t *pn = netlist().m_nets.first(); pn != NULL; pn = netlist().m_nets.next(pn))
+	// delete empty nets ... and save m_list ...
+
+	netlist_net_t::list_t todelete;
+
+	for (netlist_net_t *const *pn = netlist().m_nets.first(); pn != NULL; pn = netlist().m_nets.next(pn))
 	{
-		if (pn->object()->m_head == NULL)
+		if ((*pn)->num_cons() == 0)
 		{
-			NL_VERBOSE_OUT(("Deleting net ...\n"));
-			netlist_net_t *to_delete = pn->object();
-			netlist().m_nets.remove(to_delete);
-			if (!to_delete->isRailNet())
-				delete to_delete;
-			pn--;
+			todelete.add(*pn);
+		}
+		else
+		{
+#if 0
+			for (netlist_core_terminal_t *p = (*pn)->m_list.first(); p != NULL; p = (*pn)->m_list.next(p))
+				(*pn)->m_registered.add(p);
+#else
+			(*pn)->rebuild_list();
+#endif
 		}
 	}
-#endif
-	if (m_netlist.solver() != NULL)
-		m_netlist.solver()->post_start();
 
+	for (int i=0; i < todelete.count(); i++)
+	{
+		netlist().log("Deleting net %s ...", todelete[i]->name().cstr());
+		netlist().m_nets.remove(todelete[i]);
+		if (!todelete[i]->isRailNet())
+			delete todelete[i];
+	}
+
+	pstring errstr("");
+
+	netlist().log("looking for terminals not connected ...");
+	for (int i = 0; i < m_terminals.count(); i++)
+	{
+		if (!m_terminals[i]->has_net())
+			errstr += pstring::sprintf("Found terminal %s without a net\n",
+					m_terminals[i]->name().cstr());
+		else if (m_terminals[i]->net().num_cons() == 0)
+			netlist().warning("Found terminal %s without connections",
+					m_terminals[i]->name().cstr());
+	}
+	if (errstr != "")
+		netlist().error("%s", errstr.cstr());
+
+
+	netlist().log("looking for two terms connected to rail nets ...\n");
+	// FIXME: doesn't find internal devices. This needs to be more clever
+	for (int i=0; i < netlist().m_devices.count(); i++)
+	{
+		NETLIB_NAME(twoterm) *t = dynamic_cast<NETLIB_NAME(twoterm) *>(netlist().m_devices[i]);
+		if (t != NULL)
+		{
+			has_twoterms = true;
+			if (t->m_N.net().isRailNet() && t->m_P.net().isRailNet())
+				netlist().error("Found device %s connected only to railterminals %s/%s\n",
+						t->name().cstr(), t->m_N.net().name().cstr(), t->m_P.net().name().cstr());
+		}
+	}
+
+	netlist().log("initialize solver ...\n");
+
+	if (m_netlist.solver() == NULL)
+	{
+		if (has_twoterms)
+			netlist().error("No solver found for this net although analog elements are present\n");
+	}
+	else
+		m_netlist.solver()->post_start();
 
 }
 
@@ -572,6 +697,7 @@ void netlist_setup_t::start_devices()
 		nl_util::pstring_list ll = nl_util::split(getenv("NL_LOGS"), ":");
 		for (int i=0; i < ll.count(); i++)
 		{
+			NL_VERBOSE_OUT(("%d: <%s>\n",i, ll[i].cstr()));
 			NL_VERBOSE_OUT(("%d: <%s>\n",i, ll[i].cstr()));
 			netlist_device_t *nc = factory().new_device_by_classname("nld_log", *this);
 			pstring name = "log_" + ll[i];
@@ -582,27 +708,8 @@ void netlist_setup_t::start_devices()
 
 
 	NL_VERBOSE_OUT(("Searching for mainclock and solver ...\n"));
-	/* find the main clock ... */
-	for (tagmap_devices_t::entry_t *entry = netlist().m_devices.first(); entry != NULL; entry = netlist().m_devices.next(entry))
-	{
-		netlist_device_t *dev = entry->object();
-		if (dynamic_cast<NETLIB_NAME(mainclock)*>(dev) != NULL)
-		{
-			m_netlist.set_mainclock_dev(dynamic_cast<NETLIB_NAME(mainclock)*>(dev));
-		}
-		if (dynamic_cast<NETLIB_NAME(solver)*>(dev) != NULL)
-		{
-			m_netlist.set_solver_dev(dynamic_cast<NETLIB_NAME(solver)*>(dev));
-		}
-	}
-
-	NL_VERBOSE_OUT(("Initializing devices ...\n"));
-	for (tagmap_devices_t::entry_t *entry = netlist().m_devices.first(); entry != NULL; entry = netlist().m_devices.next(entry))
-	{
-		netlist_device_t *dev = entry->object();
-		dev->init(netlist(), entry->tag().cstr());
-	}
 
+	netlist().start();
 }
 
 void netlist_setup_t::parse(const char *buf)
@@ -611,11 +718,11 @@ void netlist_setup_t::parse(const char *buf)
 	parser.parse(buf);
 }
 
-void netlist_setup_t::print_stats()
+void netlist_setup_t::print_stats() const
 {
 #if (NL_KEEP_STATISTICS)
 	{
-		for (netlist_setup_t::tagmap_devices_t::entry_t *entry = m_devices.first(); entry != NULL; entry = m_devices.next(entry))
+		for (netlist_setup_t::devices_list_t::entry_t *entry = m_devices.first(); entry != NULL; entry = m_devices.next(entry))
 		{
 			//entry->object()->s
 			printf("Device %20s : %12d %15ld\n", entry->object()->name().cstr(), entry->object()->stat_count, (long int) entry->object()->total_time / (entry->object()->stat_count + 1));
