@@ -162,7 +162,6 @@ class render_font;
 struct object_transform;
 class layout_element;
 class layout_view;
-class layout_file;
 
 
 // texture scaling callback
@@ -246,15 +245,11 @@ class render_screen_list
 	};
 
 public:
-	// construction/destruction
-	render_screen_list(resource_pool &pool = global_resource_pool())
-		: m_list(pool) { }
-
 	// getters
 	int count() const { return m_list.count(); }
 
 	// operations
-	void add(screen_device &screen) { m_list.append(*pool_alloc(m_list.pool(), item(screen))); }
+	void add(screen_device &screen) { m_list.append(*global_alloc(item(screen))); }
 	void reset() { m_list.reset(); }
 
 	// query
@@ -424,6 +419,7 @@ class render_texture
 public:
 	// getters
 	int format() const { return m_format; }
+	render_manager *manager() const { return m_manager; }
 
 	// configure the texture bitmap
 	void set_bitmap(bitmap_t &bitmap, const rectangle &sbounds, texture_format format);
@@ -454,8 +450,6 @@ private:
 	bitmap_t *          m_bitmap;                   // pointer to the original bitmap
 	rectangle           m_sbounds;                  // source bounds within the bitmap
 	texture_format      m_format;                   // format of the texture data
-	rgb_t *             m_bcglookup;                // dynamically allocated B/C/G lookup table
-	UINT32              m_bcglookup_entries;        // number of B/C/G lookup entries allocated
 	UINT64              m_osddata;                  // aux data to pass to osd
 
 	// scaling state (ARGB32 only)
@@ -579,12 +573,14 @@ private:
 	user_settings           m_user;                 // user settings
 	bitmap_argb32 *         m_overlaybitmap;        // overlay bitmap
 	render_texture *        m_overlaytexture;       // overlay texture
-	palette_client *        m_palclient;            // client to the system palette
+	auto_pointer<palette_client> m_palclient;       // client to the screen palette
+	dynamic_array<rgb_t>    m_bcglookup;            // full palette lookup with bcg adjustments
 	rgb_t                   m_bcglookup256[0x400];  // lookup table for brightness/contrast/gamma
-	rgb_t                   m_bcglookup[0x10000];   // full palette lookup with bcg adjustements
 };
 
 
+#include "rendlay.h"
+
 // ======================> render_target
 
 // a render_target describes a surface that is being rendered to
@@ -695,7 +691,7 @@ private:
 	render_target *         m_next;                     // link to next target
 	render_manager &        m_manager;                  // reference to our owning manager
 	layout_view *           m_curview;                  // current view
-	simple_list<layout_file> &m_filelist;               // list of layout files
+	simple_list<layout_file> m_filelist;                // list of layout files
 	UINT32                  m_flags;                    // creation flags
 	render_primitive_list   m_primlist[NUM_PRIMLISTS];  // list of primitives
 	int                     m_listindex;                // index of next primlist to use
@@ -715,7 +711,7 @@ private:
 	INT32                   m_clear_extent_count;       // number of clear extents
 	INT32                   m_clear_extents[MAX_CLEAR_EXTENTS]; // array of clear extents
 
-	static const render_screen_list s_empty_screen_list;
+	static render_screen_list s_empty_screen_list;
 };
 
 
