@@ -19,6 +19,7 @@
 #define VERBOSE 0
 
 #define LOG(x)  do { if (VERBOSE) logerror x; } while (0)
+#define PRECISION
 
 
 
@@ -174,7 +175,7 @@ bool emu_timer::enable(bool enable)
 //  firings
 //-------------------------------------------------
 
-void emu_timer::adjust(attotime start_delay, INT32 param, attotime period)
+void emu_timer::adjust(attotime start_delay, INT32 param, const attotime &period)
 {
 	// if this is the callback timer, mark it modified
 	device_scheduler &scheduler = machine().scheduler();
@@ -292,7 +293,7 @@ inline void emu_timer::schedule_next_period()
 
 void emu_timer::dump() const
 {
-	logerror("%p: en=%d temp=%d exp=%15s start=%15s per=%15s param=%d ptr=%p", this, m_enabled, m_temporary, m_expire.as_string(), m_start.as_string(), m_period.as_string(), m_param, m_ptr);
+	logerror("%p: en=%d temp=%d exp=%15s start=%15s per=%15s param=%d ptr=%p", this, m_enabled, m_temporary, m_expire.as_string(PRECISION), m_start.as_string(PRECISION), m_period.as_string(PRECISION), m_param, m_ptr);
 	if (m_device == NULL)
 		logerror(" cb=%s\n", m_callback.name());
 	else
@@ -315,13 +316,10 @@ device_scheduler::device_scheduler(running_machine &machine) :
 	m_execute_list(NULL),
 	m_basetime(attotime::zero),
 	m_timer_list(NULL),
-	m_timer_allocator(machine.respool()),
 	m_callback_timer(NULL),
 	m_callback_timer_modified(false),
 	m_callback_timer_expire_time(attotime::zero),
 	m_suspend_changes_pending(true),
-	m_quantum_list(machine.respool()),
-	m_quantum_allocator(machine.respool()),
 	m_quantum_minimum(ATTOSECONDS_IN_NSEC(1) / 1000)
 {
 	// append a single never-expiring timer so there is always one in the list
@@ -418,11 +416,12 @@ void device_scheduler::timeslice()
 	bool call_debugger = ((machine().debug_flags & DEBUG_FLAG_ENABLED) != 0);
 
 	// build the execution list if we don't have one yet
-	if (m_execute_list == NULL)
+	if (UNEXPECTED(m_execute_list == NULL))
 		rebuild_execute_list();
 
-	// execute timers
-	execute_timers();
+	// if the current quantum has expired, find a new one
+	while (m_basetime >= m_quantum_list.first()->m_expire)
+		m_quantum_allocator.reclaim(m_quantum_list.detach_head());
 
 	// loop until we hit the next timer
 	while (m_basetime < m_timer_list->m_expire)
@@ -435,17 +434,18 @@ void device_scheduler::timeslice()
 			target = m_timer_list->m_expire;
 
 		LOG(("------------------\n"));
-		LOG(("cpu_timeslice: target = %s\n", target.as_string()));
+		LOG(("cpu_timeslice: target = %s\n", target.as_string(PRECISION)));
 
 		// do we have pending suspension changes?
 		if (m_suspend_changes_pending)
 			apply_suspend_changes();
 
-		// loop over non-suspended CPUs
+		// loop over all CPUs
 		for (device_execute_interface *exec = m_execute_list; exec != NULL; exec = exec->m_nextexec)
 		{
-			// only process if our target is later than the CPU's current time (coarse check)
-			if (target.seconds >= exec->m_localtime.seconds)
+			// only process if this CPU is executing or truly halted (not yielding)
+			// and if our target is later than the CPU's current time (coarse check)
+			if (EXPECTED((exec->m_suspend == 0 || exec->m_eatcycles) && target.seconds >= exec->m_localtime.seconds))
 			{
 				// compute how many attoseconds to execute this CPU
 				attoseconds_t delta = target.attoseconds - exec->m_localtime.attoseconds;
@@ -460,7 +460,7 @@ void device_scheduler::timeslice()
 				{
 					// compute how many cycles we want to execute
 					int ran = exec->m_cycles_running = divu_64x32((UINT64)delta >> exec->m_divshift, exec->m_divisor);
-					LOG(("  cpu '%s': %d cycles\n", exec->device().tag(), exec->m_cycles_running));
+					LOG(("  cpu '%s': %"I64FMT"d (%d cycles)\n", exec->device().tag(), delta, exec->m_cycles_running));
 
 					// if we're not suspended, actually execute
 					if (exec->m_suspend == 0)
@@ -496,12 +496,11 @@ void device_scheduler::timeslice()
 					attotime delta = attotime(0, exec->m_attoseconds_per_cycle * ran);
 					assert(delta >= attotime::zero);
 					exec->m_localtime += delta;
-					LOG(("         %d ran, %d total, time = %s\n", ran, (INT32)exec->m_totalcycles, exec->m_localtime.as_string()));
+					LOG(("         %d ran, %d total, time = %s\n", ran, (INT32)exec->m_totalcycles, exec->m_localtime.as_string(PRECISION)));
 
 					// if the new local CPU time is less than our target, move the target up, but not before the base
 					if (exec->m_localtime < target)
 					{
-						assert(exec->m_localtime < target);
 						target = max(exec->m_localtime, m_basetime);
 						LOG(("         (new target)\n"));
 					}
@@ -513,6 +512,9 @@ void device_scheduler::timeslice()
 		// update the base time
 		m_basetime = target;
 	}
+
+	// execute timers
+	execute_timers();
 }
 
 
@@ -532,7 +534,7 @@ void device_scheduler::abort_timeslice()
 //  trigger - generate a global trigger
 //-------------------------------------------------
 
-void device_scheduler::trigger(int trigid, attotime after)
+void device_scheduler::trigger(int trigid, const attotime &after)
 {
 	// ensure we have a list of executing devices
 	if (m_execute_list == NULL)
@@ -554,7 +556,7 @@ void device_scheduler::trigger(int trigid, attotime after)
 //  interleave factor
 //-------------------------------------------------
 
-void device_scheduler::boost_interleave(attotime timeslice_time, attotime boost_duration)
+void device_scheduler::boost_interleave(const attotime &timeslice_time, const attotime &boost_duration)
 {
 	// ignore timeslices > 1 second
 	if (timeslice_time.seconds > 0)
@@ -580,7 +582,7 @@ emu_timer *device_scheduler::timer_alloc(timer_expired_delegate callback, void *
 //  amount of time
 //-------------------------------------------------
 
-void device_scheduler::timer_set(attotime duration, timer_expired_delegate callback, int param, void *ptr)
+void device_scheduler::timer_set(const attotime &duration, timer_expired_delegate callback, int param, void *ptr)
 {
 	m_timer_allocator.alloc()->init(machine(), callback, ptr, true).adjust(duration, param);
 }
@@ -592,7 +594,7 @@ void device_scheduler::timer_set(attotime duration, timer_expired_delegate callb
 //  frequency
 //-------------------------------------------------
 
-void device_scheduler::timer_pulse(attotime period, timer_expired_delegate callback, int param, void *ptr)
+void device_scheduler::timer_pulse(const attotime &period, timer_expired_delegate callback, int param, void *ptr)
 {
 	m_timer_allocator.alloc()->init(machine(), callback, ptr, false).adjust(period, param, period);
 }
@@ -615,7 +617,7 @@ emu_timer *device_scheduler::timer_alloc(device_t &device, device_timer_id id, v
 //  time
 //-------------------------------------------------
 
-void device_scheduler::timer_set(attotime duration, device_t &device, device_timer_id id, int param, void *ptr)
+void device_scheduler::timer_set(const attotime &duration, device_t &device, device_timer_id id, int param, void *ptr)
 {
 	m_timer_allocator.alloc()->init(device, id, ptr, true).adjust(duration, param);
 }
@@ -683,6 +685,7 @@ void device_scheduler::postload()
 		timer_list_insert(*timer);
 
 	m_suspend_changes_pending = true;
+	rebuild_execute_list();
 
 	// report the timer state after a log
 	logerror("After resetting/reordering timers:\n");
@@ -867,17 +870,12 @@ emu_timer &device_scheduler::timer_list_remove(emu_timer &timer)
 
 
 //-------------------------------------------------
-//  execute_timers - execute timers and update
-//  scheduling quanta
+//  execute_timers - execute timers that are due
 //-------------------------------------------------
 
 inline void device_scheduler::execute_timers()
 {
-	// if the current quantum has expired, find a new one
-	while (m_basetime >= m_quantum_list.first()->m_expire)
-		m_quantum_allocator.reclaim(m_quantum_list.detach_head());
-
-	LOG(("execute_timers: new=%s head->expire=%s\n", m_basetime.as_string(), m_timer_list->m_expire.as_string()));
+	LOG(("execute_timers: new=%s head->expire=%s\n", m_basetime.as_string(PRECISION), m_timer_list->m_expire.as_string(PRECISION)));
 
 	// now process any timers that are overdue
 	while (m_timer_list->m_expire <= m_basetime)
@@ -900,7 +898,7 @@ inline void device_scheduler::execute_timers()
 
 			if (timer.m_device != NULL)
 			{
-				LOG(("execute_timers: timer device %s timer %d\n", timer.m_device->name(), timer.m_id));
+				LOG(("execute_timers: timer device %s timer %d\n", timer.m_device->tag(), timer.m_id));
 				timer.m_device->timer_expired(timer, timer.m_id, timer.m_param, timer.m_ptr);
 			}
 			else if (!timer.m_callback.isnull())
@@ -936,7 +934,7 @@ inline void device_scheduler::execute_timers()
 //  that is in use
 //-------------------------------------------------
 
-void device_scheduler::add_scheduling_quantum(attotime quantum, attotime duration)
+void device_scheduler::add_scheduling_quantum(const attotime &quantum, const attotime &duration)
 {
 	assert(quantum.seconds == 0);
 
@@ -981,7 +979,7 @@ void device_scheduler::add_scheduling_quantum(attotime quantum, attotime duratio
 void device_scheduler::dump_timers() const
 {
 	logerror("=============================================\n");
-	logerror("Timer Dump: Time = %15s\n", time().as_string());
+	logerror("Timer Dump: Time = %15s\n", time().as_string(PRECISION));
 	for (emu_timer *timer = first_timer(); timer != NULL; timer = timer->next())
 		timer->dump();
 	logerror("=============================================\n");
