@@ -17,25 +17,25 @@
 static void psg_set_clock(void *param, int clock)
 {
 	ym2610_device *ym2610 = (ym2610_device *) param;
-	ay8910_set_clock_ym(ym2610->_psg(), clock);
+	ym2610->ay_set_clock(clock);
 }
 
 static void psg_write(void *param, int address, int data)
 {
 	ym2610_device *ym2610 = (ym2610_device *) param;
-	ay8910_write_ym(ym2610->_psg(), address, data);
+	ym2610->ay8910_write_ym(address, data);
 }
 
 static int psg_read(void *param)
 {
 	ym2610_device *ym2610 = (ym2610_device *) param;
-	return ay8910_read_ym(ym2610->_psg());
+	return ym2610->ay8910_read_ym();
 }
 
 static void psg_reset(void *param)
 {
 	ym2610_device *ym2610 = (ym2610_device *) param;
-	ay8910_reset_ym(ym2610->_psg());
+	ym2610->ay8910_reset_ym();
 }
 
 static const ssg_callbacks psgintf =
@@ -46,11 +46,6 @@ static const ssg_callbacks psgintf =
 	psg_reset
 };
 
-void *ym2610_device::_psg()
-{
-	return m_psg;
-}
-
 /*------------------------- TM2610 -------------------------------*/
 /* IRQ Handler */
 static void IRQHandler(void *param,int irq)
@@ -116,8 +111,7 @@ void ym2610_device::_ym2610_update_request()
 //-------------------------------------------------
 //  sound_stream_update - handle a stream update
 //-------------------------------------------------
-
-void ym2610_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void ym2610_device::stream_generate(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
 {
 	ym2610_update_one(m_chip, outputs, samples);
 }
@@ -126,7 +120,7 @@ void ym2610_device::sound_stream_update(sound_stream &stream, stream_sample_t **
 //  sound_stream_update - handle a stream update
 //-------------------------------------------------
 
-void ym2610b_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void ym2610b_device::stream_generate(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
 {
 	ym2610b_update_one(m_chip, outputs, samples);
 }
@@ -144,12 +138,7 @@ void ym2610_device::device_post_load()
 
 void ym2610_device::device_start()
 {
-	static const ay8910_interface generic_ay8910 =
-	{
-		AY8910_LEGACY_OUTPUT | AY8910_SINGLE_OUTPUT,
-		AY8910_DEFAULT_LOADS,
-		DEVCB_NULL, DEVCB_NULL, DEVCB_NULL, DEVCB_NULL
-	};
+	ay8910_device::device_start();
 
 	int rate = clock()/72;
 	void *pcmbufa,*pcmbufb;
@@ -157,15 +146,13 @@ void ym2610_device::device_start()
 	astring name;
 
 	m_irq_handler.resolve();
-	m_psg = ay8910_start_ym(this, &generic_ay8910);
-	assert_always(m_psg != NULL, "Error creating YM2610/AY8910 chip");
 
 	/* Timer Handler set */
 	m_timer[0] = timer_alloc(0);
 	m_timer[1] = timer_alloc(1);
 
 	/* stream system initialize */
-	m_stream = machine().sound().stream_alloc(*this,0,2,rate);
+	m_stream = machine().sound().stream_alloc(*this,0,2,rate, stream_update_delegate(FUNC(ym2610_device::stream_generate),this));
 	/* setup adpcm buffers */
 	pcmbufa  = *region();
 	pcmsizea = region()->bytes();
@@ -192,7 +179,6 @@ void ym2610_device::device_start()
 void ym2610_device::device_stop()
 {
 	ym2610_shutdown(m_chip);
-	ay8910_stop_ym(m_psg);
 }
 
 //-------------------------------------------------
@@ -219,29 +205,17 @@ WRITE8_MEMBER( ym2610_device::write )
 const device_type YM2610 = &device_creator<ym2610_device>;
 
 ym2610_device::ym2610_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: device_t(mconfig, YM2610, "YM2610", tag, owner, clock, "ym2610", __FILE__),
-		device_sound_interface(mconfig, *this),
+	: ay8910_device(mconfig, YM2610, "YM2610", tag, owner, clock, PSG_TYPE_YM, 1, 0, "ym2610", __FILE__),
 		m_irq_handler(*this)
 {
 }
 
 ym2610_device::ym2610_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, const char *shortname, const char *source)
-	: device_t(mconfig, type, name, tag, owner, clock, shortname, source),
-		device_sound_interface(mconfig, *this),
+	: ay8910_device(mconfig, type, name, tag, owner, clock, PSG_TYPE_YM, 1, 0, shortname, source),
 		m_irq_handler(*this)
 {
 }
 
-//-------------------------------------------------
-//  device_config_complete - perform any
-//  operations now that the configuration is
-//  complete
-//-------------------------------------------------
-
-void ym2610_device::device_config_complete()
-{
-}
-
 const device_type YM2610B = &device_creator<ym2610b_device>;
 
 ym2610b_device::ym2610b_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
