@@ -46,13 +46,13 @@ void y8950_device::device_timer(emu_timer &timer, device_timer_id id, int param,
 	}
 }
 
-static void timer_handler(void *param, int c, attotime period)
+static void timer_handler(void *param, int c, const attotime &period)
 {
 	y8950_device *y8950 = (y8950_device *) param;
 	y8950->_timer_handler(c, period);
 }
 
-void y8950_device::_timer_handler(int c, attotime period)
+void y8950_device::_timer_handler(int c, const attotime &period)
 {
 	if( period == attotime::zero )
 	{   /* Reset FM Timer */
