@@ -106,12 +106,8 @@ c140_device::c140_device(const machine_config &mconfig, const char *tag, device_
 
 void c140_device::device_start()
 {
-	const c140_interface *intf = (const c140_interface *)static_config();
-
 	m_sample_rate=m_baserate=clock();
 
-	m_banking_type = intf->banking_type;
-
 	m_stream = stream_alloc(0, 2, m_sample_rate);
 
 	m_pRom=*region();
@@ -331,8 +327,12 @@ void c140_device::sound_stream_update(sound_stream &stream, stream_sample_t **in
 		stream_sample_t *dest2 = outputs[1];
 		for (i = 0; i < samples; i++)
 		{
-			*dest1++ = limit(8*(*lmix++));
-			*dest2++ = limit(8*(*rmix++));
+			INT32 val;
+
+			val = 8 * (*lmix++);
+			*dest1++ = limit(val);
+			val = 8 * (*rmix++);
+			*dest2++ = limit(val);
 		}
 	}
 }
