@@ -17,26 +17,22 @@
 // device type definition
 const device_type ICS2115 = &device_creator<ics2115_device>;
 
-void ics2115_device::static_set_irqf(device_t &device, void (*irqf)(device_t *device, int state))
-{
-	ics2115_device &ics2115 = downcast<ics2115_device &>(device);
-	ics2115.m_irq_cb = irqf;
-}
-
 ics2115_device::ics2115_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
 	: device_t(mconfig, ICS2115, "ICS2115", tag, owner, clock, "ics2115", __FILE__),
 		device_sound_interface(mconfig, *this),
-		m_irq_cb(NULL)
+		m_irq_cb(*this)
 {
 }
 
 void ics2115_device::device_start()
 {
 	m_rom = *region();
-	m_timer[0].timer = machine().scheduler().timer_alloc(FUNC(timer_cb_0), this);
-	m_timer[1].timer = machine().scheduler().timer_alloc(FUNC(timer_cb_1), this);
+	m_timer[0].timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(ics2115_device::timer_cb_0),this), this);
+	m_timer[1].timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(ics2115_device::timer_cb_1),this), this);
 	m_stream = machine().sound().stream_alloc(*this, 0, 2, 33075);
 
+	m_irq_cb.resolve_safe();
+
 	//Exact formula as per patent 5809466
 	//This seems to give the ok fit but it is not good enough.
 	/*double maxvol = ((1 << volume_bits) - 1) * pow(2., (double)1/0x100);
@@ -110,6 +106,7 @@ void ics2115_device::device_reset()
 	m_osc_select = 0;
 	m_reg_select = 0;
 	m_vmode = 0;
+	m_irq_on = false;
 	memset(m_voice, 0, sizeof(m_voice));
 	for(int i = 0; i < 2; ++i)
 	{
@@ -760,22 +757,20 @@ void ics2115_device::reg_write(UINT8 data, bool msb) {
 	}
 }
 
-//UINT8 ics2115_device::read (offs_t offset)
-READ8_DEVICE_HANDLER(ics2115_device::read)
+READ8_MEMBER(ics2115_device::read)
 {
-	ics2115_device *chip = downcast<ics2115_device *>(device);
 	UINT8 ret = 0;
 
 	switch(offset) {
 		case 0:
 			//TODO: check this suspect code
-			if (chip->m_irq_on) {
+			if (m_irq_on) {
 				ret |= 0x80;
-				if (chip->m_irq_enabled && (chip->m_irq_pending & 3))
+				if (m_irq_enabled && (m_irq_pending & 3))
 					ret |= 1;
-				for (int i = 0; i <= chip->m_active_osc; i++) {
-					if (//chip->m_voice[i].vol_ctrl.irq_pending ||
-						chip->m_voice[i].osc_conf.irq_pending) {
+				for (int i = 0; i <= m_active_osc; i++) {
+					if (//m_voice[i].vol_ctrl.irq_pending ||
+						m_voice[i].osc_conf.irq_pending) {
 						ret |= 2;
 						break;
 					}
@@ -784,13 +779,13 @@ READ8_DEVICE_HANDLER(ics2115_device::read)
 
 			break;
 		case 1:
-			ret = chip->m_reg_select;
+			ret = m_reg_select;
 			break;
 		case 2:
-			ret = (UINT8)(chip->reg_read());
+			ret = (UINT8)(reg_read());
 			break;
 		case 3:
-			ret = chip->reg_read() >> 8;
+			ret = reg_read() >> 8;
 			break;
 		default:
 #ifdef ICS2115_DEBUG
@@ -801,19 +796,17 @@ READ8_DEVICE_HANDLER(ics2115_device::read)
 	return ret;
 }
 
-//UINT8 ics2115_device::write(offs_t offset, UINT8 data)
-WRITE8_DEVICE_HANDLER(ics2115_device::write)
+WRITE8_MEMBER(ics2115_device::write)
 {
-	ics2115_device *chip = downcast<ics2115_device *>(device);
 	switch(offset) {
 		case 1:
-			chip->m_reg_select = data;
+			m_reg_select = data;
 			break;
 		case 2:
-			chip->reg_write(data,0);
+			reg_write(data,0);
 			break;
 		case 3:
-			chip->reg_write(data,1);
+			reg_write(data,1);
 			break;
 		default:
 #ifdef ICS2115_DEBUG
@@ -861,22 +854,20 @@ void ics2115_device::recalc_irq()
 	for(int i = 0; (!irq) && (i < 32); i++)
 		irq |=  m_voice[i].vol_ctrl.irq_pending && m_voice[i].osc_conf.irq_pending;
 	m_irq_on = irq;
-	if(m_irq_cb)
-		m_irq_cb(this, irq ? ASSERT_LINE : CLEAR_LINE);
+	if(!m_irq_cb.isnull())
+		m_irq_cb(irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-TIMER_CALLBACK( ics2115_device::timer_cb_0 )
+TIMER_CALLBACK_MEMBER( ics2115_device::timer_cb_0 )
 {
-	ics2115_device *chip = (ics2115_device *)ptr;
-	chip->m_irq_pending |= 1 << 0;
-	chip->recalc_irq();
+	m_irq_pending |= 1 << 0;
+	recalc_irq();
 }
 
-TIMER_CALLBACK( ics2115_device::timer_cb_1 )
+TIMER_CALLBACK_MEMBER( ics2115_device::timer_cb_1 )
 {
-	ics2115_device *chip = (ics2115_device *)ptr;
-	chip->m_irq_pending |= 1 << 1;
-	chip->recalc_irq();
+	m_irq_pending |= 1 << 1;
+	recalc_irq();
 }
 
 void ics2115_device::recalc_timer(int timer)
