@@ -1,6 +1,6 @@
 /*****************************************************************************
  *
- *  POKEY chip emulator 4.3
+ *  POKEY chip emulator 4.6
  *  Copyright Nicola Salmoria and the MAME Team
  *
  *  Based on original info found in Ron Fries' Pokey emulator,
@@ -66,14 +66,38 @@
 //  INTERFACE CONFIGURATION MACROS
 //**************************************************************************
 
-#define MCFG_POKEY_ADD(_tag, _clock) \
-	MCFG_DEVICE_ADD(_tag, POKEY, _clock)
+#define MCFG_POKEY_POT0_R_CB(_devcb) \
+	devcb = &pokey_device::set_pot0_r_callback(*device, DEVCB_##_devcb);
 
-#define MCFG_POKEY_REPLACE(_tag, _clock) \
-	MCFG_DEVICE_REPLACE(_tag, POKEY, _clock)
+#define MCFG_POKEY_POT1_R_CB(_devcb) \
+	devcb = &pokey_device::set_pot1_r_callback(*device, DEVCB_##_devcb);
 
-#define MCFG_POKEY_CONFIG(_intf) \
-	MCFG_DEVICE_CONFIG(_intf)
+#define MCFG_POKEY_POT2_R_CB(_devcb) \
+	devcb = &pokey_device::set_pot2_r_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_POKEY_POT3_R_CB(_devcb) \
+	devcb = &pokey_device::set_pot3_r_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_POKEY_POT4_R_CB(_devcb) \
+	devcb = &pokey_device::set_pot4_r_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_POKEY_POT5_R_CB(_devcb) \
+	devcb = &pokey_device::set_pot5_r_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_POKEY_POT6_R_CB(_devcb) \
+	devcb = &pokey_device::set_pot6_r_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_POKEY_POT7_R_CB(_devcb) \
+	devcb = &pokey_device::set_pot7_r_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_POKEY_ALLPOT_R_CB(_devcb) \
+	devcb = &pokey_device::set_allpot_r_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_POKEY_SERIN_R_CB(_devcb) \
+	devcb = &pokey_device::set_serin_r_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_POKEY_SEROUT_W_CB(_devcb) \
+	devcb = &pokey_device::set_serout_w_callback(*device, DEVCB_##_devcb);
 
 /* k543210 = k5 ... k0 returns bit0: kr1, bit1: kr2 */
 /* all are, in contrast to actual hardware, ACTIVE_HIGH */
@@ -110,24 +134,12 @@
 //  TYPE DEFINITIONS
 //**************************************************************************
 
-// ======================> pokey_interface
-
-struct pokey_interface
-{
-	devcb_read8 m_pot_r_cb[8];
-	devcb_read8 m_allpot_r_cb;
-	devcb_read8 m_serin_r_cb;
-	devcb_write8 m_serout_w_cb;
-};
-
-
 // ======================> pokey_device
 
 class pokey_device : public device_t,
 						public device_sound_interface,
 						public device_execute_interface,
-						public device_state_interface,
-						public pokey_interface
+						public device_state_interface
 {
 public:
 
@@ -197,6 +209,18 @@ public:
 	// construction/destruction
 	pokey_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
 
+	template<class _Object> static devcb_base &set_pot0_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_pot0_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_pot1_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_pot1_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_pot2_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_pot2_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_pot3_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_pot3_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_pot4_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_pot4_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_pot5_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_pot5_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_pot6_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_pot6_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_pot7_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_pot7_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_allpot_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_allpot_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_serin_r_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_serin_r_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_serout_w_callback(device_t &device, _Object object) { return downcast<pokey_device &>(device).m_serout_w_cb.set_callback(object); }
+
 	DECLARE_READ8_MEMBER( read );
 	DECLARE_WRITE8_MEMBER( write );
 
@@ -219,7 +243,6 @@ public:
 
 protected:
 	// device-level overrides
-	virtual void device_config_complete();
 	virtual void device_start();
 	virtual void device_reset();
 	virtual void device_post_load();
@@ -311,10 +334,17 @@ private:
 	UINT32 m_p9;              /* poly9 index */
 	UINT32 m_p17;             /* poly17 index */
 
-	devcb_resolved_read8 m_pot_r[8];
-	devcb_resolved_read8 m_allpot_r;
-	devcb_resolved_read8 m_serin_r;
-	devcb_resolved_write8 m_serout_w;
+	devcb_read8 m_pot0_r_cb;
+	devcb_read8 m_pot1_r_cb;
+	devcb_read8 m_pot2_r_cb;
+	devcb_read8 m_pot3_r_cb;
+	devcb_read8 m_pot4_r_cb;
+	devcb_read8 m_pot5_r_cb;
+	devcb_read8 m_pot6_r_cb;
+	devcb_read8 m_pot7_r_cb;
+	devcb_read8 m_allpot_r_cb;
+	devcb_read8 m_serin_r_cb;
+	devcb_write8 m_serout_w_cb;
 
 	UINT8 m_POTx[8];        /* POTx   (R/D200-D207) */
 	UINT8 m_AUDCTL;         /* AUDCTL (W/D208) */
