@@ -3,7 +3,7 @@
   t6w28.c (based on sn74696.c)
 
   The t6w28 sound core is used in the SNK NeoGeo Pocket. It is a stereo
-  sound chip based on 2 partial sn76498a cores.
+  sound chip based on 2 partial sn76489a cores.
 
   The block diagram for this chip is as follows:
 
@@ -294,7 +294,7 @@ void t6w28_device::device_start()
 	int i;
 
 	m_sample_rate = clock() / 16;
-	m_channel = machine().sound().stream_alloc(*this, 0, 2, m_sample_rate, this);
+	m_channel = machine().sound().stream_alloc(*this, 0, 2, m_sample_rate);
 
 	for (i = 0;i < 8;i++) m_volume[i] = 0;
 
