@@ -23,30 +23,35 @@
 /* usually 640000 for 8000 Hz sample rate or */
 /* usually 800000 for 10000 Hz sample rate.  */
 
-struct tms5110_interface
-{
-	/* legacy interface */
-	int (*M0_callback)(device_t *device);   /* function to be called when chip requests another bit */
-	void (*load_address)(device_t *device, int addr);   /* speech ROM load address callback */
-	/* new rom controller interface */
-	devcb_write_line m0_func;       /* the M0 line */
-	devcb_write_line m1_func;       /* the M1 line */
-	devcb_write8 addr_func;         /* Write to ADD1,2,4,8 - 4 address bits */
-	devcb_read_line data_func;      /* Read one bit from ADD8/Data - voice data */
-	/* on a real chip rom_clk is running all the time
-	 * Here, we only use it to properly emulate the protocol.
-	 * Do not rely on it to be a timed signal.
-	 */
-	devcb_write_line romclk_func;   /* rom clock - Only used to drive the data lines */
-};
+#define MCFG_TMS5110_M0_CB(_devcb) \
+	devcb = &tms5110_device::set_m0_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_TMS5110_M1_CB(_devcb) \
+	devcb = &tms5110_device::set_m1_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_TMS5110_ADDR_CB(_devcb) \
+	devcb = &tms5110_device::set_addr_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_TMS5110_DATA_CB(_devcb) \
+	devcb = &tms5110_device::set_data_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_TMS5110_ROMCLK_CB(_devcb) \
+	devcb = &tms5110_device::set_romclk_callback(*device, DEVCB_##_devcb);
+
 
 class tms5110_device : public device_t,
-									public device_sound_interface
+						public device_sound_interface
 {
 public:
 	tms5110_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
 	tms5110_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, const char *shortname, const char *source);
 
+	template<class _Object> static devcb_base &set_m0_callback(device_t &device, _Object object) { return downcast<tms5110_device &>(device).m_m0_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_m1_callback(device_t &device, _Object object) { return downcast<tms5110_device &>(device).m_m1_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_addr_callback(device_t &device, _Object object) { return downcast<tms5110_device &>(device).m_addr_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_data_callback(device_t &device, _Object object) { return downcast<tms5110_device &>(device).m_data_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_romclk_callback(device_t &device, _Object object) { return downcast<tms5110_device &>(device).m_romclk_cb.set_callback(object); }
+
 	DECLARE_WRITE8_MEMBER( ctl_w );
 	DECLARE_READ8_MEMBER( ctl_r );
 	DECLARE_WRITE_LINE_MEMBER( pdc_w );
@@ -65,7 +70,6 @@ public:
 
 protected:
 	// device-level overrides
-	virtual void device_config_complete();
 	virtual void device_start();
 	virtual void device_reset();
 
@@ -76,6 +80,9 @@ protected:
 
 	void set_variant(int variant);
 
+	UINT8 m_talk_status;
+	sound_stream *m_stream;
+
 private:
 	void new_int_write(UINT8 rc, UINT8 m0, UINT8 m1, UINT8 addr);
 	void new_int_write_addr(UINT8 addr);
@@ -99,7 +106,8 @@ private:
 	UINT8 m_PDC;
 	UINT8 m_CTL_pins;
 	UINT8 m_speaking_now;
-protected:  UINT8 m_talk_status; private:
+
+
 	UINT8 m_state;
 
 	/* Rom interface */
@@ -108,16 +116,15 @@ protected:  UINT8 m_talk_status; private:
 	UINT8  m_schedule_dummy_read;
 	UINT8  m_addr_bit;
 
-	/* external callback */
-	int (*m_M0_callback)(device_t *);
-	void (*m_set_load_address)(device_t *, int);
-
 	/* callbacks */
-	devcb_resolved_write_line m_m0_func;      /* the M0 line */
-	devcb_resolved_write_line m_m1_func;      /* the M1 line */
-	devcb_resolved_write8 m_addr_func;        /* Write to ADD1,2,4,8 - 4 address bits */
-	devcb_resolved_read_line m_data_func;     /* Read one bit from ADD8/Data - voice data */
-	devcb_resolved_write_line m_romclk_func;  /* rom clock - Only used to drive the data lines */
+	devcb_write_line   m_m0_cb;      // the M0 line
+	devcb_write_line   m_m1_cb;      // the M1 line
+	devcb_write8       m_addr_cb;    // Write to ADD1,2,4,8 - 4 address bits
+	devcb_read_line    m_data_cb;    // Read one bit from ADD8/Data - voice data
+	// On a real chip rom_clk is running all the time
+	// Here, we only use it to properly emulate the protocol.
+	// Do not rely on it to be a timed signal.
+	devcb_write_line   m_romclk_cb;  // rom clock - Only used to drive the data lines
 
 	/* these contain data describing the current and previous voice frames */
 	UINT16 m_old_energy;
@@ -157,9 +164,7 @@ protected:  UINT8 m_talk_status; private:
 	/* coefficient tables */
 	const struct tms5100_coeffs *m_coeff;
 
-protected: sound_stream *m_stream; private:
 	emu_timer *m_romclk_hack_timer;
-	const tms5110_interface *m_intf;
 	const UINT8 *m_table;
 };
 
@@ -238,38 +243,33 @@ extern const device_type M58817;
 
 /* PROM controlled TMS5110 interface */
 
-struct tmsprom_interface
-{
-	const char *prom_region;        /* prom memory region - sound region is automatically assigned */
-	UINT32 rom_size;                /* individual rom_size */
-	UINT8 pdc_bit;                  /* bit # of pdc line */
-	/* virtual bit 8: constant 0, virtual bit 9:constant 1 */
-	UINT8 ctl1_bit;                 /* bit # of ctl1 line */
-	UINT8 ctl2_bit;                 /* bit # of ctl2 line */
-	UINT8 ctl4_bit;                 /* bit # of ctl4 line */
-	UINT8 ctl8_bit;                 /* bit # of ctl8 line */
-	UINT8 reset_bit;                /* bit # of rom reset */
-	UINT8 stop_bit;                 /* bit # of stop */
-	devcb_write_line pdc_func;      /* tms pdc func */
-	devcb_write8 ctl_func;          /* tms ctl func */
-};
-
 class tmsprom_device : public device_t
 {
 public:
 	tmsprom_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
 
-	WRITE_LINE_MEMBER( m0_w );
-	READ_LINE_MEMBER( data_r );
+	static void set_region(device_t &device, const char *region) { downcast<tmsprom_device &>(device).m_prom_region = region; }
+	static void set_rom_size(device_t &device, UINT32 rom_size) { downcast<tmsprom_device &>(device).m_rom_size = rom_size; }
+	static void set_pdc_bit(device_t &device, UINT8 pdc_bit) { downcast<tmsprom_device &>(device).m_pdc_bit = pdc_bit; }
+	static void set_ctl1_bit(device_t &device, UINT8 ctl1_bit) { downcast<tmsprom_device &>(device).m_ctl1_bit = ctl1_bit; }
+	static void set_ctl2_bit(device_t &device, UINT8 ctl2_bit) { downcast<tmsprom_device &>(device).m_ctl2_bit = ctl2_bit; }
+	static void set_ctl4_bit(device_t &device, UINT8 ctl4_bit) { downcast<tmsprom_device &>(device).m_ctl4_bit = ctl4_bit; }
+	static void set_ctl8_bit(device_t &device, UINT8 ctl8_bit) { downcast<tmsprom_device &>(device).m_ctl8_bit = ctl8_bit; }
+	static void set_reset_bit(device_t &device, UINT8 reset_bit) { downcast<tmsprom_device &>(device).m_reset_bit = reset_bit; }
+	static void set_stop_bit(device_t &device, UINT8 stop_bit) { downcast<tmsprom_device &>(device).m_stop_bit = stop_bit; }
+	template<class _Object> static devcb_base &set_pdc_callback(device_t &device, _Object object) { return downcast<tmsprom_device &>(device).m_pdc_cb.set_callback(object); }
+	template<class _Object> static devcb_base &set_ctl_callback(device_t &device, _Object object) { return downcast<tmsprom_device &>(device).m_ctl_cb.set_callback(object); }
+
+	DECLARE_WRITE_LINE_MEMBER( m0_w );
+	DECLARE_READ_LINE_MEMBER( data_r );
 
 	/* offset is rom # */
 	DECLARE_WRITE8_MEMBER( rom_csq_w );
 	DECLARE_WRITE8_MEMBER( bit_w );
-	WRITE_LINE_MEMBER( enable_w );
+	DECLARE_WRITE_LINE_MEMBER( enable_w );
 
 protected:
 	// device-level overrides
-	virtual void device_config_complete();
 	virtual void device_start();
 
 	virtual void device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr);
@@ -289,17 +289,57 @@ private:
 
 	int m_prom_cnt;
 
-	devcb_resolved_write_line m_pdc_func;     /* tms pdc func */
-	devcb_resolved_write8 m_ctl_func;         /* tms ctl func */
+	const char *m_prom_region;        /* prom memory region - sound region is automatically assigned */
+	UINT32 m_rom_size;                /* individual rom_size */
+	UINT8 m_pdc_bit;                  /* bit # of pdc line */
+	/* virtual bit 8: constant 0, virtual bit 9:constant 1 */
+	UINT8 m_ctl1_bit;                 /* bit # of ctl1 line */
+	UINT8 m_ctl2_bit;                 /* bit # of ctl2 line */
+	UINT8 m_ctl4_bit;                 /* bit # of ctl4 line */
+	UINT8 m_ctl8_bit;                 /* bit # of ctl8 line */
+	UINT8 m_reset_bit;                /* bit # of rom reset */
+	UINT8 m_stop_bit;                 /* bit # of stop */
+	devcb_write_line m_pdc_cb;      /* tms pdc func */
+	devcb_write8 m_ctl_cb;          /* tms ctl func */
 
-	int    m_clock;
 	emu_timer *m_romclk_timer;
-	const tmsprom_interface *m_intf;
 	const UINT8 *m_rom;
 	const UINT8 *m_prom;
 };
 
 extern const device_type TMSPROM;
 
+#define MCFG_TMSPROM_REGION(_region) \
+	tmsprom_device::set_region(*device, _region);
+
+#define MCFG_TMSPROM_ROM_SIZE(_size) \
+	tmsprom_device::set_rom_size(*device, _size);
+
+#define MCFG_TMSPROM_PDC_BIT(_bit) \
+	tmsprom_device::set_pdc_bit(*device, _bit);
+
+#define MCFG_TMSPROM_CTL1_BIT(_bit) \
+	tmsprom_device::set_ctl1_bit(*device, _bit);
+
+#define MCFG_TMSPROM_CTL2_BIT(_bit) \
+	tmsprom_device::set_ctl2_bit(*device, _bit);
+
+#define MCFG_TMSPROM_CTL4_BIT(_bit) \
+	tmsprom_device::set_ctl4_bit(*device, _bit);
+
+#define MCFG_TMSPROM_CTL8_BIT(_bit) \
+	tmsprom_device::set_ctl8_bit(*device, _bit);
+
+#define MCFG_TMSPROM_RESET_BIT(_bit) \
+	tmsprom_device::set_reset_bit(*device, _bit);
+
+#define MCFG_TMSPROM_STOP_BIT(_bit) \
+	tmsprom_device::set_stop_bit(*device, _bit);
+
+#define MCFG_TMSPROM_PDC_CB(_devcb) \
+	devcb = &tmsprom_device::set_pdc_callback(*device, DEVCB_##_devcb);
+
+#define MCFG_TMSPROM_CTL_CB(_devcb) \
+	devcb = &tmsprom_device::set_ctl_callback(*device, DEVCB_##_devcb);
 
 #endif /* __TMS5110_H__ */
