@@ -126,7 +126,7 @@
 
 
 #define DEBUG_STATES    (0)
-#define DEBUG_METHOD    mame_printf_debug
+#define DEBUG_METHOD    osd_printf_debug
 
 
 
@@ -189,7 +189,8 @@ upd775x_device::upd775x_device(const machine_config &mconfig, device_type type,
 		m_rom(NULL),
 		m_rombase(NULL),
 		m_romoffset(0),
-		m_rommask(0)
+		m_rommask(0),
+		m_drqcallback(*this)
 {
 }
 
@@ -208,26 +209,6 @@ upd7756_device::upd7756_device(const machine_config &mconfig, const char *tag, d
 {
 }
 
-//-------------------------------------------------
-//  device_config_complete - perform any
-//  operations now that the configuration is
-//  complete
-//-------------------------------------------------
-
-void upd775x_device::device_config_complete()
-{
-	// inherit a copy of the static data
-	const upd775x_interface *intf = reinterpret_cast<const upd775x_interface *>(static_config());
-	if (intf != NULL)
-	*static_cast<upd775x_interface *>(this) = *intf;
-
-	// or initialize to defaults if none provided
-	else
-	{
-	m_drqcallback = NULL;
-	}
-}
-
 //-------------------------------------------------
 //  device_start - device-specific startup
 //-------------------------------------------------
@@ -238,11 +219,13 @@ void upd775x_device::device_start()
 
 void upd7759_device::device_start()
 {
+	m_drqcallback.resolve_safe();
+
 	/* chip configuration */
 	m_sample_offset_shift = (type() == UPD7759) ? 1 : 0;
 
 	/* allocate a stream channel */
-	m_channel = machine().sound().stream_alloc(*this, 0, 1, clock()/4, this);
+	m_channel = machine().sound().stream_alloc(*this, 0, 1, clock()/4);
 
 	/* compute the stepping rate based on the chip's clock speed */
 	m_step = 4 * FRAC_ONE;
@@ -268,7 +251,7 @@ void upd7759_device::device_start()
 		if (romsize >= 0x20000) m_rommask = 0x1ffff;
 		else m_rommask = romsize - 1;
 
-		m_drqcallback = NULL;
+		m_drqcallback.set_callback(DEVCB_NULL);
 	}
 
 	/* assume /RESET and /START are both high */
@@ -311,11 +294,13 @@ void upd7759_device::device_start()
 
 void upd7756_device::device_start()
 {
+	m_drqcallback.resolve_safe();
+
 	/* chip configuration */
 	m_sample_offset_shift = (type() == UPD7759) ? 1 : 0;
 
 	/* allocate a stream channel */
-	m_channel = machine().sound().stream_alloc(*this, 0, 1, clock()/4, this);
+	m_channel = machine().sound().stream_alloc(*this, 0, 1, clock()/4);
 
 	/* compute the stepping rate based on the chip's clock speed */
 	m_step = 4 * FRAC_ONE;
@@ -339,7 +324,7 @@ void upd7756_device::device_start()
 		if (romsize >= 0x20000) m_rommask = 0x1ffff;
 		else m_rommask = romsize - 1;
 
-		m_drqcallback = NULL;
+		m_drqcallback.set_callback(DEVCB_NULL);
 	}
 
 	/* assume /RESET and /START are both high */
@@ -720,8 +705,8 @@ void upd7759_device::device_timer(emu_timer &timer, device_timer_id id, int para
 
 		/* if the DRQ changed, update it */
 		logerror("upd7759_slave_update: DRQ %d->%d\n", olddrq, m_drq);
-		if (olddrq != m_drq && m_drqcallback)
-			(*m_drqcallback)(this, m_drq);
+		if (olddrq != m_drq)
+			m_drqcallback(m_drq);
 
 		/* set a timer to go off when that is done */
 		if (m_state != STATE_IDLE)
