@@ -5,20 +5,16 @@
 
 #define SETA_NUM_CHANNELS 16
 
-struct x1_010_interface
-{
-	int m_adr;    /* address */
-};
-
-
 class x1_010_device : public device_t,
-									public device_sound_interface,
-									public x1_010_interface
+						public device_sound_interface
 {
 public:
 	x1_010_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
 	~x1_010_device() {}
 
+	// static configuration
+	static void set_address(device_t &device, int addr) { downcast<x1_010_device &>(device).m_adr = addr; }
+
 	DECLARE_READ8_MEMBER ( read );
 	DECLARE_WRITE8_MEMBER( write );
 
@@ -29,7 +25,6 @@ public:
 
 protected:
 	// device-level overrides
-	virtual void device_config_complete();
 	virtual void device_start();
 
 	// sound stream update overrides
@@ -39,6 +34,7 @@ private:
 
 	/* Variables only used here */
 	int m_rate;                               // Output sampling rate (Hz)
+	int m_adr;                                // address
 	sound_stream *  m_stream;                 // Stream handle
 	const UINT8 *m_region;                    // region name
 	int m_sound_enable;                       // sound output enable/disable
@@ -53,4 +49,8 @@ private:
 extern const device_type X1_010;
 
 
+#define MCFG_X1_010_ADDRESS(_addr) \
+	x1_010_device::set_address(*device, _addr);
+
+
 #endif /* __X1_010_H__ */
