@@ -251,9 +251,8 @@ void ymf278b_device::sound_stream_update(sound_stream &stream, stream_sample_t *
 	INT16 sample = 0;
 	INT32 *mixp;
 	INT32 vl, vr;
-	INT32 mix[44100*2];
 
-	memset(mix, 0, sizeof(mix[0])*samples*2);
+	memset(m_mix_buffer, 0, sizeof(m_mix_buffer[0])*samples*2);
 
 	for (i = 0; i < 24; i++)
 	{
@@ -261,15 +260,16 @@ void ymf278b_device::sound_stream_update(sound_stream &stream, stream_sample_t *
 
 		if (slot->active)
 		{
-			mixp = mix;
+			mixp = m_mix_buffer;
 
 			for (j = 0; j < samples; j++)
 			{
 				if (slot->stepptr >= slot->endaddr)
 				{
 					slot->stepptr = slot->stepptr - slot->endaddr + slot->loopaddr;
-					if (slot->stepptr >= slot->endaddr)
-						slot->stepptr = slot->loopaddr; // loop overflow
+
+					// NOTE: loop overflow is still possible here if (slot->stepptr >= slot->endaddr)
+					// This glitch may be (ab)used to your advantage to create pseudorandom noise.
 				}
 
 				switch (slot->bits)
@@ -320,7 +320,7 @@ void ymf278b_device::sound_stream_update(sound_stream &stream, stream_sample_t *
 		}
 	}
 
-	mixp = mix;
+	mixp = m_mix_buffer;
 	vl = m_mix_level[m_pcm_l];
 	vr = m_mix_level[m_pcm_r];
 	for (i = 0; i < samples; i++)
@@ -479,17 +479,8 @@ void ymf278b_device::retrigger_note(YMF278BSlot *slot)
 	compute_envelope(slot);
 }
 
-void ymf278b_device::C_w(UINT8 reg, UINT8 data, int init)
+void ymf278b_device::C_w(UINT8 reg, UINT8 data)
 {
-	if (!init)
-	{
-		// PCM regs are only accessible if NEW2 is set
-		if (~m_exp & 2)
-			return;
-
-		m_stream->update();
-	}
-
 	// Handle slot registers specifically
 	if (reg >= 0x08 && reg <= 0xf7)
 	{
@@ -526,7 +517,7 @@ void ymf278b_device::C_w(UINT8 reg, UINT8 data, int init)
 
 				// copy internal registers data
 				for (i = 7; i < 12; i++)
-					C_w(8 + snum + (i-2) * 24, p[i], 1);
+					C_w(8 + snum + (i-2) * 24, p[i]);
 
 				// status register LD bit is on for approx 300us
 				m_status_ld = 1;
@@ -665,11 +656,13 @@ void ymf278b_device::C_w(UINT8 reg, UINT8 data, int init)
 				break;
 
 			case 0x03:
+				data &= 0x3f; // !
+				break;
 			case 0x04:
 				break;
 			case 0x05:
 				// set memory address
-				m_memadr = (m_pcmregs[3] & 0x3f) << 16 | m_pcmregs[4] << 8 | data;
+				m_memadr = m_pcmregs[3] << 16 | m_pcmregs[4] << 8 | data;
 				break;
 
 			case 0x06:
@@ -731,8 +724,14 @@ WRITE8_MEMBER( ymf278b_device::write )
 			break;
 
 		case 5:
+			// PCM regs are only accessible if NEW2 is set
+			if (~m_exp & 2)
+				break;
+
+			m_stream->update();
+
 			timer_busy_start(1);
-			C_w(m_port_C, data, 0);
+			C_w(m_port_C, data);
 			break;
 
 		default:
@@ -813,10 +812,10 @@ void ymf278b_device::device_reset()
 		A_w(i, 0);
 	B_w(5, 0);
 	for (i = 0; i < 8; i++)
-		C_w(i, 0, 1);
+		C_w(i, 0);
 	for (i = 0xff; i >= 8; i--)
-		C_w(i, 0, 1);
-	C_w(0xf8, 0x1b, 1);
+		C_w(i, 0);
+	C_w(0xf8, 0x1b);
 
 	m_port_AB = m_port_C = 0;
 	m_lastport = 0;
@@ -972,6 +971,7 @@ void ymf278b_device::device_start()
 	}
 
 	m_stream = machine().sound().stream_alloc(*this, 0, 2, clock()/768);
+	m_mix_buffer = auto_alloc_array(machine(), INT32, 44100*2);
 
 	// rate tables
 	precompute_rate_tables();
@@ -1002,7 +1002,7 @@ void ymf278b_device::device_start()
 const device_type YMF278B = &device_creator<ymf278b_device>;
 
 ymf278b_device::ymf278b_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: device_t(mconfig, YMF278B, "YMF278B", tag, owner, clock),
+	: device_t(mconfig, YMF278B, "YMF278B", tag, owner, clock, "ymf278b", __FILE__),
 		device_sound_interface(mconfig, *this),
 		m_irq_handler(*this)
 {
