@@ -8,7 +8,7 @@
 #define YMF278B_STD_CLOCK (33868800)            /* standard clock for OPL4 */
 
 #define MCFG_YMF278B_IRQ_HANDLER(_devcb) \
-	devcb = &ymf278b_device::set_irq_handler(*device, DEVCB2_##_devcb);
+	devcb = &ymf278b_device::set_irq_handler(*device, DEVCB_##_devcb);
 
 class ymf278b_device : public device_t,
 									public device_sound_interface
@@ -17,7 +17,7 @@ public:
 	ymf278b_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
 
 	// static configuration helpers
-	template<class _Object> static devcb2_base &set_irq_handler(device_t &device, _Object object) { return downcast<ymf278b_device &>(device).m_irq_handler.set_callback(object); }
+	template<class _Object> static devcb_base &set_irq_handler(device_t &device, _Object object) { return downcast<ymf278b_device &>(device).m_irq_handler.set_callback(object); }
 
 	DECLARE_READ8_MEMBER( read );
 	DECLARE_WRITE8_MEMBER( write );
@@ -85,7 +85,7 @@ private:
 	void A_w(UINT8 reg, UINT8 data);
 	void B_w(UINT8 reg, UINT8 data);
 	void retrigger_note(YMF278BSlot *slot);
-	void C_w(UINT8 reg, UINT8 data, int init);
+	void C_w(UINT8 reg, UINT8 data);
 	void timer_busy_start(int is_pcm);
 	void precompute_rate_tables();
 	void register_save_state();
@@ -126,7 +126,7 @@ private:
 
 	sound_stream * m_stream;
 	INT32 *m_mix_buffer;
-	devcb2_write_line m_irq_handler;
+	devcb_write_line m_irq_handler;
 };
 
 extern const device_type YMF278B;
