@@ -12,11 +12,10 @@
 #include "emuopts.h"
 #include "png.h"
 #include "debugger.h"
-#include "debugint/debugint.h"
-#include "ui.h"
+#include "ui/ui.h"
 #include "aviio.h"
 #include "crsshair.h"
-#include "rendersw.c"
+#include "rendersw.inc"
 #include "output.h"
 
 #include "snap.lh"
@@ -85,7 +84,8 @@ video_manager::video_manager(running_machine &machine)
 		m_overall_real_ticks(0),
 		m_overall_emutime(attotime::zero),
 		m_overall_valid_counter(0),
-		m_throttle(machine.options().throttle()),
+		m_throttled(machine.options().throttle()),
+		m_throttle_rate(1.0f),
 		m_fastforward(false),
 		m_seconds_to_run(machine.options().seconds_to_run()),
 		m_auto_frameskip(machine.options().auto_frameskip()),
@@ -100,11 +100,13 @@ video_manager::video_manager(running_machine &machine)
 		m_snap_native(true),
 		m_snap_width(0),
 		m_snap_height(0),
-		m_mngfile(NULL),
-		m_avifile(NULL),
-		m_movie_frame_period(attotime::zero),
-		m_movie_next_frame_time(attotime::zero),
-		m_movie_frame(0)
+		m_mng_frame_period(attotime::zero),
+		m_mng_next_frame_time(attotime::zero),
+		m_mng_frame(0),
+		m_avi_file(NULL),
+		m_avi_frame_period(attotime::zero),
+		m_avi_next_frame_time(attotime::zero),
+		m_avi_frame(0)
 {
 	// request a callback upon exiting
 	machine.add_notifier(MACHINE_NOTIFY_EXIT, machine_notify_delegate(FUNC(video_manager::exit), this));
@@ -115,7 +117,7 @@ video_manager::video_manager(running_machine &machine)
 
 	// create a render target for snapshots
 	const char *viewname = machine.options().snap_view();
-	m_snap_native = (machine.primary_screen != NULL && (viewname[0] == 0 || strcmp(viewname, "native") == 0));
+	m_snap_native = (machine.first_screen() != NULL && (viewname[0] == 0 || strcmp(viewname, "native") == 0));
 
 	// the native target is hard-coded to our internal layout and has all options disabled
 	if (m_snap_native)
@@ -152,7 +154,7 @@ video_manager::video_manager(running_machine &machine)
 		begin_recording(filename, MF_AVI);
 
 	// if no screens, create a periodic timer to drive updates
-	if (machine.primary_screen == NULL)
+	if (machine.first_screen() == NULL)
 	{
 		m_screenless_frame_timer = machine.scheduler().timer_alloc(timer_expired_delegate(FUNC(video_manager::screenless_update_callback), this));
 		m_screenless_frame_timer->adjust(screen_device::DEFAULT_FRAME_PERIOD, 0, screen_device::DEFAULT_FRAME_PERIOD);
@@ -209,10 +211,7 @@ void video_manager::frame_update(bool debug)
 	}
 
 	// draw the user interface
-	ui_update_and_render(machine(), &machine().render().ui_container());
-
-	// update the internal render debugger
-	debugint_update_during_game(machine());
+	machine().ui().update_and_render(&machine().render().ui_container());
 
 	// if we're throttling, synchronize before rendering
 	attotime current_time = machine().time();
@@ -224,6 +223,8 @@ void video_manager::frame_update(bool debug)
 	machine().osd().update(!debug && skipped_it);
 	g_profiler.stop();
 
+	machine().manager().lua()->periodic_check();
+
 	// perform tasks for this frame
 	if (!debug)
 		machine().call_notifiers(MACHINE_NOTIFY_FRAME);
@@ -240,8 +241,8 @@ void video_manager::frame_update(bool debug)
 	if (phase == MACHINE_PHASE_RUNNING)
 	{
 		// reset partial updates if we're paused or if the debugger is active
-		if (machine().primary_screen != NULL && (machine().paused() || debug || debugger_within_instruction_hook(machine())))
-			machine().primary_screen->reset_partial_updates();
+		if (machine().first_screen() != NULL && (machine().paused() || debug || debugger_within_instruction_hook(machine())))
+			machine().first_screen()->reset_partial_updates();
 	}
 }
 
@@ -309,10 +310,11 @@ void video_manager::save_snapshot(screen_device *screen, emu_file &file)
 	png_add_text(&pnginfo, "System", text2);
 
 	// now do the actual work
-	const rgb_t *palette = (machine().palette != NULL) ? palette_entry_list_adjusted(machine().palette) : NULL;
-	png_error error = png_write_bitmap(file, &pnginfo, m_snap_bitmap, machine().total_colors(), palette);
+	const rgb_t *palette = (screen !=NULL && screen->palette() != NULL) ? screen->palette()->palette()->entry_list_adjusted() : NULL;
+	int entries = (screen !=NULL && screen->palette() != NULL) ? screen->palette()->entries() : 0;
+	png_error error = png_write_bitmap(file, &pnginfo, m_snap_bitmap, entries, palette);
 	if (error != PNGERR_NONE)
-		mame_printf_error("Error generating PNG for snapshot: png_error = %d\n", error);
+		osd_printf_error("Error generating PNG for snapshot: png_error = %d\n", error);
 
 	// free any data allocated
 	png_free(&pnginfo);
@@ -358,23 +360,23 @@ void video_manager::save_active_screen_snapshots()
 
 void video_manager::begin_recording(const char *name, movie_format format)
 {
-	// stop any existign recording
-	end_recording();
-
 	// create a snapshot bitmap so we know what the target size is
 	create_snapshot_bitmap(NULL);
 
-	// reset the state
-	m_movie_frame = 0;
-	m_movie_next_frame_time = machine().time();
-
 	// start up an AVI recording
 	if (format == MF_AVI)
 	{
+		// stop any existing recording
+		end_recording(format);
+
+		// reset the state
+		m_avi_frame = 0;
+		m_avi_next_frame_time = machine().time();
+
 		// build up information about this new movie
 		avi_movie_info info;
 		info.video_format = 0;
-		info.video_timescale = 1000 * ((machine().primary_screen != NULL) ? ATTOSECONDS_TO_HZ(machine().primary_screen->frame_period().attoseconds) : screen_device::DEFAULT_FRAME_RATE);
+		info.video_timescale = 1000 * ((machine().first_screen() != NULL) ? ATTOSECONDS_TO_HZ(machine().first_screen()->frame_period().attoseconds) : screen_device::DEFAULT_FRAME_RATE);
 		info.video_sampletime = 1000;
 		info.video_numsamples = 0;
 		info.video_width = m_snap_bitmap.width();
@@ -399,9 +401,6 @@ void video_manager::begin_recording(const char *name, movie_format format)
 			else
 				filerr = open_next(tempfile, "avi");
 
-			// compute the frame time
-			m_movie_frame_period = attotime::from_seconds(1000) / info.video_timescale;
-
 			// if we succeeded, make a copy of the name and create the real file over top
 			if (filerr == FILERR_NONE)
 				fullpath = tempfile.fullpath();
@@ -409,40 +408,55 @@ void video_manager::begin_recording(const char *name, movie_format format)
 
 		if (filerr == FILERR_NONE)
 		{
+			// compute the frame time
+			m_avi_frame_period = attotime::from_seconds(1000) / info.video_timescale;
+
 			// create the file and free the string
-			avi_error avierr = avi_create(fullpath, &info, &m_avifile);
+			avi_error avierr = avi_create(fullpath, &info, &m_avi_file);
 			if (avierr != AVIERR_NONE)
-				mame_printf_error("Error creating AVI: %s\n", avi_error_string(avierr));
+			{
+				osd_printf_error("Error creating AVI: %s\n", avi_error_string(avierr));
+				return end_recording(format);
+			}
 		}
 	}
 
 	// start up a MNG recording
 	else if (format == MF_MNG)
 	{
+		// stop any existing recording
+		end_recording(format);
+
+		// reset the state
+		m_mng_frame = 0;
+		m_mng_next_frame_time = machine().time();
+
 		// create a new movie file and start recording
-		m_mngfile = auto_alloc(machine(), emu_file(machine().options().snapshot_directory(), OPEN_FLAG_WRITE | OPEN_FLAG_CREATE | OPEN_FLAG_CREATE_PATHS));
+		m_mng_file.reset(global_alloc(emu_file(machine().options().snapshot_directory(), OPEN_FLAG_WRITE | OPEN_FLAG_CREATE | OPEN_FLAG_CREATE_PATHS)));
 		file_error filerr;
 		if (name != NULL)
-			filerr = m_mngfile->open(name);
+			filerr = m_mng_file->open(name);
 		else
-			filerr = open_next(*m_mngfile, "mng");
+			filerr = open_next(*m_mng_file, "mng");
 
 		if (filerr == FILERR_NONE)
 		{
 			// start the capture
-			int rate = (machine().primary_screen != NULL) ? ATTOSECONDS_TO_HZ(machine().primary_screen->frame_period().attoseconds) : screen_device::DEFAULT_FRAME_RATE;
-			png_error pngerr = mng_capture_start(*m_mngfile, m_snap_bitmap, rate);
+			int rate = (machine().first_screen() != NULL) ? ATTOSECONDS_TO_HZ(machine().first_screen()->frame_period().attoseconds) : screen_device::DEFAULT_FRAME_RATE;
+			png_error pngerr = mng_capture_start(*m_mng_file, m_snap_bitmap, rate);
 			if (pngerr != PNGERR_NONE)
-				return end_recording();
+			{
+				osd_printf_error("Error capturing MNG, png_error=%d\n", pngerr);
+				return end_recording(format);
+			}
 
 			// compute the frame time
-			m_movie_frame_period = attotime::from_hz(rate);
+			m_mng_frame_period = attotime::from_hz(rate);
 		}
 		else
 		{
-			mame_printf_error("Error creating MNG\n");
-			global_free(m_mngfile);
-			m_mngfile = NULL;
+			osd_printf_error("Error creating MNG, file_error=%d\n", filerr);
+			m_mng_file.reset();
 		}
 	}
 }
@@ -452,25 +466,32 @@ void video_manager::begin_recording(const char *name, movie_format format)
 //  end_recording - stop recording of a movie
 //-------------------------------------------------
 
-void video_manager::end_recording()
+void video_manager::end_recording(movie_format format)
 {
-	// close the file if it exists
-	if (m_avifile != NULL)
+	if (format == MF_AVI)
 	{
-		avi_close(m_avifile);
-		m_avifile = NULL;
-	}
+		// close the file if it exists
+		if (m_avi_file != NULL)
+		{
+			avi_close(m_avi_file);
+			m_avi_file = NULL;
 
-	// close the file if it exists
-	if (m_mngfile != NULL)
+			// reset the state
+			m_avi_frame = 0;
+		}
+	}
+	else if (format == MF_MNG)
 	{
-		mng_capture_stop(*m_mngfile);
-		auto_free(machine(), m_mngfile);
-		m_mngfile = NULL;
-	}
+		// close the file if it exists
+		if (m_mng_file != NULL)
+		{
+			mng_capture_stop(*m_mng_file);
+			m_mng_file.reset();
 
-	// reset the state
-	m_movie_frame = 0;
+			// reset the state
+			m_mng_frame = 0;
+		}
+	}
 }
 
 
@@ -482,16 +503,16 @@ void video_manager::end_recording()
 void video_manager::add_sound_to_recording(const INT16 *sound, int numsamples)
 {
 	// only record if we have a file
-	if (m_avifile != NULL)
+	if (m_avi_file != NULL)
 	{
 		g_profiler.start(PROFILER_MOVIE_REC);
 
 		// write the next frame
-		avi_error avierr = avi_append_sound_samples(m_avifile, 0, sound + 0, numsamples, 1);
+		avi_error avierr = avi_append_sound_samples(m_avi_file, 0, sound + 0, numsamples, 1);
 		if (avierr == AVIERR_NONE)
-			avierr = avi_append_sound_samples(m_avifile, 1, sound + 1, numsamples, 1);
+			avierr = avi_append_sound_samples(m_avi_file, 1, sound + 1, numsamples, 1);
 		if (avierr != AVIERR_NONE)
-			end_recording();
+			end_recording(MF_AVI);
 
 		g_profiler.stop();
 	}
@@ -506,11 +527,8 @@ void video_manager::add_sound_to_recording(const INT16 *sound, int numsamples)
 void video_manager::exit()
 {
 	// stop recording any movie
-	end_recording();
-
-	// free all the graphics elements
-	for (int i = 0; i < MAX_GFX_ELEMENTS; i++)
-		auto_free(machine(), machine().gfx[i]);
+	end_recording(MF_AVI);
+	end_recording(MF_MNG);
 
 	// free the snapshot target
 	machine().render().target_free(m_snap_target);
@@ -522,7 +540,7 @@ void video_manager::exit()
 		osd_ticks_t tps = osd_ticks_per_second();
 		double final_real_time = (double)m_overall_real_seconds + (double)m_overall_real_ticks / (double)tps;
 		double final_emu_time = m_overall_emutime.as_double();
-		mame_printf_info("Average speed: %.2f%% (%d seconds)\n", 100 * final_emu_time / final_real_time, (m_overall_emutime + attotime(0, ATTOSECONDS_PER_SECOND / 2)).seconds);
+		osd_printf_info("Average speed: %.2f%% (%d seconds)\n", 100 * final_emu_time / final_real_time, (m_overall_emutime + attotime(0, ATTOSECONDS_PER_SECOND / 2)).seconds);
 	}
 }
 
@@ -546,7 +564,8 @@ void video_manager::screenless_update_callback(void *ptr, int param)
 
 void video_manager::postload()
 {
-	m_movie_next_frame_time = machine().time();
+	m_avi_next_frame_time = machine().time();
+	m_mng_next_frame_time = machine().time();
 }
 
 
@@ -593,7 +612,7 @@ inline int video_manager::effective_frameskip() const
 inline bool video_manager::effective_throttle() const
 {
 	// if we're paused, or if the UI is active, we always throttle
-	if (machine().paused() || ui_is_menu_active())
+	if (machine().paused() || machine().ui().is_menu_active())
 		return true;
 
 	// if we're fast forwarding, we don't throttle
@@ -601,7 +620,7 @@ inline bool video_manager::effective_throttle() const
 		return false;
 
 	// otherwise, it's up to the user
-	return m_throttle;
+	return throttled();
 }
 
 
@@ -625,6 +644,7 @@ bool video_manager::finish_screen_updates()
 {
 	// finish updating the screens
 	screen_device_iterator iter(machine().root_device());
+
 	for (screen_device *screen = iter.first(); screen != NULL; screen = iter.next())
 		screen->update_partial(screen->visible_area().max_y);
 
@@ -718,7 +738,7 @@ void video_manager::update_throttle(attotime emutime)
 
 		// compute conversion factors up front
 		osd_ticks_t ticks_per_second = osd_ticks_per_second();
-		attoseconds_t attoseconds_per_tick = ATTOSECONDS_PER_SECOND / ticks_per_second;
+		attoseconds_t attoseconds_per_tick = ATTOSECONDS_PER_SECOND / ticks_per_second * m_throttle_rate;
 
 		// if we're paused, emutime will not advance; instead, we subtract a fixed
 		// amount of time (1/60th of a second) from the emulated time that was passed in,
@@ -872,9 +892,12 @@ void video_manager::update_frameskip()
 	// if we're throttling and autoframeskip is on, adjust
 	if (effective_throttle() && effective_autoframeskip() && m_frameskip_counter == 0)
 	{
+		// calibrate the "adjusted speed" based on the target
+		double adjusted_speed_percent = m_speed_percent / m_throttle_rate;
+
 		// if we're too fast, attempt to increase the frameskip
 		double speed = m_speed * 0.001;
-		if (m_speed_percent >= 0.995 * speed)
+		if (adjusted_speed_percent >= 0.995 * speed)
 		{
 			// but only after 3 consecutive frames where we are too fast
 			if (++m_frameskip_adjust >= 3)
@@ -889,7 +912,7 @@ void video_manager::update_frameskip()
 		else
 		{
 			// if below 80% speed, be more aggressive
-			if (m_speed_percent < 0.80 *  speed)
+			if (adjusted_speed_percent < 0.80 *  speed)
 				m_frameskip_adjust -= (0.90 * speed - m_speed_percent) / 0.05;
 
 			// if we're close, only force it up to frameskip 8
@@ -946,7 +969,7 @@ void video_manager::update_refresh_speed()
 			// if we changed, log that verbosely
 			if (target_speed != m_speed)
 			{
-				mame_printf_verbose("Adjusting target speed to %.1f%% (hw=%.2fHz, game=%.2fHz, adjusted=%.2fHz)\n", target_speed / 10.0, minrefresh, ATTOSECONDS_TO_HZ(min_frame_period), ATTOSECONDS_TO_HZ(min_frame_period * 1000.0 / target_speed));
+				osd_printf_verbose("Adjusting target speed to %.1f%% (hw=%.2fHz, game=%.2fHz, adjusted=%.2fHz)\n", target_speed / 10.0, minrefresh, ATTOSECONDS_TO_HZ(min_frame_period), ATTOSECONDS_TO_HZ(min_frame_period * 1000.0 / target_speed));
 				m_speed = target_speed;
 			}
 		}
@@ -960,7 +983,7 @@ void video_manager::update_refresh_speed()
 //  if we did not skip a frame
 //-------------------------------------------------
 
-void video_manager::recompute_speed(attotime emutime)
+void video_manager::recompute_speed(const attotime &emutime)
 {
 	// if we don't have a starting time yet, or if we're paused, reset our starting point
 	if (m_speed_last_realtime == 0 || machine().paused())
@@ -1005,13 +1028,13 @@ void video_manager::recompute_speed(attotime emutime)
 	// if we're past the "time-to-execute" requested, signal an exit
 	if (m_seconds_to_run != 0 && emutime.seconds >= m_seconds_to_run)
 	{
-		if (machine().primary_screen != NULL)
+		if (machine().first_screen() != NULL)
 		{
 			// create a final screenshot
 			emu_file file(machine().options().snapshot_directory(), OPEN_FLAG_WRITE | OPEN_FLAG_CREATE | OPEN_FLAG_CREATE_PATHS);
 			file_error filerr = file.open(machine().basename(), PATH_SEPARATOR "final.png");
 			if (filerr == FILERR_NONE)
-				save_snapshot(machine().primary_screen, file);
+				save_snapshot(machine().first_screen(), file);
 		}
 
 		// schedule our demise
@@ -1184,7 +1207,6 @@ file_error video_manager::open_next(emu_file &file, const char *extension)
 }
 
 
-
 //-------------------------------------------------
 //  record_frame - record a frame of a movie
 //-------------------------------------------------
@@ -1192,7 +1214,7 @@ file_error video_manager::open_next(emu_file &file, const char *extension)
 void video_manager::record_frame()
 {
 	// ignore if nothing to do
-	if (m_mngfile == NULL && m_avifile == NULL)
+	if (m_mng_file == NULL && m_avi_file == NULL)
 		return;
 
 	// start the profiler and get the current time
@@ -1202,27 +1224,36 @@ void video_manager::record_frame()
 	// create the bitmap
 	create_snapshot_bitmap(NULL);
 
-	// loop until we hit the right time
-	while (m_movie_next_frame_time <= curtime)
+	// handle an AVI recording
+	if (m_avi_file != NULL)
 	{
-		// handle an AVI recording
-		if (m_avifile != NULL)
+		// loop until we hit the right time
+		while (m_avi_next_frame_time <= curtime)
 		{
 			// write the next frame
-			avi_error avierr = avi_append_video_frame(m_avifile, m_snap_bitmap);
+			avi_error avierr = avi_append_video_frame(m_avi_file, m_snap_bitmap);
 			if (avierr != AVIERR_NONE)
 			{
 				g_profiler.stop();
-				return end_recording();
+				end_recording(MF_AVI);
+				break;
 			}
-		}
 
-		// handle a MNG recording
-		if (m_mngfile != NULL)
+			// advance time
+			m_avi_next_frame_time += m_avi_frame_period;
+			m_avi_frame++;
+		}
+	}
+
+	// handle a MNG recording
+	if (m_mng_file != NULL)
+	{
+		// loop until we hit the right time
+		while (m_mng_next_frame_time <= curtime)
 		{
 			// set up the text fields in the movie info
 			png_info pnginfo = { 0 };
-			if (m_movie_frame == 0)
+			if (m_mng_frame == 0)
 			{
 				astring text1(emulator_info::get_appname(), " ", build_version);
 				astring text2(machine().system().manufacturer, " ", machine().system().description);
@@ -1231,46 +1262,50 @@ void video_manager::record_frame()
 			}
 
 			// write the next frame
-			const rgb_t *palette = (machine().palette != NULL) ? palette_entry_list_adjusted(machine().palette) : NULL;
-			png_error error = mng_capture_frame(*m_mngfile, &pnginfo, m_snap_bitmap, machine().total_colors(), palette);
+			const rgb_t *palette = (machine().first_screen() !=NULL && machine().first_screen()->palette() != NULL) ? machine().first_screen()->palette()->palette()->entry_list_adjusted() : NULL;
+			int entries = (machine().first_screen() !=NULL && machine().first_screen()->palette() != NULL) ? machine().first_screen()->palette()->entries() : 0;
+			png_error error = mng_capture_frame(*m_mng_file, &pnginfo, m_snap_bitmap, entries, palette);
 			png_free(&pnginfo);
 			if (error != PNGERR_NONE)
 			{
 				g_profiler.stop();
-				return end_recording();
+				end_recording(MF_MNG);
+				break;
 			}
-		}
 
-		// advance time
-		m_movie_next_frame_time += m_movie_frame_period;
-		m_movie_frame++;
+			// advance time
+			m_mng_next_frame_time += m_mng_frame_period;
+			m_mng_frame++;
+		}
 	}
+
 	g_profiler.stop();
 }
 
+//-------------------------------------------------
+//  toggle_throttle
+//-------------------------------------------------
 
-
-/*-------------------------------------------------
-    video_assert_out_of_range_pixels - assert if
-    any pixels in the given bitmap contain an
-    invalid palette index
--------------------------------------------------*/
-
-bool video_assert_out_of_range_pixels(running_machine &machine, bitmap_ind16 &bitmap)
+void video_manager::toggle_throttle()
 {
-#ifdef MAME_DEBUG
-	// iterate over rows
-	int maxindex = palette_get_max_index(machine.palette);
-	for (int y = 0; y < bitmap.height(); y++)
+	set_throttled(!throttled());
+}
+
+
+//-------------------------------------------------
+//  toggle_record_movie
+//-------------------------------------------------
+
+void video_manager::toggle_record_movie()
+{
+	if (!is_recording())
 	{
-		UINT16 *rowbase = &bitmap.pix16(y);
-		for (int x = 0; x < bitmap.width(); x++)
-			if (rowbase[x] > maxindex)
-			{
-				osd_break_into_debugger("Out of range pixel");
-				return true;
-			}
+		begin_recording(NULL, MF_MNG);
+		popmessage("REC START");
 	}
-#endif
-	return false;
+	else
+	{
+		end_recording(MF_MNG);
+		popmessage("REC STOP");
+	}
 }
