@@ -64,9 +64,9 @@ INLINE void rgba_comp_to_rgbaint(rgbaint *rgb, INT16 a, INT16 r, INT16 g, INT16
     components to an rgbint type
 -------------------------------------------------*/
 
-INLINE void rgb_to_rgbint(rgbint *rgb, rgb_t color)
+INLINE void rgb_to_rgbint(rgbint *rgb, rgb_t const &color)
 {
-	vector signed char temp = (vector signed char)vec_perm((vector signed int)vec_lde(0, &color), vec_splat_s32(0), vec_lvsl(0, &color));
+	vector signed char temp = (vector signed char)vec_perm((vector signed int)vec_lde(0, color.ptr()), vec_splat_s32(0), vec_lvsl(0, color.ptr()));
 	*rgb = (rgbint)vec_mergeh((vector signed char)vec_splat_s32(0), temp);
 }
 
@@ -76,9 +76,9 @@ INLINE void rgb_to_rgbint(rgbint *rgb, rgb_t color)
     components to an rgbint type
 -------------------------------------------------*/
 
-INLINE void rgba_to_rgbaint(rgbaint *rgb, rgb_t color)
+INLINE void rgba_to_rgbaint(rgbaint *rgb, rgb_t const &color)
 {
-	vector signed char temp = (vector signed char)vec_perm((vector signed int)vec_lde(0, &color), vec_splat_s32(0), vec_lvsl(0, &color));
+	vector signed char temp = (vector signed char)vec_perm((vector signed int)vec_lde(0, color.ptr()), vec_splat_s32(0), vec_lvsl(0, color.ptr()));
 	*rgb = (rgbaint)vec_mergeh((vector signed char)vec_splat_s32(0), temp);
 }
 
@@ -91,7 +91,7 @@ INLINE void rgba_to_rgbaint(rgbaint *rgb, rgb_t color)
 INLINE rgb_t rgbint_to_rgb(const rgbint *color)
 {
 	vector unsigned int temp = vec_splat((vector unsigned int)vec_packsu(*color, *color), 0);
-	rgb_t result;
+	UINT32 result;
 	vec_ste(temp, 0, &result);
 	return result;
 }
@@ -105,7 +105,7 @@ INLINE rgb_t rgbint_to_rgb(const rgbint *color)
 INLINE rgb_t rgbaint_to_rgba(const rgbaint *color)
 {
 	vector unsigned int temp = vec_splat((vector unsigned int)vec_packsu(*color, *color), 0);
-	rgb_t result;
+	UINT32 result;
 	vec_ste(temp, 0, &result);
 	return result;
 }
@@ -120,7 +120,7 @@ INLINE rgb_t rgbaint_to_rgba(const rgbaint *color)
 INLINE rgb_t rgbint_to_rgb_clamp(const rgbint *color)
 {
 	vector unsigned int temp = vec_splat((vector unsigned int)vec_packsu(*color, *color), 0);
-	rgb_t result;
+	UINT32 result;
 	vec_ste(temp, 0, &result);
 	return result;
 }
@@ -135,7 +135,7 @@ INLINE rgb_t rgbint_to_rgb_clamp(const rgbint *color)
 INLINE rgb_t rgbaint_to_rgba_clamp(const rgbaint *color)
 {
 	vector unsigned int temp = vec_splat((vector unsigned int)vec_packsu(*color, *color), 0);
-	rgb_t result;
+	UINT32 result;
 	vec_ste(temp, 0, &result);
 	return result;
 }
@@ -318,13 +318,12 @@ INLINE void rgbaint_scale_channel_and_clamp(rgbaint *color, const rgbint *colors
     four pixel values
 -------------------------------------------------*/
 
-INLINE rgb_t rgb_bilinear_filter(rgb_t rgb00, rgb_t rgb01, rgb_t rgb10, rgb_t rgb11, UINT8 u, UINT8 v)
+INLINE rgb_t rgb_bilinear_filter(rgb_t const &rgb00, rgb_t const &rgb01, rgb_t const &rgb10, rgb_t const &rgb11, UINT8 u, UINT8 v)
 {
-	rgb_t   result;
-	rgbint  color00 = (rgbint)vec_perm((vector signed int)vec_lde(0, &rgb00), vec_splat_s32(0), vec_lvsl(0, &rgb00));
-	rgbint  color01 = (rgbint)vec_perm((vector signed int)vec_lde(0, &rgb01), vec_splat_s32(0), vec_lvsl(0, &rgb01));
-	rgbint  color10 = (rgbint)vec_perm((vector signed int)vec_lde(0, &rgb10), vec_splat_s32(0), vec_lvsl(0, &rgb10));
-	rgbint  color11 = (rgbint)vec_perm((vector signed int)vec_lde(0, &rgb11), vec_splat_s32(0), vec_lvsl(0, &rgb11));
+	rgbint  color00 = (rgbint)vec_perm((vector signed int)vec_lde(0, rgb00.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb00.ptr()));
+	rgbint  color01 = (rgbint)vec_perm((vector signed int)vec_lde(0, rgb01.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb01.ptr()));
+	rgbint  color10 = (rgbint)vec_perm((vector signed int)vec_lde(0, rgb10.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb10.ptr()));
+	rgbint  color11 = (rgbint)vec_perm((vector signed int)vec_lde(0, rgb11.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb11.ptr()));
 
 	/* interleave color01 and color00 at the byte level */
 	color01 = (rgbint)vec_mergeh((vector signed char)color01, (vector signed char)color00);
@@ -340,6 +339,8 @@ INLINE rgb_t rgb_bilinear_filter(rgb_t rgb00, rgb_t rgb01, rgb_t rgb10, rgb_t rg
 	color01 = (rgbint)vec_sr((vector signed int)color01, vec_splat_u32(15));
 	color01 = vec_packs((vector signed int)color01, (vector signed int)color01);
 	color01 = (rgbint)vec_packsu(color01, color01);
+
+	UINT32 result;
 	vec_ste((vector unsigned int)color01, 0, &result);
 	return result;
 }
@@ -350,13 +351,12 @@ INLINE rgb_t rgb_bilinear_filter(rgb_t rgb00, rgb_t rgb01, rgb_t rgb10, rgb_t rg
     four pixel values
 -------------------------------------------------*/
 
-INLINE rgb_t rgba_bilinear_filter(rgb_t rgb00, rgb_t rgb01, rgb_t rgb10, rgb_t rgb11, UINT8 u, UINT8 v)
+INLINE rgb_t rgba_bilinear_filter(rgb_t const &rgb00, rgb_t const &rgb01, rgb_t const &rgb10, rgb_t const &rgb11, UINT8 u, UINT8 v)
 {
-	rgb_t   result;
-	rgbaint color00 = (rgbaint)vec_perm((vector signed int)vec_lde(0, &rgb00), vec_splat_s32(0), vec_lvsl(0, &rgb00));
-	rgbaint color01 = (rgbaint)vec_perm((vector signed int)vec_lde(0, &rgb01), vec_splat_s32(0), vec_lvsl(0, &rgb01));
-	rgbaint color10 = (rgbaint)vec_perm((vector signed int)vec_lde(0, &rgb10), vec_splat_s32(0), vec_lvsl(0, &rgb10));
-	rgbaint color11 = (rgbaint)vec_perm((vector signed int)vec_lde(0, &rgb11), vec_splat_s32(0), vec_lvsl(0, &rgb11));
+	rgbaint color00 = (rgbaint)vec_perm((vector signed int)vec_lde(0, rgb00.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb00.ptr()));
+	rgbaint color01 = (rgbaint)vec_perm((vector signed int)vec_lde(0, rgb01.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb01.ptr()));
+	rgbaint color10 = (rgbaint)vec_perm((vector signed int)vec_lde(0, rgb10.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb10.ptr()));
+	rgbaint color11 = (rgbaint)vec_perm((vector signed int)vec_lde(0, rgb11.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb11.ptr()));
 
 	/* interleave color01 and color00 at the byte level */
 	color01 = (rgbaint)vec_mergeh((vector signed char)color01, (vector signed char)color00);
@@ -372,6 +372,8 @@ INLINE rgb_t rgba_bilinear_filter(rgb_t rgb00, rgb_t rgb01, rgb_t rgb10, rgb_t r
 	color01 = (rgbaint)vec_sr((vector signed int)color01, vec_splat_u32(15));
 	color01 = vec_packs((vector signed int)color01, (vector signed int)color01);
 	color01 = (rgbaint)vec_packsu(color01, color01);
+
+	UINT32 result;
 	vec_ste((vector unsigned int)color01, 0, &result);
 	return result;
 }
@@ -382,12 +384,12 @@ INLINE rgb_t rgba_bilinear_filter(rgb_t rgb00, rgb_t rgb01, rgb_t rgb10, rgb_t r
     four pixel values
 -------------------------------------------------*/
 
-INLINE void rgbint_bilinear_filter(rgbint *color, rgb_t rgb00, rgb_t rgb01, rgb_t rgb10, rgb_t rgb11, UINT8 u, UINT8 v)
+INLINE void rgbint_bilinear_filter(rgbint *color, rgb_t const &rgb00, rgb_t const &rgb01, rgb_t const &rgb10, rgb_t const &rgb11, UINT8 u, UINT8 v)
 {
-	rgbint color00 = (rgbint)vec_perm((vector signed int)vec_lde(0, &rgb00), vec_splat_s32(0), vec_lvsl(0, &rgb00));
-	rgbint color01 = (rgbint)vec_perm((vector signed int)vec_lde(0, &rgb01), vec_splat_s32(0), vec_lvsl(0, &rgb01));
-	rgbint color10 = (rgbint)vec_perm((vector signed int)vec_lde(0, &rgb10), vec_splat_s32(0), vec_lvsl(0, &rgb10));
-	rgbint color11 = (rgbint)vec_perm((vector signed int)vec_lde(0, &rgb11), vec_splat_s32(0), vec_lvsl(0, &rgb11));
+	rgbint color00 = (rgbint)vec_perm((vector signed int)vec_lde(0, rgb00.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb00.ptr()));
+	rgbint color01 = (rgbint)vec_perm((vector signed int)vec_lde(0, rgb01.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb01.ptr()));
+	rgbint color10 = (rgbint)vec_perm((vector signed int)vec_lde(0, rgb10.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb10.ptr()));
+	rgbint color11 = (rgbint)vec_perm((vector signed int)vec_lde(0, rgb11.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb11.ptr()));
 
 	/* interleave color01 and color00 at the byte level */
 	color01 = (rgbint)vec_mergeh((vector signed char)color01, (vector signed char)color00);
@@ -410,12 +412,12 @@ INLINE void rgbint_bilinear_filter(rgbint *color, rgb_t rgb00, rgb_t rgb01, rgb_
     four pixel values
 -------------------------------------------------*/
 
-INLINE void rgbaint_bilinear_filter(rgbaint *color, rgb_t rgb00, rgb_t rgb01, rgb_t rgb10, rgb_t rgb11, UINT8 u, UINT8 v)
+INLINE void rgbaint_bilinear_filter(rgbaint *color, rgb_t const &rgb00, rgb_t const &rgb01, rgb_t const &rgb10, rgb_t const &rgb11, UINT8 u, UINT8 v)
 {
-	rgbaint color00 = (rgbaint)vec_perm((vector signed int)vec_lde(0, &rgb00), vec_splat_s32(0), vec_lvsl(0, &rgb00));
-	rgbaint color01 = (rgbaint)vec_perm((vector signed int)vec_lde(0, &rgb01), vec_splat_s32(0), vec_lvsl(0, &rgb01));
-	rgbaint color10 = (rgbaint)vec_perm((vector signed int)vec_lde(0, &rgb10), vec_splat_s32(0), vec_lvsl(0, &rgb10));
-	rgbaint color11 = (rgbaint)vec_perm((vector signed int)vec_lde(0, &rgb11), vec_splat_s32(0), vec_lvsl(0, &rgb11));
+	rgbaint color00 = (rgbaint)vec_perm((vector signed int)vec_lde(0, rgb00.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb00.ptr()));
+	rgbaint color01 = (rgbaint)vec_perm((vector signed int)vec_lde(0, rgb01.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb01.ptr()));
+	rgbaint color10 = (rgbaint)vec_perm((vector signed int)vec_lde(0, rgb10.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb10.ptr()));
+	rgbaint color11 = (rgbaint)vec_perm((vector signed int)vec_lde(0, rgb11.ptr()), vec_splat_s32(0), vec_lvsl(0, rgb11.ptr()));
 
 	/* interleave color01 and color00 at the byte level */
 	color01 = (rgbaint)vec_mergeh((vector signed char)color01, (vector signed char)color00);
