@@ -13,7 +13,7 @@
 #ifndef __WEB_ENGINE_H__
 #define __WEB_ENGINE_H__
 
-struct mg_context;     // Handle for the HTTP service itself
+struct mg_server;      // Handle for the HTTP server itself
 struct mg_connection;  // Handle for the individual connection
 
 class web_engine
@@ -26,13 +26,8 @@ public:
 	void push_message(const char *message);
 	void close();
 
-	void set_machine(running_machine &machine) { m_machine = &machine; }
-
-	void websocket_ready_handler(struct mg_connection *conn);
-	int websocket_data_handler(struct mg_connection *conn, int flags, char *data, size_t data_len);
+	void set_machine(running_machine *machine) { m_machine = machine; }
 	int begin_request_handler(struct mg_connection *conn);
-	int begin_http_error_handler(struct mg_connection *conn, int status);
-	void *websocket_keepalive();
 protected:
 	// getters
 	running_machine &machine() const { return *m_machine; }
@@ -43,10 +38,9 @@ private:
 	// internal state
 	emu_options &       m_options;
 	running_machine *   m_machine;
-	struct mg_context * m_ctx;
-	osd_ticks_t         m_lastupdatetime;
+	struct mg_server *  m_server;
+	//osd_ticks_t         m_lastupdatetime;
 	bool                m_exiting_core;
-	simple_list<simple_list_wrapper<mg_connection> > m_websockets;
 };
 
 #endif  /* __web_engine_H__ */
