@@ -60,7 +60,7 @@ const char * emulator_info::get_usage() { return USAGE;}
 const char * emulator_info::get_xml_root() { return XML_ROOT;}
 const char * emulator_info::get_xml_top() { return XML_TOP;}
 const char * emulator_info::get_state_magic_num() { return STATE_MAGIC_NUM;}
-void emulator_info::printf_usage(const char *par1, const char *par2) { mame_printf_info(USAGE, par1, par2); }
+void emulator_info::printf_usage(const char *par1, const char *par2) { osd_printf_info(USAGE, par1, par2); }
 
 /*************************************
  *
@@ -343,8 +343,8 @@ void ldplayer_state::device_timer(emu_timer &timer, device_timer_id id, int para
 				process_commands();
 
 			// set a timer to go off on the next VBLANK
-			int vblank_scanline = machine().primary_screen->visible_area().max_y + 1;
-			attotime target = machine().primary_screen->time_until_pos(vblank_scanline);
+			int vblank_scanline = machine().first_screen()->visible_area().max_y + 1;
+			attotime target = machine().first_screen()->time_until_pos(vblank_scanline);
 			timer_set(target, TIMER_ID_VSYNC_UPDATE);
 			break;
 		}
