@@ -1,5 +1,5 @@
 /*
-** $Id: ldo.c,v 2.108 2012/10/01 14:05:04 roberto Exp $
+** $Id: ldo.c,v 2.108.1.3 2013/11/08 18:22:50 roberto Exp $
 ** Stack and Call structure of Lua
 ** See Copyright Notice in lua.h
 */
@@ -260,6 +260,7 @@ static StkId adjust_varargs (lua_State *L, Proto *p, int actual) {
 	StkId base, fixed;
 	lua_assert(actual >= nfixargs);
 	/* move fixed parameters to final position */
+	luaD_checkstack(L, p->maxstacksize);  /* check again for new 'base' */
 	fixed = L->top - actual;  /* first fixed argument */
 	base = L->top;  /* final position of first argument */
 	for (i=0; i<nfixargs; i++) {
@@ -324,12 +325,18 @@ int luaD_precall (lua_State *L, StkId func, int nresults) {
 	case LUA_TLCL: {  /* Lua function: prepare its call */
 		StkId base;
 		Proto *p = clLvalue(func)->p;
-		luaD_checkstack(L, p->maxstacksize);
-		func = restorestack(L, funcr);
 		n = cast_int(L->top - func) - 1;  /* number of real arguments */
+		luaD_checkstack(L, p->maxstacksize);
 		for (; n < p->numparams; n++)
 		setnilvalue(L->top++);  /* complete missing arguments */
-		base = (!p->is_vararg) ? func + 1 : adjust_varargs(L, p, n);
+		if (!p->is_vararg) {
+		func = restorestack(L, funcr);
+		base = func + 1;
+		}
+		else {
+		base = adjust_varargs(L, p, n);
+		func = restorestack(L, funcr);  /* previous call can change stack */
+		}
 		ci = next_ci(L);  /* now 'enter' new function */
 		ci->nresults = nresults;
 		ci->func = func;
@@ -527,6 +534,7 @@ static void resume (lua_State *L, void *ud) {
 
 LUA_API int lua_resume (lua_State *L, lua_State *from, int nargs) {
 	int status;
+	int oldnny = L->nny;  /* save 'nny' */
 	lua_lock(L);
 	luai_userstateresume(L, nargs);
 	L->nCcalls = (from) ? from->nCcalls + 1 : 1;
@@ -548,7 +556,7 @@ LUA_API int lua_resume (lua_State *L, lua_State *from, int nargs) {
 	}
 	lua_assert(status == L->status);
 	}
-	L->nny = 1;  /* do not allow yields */
+	L->nny = oldnny;  /* restore 'nny' */
 	L->nCcalls--;
 	lua_assert(L->nCcalls == ((from) ? from->nCcalls : 0));
 	lua_unlock(L);
