@@ -1412,6 +1412,7 @@ UINT32 chd_file::guess_unitbytes()
 	if (read_metadata(CDROM_OLD_METADATA_TAG, 0, metadata) == CHDERR_NONE ||
 		read_metadata(CDROM_TRACK_METADATA_TAG, 0, metadata) == CHDERR_NONE ||
 		read_metadata(CDROM_TRACK_METADATA2_TAG, 0, metadata) == CHDERR_NONE ||
+		read_metadata(GDROM_OLD_METADATA_TAG, 0, metadata) == CHDERR_NONE ||
 		read_metadata(GDROM_TRACK_METADATA_TAG, 0, metadata) == CHDERR_NONE)
 		return CD_FRAME_SIZE;
 
@@ -2316,7 +2317,6 @@ chd_file_compressor::chd_file_compressor()
 		m_write_hunk(0)
 {
 	// zap arrays
-	memset(m_work_item, 0, sizeof(m_work_item));
 	memset(m_codecs, 0, sizeof(m_codecs));
 
 	// allocate work queues
@@ -2363,8 +2363,7 @@ void chd_file_compressor::compress_begin()
 	m_read_error = false;
 
 	// reset work item state
-	m_work_buffer.resize(hunk_bytes() * (WORK_BUFFER_HUNKS + 1));
-	memset(m_work_buffer, 0, m_work_buffer.count());
+	m_work_buffer.resize_and_clear(hunk_bytes() * (WORK_BUFFER_HUNKS + 1));
 	m_compressed_buffer.resize(hunk_bytes() * WORK_BUFFER_HUNKS);
 	for (int itemnum = 0; itemnum < WORK_BUFFER_HUNKS; itemnum++)
 	{
