@@ -225,7 +225,8 @@ const chd_metadata_tag CDROM_TRACK_METADATA_TAG = CHD_MAKE_TAG('C','H','T','R');
 extern const char *CDROM_TRACK_METADATA_FORMAT;
 const chd_metadata_tag CDROM_TRACK_METADATA2_TAG = CHD_MAKE_TAG('C','H','T','2');
 extern const char *CDROM_TRACK_METADATA2_FORMAT;
-const chd_metadata_tag GDROM_TRACK_METADATA_TAG = CHD_MAKE_TAG('C','H','G','T');
+const chd_metadata_tag GDROM_OLD_METADATA_TAG = CHD_MAKE_TAG('C','H','G','T');
+const chd_metadata_tag GDROM_TRACK_METADATA_TAG = CHD_MAKE_TAG('C', 'H', 'G', 'D');
 extern const char *GDROM_TRACK_METADATA_FORMAT;
 
 // standard A/V metadata
@@ -516,6 +517,17 @@ private:
 	// a single work item
 	struct work_item
 	{
+		work_item()
+			: m_osd(NULL)
+			, m_compressor(NULL)
+			, m_status(WS_READY)
+			, m_data(NULL)
+			, m_compressed(NULL)
+			, m_complen(0)
+			, m_compression(0)
+			, m_codecs(NULL)
+		{ }
+
 		osd_work_item *     m_osd;              // OSD work item running on this block
 		chd_file_compressor *m_compressor;      // pointer back to the compressor
 		volatile work_status m_status;          // current status of this item
