@@ -154,7 +154,7 @@ static UINT32 parse_wav_sample(const char *filename, UINT32 *dataoffs)
 	filerr = osd_open(filename, OPEN_FLAG_READ, &file, &fsize);
 	if (filerr != FILERR_NONE)
 	{
-		osd_close(file);
+		printf("ERROR: could not open (%s)\n", filename);
 		return 0;
 	}
 
@@ -162,24 +162,44 @@ static UINT32 parse_wav_sample(const char *filename, UINT32 *dataoffs)
 	osd_read(file, buf, 0, 4, &actual);
 	offset += actual;
 	if (offset < 4)
+	{
+		osd_close(file);
+		printf("ERROR: unexpected RIFF offset %lu (%s)\n", offset, filename);
 		return 0;
+	}
 	if (memcmp(&buf[0], "RIFF", 4) != 0)
+	{
+		osd_close(file);
+		printf("ERROR: could not find RIFF header (%s)\n", filename);
 		return 0;
+	}
 
 	/* get the total size */
 	osd_read(file, &filesize, offset, 4, &actual);
 	offset += actual;
 	if (offset < 8)
+	{
+		osd_close(file);
+		printf("ERROR: unexpected size offset %lu (%s)\n", offset, filename);
 		return 0;
+	}
 	filesize = LITTLE_ENDIANIZE_INT32(filesize);
 
 	/* read the RIFF file type and make sure it's a WAVE file */
 	osd_read(file, buf, offset, 4, &actual);
 	offset += actual;
 	if (offset < 12)
+	{
+		osd_close(file);
+		printf("ERROR: unexpected WAVE offset %lu (%s)\n", offset, filename);
 		return 0;
+	}
 	if (memcmp(&buf[0], "WAVE", 4) != 0)
+	{
+		osd_close(file);
+		printf("ERROR: could not find WAVE header (%s)\n", filename);
 		return 0;
+	}
 
 	/* seek until we find a format tag */
 	while (1)
@@ -195,7 +215,11 @@ static UINT32 parse_wav_sample(const char *filename, UINT32 *dataoffs)
 		/* seek to the next block */
 		offset += length;
 		if (offset >= filesize)
+		{
+			osd_close(file);
+			printf("ERROR: could not find fmt tag (%s)\n", filename);
 			return 0;
+		}
 	}
 
 	/* read the format -- make sure it is PCM */
@@ -203,21 +227,33 @@ static UINT32 parse_wav_sample(const char *filename, UINT32 *dataoffs)
 	offset += actual;
 	temp16 = LITTLE_ENDIANIZE_INT16(temp16);
 	if (temp16 != 1)
+	{
+		osd_close(file);
+		printf("ERROR: unsupported format %u - only PCM is supported (%s)\n", temp16, filename);
 		return 0;
+	}
 
-	/* number of channels -- only mono is supported */
+	/* number of channels -- only stereo is supported */
 	osd_read(file, &temp16, offset, 2, &actual);
 	offset += actual;
 	temp16 = LITTLE_ENDIANIZE_INT16(temp16);
 	if (temp16 != 2)
+	{
+		osd_close(file);
+		printf("ERROR: unsupported number of channels %u - only stereo is supported (%s)\n", temp16, filename);
 		return 0;
+	}
 
 	/* sample rate */
 	osd_read(file, &rate, offset, 4, &actual);
 	offset += actual;
 	rate = LITTLE_ENDIANIZE_INT32(rate);
 	if (rate != 44100)
+	{
+		osd_close(file);
+		printf("ERROR: unsupported samplerate %u - only 44100 is supported (%s)\n", rate, filename);
 		return 0;
+	}
 
 	/* bytes/second and block alignment are ignored */
 	osd_read(file, buf, offset, 6, &actual);
@@ -226,8 +262,13 @@ static UINT32 parse_wav_sample(const char *filename, UINT32 *dataoffs)
 	/* bits/sample */
 	osd_read(file, &bits, offset, 2, &actual);
 	offset += actual;
+	bits = LITTLE_ENDIANIZE_INT16(bits);
 	if (bits != 16)
+	{
+		osd_close(file);
+		printf("ERROR: unsupported bits/sample %u - only 16 is supported (%s)\n", bits, filename);
 		return 0;
+	}
 
 	/* seek past any extra data */
 	offset += length - 16;
@@ -246,14 +287,21 @@ static UINT32 parse_wav_sample(const char *filename, UINT32 *dataoffs)
 		/* seek to the next block */
 		offset += length;
 		if (offset >= filesize)
+		{
+			osd_close(file);
+			printf("ERROR: could not find data tag (%s)\n", filename);
 			return 0;
+		}
 	}
 
+	osd_close(file);
+
 	/* if there was a 0 length data block, we're done */
 	if (length == 0)
+	{
+		printf("ERROR: empty data block (%s)\n", filename);
 		return 0;
-
-	osd_close(file);
+	}
 
 	*dataoffs = offset;
 
@@ -313,7 +361,7 @@ chd_error chdcd_parse_nero(const char *tocfname, cdrom_toc &outtoc, chdcd_track_
 
 	astring path = astring(tocfname);
 
-	infile = fopen(tocfname, "rt");
+	infile = fopen(tocfname, "rb");
 	path = get_file_path(path);
 
 	if (infile == (FILE *)NULL)
@@ -333,7 +381,7 @@ chd_error chdcd_parse_nero(const char *tocfname, cdrom_toc &outtoc, chdcd_track_
 	{
 		printf("ERROR: Not a Nero 5.5 or later image!\n");
 		fclose(infile);
-		return CHDERR_FILE_NOT_FOUND;
+		return CHDERR_UNSUPPORTED_VERSION;
 	}
 
 	chain_offs = buffer[11] | (buffer[10]<<8) | (buffer[9]<<16) | (buffer[8]<<24);
@@ -342,7 +390,7 @@ chd_error chdcd_parse_nero(const char *tocfname, cdrom_toc &outtoc, chdcd_track_
 	{
 		printf("ERROR: File size is > 4GB, this version of CHDMAN cannot handle it.");
 		fclose(infile);
-		return CHDERR_FILE_NOT_FOUND;
+		return CHDERR_UNSUPPORTED_FORMAT;
 	}
 
 //  printf("NER5 detected, chain offset: %x\n", chain_offs);
@@ -364,13 +412,12 @@ chd_error chdcd_parse_nero(const char *tocfname, cdrom_toc &outtoc, chdcd_track_
 		if (!memcmp(buffer, "DAOX", 4))
 		{
 			// skip second chunk size and UPC code
-			fseek(infile, 16, SEEK_CUR);
+			fseek(infile, 20, SEEK_CUR);
 
-			read_uint32(infile);
 			fread(&start, 1, 1, infile);
 			fread(&end, 1, 1, infile);
 
-//          printf("TOC type: %08x.  Start track %d  End track: %d\n", toc_type, start, end);
+//          printf("Start track %d  End track: %d\n", start, end);
 
 			outtoc.numtrks = (end-start) + 1;
 
@@ -378,41 +425,68 @@ chd_error chdcd_parse_nero(const char *tocfname, cdrom_toc &outtoc, chdcd_track_
 			for (track = start; track <= end; track++)
 			{
 				UINT32 size, mode;
-				UINT64 index0, index1, index2;
+				UINT64 index0, index1, track_end;
 
-				fseek(infile, 12, SEEK_CUR);	// skip ISRC code
+				fseek(infile, 12, SEEK_CUR);    // skip ISRC code
 				size = read_uint16(infile);
-				mode = read_uint32(infile);
+				mode = read_uint16(infile);
+				fseek(infile, 2, SEEK_CUR);
 				index0 = read_uint64(infile);
 				index1 = read_uint64(infile);
-				index2 = read_uint64(infile);
+				track_end = read_uint64(infile);
 
-//              printf("Track %d: sector size %d mode %x index0 %llx index1 %llx index2 %llx (pregap %d sectors, length %d sectors)\n", track, size, mode, index0, index1, index2, (UINT32)(index1-index0)/size, (UINT32)(index2-index1)/size);
-				outinfo.track[track-1].fname.cpy(path).cat(tocfname);
+//              printf("Track %d: sector size %d mode %x index0 %llx index1 %llx track_end %llx (pregap %d sectors, length %d sectors)\n", track, size, mode, index0, index1, track_end, (UINT32)(index1-index0)/size, (UINT32)(track_end-index1)/size);
+				outinfo.track[track-1].fname.cpy(tocfname);
 				outinfo.track[track-1].offset = offset + (UINT32)(index1-index0);
 				outinfo.track[track-1].idx0offs = 0;
 				outinfo.track[track-1].idx1offs = 0;
 
-				switch (mode>>24)
+				switch (mode)
 				{
-					case 0x00:	// 2048 byte data
+					case 0x0000:    // 2048 byte data
 						outtoc.tracks[track-1].trktype = CD_TRACK_MODE1;
 						outinfo.track[track-1].swap = false;
 						break;
 
-					case 0x06:	// 2352 byte mode 2 raw
+					case 0x0300:    // Mode 2 Form 1
+						printf("ERROR: Mode 2 Form 1 tracks not supported\n");
+						fclose(infile);
+						return CHDERR_UNSUPPORTED_FORMAT;
+
+					case 0x0500:    // raw data
+						printf("ERROR: Raw data tracks not supported\n");
+						fclose(infile);
+						return CHDERR_UNSUPPORTED_FORMAT;
+
+					case 0x0600:    // 2352 byte mode 2 raw
 						outtoc.tracks[track-1].trktype = CD_TRACK_MODE2_RAW;
 						outinfo.track[track-1].swap = false;
 						break;
 
-					case 0x07:	// 2352 byte audio
+					case 0x0700:    // 2352 byte audio
 						outtoc.tracks[track-1].trktype = CD_TRACK_AUDIO;
 						outinfo.track[track-1].swap = true;
 						break;
 
+					case 0x0f00:    // raw data with sub-channel
+						printf("ERROR: Raw data tracks with sub-channel not supported\n");
+						fclose(infile);
+						return CHDERR_UNSUPPORTED_FORMAT;
+
+					case 0x1000:    // audio with sub-channel
+						printf("ERROR: Audio tracks with sub-channel not supported\n");
+						fclose(infile);
+						return CHDERR_UNSUPPORTED_FORMAT;
+
+					case 0x1100:    // raw Mode 2 Form 1 with sub-channel
+						printf("ERROR: Raw Mode 2 Form 1 tracks with sub-channel not supported\n");
+						fclose(infile);
+						return CHDERR_UNSUPPORTED_FORMAT;
+
 					default:
-						printf("ERROR: Unknown track type %x, contact MAMEDEV!\n", mode>>24);
-						break;
+						printf("ERROR: Unknown track type %x, contact MAMEDEV!\n", mode);
+						fclose(infile);
+						return CHDERR_UNSUPPORTED_FORMAT;
 				}
 
 				outtoc.tracks[track-1].datasize = size;
@@ -421,7 +495,7 @@ chd_error chdcd_parse_nero(const char *tocfname, cdrom_toc &outtoc, chdcd_track_
 				outtoc.tracks[track-1].subsize = 0;
 
 				outtoc.tracks[track-1].pregap = (UINT32)(index1-index0)/size;
-				outtoc.tracks[track-1].frames = (UINT32)(index2-index1)/size;
+				outtoc.tracks[track-1].frames = (UINT32)(track_end-index1)/size;
 				outtoc.tracks[track-1].postgap = 0;
 				outtoc.tracks[track-1].pgtype = 0;
 				outtoc.tracks[track-1].pgsub = CD_SUB_NONE;
@@ -429,7 +503,7 @@ chd_error chdcd_parse_nero(const char *tocfname, cdrom_toc &outtoc, chdcd_track_
 				outtoc.tracks[track-1].pgsubsize = 0;
 				outtoc.tracks[track-1].padframes = 0;
 
-				offset += (UINT32)index2-index1;
+				offset += (UINT32)track_end-index1;
 			}
 		}
 
@@ -448,6 +522,71 @@ chd_error chdcd_parse_nero(const char *tocfname, cdrom_toc &outtoc, chdcd_track_
 	return CHDERR_NONE;
 }
 
+/*-------------------------------------------------
+    chdcd_parse_iso - parse a .ISO file
+-------------------------------------------------*/
+
+chd_error chdcd_parse_iso(const char *tocfname, cdrom_toc &outtoc, chdcd_track_input_info &outinfo)
+{
+	FILE *infile;
+	astring path = astring(tocfname);
+
+	infile = fopen(tocfname, "rb");
+	path = get_file_path(path);
+
+	if (infile == (FILE *)NULL)
+	{
+		return CHDERR_FILE_NOT_FOUND;
+	}
+
+	/* clear structures */
+	memset(&outtoc, 0, sizeof(outtoc));
+	outinfo.reset();
+
+	fseek(infile, 0, SEEK_END);
+	long size = ftell(infile);
+	fclose(infile);
+
+
+	outtoc.numtrks = 1;
+
+	outinfo.track[0].fname = tocfname;
+	outinfo.track[0].offset = 0;
+	outinfo.track[0].idx0offs = 0;
+	outinfo.track[0].idx1offs = 0;
+
+	if ((size % 2048)==0 ) {
+		outtoc.tracks[0].trktype = CD_TRACK_MODE1;
+		outtoc.tracks[0].frames = size / 2048;
+		outtoc.tracks[0].datasize = 2048;
+		outinfo.track[0].swap = false;
+	} else if ((size % 2352)==0 ) {
+		// 2352 byte mode 2 raw
+		outtoc.tracks[0].trktype = CD_TRACK_MODE2_RAW;
+		outtoc.tracks[0].frames = size / 2352;
+		outtoc.tracks[0].datasize = 2352;
+		outinfo.track[0].swap = false;
+	} else {
+		printf("ERROR: Unrecognized track type\n");
+		return CHDERR_UNSUPPORTED_FORMAT;
+	}
+
+	outtoc.tracks[0].subtype = CD_SUB_NONE;
+	outtoc.tracks[0].subsize = 0;
+
+	outtoc.tracks[0].pregap = 0;
+
+	outtoc.tracks[0].postgap = 0;
+	outtoc.tracks[0].pgtype = 0;
+	outtoc.tracks[0].pgsub = CD_SUB_NONE;
+	outtoc.tracks[0].pgdatasize = 0;
+	outtoc.tracks[0].pgsubsize = 0;
+	outtoc.tracks[0].padframes = 0;
+
+
+	return CHDERR_NONE;
+}
+
 /*-------------------------------------------------
     chdcd_parse_gdi - parse a Sega GD-ROM rip
 -------------------------------------------------*/
@@ -471,7 +610,7 @@ static chd_error chdcd_parse_gdi(const char *tocfname, cdrom_toc &outtoc, chdcd_
 	memset(&outtoc, 0, sizeof(outtoc));
 	outinfo.reset();
 
-    outtoc.flags = CD_FLAG_GDROM;
+	outtoc.flags = CD_FLAG_GDROM;
 
 	fgets(linebuffer,511,infile);
 	numtracks=atoi(linebuffer);
@@ -492,9 +631,10 @@ static chd_error chdcd_parse_gdi(const char *tocfname, cdrom_toc &outtoc, chdcd_
 		outinfo.track[trknum].swap=false;
 		outinfo.track[trknum].offset=0;
 
-        outtoc.tracks[trknum].datasize = 0;
+		outtoc.tracks[trknum].datasize = 0;
 		outtoc.tracks[trknum].subtype = CD_SUB_NONE;
 		outtoc.tracks[trknum].subsize = 0;
+		outtoc.tracks[trknum].pgsub = CD_SUB_NONE;
 
 		tok=strtok(NULL," ");
 		outtoc.tracks[trknum].physframeofs=atoi(tok);
@@ -519,6 +659,7 @@ static chd_error chdcd_parse_gdi(const char *tocfname, cdrom_toc &outtoc, chdcd_
 		{
 			outtoc.tracks[trknum].trktype=CD_TRACK_AUDIO;
 			outtoc.tracks[trknum].datasize=2352;
+			outinfo.track[trknum].swap = true;
 		}
 
 		astring name;
@@ -550,12 +691,12 @@ static chd_error chdcd_parse_gdi(const char *tocfname, cdrom_toc &outtoc, chdcd_
 		}
 	}
 
-    #if 0
+	#if 0
 	for(i=0; i < numtracks; i++)
-    {
-        printf("%s %d %d %d (true %d)\n", outinfo.track[i].fname.cstr(), outtoc.tracks[i].frames, outtoc.tracks[i].padframes, outtoc.tracks[i].physframeofs, outtoc.tracks[i].frames - outtoc.tracks[i].padframes);
-    }
-    #endif
+	{
+		printf("%s %d %d %d (true %d)\n", outinfo.track[i].fname.cstr(), outtoc.tracks[i].frames, outtoc.tracks[i].padframes, outtoc.tracks[i].physframeofs, outtoc.tracks[i].frames - outtoc.tracks[i].padframes);
+	}
+	#endif
 
 	/* close the input TOC */
 	fclose(infile);
@@ -567,7 +708,7 @@ static chd_error chdcd_parse_gdi(const char *tocfname, cdrom_toc &outtoc, chdcd_
 }
 
 /*-------------------------------------------------
-    chdcd_parse_toc - parse a CDRWin format CUE file
+    chdcd_parse_cue - parse a CDRWin format CUE file
 -------------------------------------------------*/
 
 chd_error chdcd_parse_cue(const char *tocfname, cdrom_toc &outtoc, chdcd_track_input_info &outinfo)
@@ -618,32 +759,25 @@ chd_error chdcd_parse_cue(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 
 				if (!strcmp(token, "BINARY"))
 				{
-					outinfo.track[trknum].swap = false;
+					outinfo.track[trknum+1].swap = false;
 				}
 				else if (!strcmp(token, "MOTOROLA"))
 				{
-					outinfo.track[trknum].swap = true;
+					outinfo.track[trknum+1].swap = true;
 				}
 				else if (!strcmp(token, "WAVE"))
 				{
 					wavlen = parse_wav_sample(lastfname, &wavoffs);
 					if (!wavlen)
 					{
-						file_error err;
-						core_file *fhand;
-
-						err = core_fopen(lastfname, OPEN_FLAG_READ, &fhand);
-						if (err != FILERR_NONE) printf("holy moley!\n");
-						else core_fclose(fhand);
-
 						printf("ERROR: couldn't read [%s] or not a valid .WAV\n", lastfname.cstr());
-						return CHDERR_FILE_NOT_FOUND;
+						return CHDERR_INVALID_DATA;
 					}
 				}
 				else
 				{
 					printf("ERROR: Unhandled track type %s\n", token);
-					return CHDERR_FILE_NOT_FOUND;
+					return CHDERR_UNSUPPORTED_FORMAT;
 				}
 			}
 			else if (!strcmp(token, "TRACK"))
@@ -683,7 +817,7 @@ chd_error chdcd_parse_cue(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 				if (outtoc.tracks[trknum].datasize == 0)
 				{
 					printf("ERROR: Unknown track type [%s].  Contact MAMEDEV.\n", token);
-					return CHDERR_FILE_NOT_FOUND;
+					return CHDERR_UNSUPPORTED_FORMAT;
 				}
 
 				/* next (optional) token on the line is the subcode type */
@@ -691,7 +825,7 @@ chd_error chdcd_parse_cue(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 
 				cdrom_convert_subtype_string_to_track_info(token, &outtoc.tracks[trknum]);
 			}
-			else if (!strcmp(token, "INDEX"))	/* only in bin/cue files */
+			else if (!strcmp(token, "INDEX"))   /* only in bin/cue files */
 			{
 				int idx, frames;
 
@@ -713,6 +847,33 @@ chd_error chdcd_parse_cue(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 					if ((outtoc.tracks[trknum].pregap == 0) && (outinfo.track[trknum].idx0offs != -1))
 					{
 						outtoc.tracks[trknum].pregap = frames - outinfo.track[trknum].idx0offs;
+						outtoc.tracks[trknum].pgtype = outtoc.tracks[trknum].trktype;
+						switch (outtoc.tracks[trknum].pgtype)
+						{
+							case CD_TRACK_MODE1:
+							case CD_TRACK_MODE2_FORM1:
+								outtoc.tracks[trknum].pgdatasize = 2048;
+								break;
+
+							case CD_TRACK_MODE1_RAW:
+							case CD_TRACK_MODE2_RAW:
+							case CD_TRACK_AUDIO:
+								outtoc.tracks[trknum].pgdatasize = 2352;
+								break;
+
+							case CD_TRACK_MODE2:
+							case CD_TRACK_MODE2_FORM_MIX:
+								outtoc.tracks[trknum].pgdatasize = 2336;
+								break;
+
+							case CD_TRACK_MODE2_FORM2:
+								outtoc.tracks[trknum].pgdatasize = 2324;
+								break;
+						}
+					}
+					else    // pregap sectors not in file, but we're always using idx0ofs for track length calc now
+					{
+						outinfo.track[trknum].idx0offs = frames;
 					}
 				}
 			}
@@ -774,7 +935,7 @@ chd_error chdcd_parse_cue(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 					outinfo.track[trknum].offset = outinfo.track[trknum-1].offset + outtoc.tracks[trknum-1].frames * (outtoc.tracks[trknum-1].datasize + outtoc.tracks[trknum-1].subsize);
 					outtoc.tracks[trknum].frames = (tlen - outinfo.track[trknum].offset) / (outtoc.tracks[trknum].datasize + outtoc.tracks[trknum].subsize);
 				}
-				else	/* data files are different */
+				else    /* data files are different */
 				{
 					tlen = get_file_size(outinfo.track[trknum].fname);
 					if (tlen == 0)
@@ -792,9 +953,9 @@ chd_error chdcd_parse_cue(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 				/* if we have the same filename as the next track, do it that way */
 				if (outinfo.track[trknum].fname == outinfo.track[trknum+1].fname)
 				{
-					outtoc.tracks[trknum].frames = outinfo.track[trknum+1].idx1offs - outinfo.track[trknum].idx1offs;
+					outtoc.tracks[trknum].frames = outinfo.track[trknum+1].idx0offs - outinfo.track[trknum].idx0offs;
 
-					if (trknum == 0)	// track 0 offset is 0
+					if (trknum == 0)    // track 0 offset is 0
 					{
 						outinfo.track[trknum].offset = 0;
 					}
@@ -806,10 +967,10 @@ chd_error chdcd_parse_cue(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 					if (!outtoc.tracks[trknum].frames)
 					{
 						printf("ERROR: unable to determine size of track %d, missing INDEX 01 markers?\n", trknum+1);
-						return CHDERR_FILE_NOT_FOUND;
+						return CHDERR_INVALID_DATA;
 					}
 				}
-				else	/* data files are different */
+				else    /* data files are different */
 				{
 					tlen = get_file_size(outinfo.track[trknum].fname);
 					if (tlen == 0)
@@ -823,7 +984,7 @@ chd_error chdcd_parse_cue(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 				}
 			}
 		}
-		printf("trk %d: %d frames @ offset %d\n", trknum+1, outtoc.tracks[trknum].frames, outinfo.track[trknum].offset);
+		//printf("trk %d: %d frames @ offset %d\n", trknum+1, outtoc.tracks[trknum].frames, outinfo.track[trknum].offset);
 	}
 
 	return CHDERR_NONE;
@@ -838,13 +999,13 @@ chd_error chdcd_parse_toc(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 	FILE *infile;
 	int i, trknum;
 	static char token[512];
-    char tocftemp[512];
+	char tocftemp[512];
 
-    strcpy(tocftemp, tocfname);
-    for (i = 0; i < strlen(tocfname); i++)
-    {
-        tocftemp[i] = tolower(tocftemp[i]);
-    }
+	strcpy(tocftemp, tocfname);
+	for (i = 0; i < strlen(tocfname); i++)
+	{
+		tocftemp[i] = tolower(tocftemp[i]);
+	}
 
 	if (strstr(tocftemp,".gdi"))
 	{
@@ -861,6 +1022,11 @@ chd_error chdcd_parse_toc(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 		return chdcd_parse_nero(tocfname, outtoc, outinfo);
 	}
 
+	if (strstr(tocftemp,".iso") || strstr(tocftemp,".cdr"))
+	{
+		return chdcd_parse_iso(tocfname, outtoc, outinfo);
+	}
+
 	astring path = astring(tocfname);
 
 	infile = fopen(tocfname, "rt");
@@ -983,7 +1149,7 @@ chd_error chdcd_parse_toc(const char *tocfname, cdrom_toc &outtoc, chdcd_track_i
 				if (outtoc.tracks[trknum].datasize == 0)
 				{
 					printf("ERROR: Unknown track type [%s].  Contact MAMEDEV.\n", token);
-					return CHDERR_FILE_NOT_FOUND;
+					return CHDERR_UNSUPPORTED_FORMAT;
 				}
 
 				/* next (optional) token on the line is the subcode type */
