@@ -867,14 +867,14 @@ static void starcas_sound_w(running_machine &machine, UINT8 sound_val, UINT8 bit
 		target_pitch = 0x5800 + (target_pitch << 12);
 
 		/* once per frame slide the pitch toward the target */
-		if (machine.primary_screen->frame_number() > state->m_last_frame)
+		if (machine.first_screen()->frame_number() > state->m_last_frame)
 		{
 			if (state->m_current_pitch > target_pitch)
 				state->m_current_pitch -= 225;
 			if (state->m_current_pitch < target_pitch)
 				state->m_current_pitch += 150;
 			samples->set_frequency(4, state->m_current_pitch);
-			state->m_last_frame = machine.primary_screen->frame_number();
+			state->m_last_frame = machine.first_screen()->frame_number();
 		}
 
 		/* remember the previous value */
@@ -970,7 +970,7 @@ static void solarq_sound_w(running_machine &machine, UINT8 sound_val, UINT8 bits
 			state->m_target_volume = 0;
 
 		/* ramp the thrust volume */
-		if (samples->playing(2) && machine.primary_screen->frame_number() > state->m_last_frame)
+		if (samples->playing(2) && machine.first_screen()->frame_number() > state->m_last_frame)
 		{
 			if (state->m_current_volume > state->m_target_volume)
 				state->m_current_volume -= 0.078f;
@@ -980,7 +980,7 @@ static void solarq_sound_w(running_machine &machine, UINT8 sound_val, UINT8 bits
 				samples->set_volume(2, state->m_current_volume);
 			else
 				samples->stop(2);
-			state->m_last_frame = machine.primary_screen->frame_number();
+			state->m_last_frame = machine.first_screen()->frame_number();
 		}
 
 		/* fire - falling edge */
@@ -1250,14 +1250,14 @@ static void wotw_sound_w(running_machine &machine, UINT8 sound_val, UINT8 bits_c
 		target_pitch = 0x10000 + (target_pitch << 12);
 
 		/* once per frame slide the pitch toward the target */
-		if (machine.primary_screen->frame_number() > state->m_last_frame)
+		if (machine.first_screen()->frame_number() > state->m_last_frame)
 		{
 			if (state->m_current_pitch > target_pitch)
 				state->m_current_pitch -= 300;
 			if (state->m_current_pitch < target_pitch)
 				state->m_current_pitch += 200;
 			samples->set_frequency(4, state->m_current_pitch);
-			state->m_last_frame = machine.primary_screen->frame_number();
+			state->m_last_frame = machine.first_screen()->frame_number();
 		}
 
 		/* remember the previous value */
@@ -1349,43 +1349,11 @@ WRITE8_MEMBER(cinemat_state::sound_portb_w)
 	m_last_portb_write = data;
 }
 
-
 WRITE8_MEMBER(cinemat_state::sound_output_w)
 {
 	logerror("sound_output = %02X\n", data);
 }
 
-
-static const ay8910_interface demon_ay8910_interface_1 =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_DRIVER_MEMBER(cinemat_state,sound_porta_r),
-	DEVCB_DRIVER_MEMBER(cinemat_state,sound_portb_r),
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(cinemat_state,sound_portb_w)
-};
-
-static const ay8910_interface demon_ay8910_interface_3 =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(cinemat_state,sound_output_w)
-};
-
-
-static Z80CTC_INTERFACE( demon_z80ctc_interface )
-{
-	DEVCB_CPU_INPUT_LINE("audiocpu", INPUT_LINE_IRQ0),   /* interrupt handler */
-	DEVCB_NULL,     /* ZC/TO0 callback */
-	DEVCB_NULL,     /* ZC/TO1 callback */
-	DEVCB_NULL      /* ZC/TO2 callback */
-};
-
-
 SOUND_RESET_MEMBER( cinemat_state, demon )
 {
 	/* generic init */
@@ -1435,7 +1403,8 @@ MACHINE_CONFIG_FRAGMENT( demon_sound )
 	MCFG_CPU_PROGRAM_MAP(demon_sound_map)
 	MCFG_CPU_IO_MAP(demon_sound_ports)
 
-	MCFG_Z80CTC_ADD("ctc", 3579545 /* same as "audiocpu" */, demon_z80ctc_interface)
+	MCFG_DEVICE_ADD("ctc", Z80CTC, 3579545 /* same as "audiocpu" */)
+	MCFG_Z80CTC_INTR_CB(INPUTLINE("audiocpu", INPUT_LINE_IRQ0))
 
 	MCFG_SOUND_RESET_OVERRIDE(cinemat_state, demon)
 
@@ -1443,14 +1412,18 @@ MACHINE_CONFIG_FRAGMENT( demon_sound )
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("ay1", AY8910, 3579545)
-	MCFG_SOUND_CONFIG(demon_ay8910_interface_1)
+	MCFG_AY8910_PORT_A_READ_CB(READ8(cinemat_state, sound_porta_r))
+	MCFG_AY8910_PORT_B_READ_CB(READ8(cinemat_state, sound_portb_r))
+	MCFG_AY8910_PORT_B_WRITE_CB(WRITE8(cinemat_state, sound_portb_w))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	MCFG_SOUND_ADD("ay2", AY8910, 3579545)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	MCFG_SOUND_ADD("ay3", AY8910, 3579545)
-	MCFG_SOUND_CONFIG(demon_ay8910_interface_3)
+
+
+	MCFG_AY8910_PORT_B_WRITE_CB(WRITE8(cinemat_state, sound_output_w))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_CONFIG_END
 
