@@ -131,7 +131,7 @@ logerror("Votrax: intonation %d, phoneme %02x %s\n",data >> 6,data & 0x3f,Phonem
 				else strcat(phonemes,PhonemeTable[phoneme]);
 			}
 
-			mame_printf_debug("Votrax played '%s'\n", phonemes);
+			osd_printf_debug("Votrax played '%s'\n", phonemes);
 
 			if (strcmp(phonemes, "[0] HEH3LOOW     AH1EH3I3YMTERI2NDAHN") == 0)   /* Q-Bert & Tylz - Hello, I am turned on */
 								m_samples->start(0, 42);
@@ -415,7 +415,7 @@ WRITE8_MEMBER( gottlieb_sound_r1_device::speech_clock_dac_w )
 		// nominal clock is 0xa0
 		if (data != m_last_speech_clock)
 		{
-			mame_printf_debug("clock = %02X\n", data);
+			osd_printf_debug("clock = %02X\n", data);
 
 			// totally random guesswork; would like to get real measurements on a board
 			if (m_votrax != NULL)
@@ -437,30 +437,6 @@ WRITE_LINE_MEMBER( gottlieb_sound_r1_device::votrax_request )
 }
 
 
-//-------------------------------------------------
-//  RIOT interface
-//-------------------------------------------------
-
-static const riot6532_interface gottlieb_riot6532_intf =
-{
-	DEVCB_NULL,
-	DEVCB_INPUT_PORT("SB1"),
-	DEVCB_NULL,
-	DEVCB_DEVICE_MEMBER(DEVICE_SELF_OWNER, gottlieb_sound_r1_device, r6532_portb_w),
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, gottlieb_sound_r1_device, snd_interrupt)
-};
-
-
-//-------------------------------------------------
-//  VOTRAX interface
-//-------------------------------------------------
-
-static const votrax_sc01_interface gottlieb_votrax_interface =
-{
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, gottlieb_sound_r1_device, votrax_request)
-};
-
-
 //-------------------------------------------------
 //  audio CPU map
 //-------------------------------------------------
@@ -487,7 +463,10 @@ MACHINE_CONFIG_FRAGMENT( gottlieb_sound_r1 )
 	MCFG_CPU_PROGRAM_MAP(gottlieb_sound_r1_map)
 
 	// I/O configuration
-	MCFG_RIOT6532_ADD("riot", SOUND1_CLOCK/4, gottlieb_riot6532_intf)
+	MCFG_DEVICE_ADD("riot", RIOT6532, SOUND1_CLOCK/4)
+	MCFG_RIOT6532_IN_PB_CB(IOPORT("SB1"))
+	MCFG_RIOT6532_OUT_PB_CB(WRITE8(gottlieb_sound_r1_device, r6532_portb_w))
+	MCFG_RIOT6532_IRQ_CB(WRITELINE(gottlieb_sound_r1_device, snd_interrupt))
 
 	// sound devices
 	MCFG_DAC_ADD("dac")
@@ -498,7 +477,8 @@ MACHINE_CONFIG_FRAGMENT( gottlieb_sound_r1_with_votrax )
 	MCFG_FRAGMENT_ADD(gottlieb_sound_r1)
 
 	// add the VOTRAX
-	MCFG_VOTRAX_SC01_ADD("votrax", 720000, gottlieb_votrax_interface)
+	MCFG_DEVICE_ADD("votrax", VOTRAX_SC01, 720000)
+	MCFG_VOTRAX_SC01_REQUEST_CB(DEVWRITELINE(DEVICE_SELF_OWNER, gottlieb_sound_r1_device, votrax_request))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, DEVICE_SELF_OWNER, 0.50)
 MACHINE_CONFIG_END
 
