@@ -196,21 +196,21 @@ MACHINE_CONFIG_FRAGMENT( jedi_audio )
 
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MCFG_POKEY_ADD("pokey1", JEDI_POKEY_CLOCK)
+	MCFG_SOUND_ADD("pokey1", POKEY, JEDI_POKEY_CLOCK)
 	MCFG_POKEY_OUTPUT_OPAMP(RES_K(1), 0.0, 5.0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.30)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.30)
 
-	MCFG_POKEY_ADD("pokey2", JEDI_POKEY_CLOCK)
+	MCFG_SOUND_ADD("pokey2", POKEY, JEDI_POKEY_CLOCK)
 	MCFG_POKEY_OUTPUT_OPAMP(RES_K(1), 0.0, 5.0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.30)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.30)
 
-	MCFG_POKEY_ADD("pokey3", JEDI_POKEY_CLOCK)
+	MCFG_SOUND_ADD("pokey3", POKEY, JEDI_POKEY_CLOCK)
 	MCFG_POKEY_OUTPUT_OPAMP(RES_K(1), 0.0, 5.0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.30)
 
-	MCFG_POKEY_ADD("pokey4", JEDI_POKEY_CLOCK)
+	MCFG_SOUND_ADD("pokey4", POKEY, JEDI_POKEY_CLOCK)
 	MCFG_POKEY_OUTPUT_OPAMP(RES_K(1), 0.0, 5.0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.30)
 
