@@ -493,7 +493,7 @@ READ8_MEMBER(mario_state::mario_sh_tune_r)
 
 WRITE8_MEMBER(mario_state::mario_sh_sound_w)
 {
-	discrete_sound_w(m_discrete, space, DS_DAC, data);
+	m_discrete->write(space, DS_DAC, data);
 }
 
 WRITE8_MEMBER(mario_state::mario_sh_p1_w)
@@ -533,13 +533,13 @@ WRITE8_MEMBER(mario_state::mario_sh_tuneselect_w)
 /* Mario running sample */
 WRITE8_MEMBER(mario_state::mario_sh1_w)
 {
-	discrete_sound_w(m_discrete, space, DS_SOUND0_INP, 0);
+	m_discrete->write(space, DS_SOUND0_INP, 0);
 }
 
 /* Luigi running sample */
 WRITE8_MEMBER(mario_state::mario_sh2_w)
 {
-	discrete_sound_w(m_discrete, space, DS_SOUND1_INP, 0);
+	m_discrete->write(space, DS_SOUND1_INP, 0);
 }
 
 /* Misc samples */
@@ -572,7 +572,7 @@ WRITE8_MEMBER(mario_state::mario_sh3_w)
 			I8035_P1_W_AH(space, 3, data & 1);
 			break;
 		case 7: /* skid */
-			discrete_sound_w(machine().device("discrete"), space, DS_SOUND7_INP, data & 1);
+			machine().device<discrete_device>("discrete")->write(space, DS_SOUND7_INP, data & 1);
 			break;
 	}
 }
@@ -603,22 +603,6 @@ static ADDRESS_MAP_START( masao_sound_map, AS_PROGRAM, 8, mario_state )
 	AM_RANGE(0x6000, 0x6000) AM_DEVWRITE("aysnd", ay8910_device, address_w)
 ADDRESS_MAP_END
 
-/*************************************
- *
- *  Sound Interfaces
- *
- *************************************/
-
-static const ay8910_interface ay8910_config =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_DRIVER_MEMBER(driver_device, soundlatch_byte_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
 
 /*************************************
  *
@@ -651,7 +635,7 @@ MACHINE_CONFIG_FRAGMENT( masao_audio )
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("aysnd", AY8910, 14318000/6)
-	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_AY8910_PORT_A_READ_CB(READ8(driver_device, soundlatch_byte_r))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
 MACHINE_CONFIG_END
