@@ -119,20 +119,6 @@ WRITE8_MEMBER(_20pacgal_state::timer_pulse_w)
 	//printf("timer pulse %02x\n", data);
 }
 
-/*************************************
- *
- *  Audio
- *
- *************************************/
-
-static const namco_interface namco_config =
-{
-	3,      /* number of voices */
-	0       /* stereo */
-};
-
-
-
 /*************************************
  *
  *  Coin counter
@@ -207,20 +193,21 @@ WRITE8_MEMBER(_20pacgal_state::sprite_lookup_w)
 // we also need the palette data because there is only a single rom on this pcb?
 static ADDRESS_MAP_START( 25pacman_map, AS_PROGRAM, 8, _25pacman_state )
 
-	AM_RANGE(0x00000, 0x3ffff) AM_ROM AM_REGION("flash", 0)
-
-	AM_RANGE(0x08000, 0x09fff) AM_READ_BANK("bank1") AM_WRITE(ram_48000_w)
-
 	AM_RANGE(0x04000, 0x047ff) AM_RAM AM_SHARE("video_ram")
+
 	AM_RANGE(0x04800, 0x05fff) AM_RAM
+
 	AM_RANGE(0x06000, 0x06fff) AM_WRITEONLY AM_SHARE("char_gfx_ram")
-	AM_RANGE(0x0a000, 0x0bfff) AM_WRITE(sprite_gfx_w)
-//  AM_RANGE(0x0fffe, 0x0ffff) AM_WRITENOP
-
-//  AM_RANGE(0x0c000, 0x0dfff) // is this the sound waveforms in a different format?
 	AM_RANGE(0x07000, 0x0717f) AM_WRITE(sprite_ram_w)
+//  AM_RANGE(0x08000, 0x09fff) AM_READ_BANK("bank1") AM_WRITE(ram_48000_w)
+	AM_RANGE(0x08000, 0x09fff) AM_WRITENOP
+	AM_RANGE(0x0a000, 0x0bfff) AM_WRITE(sprite_gfx_w)
 
-//  AM_RANGE(0x00000, 0x3ffff) AM_DEVREADWRITE("flash", sst_39vf020_device, read, write )  // (always fall through if nothing else is mapped?)
+	AM_RANGE(0x0c000, 0x0dfff) AM_WRITENOP // is this the sound waveforms in a different format?
+	AM_RANGE(0x0e000, 0x0ffff) AM_WRITENOP
+	AM_RANGE(0x1c000, 0x1ffff) AM_WRITENOP
+
+	AM_RANGE(0x00000, 0x3ffff) AM_DEVREADWRITE("flash", amd_29lv200t_device, read, write )  // (always fall through if nothing else is mapped?)
 
 ADDRESS_MAP_END
 
@@ -236,7 +223,7 @@ static ADDRESS_MAP_START( 20pacgal_map, AS_PROGRAM, 8, _20pacgal_state )
 	AM_RANGE(0x45f00, 0x45fff) AM_DEVWRITE("namco", namco_cus30_device, namcos1_cus30_w)
 	AM_RANGE(0x46000, 0x46fff) AM_WRITEONLY AM_SHARE("char_gfx_ram")
 	AM_RANGE(0x47100, 0x47100) AM_RAM   /* leftover from original Galaga code */
-	AM_RANGE(0x48000, 0x49fff) AM_READ_BANK("bank1") AM_WRITE(ram_48000_w)  /* this should be a mirror of 08000-09ffff */
+	AM_RANGE(0x48000, 0x49fff) AM_READ_BANK("bank1") AM_WRITE(ram_48000_w)  /* this should be a mirror of 08000-09fff */
 	AM_RANGE(0x4c000, 0x4dfff) AM_WRITE(sprite_gfx_w)
 	AM_RANGE(0x4e000, 0x4e17f) AM_WRITE(sprite_ram_w)
 	AM_RANGE(0x4e180, 0x4feff) AM_WRITENOP
@@ -268,10 +255,12 @@ READ8_MEMBER( _25pacman_state::_25pacman_io_87_r )
 //  AM_RANGE(0x84, 0x84) AM_NOP /* ?? */
 	AM_RANGE(0x85, 0x86) AM_WRITEONLY AM_SHARE("stars_seed")    /* stars: rng seed (lo/hi) */
 	AM_RANGE(0x87, 0x87) AM_READ( _25pacman_io_87_r ) // not eeprom on this
-	AM_RANGE(0x88, 0x88) AM_WRITE(ram_bank_select_w)
+	AM_RANGE(0x87, 0x87) AM_WRITENOP
+//  AM_RANGE(0x88, 0x88) AM_WRITE(ram_bank_select_w)
 	AM_RANGE(0x89, 0x89) AM_DEVWRITE("dac", dac_device, write_signed8)
 	AM_RANGE(0x8a, 0x8a) AM_WRITEONLY AM_SHARE("stars_ctrl")    /* stars: bits 3-4 = active set; bit 5 = enable */
 	AM_RANGE(0x8b, 0x8b) AM_WRITEONLY AM_SHARE("flip")
+	AM_RANGE(0x8c, 0x8c) AM_WRITENOP
 	AM_RANGE(0x8f, 0x8f) AM_WRITE(_20pacgal_coin_counter_w)
 ADDRESS_MAP_END
 
@@ -396,7 +385,6 @@ static MACHINE_CONFIG_START( 20pacgal, _20pacgal_state )
 	MCFG_CPU_IO_MAP(20pacgal_io_map)
 	MCFG_CPU_VBLANK_INT_DRIVER("screen", _20pacgal_state,  vblank_irq)
 
-
 	MCFG_EEPROM_SERIAL_93C46_8BIT_ADD("eeprom")
 
 	/* video hardware */
@@ -406,7 +394,7 @@ static MACHINE_CONFIG_START( 20pacgal, _20pacgal_state )
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("namco", NAMCO_CUS30, NAMCO_AUDIO_CLOCK)
-	MCFG_SOUND_CONFIG(namco_config)
+	MCFG_NAMCO_AUDIO_VOICES(3)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
 	MCFG_DAC_ADD("dac")
@@ -421,8 +409,7 @@ static MACHINE_CONFIG_DERIVED_CLASS( 25pacman, 20pacgal, _25pacman_state )
 	MCFG_CPU_PROGRAM_MAP(25pacman_map)
 	MCFG_CPU_IO_MAP(25pacman_io_map)
 
-
-	MCFG_SST_39VF020_ADD("flash") // wrong type, should be AM29LV20
+	MCFG_AMD_29LV200T_ADD("flash")
 MACHINE_CONFIG_END
 
 
@@ -447,7 +434,7 @@ ROM_START( 25pacmano ) /* Revision 2.00 */
 ROM_END
 
 // guzuta v2.2 PCB
-// this uses the main FLASH rom to save things instead of eeprom (type is AM29LV20)
+// this uses the main FLASH rom to save things instead of eeprom (type is AM29LV200)
 // different memory map.. no palette rom
 ROM_START( 25pacman ) /* Revision 3.00 */
 	ROM_REGION( 0x40000, "flash", 0 )
@@ -532,8 +519,8 @@ DRIVER_INIT_MEMBER(_20pacgal_state,25pacman)
  *
  *************************************/
 
-GAME( 2006, 25pacman,          0, 25pacman, 25pacman, _20pacgal_state, 25pacman, ROT90, "Namco", "Pac-Man - 25th Anniversary Edition (Rev 3.00)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE | GAME_NOT_WORKING )
-GAME( 2005, 25pacmano,  25pacman, 20pacgal, 25pacman, _20pacgal_state, 25pacman, ROT90, "Namco", "Pac-Man - 25th Anniversary Edition (Rev 2.00)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE)
+GAME( 2006, 25pacman,          0, 25pacman, 25pacman, _20pacgal_state, 25pacman, ROT90, "Namco / Cosmodog", "Pac-Man - 25th Anniversary Edition (Rev 3.00)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE | GAME_NOT_WORKING )
+GAME( 2005, 25pacmano,  25pacman, 20pacgal, 25pacman, _20pacgal_state, 25pacman, ROT90, "Namco / Cosmodog", "Pac-Man - 25th Anniversary Edition (Rev 2.00)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE)
 
 GAME( 2000, 20pacgal,          0, 20pacgal, 20pacgal, _20pacgal_state, 20pacgal, ROT90, "Namco / Cosmodog", "Ms. Pac-Man/Galaga - 20th Anniversary Class of 1981 Reunion (V1.08)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE)
 GAME( 2000, 20pacgalr4, 20pacgal, 20pacgal, 20pacgal, _20pacgal_state, 20pacgal, ROT90, "Namco / Cosmodog", "Ms. Pac-Man/Galaga - 20th Anniversary Class of 1981 Reunion (V1.04)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE)
