@@ -78,7 +78,7 @@ public:
 	emu_timer *m_aces1_nmi_timer;
 
 
-	DECLARE_WRITE8_MEMBER(ppi8255_ic24_intf_write_a)
+	DECLARE_WRITE8_MEMBER(ic24_write_a)
 	{
 		if (m_led_strobe != m_input_strobe)
 		{
@@ -87,7 +87,7 @@ public:
 		}
 	}
 
-	DECLARE_WRITE8_MEMBER(ppi8255_ic24_intf_write_b)
+	DECLARE_WRITE8_MEMBER(ic24_write_b)
 	{
 	//cheating a bit here, need persistence
 	int i;
@@ -105,37 +105,37 @@ public:
 		}
 	}
 
-	DECLARE_WRITE8_MEMBER(ppi8255_ic24_intf_write_c)
+	DECLARE_WRITE8_MEMBER(ic24_write_c)
 	{
 		m_input_strobe = (data & 0x0f);
 	}
 
-	DECLARE_WRITE8_MEMBER(ppi8255_ic25_intf_write_a)
+	DECLARE_WRITE8_MEMBER(ic25_write_a)
 	{
 	//  printf("extender lamps %02x\n", data);
 	}
 
-	DECLARE_WRITE8_MEMBER(ppi8255_ic25_intf_write_b)
+	DECLARE_WRITE8_MEMBER(ic25_write_b)
 	{
 	//  printf("meters, extender select %02x\n", data);
 	}
 
-	DECLARE_WRITE8_MEMBER(ppi8255_ic25_intf_write_c)
+	DECLARE_WRITE8_MEMBER(ic25_write_c)
 	{
 	//  printf("reels, extender strobe %02x\n", data);
 	}
 
-	DECLARE_READ8_MEMBER( ppi8255_ic37_intf_read_a )
+	DECLARE_READ8_MEMBER( ic37_read_a )
 	{
 		return 0xff;
 	}
 
-	DECLARE_READ8_MEMBER( ppi8255_ic37_intf_read_b )
+	DECLARE_READ8_MEMBER( ic37_read_b )
 	{
 		return 0xff;
 	}
 
-	DECLARE_READ8_MEMBER( ppi8255_ic37_intf_read_c )
+	DECLARE_READ8_MEMBER( ic37_read_c )
 	{
 		return 0xff;
 	}
@@ -184,9 +184,9 @@ static ADDRESS_MAP_START( aces1_map, AS_PROGRAM, 8, aces1_state )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x8fff) AM_RAM
 	AM_RANGE(0xadf0, 0xadf3) AM_DEVREADWRITE("aysnd", ay8910_device, data_r, address_data_w) //  Dips, Sound
-	AM_RANGE(0xafb0, 0xafb3) AM_DEVREADWRITE("ppi8255_ic24", i8255_device, read, write) // IC24 - lamps, 7segs
-	AM_RANGE(0xafd0, 0xafd3) AM_DEVREADWRITE("ppi8255_ic25", i8255_device, read, write) // IC25 - lamps, meters, reel comms (writes)
-	AM_RANGE(0xafe0, 0xafe3) AM_DEVREADWRITE("ppi8255_ic37", i8255_device, read, write)//  IC37 - doors, coins, reel optics (reads)
+	AM_RANGE(0xafb0, 0xafb3) AM_DEVREADWRITE("ic24", i8255_device, read, write) // IC24 - lamps, 7segs
+	AM_RANGE(0xafd0, 0xafd3) AM_DEVREADWRITE("ic25", i8255_device, read, write) // IC25 - lamps, meters, reel comms (writes)
+	AM_RANGE(0xafe0, 0xafe3) AM_DEVREADWRITE("ic37", i8255_device, read, write)//  IC37 - doors, coins, reel optics (reads)
 	AM_RANGE(0xc000, 0xc000) AM_READ(aces1_unk_r) // illegal or reset irq?
 	AM_RANGE(0xe000, 0xe000) AM_READWRITE(aces1_nmi_counter_reset_r, aces1_nmi_counter_reset_w)
 ADDRESS_MAP_END
@@ -252,77 +252,43 @@ static INPUT_PORTS_START( aces1 )
 INPUT_PORTS_END
 
 
-
-
-// 0xafb0 IC24 - lamps, 7segs
-static I8255A_INTERFACE( ppi8255_ic24_intf )
-{
-	DEVCB_NULL,                         /* Port A read */
-	DEVCB_DRIVER_MEMBER(aces1_state,ppi8255_ic24_intf_write_a),                         /* Port A write */ // 7segs
-	DEVCB_NULL,                         /* Port B read */
-	DEVCB_DRIVER_MEMBER(aces1_state,ppi8255_ic24_intf_write_b),                         /* Port B write */ // lamps
-	DEVCB_NULL,                         /* Port C read */
-	DEVCB_DRIVER_MEMBER(aces1_state,ppi8255_ic24_intf_write_c)                          /* Port C write */ // strobe
-};
-
-// 0xafd0 IC25 - lamps, meters, reel comms (writes)
-static I8255A_INTERFACE( ppi8255_ic25_intf )
-{
-	DEVCB_NULL,                         /* Port A read */
-	DEVCB_DRIVER_MEMBER(aces1_state,ppi8255_ic25_intf_write_a),                         /* Port A write */ // extra lamps
-	DEVCB_NULL,                         /* Port B read */
-	DEVCB_DRIVER_MEMBER(aces1_state,ppi8255_ic25_intf_write_b),                         /* Port B write */ // meters, extra lamp select
-	DEVCB_NULL,                         /* Port C read */
-	DEVCB_DRIVER_MEMBER(aces1_state,ppi8255_ic25_intf_write_c)                          /* Port C write */ // reel write, extra lamp strobe
-};
-
-// 0xafe0 IC37 - doors, coins, reel optics (reads)
-static I8255A_INTERFACE( ppi8255_ic37_intf )
-{
-	DEVCB_DRIVER_MEMBER(aces1_state,ppi8255_ic37_intf_read_a),                          /* Port A read */ // doors + coins
-	DEVCB_NULL,                         /* Port A write */
-	DEVCB_DRIVER_MEMBER(aces1_state,ppi8255_ic37_intf_read_b),                          /* Port B read */ // switches
-	DEVCB_NULL,                         /* Port B write */
-	DEVCB_DRIVER_MEMBER(aces1_state,ppi8255_ic37_intf_read_c),                          /* Port C read */ // reel optics
-	DEVCB_NULL                          /* Port C write */
-};
-
-// 0xadf0 - Dips, Sound
-static const ay8910_interface ay8910_config =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_INPUT_PORT("DSWA"),
-	DEVCB_INPUT_PORT("DSWB"),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
 static MACHINE_CONFIG_START( aces1, aces1_state )
 
 	MCFG_CPU_ADD("maincpu", Z80, 4000000) /* ?? Mhz */
 	MCFG_CPU_PROGRAM_MAP(aces1_map)
 	MCFG_CPU_IO_MAP(aces1_portmap)
 
-	MCFG_I8255A_ADD( "ppi8255_ic24", ppi8255_ic24_intf )
-	MCFG_I8255A_ADD( "ppi8255_ic25", ppi8255_ic25_intf )
-	MCFG_I8255A_ADD( "ppi8255_ic37", ppi8255_ic37_intf )
+	// 0xafb0 IC24 - lamps, 7segs
+	MCFG_DEVICE_ADD("ic24", I8255A, 0)
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(aces1_state, ic24_write_a))  // 7segs
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(aces1_state, ic24_write_b))  // lamps
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(aces1_state, ic24_write_c))  // strobe
+
+	// 0xafd0 IC25 - lamps, meters, reel comms (writes)
+	MCFG_DEVICE_ADD("ic25", I8255A, 0)
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(aces1_state, ic25_write_a))  // extra lamps
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(aces1_state, ic25_write_b))  // meters, extra lamp select
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(aces1_state, ic25_write_c))  // reel write, extra lamp strobe
+
+	// 0xafe0 IC37 - doors, coins, reel optics (reads)
+	MCFG_DEVICE_ADD("ic37", I8255A, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(aces1_state, ic37_read_a)) // extra lamps
+	MCFG_I8255_IN_PORTB_CB(READ8(aces1_state, ic37_read_b)) // meters, extra lamp select
+	MCFG_I8255_IN_PORTC_CB(READ8(aces1_state, ic37_read_c)) // reel write, extra lamp strobe
 
 	MCFG_DEFAULT_LAYOUT(layout_aces1)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
+	// 0xadf0 - Dips, Sound
 	MCFG_SOUND_ADD("aysnd", AY8910, 1500000) /* ?? MHz */
-	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_AY8910_PORT_A_READ_CB(IOPORT("DSWA"))
+	MCFG_AY8910_PORT_B_READ_CB(IOPORT("DSWB"))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
-
 MACHINE_CONFIG_END
 
 
-
-
 ROM_START( ac1clbmn )
 	ROM_REGION( 0x8000, "maincpu", 0 ) // same thing but in smaller roms? should they all really be like this?
 	ROM_LOAD( "cm388p71.bin", 0x0000, 0x2000, CRC(c686c1e3) SHA1(c60bf1616b30413f8ecd4a2c8b75d1b37f456c1f) )
@@ -354,7 +320,6 @@ ROM_START( ac1pstrt )
 	ROM_LOAD( "pst.bin", 0x0000, 0x8000, CRC(8e2ee921) SHA1(100de5ab0420d6c0196d90da4412a7d2c24a0912) )
 ROM_END
 
-
 ROM_START( ac1primt )
 	ROM_REGION( 0x8000, "maincpu", 0 ) // same thing but in smaller roms? should they all really be like this?
 	ROM_LOAD( "403ptp21.bin", 0x0000, 0x2000, CRC(5437973c) SHA1(cd42fe09a75ea8bf8efd25c1ca7b12c4db029f31) )
@@ -371,13 +336,10 @@ ROM_START( ac1taklv )
 	ROM_LOAD( "430tlp14.bin", 0x6000, 0x2000, CRC(09008e12) SHA1(f3f6dd3bafdcf7187148fed914d7c43caf53d48a) )
 ROM_END
 
-/*
-
 ROM_START( ac1cshtw ) // Cash Towers, same ROM as above, original machine apparently plays the same, reskinned machine?
-    ROM_REGION( 0x8000, "maincpu", 0 )
-    ROM_LOAD( "ctp1.bin", 0x0000, 0x8000, CRC(2fabb08f) SHA1(b737930e428f9258ab22394229c2b5039edf8f97) )
+	ROM_REGION( 0x8000, "maincpu", 0 )
+	ROM_LOAD( "ctp1.bin", 0x0000, 0x8000, CRC(2fabb08f) SHA1(b737930e428f9258ab22394229c2b5039edf8f97) )
 ROM_END
-*/
 
 
 ROM_START( ac1bbclb )
@@ -694,7 +656,7 @@ GAME( 199?, ac1pster        ,0          ,aces1  ,aces1  , aces1_state,aces1 ,ROT
 GAME( 199?, ac1pstrt        ,0          ,aces1  ,aces1  , aces1_state,aces1 ,ROT0   ,"Pcp", "Pound Stretcher (Pcp) (ACESYS1)",GAME_IS_SKELETON_MECHANICAL )
 GAME( 199?, ac1primt        ,0          ,aces1  ,aces1  , aces1_state,aces1 ,ROT0   ,"Ace", "Primetime (Ace) (ACESYS1) (set 1)",GAME_IS_SKELETON_MECHANICAL )
 GAME( 199?, ac1taklv        ,0          ,aces1  ,aces1  , aces1_state,aces1 ,ROT0   ,"Ace", "Take It Or Leave It (Ace) (ACESYS1) (set 1)",GAME_IS_SKELETON_MECHANICAL )
-//GAME( 199?, ac1cshtw      ,0          ,aces1  ,aces1  , aces1_state,aces1  ,ROT0   ,"Ace", "Cash Towers (Ace) (ACESYS1)",GAME_IS_SKELETON_MECHANICAL ) // same ROM as above, original machine apparently plays the same, reskinned machine?
+GAME( 199?, ac1cshtw        ,0          ,aces1  ,aces1  , aces1_state,aces1 ,ROT0   ,"Ace", "Cash Towers (Ace) (ACESYS1)",GAME_IS_SKELETON_MECHANICAL ) // same ROM as above, combined, original machine apparently plays the same, reskinned machine?
 GAME( 199?, ac1bbclb        ,0          ,aces1  ,aces1  , aces1_state,aces1 ,ROT0   ,"Ace", "Big Break Club (Ace) (ACESYS1) (set 1)",GAME_IS_SKELETON_MECHANICAL )
 GAME( 199?, ac1bbclba       ,ac1bbclb   ,aces1  ,aces1  , aces1_state,aces1 ,ROT0   ,"Ace", "Big Break Club (Ace) (ACESYS1) (set 2)",GAME_IS_SKELETON_MECHANICAL )
 GAME( 199?, ac1clbsv        ,0          ,aces1  ,aces1  , aces1_state,aces1 ,ROT0   ,"Ace", "Club Sovereign (Ace) (ACESYS1)",GAME_IS_SKELETON_MECHANICAL )
