@@ -1129,32 +1129,6 @@ static GFXDECODE_START( hexa )
 	GFXDECODE_ENTRY( "gfx1", 0x0000, charlayout,  0 , 32 )
 GFXDECODE_END
 
-
-/* Sound Interfaces */
-
-static const ay8910_interface ay8910_config =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_INPUT_PORT("UNUSED"),
-	DEVCB_INPUT_PORT("DSW"),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
-static const ay8910_interface hexa_ay8910_config =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_INPUT_PORT("INPUTS"),
-	DEVCB_INPUT_PORT("DSW"),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
-
 /* Machine Drivers */
 
 MACHINE_START_MEMBER(arkanoid_state,arkanoid)
@@ -1218,18 +1192,18 @@ static MACHINE_CONFIG_START( arkanoid, arkanoid_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(arkanoid_state, screen_update_arkanoid)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(arkanoid)
-	MCFG_PALETTE_LENGTH(512)
-
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, RRRR_GGGG_BBBB)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", arkanoid)
+	MCFG_PALETTE_ADD_RRRRGGGGBBBB_PROMS("palette", 512)
 	MCFG_VIDEO_START_OVERRIDE(arkanoid_state,arkanoid)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("aysnd", YM2149, XTAL_12MHz/4/2) /* YM2149 clock is 3mhz, pin 26 is low so 3mhz/2 */
-	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_AY8910_PORT_A_READ_CB(IOPORT("UNUSED"))
+	MCFG_AY8910_PORT_B_READ_CB(IOPORT("DSW"))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
 MACHINE_CONFIG_END
 
@@ -1251,17 +1225,17 @@ static MACHINE_CONFIG_START( hexa, arkanoid_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(arkanoid_state, screen_update_hexa)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(hexa)
-	MCFG_PALETTE_LENGTH(256)
-
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, RRRR_GGGG_BBBB)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", hexa)
+	MCFG_PALETTE_ADD_RRRRGGGGBBBB_PROMS("palette", 256)
 	MCFG_VIDEO_START_OVERRIDE(arkanoid_state,arkanoid)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD("aysnd", AY8910, XTAL_12MHz/4/2) /* Imported from arkanoid - correct? */
-	MCFG_SOUND_CONFIG(hexa_ay8910_config)
+	MCFG_AY8910_PORT_A_READ_CB(IOPORT("INPUTS"))
+	MCFG_AY8910_PORT_B_READ_CB(IOPORT("DSW"))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_CONFIG_END
 
@@ -1296,17 +1270,17 @@ static MACHINE_CONFIG_START( brixian, arkanoid_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(arkanoid_state, screen_update_hexa)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(arkanoid)
-	MCFG_PALETTE_LENGTH(512)
-
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, RRRR_GGGG_BBBB)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", arkanoid)
+	MCFG_PALETTE_ADD_RRRRGGGGBBBB_PROMS("palette", 512)
 	MCFG_VIDEO_START_OVERRIDE(arkanoid_state,arkanoid)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD("aysnd", AY8910, XTAL_12MHz/4/2) /* Imported from arkanoid - correct? */
-	MCFG_SOUND_CONFIG(hexa_ay8910_config)
+	MCFG_AY8910_PORT_A_READ_CB(IOPORT("INPUTS"))
+	MCFG_AY8910_PORT_B_READ_CB(IOPORT("DSW"))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_CONFIG_END
 
@@ -1806,7 +1780,7 @@ DRIVER_INIT_MEMBER(arkanoid_state,block2)
 	// the graphics on this bootleg have the data scrambled
 	int tile;
 	UINT8* srcgfx = memregion("gfx1")->base();
-	UINT8* buffer = auto_alloc_array(machine(), UINT8, 0x18000);
+	dynamic_buffer buffer(0x18000);
 
 	for (tile = 0; tile < 0x3000; tile++)
 	{
@@ -1830,8 +1804,6 @@ DRIVER_INIT_MEMBER(arkanoid_state,block2)
 
 	memcpy(srcgfx, buffer, 0x18000);
 
-	auto_free(machine(), buffer);
-
 	m_bootleg_id = BLOCK2;
 	arkanoid_bootleg_init();
 }
