@@ -117,25 +117,25 @@
  *
  *************************************/
 
-void atarifb_state::palette_init()
+PALETTE_INIT_MEMBER(atarifb_state, atarifb)
 {
 	/* chars */
-	palette_set_color(machine(), 0, MAKE_RGB(0xff,0xff,0xff)); /* white  */
-	palette_set_color(machine(), 1, MAKE_RGB(0x00,0x00,0x00)); /* black  */
+	palette.set_pen_color(0, rgb_t(0xff,0xff,0xff)); /* white  */
+	palette.set_pen_color(1, rgb_t(0x00,0x00,0x00)); /* black  */
 
 	/* sprites */
-	palette_set_color(machine(), 2, MAKE_RGB(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
-	palette_set_color(machine(), 3, MAKE_RGB(0xff,0xff,0xff)); /* white  */
-	palette_set_color(machine(), 4, MAKE_RGB(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
-	palette_set_color(machine(), 5, MAKE_RGB(0x00,0x00,0x00)); /* black  */
+	palette.set_pen_color(2, rgb_t(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
+	palette.set_pen_color(3, rgb_t(0xff,0xff,0xff)); /* white  */
+	palette.set_pen_color(4, rgb_t(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
+	palette.set_pen_color(5, rgb_t(0x00,0x00,0x00)); /* black  */
 
 	/* sprite masks */
-	palette_set_color(machine(), 6, MAKE_RGB(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
-	palette_set_color(machine(), 7, MAKE_RGB(0x80,0x80,0x80)); /* grey  */
-	palette_set_color(machine(), 8, MAKE_RGB(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
-	palette_set_color(machine(), 9, MAKE_RGB(0x00,0x00,0x00)); /* black  */
-	palette_set_color(machine(), 10, MAKE_RGB(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
-	palette_set_color(machine(), 11, MAKE_RGB(0xff,0xff,0xff)); /* white  */
+	palette.set_pen_color(6, rgb_t(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
+	palette.set_pen_color(7, rgb_t(0x80,0x80,0x80)); /* grey  */
+	palette.set_pen_color(8, rgb_t(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
+	palette.set_pen_color(9, rgb_t(0x00,0x00,0x00)); /* black  */
+	palette.set_pen_color(10, rgb_t(0x40,0x40,0x40)); /* dark grey (?) - used in Soccer only */
+	palette.set_pen_color(11, rgb_t(0xff,0xff,0xff)); /* white  */
 }
 
 
@@ -561,10 +561,11 @@ static MACHINE_CONFIG_START( atarifb, atarifb_state )
 	MCFG_SCREEN_SIZE(38*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 38*8-1, 1*8, 31*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(atarifb_state, screen_update_atarifb)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(atarifb)
-	MCFG_PALETTE_LENGTH(12)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", atarifb)
+	MCFG_PALETTE_ADD("palette", 12)
+	MCFG_PALETTE_INIT_OWNER(atarifb_state, atarifb)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -610,7 +611,7 @@ static MACHINE_CONFIG_DERIVED( soccer, atarifb )
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 38*8-1, 2*8, 32*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(atarifb_state, screen_update_soccer)
-	MCFG_GFXDECODE(soccer)
+	MCFG_GFXDECODE_MODIFY("gfxdecode", soccer)
 MACHINE_CONFIG_END
 
 
