@@ -2,9 +2,7 @@
 
     Scorpion 4 Hardware Platform (c)1996 Bell Fruit Manufacturing
 
-    Skeleton Driver
-
-    THIS DRIVER IS NOT WORKING
+    preliminary driver
 
     -----------------
 
@@ -23,9 +21,30 @@
     This file contains the hardware emulation, for the supported sets
     see bfm_sc4.c
 
-    ---
-    note, if game says 'read meters' simply press CTRL then 'B'
-    I think we're stuck in some king of free play test mode so Start 1 will spin and give you credit
+    The hopper(s) are not currently emulated, many of the games can
+    be operated in 'Door Open' mode granting you free credits.
+
+    Most games will show a RAM error on first boot due, after that they
+    will initialize their NVRAM.
+
+    If 'Read Meters' is shown press the 'Cancel' button (this moves around
+    per game, so where it maps might not be obvious)  Doing this will allow
+    the games to run in Door Open mode, pressing 'Start' (also moves around)
+    will allow you to test the game.  Not all games have this feature.
+
+    Pressing the service key ('Green Button') often allows test mode to be
+    entered, some games have more comprehensive tests than others.
+
+    Various (poorly programmed) sets require specific Jackpot 'keys' etc. to
+    boot and won't even warn you if they're invalid, others allow you to
+    set options if keys are not present. (again the buttons to do so move
+    between games)
+
+    Many games have missing sound roms, incorrect sound roms, or badly
+    dumped sound roms.  We also have several dumps where only sound roms
+    are present.
+
+    Many of the titles here were also released on the SC5 platform.
 
 */
 
@@ -36,11 +55,10 @@
 #include "machine/68307.h"
 #include "machine/68340.h"
 #include "includes/bfm_sc45.h"
-#include "bfm_sc4.lh"
 #include "video/awpvid.h"
 //DMD01
 #include "cpu/m6809/m6809.h"
-#include "sc4_dmd.lh"
+
 
 
 UINT8 sc4_state::read_input_matrix(running_machine &machine, int row)
@@ -112,7 +130,7 @@ READ16_MEMBER(sc4_state::sc4_cs1_r)
 READ16_MEMBER(sc4_state::sc4_mem_r)
 {
 	int pc = space.device().safe_pc();
-	int cs = m68307_get_cs(m_maincpu, offset * 2);
+	int cs = m_maincpu->get_cs(offset * 2);
 	int base = 0, end = 0, base2 = 0, end2 = 0;
 //  if (!(debugger_access())) printf("cs is %d\n", cs);
 	UINT16 retvalue;
@@ -166,28 +184,28 @@ READ16_MEMBER(sc4_state::sc4_mem_r)
 							if (mem_mask&0xff00)
 							{
 								retvalue |= (sec.read_data_line() << (6+8));
-								retvalue |= 0xbf00; // coin?
+								retvalue |= ioport("IN-COIN")->read() << 8; // coin?
 								//printf("%08x maincpu read access offset %08x mem_mask %04x cs %d (LAMPS etc.)\n", pc, offset*2, mem_mask, cs);
 							}
 							return retvalue;
 
 						case 0x02e0:
-							return 0x0080;//space.machine().rand();;
+							return 0x0080; // status of something?
 
 						case 0x1000:
-							return 0x0000;//space.machine().rand();;
+							return ioport("IN-16")->read();
 
 						case 0x1010:
-							return 0x0000;//space.machine().rand();;
+							return ioport("IN-17")->read();
 
 						case 0x1020:
-							return 0x0000;//space.machine().rand();;
+							return ioport("IN-18")->read();
 
 						case 0x1030:
-							return 0x0000;//space.machine().rand();;
+							return ioport("IN-19")->read();
 
 						case 0x1040: // door switch, test switch etc.
-							return 0x0000;//space.machine().rand();;
+							return ioport("IN-20")->read();
 
 						case 0x1244:
 							return m_ymz->read(space,0);
@@ -233,8 +251,6 @@ READ16_MEMBER(sc4_state::sc4_mem_r)
 	return 0x0000;
 }
 
-static DECLARE_WRITE8_HANDLER( bfm_sc4_reel4_w );
-
 WRITE8_MEMBER(bfm_sc45_state::mux_output_w)
 {
 	int i;
@@ -268,7 +284,7 @@ WRITE8_MEMBER(bfm_sc45_state::mux_output2_w)
 WRITE16_MEMBER(sc4_state::sc4_mem_w)
 {
 	int pc = space.device().safe_pc();
-	int cs = m68307_get_cs(m_maincpu, offset * 2);
+	int cs = m_maincpu->get_cs(offset * 2);
 	int base = 0, end = 0, base2 = 0, end2 = 0;
 
 	switch ( cs )
@@ -443,111 +459,101 @@ ADDRESS_MAP_END
 
 
 
-void bfm_sc4_reset_serial_vfd(running_machine &machine)
+void bfm_sc45_state::bfm_sc4_reset_serial_vfd()
 {
-	bfm_sc45_state *state = machine.driver_data<bfm_sc45_state>();
-
-	state->m_vfd0->reset();
-	state->vfd_old_clock = false;
+	m_vfd0->reset();
+	vfd_old_clock = false;
 }
 
-void bfm_sc45_write_serial_vfd(running_machine &machine, bool cs, bool clock, bool data)
+void bfm_sc45_state::bfm_sc45_write_serial_vfd(bool cs, bool clock, bool data)
 {
-	bfm_sc45_state *state = machine.driver_data<bfm_sc45_state>();
-
 	// if we're turned on
 	if ( cs )
 	{
-		if ( !state->vfd_enabled )
+		if ( !vfd_enabled )
 		{
-			bfm_sc4_reset_serial_vfd(machine);
-			state->vfd_old_clock = clock;
-			state->vfd_enabled = true;
+			bfm_sc4_reset_serial_vfd();
+			vfd_old_clock = clock;
+			vfd_enabled = true;
 		}
 		else
 		{
 			// if the clock line changes
-			if ( clock != state->vfd_old_clock )
+			if ( clock != vfd_old_clock )
 			{
 				if ( !clock )
 				{
 				//Should move to the internal serial process when DM01 is device-ified
 //                  m_vfd0->shift_data(!data);
-					state->vfd_ser_value <<= 1;
-					if (data) state->vfd_ser_value |= 1;
+					vfd_ser_value <<= 1;
+					if (data) vfd_ser_value |= 1;
 
-					state->vfd_ser_count++;
-					if ( state->vfd_ser_count == 8 )
+					vfd_ser_count++;
+					if ( vfd_ser_count == 8 )
 					{
-						state->vfd_ser_count = 0;
-						if (machine.device("matrix"))
+						vfd_ser_count = 0;
+						if (machine().device("matrix"))
 						{
-							state->m_dm01->writedata(state->vfd_ser_value);
+							m_dm01->writedata(vfd_ser_value);
 						}
 						else
 						{
-							state->m_vfd0->write_char(state->vfd_ser_value);
+							m_vfd0->write_char(vfd_ser_value);
 						}
 					}
 				}
-				state->vfd_old_clock = clock;
+				vfd_old_clock = clock;
 			}
 		}
 	}
 	else
 	{
-		state->vfd_enabled = false;
+		vfd_enabled = false;
 	}
 }
 
 
-void bfm_sc4_68307_porta_w(address_space &space, bool dedicated, UINT8 data, UINT8 line_mask)
+void sc4_state::bfm_sc4_68307_porta_w(address_space &space, bool dedicated, UINT8 data, UINT8 line_mask)
 {
-	sc4_state *state = space.machine().driver_data<sc4_state>();
+	m_reel12_latch = data;
 
-	state->m_reel12_latch = data;
+	if ( stepper_update(0, data&0x0f   ) ) m_reel_changed |= 0x01;
+	if ( stepper_update(1, (data>>4))&0x0f ) m_reel_changed |= 0x02;
 
-	if ( stepper_update(0, data&0x0f   ) ) state->m_reel_changed |= 0x01;
-	if ( stepper_update(1, (data>>4))&0x0f ) state->m_reel_changed |= 0x02;
-
-	if ( stepper_optic_state(0) ) state->m_optic_pattern |=  0x01;
-	else                          state->m_optic_pattern &= ~0x01;
-	if ( stepper_optic_state(1) ) state->m_optic_pattern |=  0x02;
-	else                          state->m_optic_pattern &= ~0x02;
+	if ( stepper_optic_state(0) ) m_optic_pattern |=  0x01;
+	else                          m_optic_pattern &= ~0x01;
+	if ( stepper_optic_state(1) ) m_optic_pattern |=  0x02;
+	else                          m_optic_pattern &= ~0x02;
 
 	awp_draw_reel(0);
 	awp_draw_reel(1);
 }
 
-static WRITE8_HANDLER( bfm_sc4_reel3_w )
+WRITE8_MEMBER( sc4_state::bfm_sc4_reel3_w )
 {
-	sc4_state *state = space.machine().driver_data<sc4_state>();
+	m_reel3_latch = data;
 
-	state->m_reel3_latch = data;
+	if ( stepper_update(2, data&0x0f ) ) m_reel_changed |= 0x04;
 
-	if ( stepper_update(2, data&0x0f ) ) state->m_reel_changed |= 0x04;
-
-	if ( stepper_optic_state(2) ) state->m_optic_pattern |=  0x04;
-	else                          state->m_optic_pattern &= ~0x04;
+	if ( stepper_optic_state(2) ) m_optic_pattern |=  0x04;
+	else                          m_optic_pattern &= ~0x04;
 
 	awp_draw_reel(2);
 }
 
-static WRITE8_HANDLER( bfm_sc4_reel4_w )
+WRITE8_MEMBER( sc4_state::bfm_sc4_reel4_w )
 {
-	sc4_state *state = space.machine().driver_data<sc4_state>();
+	m_reel4_latch = data;
 
-	state->m_reel4_latch = data;
+	if ( stepper_update(3, data&0x0f ) ) m_reel_changed |= 0x08;
 
-	if ( stepper_update(3, data&0x0f ) ) state->m_reel_changed |= 0x08;
-
-	if ( stepper_optic_state(3) ) state->m_optic_pattern |=  0x08;
-	else                          state->m_optic_pattern &= ~0x08;
+	if ( stepper_optic_state(3) ) m_optic_pattern |=  0x08;
+	else                          m_optic_pattern &= ~0x08;
 
 	awp_draw_reel(3);
 }
 
-void bfm_sc4_68307_portb_w(address_space &space, bool dedicated, UINT16 data, UINT16 line_mask)
+void sc4_state::bfm_sc4_68307_portb_w(address_space &space, bool dedicated, UINT16 data, UINT16 line_mask)
 {
 //  if (dedicated == false)
 	{
@@ -556,20 +562,20 @@ void bfm_sc4_68307_portb_w(address_space &space, bool dedicated, UINT16 data, UI
 		// serial output to the VFD at least..
 		logerror("%08x bfm_sc4_68307_portb_w %04x %04x\n", pc, data, line_mask);
 
-		bfm_sc45_write_serial_vfd(space.machine(), (data & 0x4000)?1:0, (data & 0x1000)?1:0, !(data & 0x2000)?1:0);
+		bfm_sc45_write_serial_vfd((data & 0x4000)?1:0, (data & 0x1000)?1:0, !(data & 0x2000)?1:0);
 
 		bfm_sc4_reel3_w(space, 0, (data&0x0f00)>>8, 0xff);
 	}
 
 }
-UINT8 bfm_sc4_68307_porta_r(address_space &space, bool dedicated, UINT8 line_mask)
+UINT8 sc4_state::bfm_sc4_68307_porta_r(address_space &space, bool dedicated, UINT8 line_mask)
 {
 	int pc = space.device().safe_pc();
 	logerror("%08x bfm_sc4_68307_porta_r\n", pc);
-	return space.machine().rand();
+	return 0xbb;// machine().rand();
 }
 
-UINT16 bfm_sc4_68307_portb_r(address_space &space, bool dedicated, UINT16 line_mask)
+UINT16 sc4_state::bfm_sc4_68307_portb_r(address_space &space, bool dedicated, UINT16 line_mask)
 {
 	if (dedicated==false)
 	{
@@ -605,14 +611,11 @@ MACHINE_START_MEMBER(sc4_state,sc4)
 	m_nvram->set_base(m_mainram, sizeof(m_mainram));
 
 
-	m68307_set_port_callbacks(m_maincpu,
-		bfm_sc4_68307_porta_r,
-		bfm_sc4_68307_porta_w,
-		bfm_sc4_68307_portb_r,
-		bfm_sc4_68307_portb_w );
-	m68307_set_duart68681(m_maincpu,machine().device("m68307_68681"));
-
-
+	m_maincpu->set_port_callbacks(
+		m68307_porta_read_delegate(FUNC(sc4_state::bfm_sc4_68307_porta_r),this),
+		m68307_porta_write_delegate(FUNC(sc4_state::bfm_sc4_68307_porta_w),this),
+		m68307_portb_read_delegate(FUNC(sc4_state::bfm_sc4_68307_portb_r),this),
+		m68307_portb_write_delegate(FUNC(sc4_state::bfm_sc4_68307_portb_w),this) );
 
 	int reels = 6;
 	m_reels=reels;
@@ -638,7 +641,7 @@ WRITE_LINE_MEMBER(sc4_state::bfm_sc4_duart_irq_handler)
 	logerror("bfm_sc4_duart_irq_handler\n");
 	if (state == ASSERT_LINE)
 	{
-		m68307_licr2_interrupt(m_maincpu);
+		m_maincpu->licr2_interrupt();
 	}
 }
 
@@ -673,82 +676,35 @@ WRITE8_MEMBER(sc4_state::bfm_sc4_duart_output_w)
 }
 
 
-static const duartn68681_config bfm_sc4_duart68681_config =
+WRITE_LINE_MEMBER(sc4_state::m68307_duart_txa)
 {
-	DEVCB_DRIVER_LINE_MEMBER(sc4_state, bfm_sc4_duart_irq_handler),
-	DEVCB_DRIVER_LINE_MEMBER(sc4_state, bfm_sc4_duart_txa),
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(sc4_state, bfm_sc4_duart_input_r),
-	DEVCB_DRIVER_MEMBER(sc4_state, bfm_sc4_duart_output_w),
-	// TODO: What are the actual frequencies?
-	XTAL_16MHz/2/8,     /* IP2/RxCB clock */
-	XTAL_16MHz/2/16,    /* IP3/TxCA clock */
-	XTAL_16MHz/2/16,    /* IP4/RxCA clock */
-	XTAL_16MHz/2/8,     /* IP5/TxCB clock */
-};
-
-
-
-void m68307_duart_irq_handler(device_t *device, int state, UINT8 vector)
-{
-	sc4_state *drvstate = device->machine().driver_data<sc4_state>();
-	logerror("m68307_duart_irq_handler\n");
-	if (state == ASSERT_LINE)
-	{
-		m68307_serial_interrupt(drvstate->m_maincpu, vector);
-	}
+	logerror("m68307_duart_tx %02x\n",state);
 }
 
-void m68307_duart_tx(device_t *device, int channel, UINT8 data)
-{
-	if (channel==0)
-	{
-		logerror("m68307_duart_tx %02x\n",data);
-	}
-	else
-	{
-		printf("(illegal channel 1) m68307_duart_tx %02x\n",data);
-	}
-}
-
-UINT8 m68307_duart_input_r(device_t *device)
+READ8_MEMBER(sc4_state::m68307_duart_input_r)
 {
 	logerror("m68307_duart_input_r\n");
 	return 0x00;
 }
 
-void m68307_duart_output_w(device_t *device, UINT8 data)
+WRITE8_MEMBER(sc4_state::m68307_duart_output_w)
 {
 	logerror("m68307_duart_output_w %02x\n", data);
 }
 
-static const duart68681_config m68307_duart68681_config =
-{
-	m68307_duart_irq_handler,
-	m68307_duart_tx,
-	m68307_duart_input_r,
-	m68307_duart_output_w
-};
-
 /* default dmd */
-static void bfmdm01_busy(running_machine &machine, int state)
+WRITE_LINE_MEMBER(sc4_state::bfmdm01_busy)
 {
 	// Must tie back to inputs somehow!
 }
 
-static const bfmdm01_interface dm01_interface =
-{
-	bfmdm01_busy
-};
-
-
-
 MACHINE_CONFIG_START( sc4, sc4_state )
 	MCFG_CPU_ADD("maincpu", M68307, 16000000)    // 68307! (EC000 core)
 	MCFG_CPU_PROGRAM_MAP(sc4_map)
+	MCFG_MC68307_SERIAL_A_TX_CALLBACK(WRITELINE(sc4_state, m68307_duart_txa))
+	MCFG_MC68307_SERIAL_INPORT_CALLBACK(READ8(sc4_state, m68307_duart_input_r))
+	MCFG_MC68307_SERIAL_OUTPORT_CALLBACK(WRITE8(sc4_state, m68307_duart_output_w))
 
-	// internal duart of the 68307... paired in machine start
-	MCFG_DUART68681_ADD("m68307_68681", 16000000/4, m68307_duart68681_config) // ?? Mhz
 
 	MCFG_MACHINE_START_OVERRIDE(sc4_state, sc4 )
 	MCFG_MACHINE_RESET_OVERRIDE(sc4_state, sc4 )
@@ -758,11 +714,16 @@ MACHINE_CONFIG_START( sc4, sc4_state )
 
 	MCFG_NVRAM_ADD_1FILL("nvram")
 
-	MCFG_DUARTN68681_ADD("duart68681", 16000000/4, bfm_sc4_duart68681_config) // ?? Mhz
+	MCFG_MC68681_ADD("duart68681", 16000000/4) // ?? Mhz
+	MCFG_MC68681_SET_EXTERNAL_CLOCKS(XTAL_16MHz/2/8, XTAL_16MHz/2/16, XTAL_16MHz/2/16, XTAL_16MHz/2/8)
+	MCFG_MC68681_IRQ_CALLBACK(WRITELINE(sc4_state, bfm_sc4_duart_irq_handler))
+	MCFG_MC68681_A_TX_CALLBACK(WRITELINE(sc4_state, bfm_sc4_duart_txa))
+	MCFG_MC68681_INPORT_CALLBACK(READ8(sc4_state, bfm_sc4_duart_input_r))
+	MCFG_MC68681_OUTPORT_CALLBACK(WRITE8(sc4_state, bfm_sc4_duart_output_w))
 
 	MCFG_BFMBDA_ADD("vfd0",0)
 
-	MCFG_DEFAULT_LAYOUT(layout_bfm_sc4)
+//  MCFG_DEFAULT_LAYOUT(layout_bfm_sc4)
 
 	MCFG_SOUND_ADD("ymz", YMZ280B, 16000000) // ?? Mhz
 	MCFG_YMZ280B_IRQ_HANDLER(WRITELINE(sc4_state, bfm_sc4_irqhandler))
@@ -788,8 +749,9 @@ MACHINE_CONFIG_END
 MACHINE_CONFIG_DERIVED_CLASS( sc4dmd, sc4, sc4_state )
 	/* video hardware */
 
-	MCFG_DEFAULT_LAYOUT(layout_sc4_dmd)
-	MCFG_DM01_ADD("dm01", dm01_interface)
+	//MCFG_DEFAULT_LAYOUT(layout_sc4_dmd)
+	MCFG_DEVICE_ADD("dm01", BF_DM01, 0)
+	MCFG_BF_DM01_BUSY_CB(WRITELINE(sc4_state, bfmdm01_busy))
 	MCFG_CPU_ADD("matrix", M6809, 2000000 )             /* matrix board 6809 CPU at 2 Mhz ?? I don't know the exact freq.*/
 	MCFG_CPU_PROGRAM_MAP(bfm_dm01_memmap)
 	MCFG_CPU_PERIODIC_INT_DRIVER(sc4_state, nmi_line_assert, 1500 )          /* generate 1500 NMI's per second ?? what is the exact freq?? */
@@ -797,183 +759,429 @@ MACHINE_CONFIG_DERIVED_CLASS( sc4dmd, sc4, sc4_state )
 	MCFG_MACHINE_START_OVERRIDE(sc4_state, sc4 )
 MACHINE_CONFIG_END
 
-INPUT_PORTS_START( sc4_base )
+INPUT_PORTS_START( sc4_raw ) // completley unmapped, but named inputs for all the ports, used for testing.
 	PORT_START("IN-0")
-	PORT_DIPNAME( 0x01, 0x00, "IN-0:0" )
+	PORT_DIPNAME( 0x01, 0x00, "IN 0-0 (STRB 0 Data 0)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, "IN-0:1" )
+	PORT_DIPNAME( 0x02, 0x00, "IN 0-1 (STRB 0 Data 1)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, "IN-0:2" )
+	PORT_DIPNAME( 0x04, 0x00, "IN 0-2 (STRB 0 Data 2)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "IN-0:3" )
+	PORT_DIPNAME( 0x08, 0x00, "IN 0-3 (STRB 0 Data 3)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x00, "IN-0:4" )
+	PORT_DIPNAME( 0x10, 0x00, "IN 0-4 (STRB 0 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 	PORT_START("IN-1")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 )
-	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_BUTTON2 )
-	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_BUTTON3 )
-	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_BUTTON4 )
-	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON5 )
+	PORT_DIPNAME( 0x01, 0x00, "IN 1-0 (STRB 1 Data 0)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 1-1 (STRB 1 Data 1)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 1-2 (STRB 1 Data 2)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 1-3 (STRB 1 Data 3)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x00, "IN 1-4 (STRB 1 Data 4)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 	PORT_START("IN-2")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON6 )
-	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_BUTTON7 )
-	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_BUTTON8 )
-	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_BUTTON9 )
-	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_START1 ) PORT_NAME("Start 1 / P1 Button 1") // also gives you 0.50 credits at the moment, I guess because we're in freeplay?
-
+	PORT_DIPNAME( 0x01, 0x00, "IN 2-0 (STRB 2 Data 0)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 2-1 (STRB 2 Data 1)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 2-2 (STRB 2 Data 2)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 2-3 (STRB 2 Data 3)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x00, "IN 2-4 (STRB 2 Data 4)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 	PORT_START("IN-3")
-	PORT_DIPNAME( 0x01, 0x00, "IN-3:0" )
+	PORT_DIPNAME( 0x01, 0x00, "IN 3-0 (STRB 3 Data 0)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, "IN-3:1" )
+	PORT_DIPNAME( 0x02, 0x00, "IN 3-1 (STRB 3 Data 1)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, "IN-3:2" )
+	PORT_DIPNAME( 0x04, 0x00, "IN 3-2 (STRB 3 Data 2)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "IN-3:3" )
+	PORT_DIPNAME( 0x08, 0x00, "IN 3-3 (STRB 3 Data 3)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x00, "IN-3:4" )
+	PORT_DIPNAME( 0x10, 0x00, "IN 3-4 (STRB 3 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
-
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 	PORT_START("IN-4")
-	PORT_DIPNAME( 0x01, 0x00, "IN-4:0" )
+	PORT_DIPNAME( 0x01, 0x00, "IN 4-0 (STRB 4 Data 0)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, "IN-4:1" )
+	PORT_DIPNAME( 0x02, 0x00, "IN 4-1 (STRB 4 Data 1)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, "IN-4:2" )
+	PORT_DIPNAME( 0x04, 0x00, "IN 4-2 (STRB 4 Data 2)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "IN-4:3" )
+	PORT_DIPNAME( 0x08, 0x00, "IN 4-3 (STRB 4 Data 3)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x00, "IN-4:4" )
+	PORT_DIPNAME( 0x10, 0x00, "IN 4-4 (STRB 4 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 
 	PORT_START("IN-5")
-	PORT_BIT( 0x0f, IP_ACTIVE_LOW, IPT_UNUSED ) // Jackpot Key, filled in later
-	PORT_DIPNAME( 0x10, 0x00, "IN-5:4" )
+	PORT_DIPNAME( 0x01, 0x00, "IN 5-0 (STRB 5 Data 0)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 5-1 (STRB 5 Data 1)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 5-2 (STRB 5 Data 2)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 5-3 (STRB 5 Data 3)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x00, "IN 5-4 (STRB 5 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 	PORT_START("IN-6")
-	PORT_DIPNAME( 0x01, 0x00, "IN-6:0" )
+	PORT_DIPNAME( 0x01, 0x00, "IN 6-0 (STRB 6 Data 0)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, "IN-6:1" )
+	PORT_DIPNAME( 0x02, 0x00, "IN 6-1 (STRB 6 Data 1)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, "IN-6:2" )
+	PORT_DIPNAME( 0x04, 0x00, "IN 6-2 (STRB 6 Data 2)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "IN-6:3" )
+	PORT_DIPNAME( 0x08, 0x00, "IN 6-3 (STRB 6 Data 3)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x00, "IN-6:4" )
+	PORT_DIPNAME( 0x10, 0x00, "IN 6-4 (STRB 6 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 	PORT_START("IN-7")
-	PORT_DIPNAME( 0x01, 0x00, "IN-7:0" )
+	PORT_DIPNAME( 0x01, 0x00, "IN 7-0 (STRB 7 Data 0)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, "IN-7:1" )
+	PORT_DIPNAME( 0x02, 0x00, "IN 7-1 (STRB 7 Data 1)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, "IN-7:2" )
+	PORT_DIPNAME( 0x04, 0x00, "IN 7-2 (STRB 7 Data 2)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "IN-7:3" )
+	PORT_DIPNAME( 0x08, 0x00, "IN 7-3 (STRB 7 Data 3)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x00, "IN-7:4" )
+	PORT_DIPNAME( 0x10, 0x00, "IN 7-4 (STRB 7 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 	PORT_START("IN-8")
-	PORT_DIPNAME( 0x01, 0x00, "IN-8:0" )
+	PORT_DIPNAME( 0x01, 0x00, "IN 8-0 (STRB 8 Data 0)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, "IN-8:1" )
+	PORT_DIPNAME( 0x02, 0x00, "IN 8-1 (STRB 8 Data 1)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, "IN-8:2" )
+	PORT_DIPNAME( 0x04, 0x00, "IN 8-2 (STRB 8 Data 2)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "IN-8:3" )
+	PORT_DIPNAME( 0x08, 0x00, "IN 8-3 (STRB 8 Data 3)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x00, "IN-8:4" )
+	PORT_DIPNAME( 0x10, 0x00, "IN 8-4 (STRB 8 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 
 	PORT_START("IN-9")
-	PORT_DIPNAME( 0x01, 0x00, "IN-9:0" )
+	PORT_DIPNAME( 0x01, 0x00, "IN 9-0 (STRB 9 Data 0)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, "IN-9:1" )
+	PORT_DIPNAME( 0x02, 0x00, "IN 9-1 (STRB 9 Data 1)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, "IN-9:2" )
+	PORT_DIPNAME( 0x04, 0x00, "IN 9-2 (STRB 9 Data 2)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "IN-9:3" )
+	PORT_DIPNAME( 0x08, 0x00, "IN 9-3 (STRB 9 Data 3)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x00, "IN-9:4" )
+	PORT_DIPNAME( 0x10, 0x00, "IN 9-4 (STRB 9 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-
-	PORT_START("IN-A")
-	PORT_DIPNAME( 0x01, 0x00, "IN-a:0" )
+	PORT_START("IN-10")
+	PORT_DIPNAME( 0x01, 0x00, "IN 10-0 (STRB 10 Data 0)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, "IN-a:1" )
+	PORT_DIPNAME( 0x02, 0x00, "IN 10-1 (STRB 10 Data 1)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, "IN-a:2" )
+	PORT_DIPNAME( 0x04, 0x00, "IN 10-2 (STRB 10 Data 2)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "IN-a:3" )
+	PORT_DIPNAME( 0x08, 0x00, "IN 10-3 (STRB 10 Data 3)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x00, "IN-a:4" )
+	PORT_DIPNAME( 0x10, 0x00, "IN 10-4 (STRB 10 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
 
-	PORT_START("IN-B")
-	PORT_DIPNAME( 0x01, 0x00, "IN-b:0" )
+	PORT_START("IN-11")
+	PORT_DIPNAME( 0x01, 0x00, "IN 11-0 (STRB 11 Data 0)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x00, "IN-b:1" )
+	PORT_DIPNAME( 0x02, 0x00, "IN 11-1 (STRB 11 Data 1)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x00, "IN-b:2" )
+	PORT_DIPNAME( 0x04, 0x00, "IN 11-2 (STRB 11 Data 2)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "IN-b:3" )
+	PORT_DIPNAME( 0x08, 0x00, "IN 11-3 (STRB 11 Data 3)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x00, "IN-b:4" )
+	PORT_DIPNAME( 0x10, 0x00, "IN 11-4 (STRB 11 Data 4)" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
+
+	// where are 11,12,13,14,15 ?
+
+	PORT_START("IN-16")
+	PORT_DIPNAME( 0x01, 0x00, "IN 16-0 (STRB 16 Data 0)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 16-1 (STRB 16 Data 1)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 16-2 (STRB 16 Data 2)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 16-3 (STRB 16 Data 3)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x00, "IN 16-4 (STRB 16 Data 4)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
+
+	PORT_START("IN-17")
+	PORT_DIPNAME( 0x01, 0x00, "IN 17-0 (STRB 17 Data 0)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 17-1 (STRB 17 Data 1)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 17-2 (STRB 17 Data 2)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 17-3 (STRB 17 Data 3)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x00, "IN 17-4 (STRB 17 Data 4)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
+
+	PORT_START("IN-18")
+	PORT_DIPNAME( 0x01, 0x00, "IN 18-0 (STRB 18 Data 0)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 18-1 (STRB 18 Data 1)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 18-2 (STRB 18 Data 2)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 18-3 (STRB 18 Data 3)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x00, "IN 18-4 (STRB 18 Data 4)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
+
+	PORT_START("IN-19")
+	PORT_DIPNAME( 0x01, 0x00, "IN 19-0 (STRB 19 Data 0)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 19-1 (STRB 19 Data 1)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 19-2 (STRB 19 Data 2)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 19-3 (STRB 19 Data 3)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x00, "IN 19-4 (STRB 19 Data 4)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
+
+	PORT_START("IN-20")
+	PORT_DIPNAME( 0x01, 0x00, "IN 20-0 (STRB 20 Data 0)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 20-1 (STRB 20 Data 1)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 20-2 (STRB 20 Data 2)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 20-3 (STRB 20 Data 3)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x00, "IN 20-4 (STRB 20 Data 4)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+	PORT_BIT(           0xffe0, IP_ACTIVE_HIGH, IPT_UNUSED )
+
+	PORT_START("IN-COIN")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) // 1 PND
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) // 50p
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 ) // 20p
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN4 ) // 10p
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_COIN5 ) // ??
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN6 ) // 5p
+INPUT_PORTS_END
+
+
+INPUT_PORTS_START( sc4_base ) // just some fairly generic defaults we map to games where there isn't a specific mapping yet
+	PORT_INCLUDE ( sc4_raw )
+	PORT_MODIFY("IN-1")
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_1_0 ) PORT_NAME("IN1-0")
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_1_1 ) PORT_NAME("IN1-1")
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_1_2 ) PORT_NAME("IN1-2")
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_1_3 ) PORT_NAME("IN1-3")
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_1_4 ) PORT_NAME("IN1-4")
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_1_5 ) PORT_NAME("IN1-5")
+
+	PORT_MODIFY("IN-2")
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_2_0 ) PORT_NAME("IN2-0")
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_2_1 ) PORT_NAME("IN2-1")
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_2_2 ) PORT_NAME("IN2-2")
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_2_3) PORT_NAME("IN2-3")
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_2_4) PORT_NAME("IN2-4")
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_2_5) PORT_NAME("IN2-5")
+
+	PORT_MODIFY("IN-3")
+	PORT_DIPNAME( 0x04, 0x00, "IN 3-2 (STK 4  3.2)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 3-3 (STK 2  3.3)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x00, "IN 3-4 (STK 3  3.4)" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
+
+	PORT_MODIFY("IN-5")
+	PORT_DIPNAME( 0x01, 0x00, "IN 5-0 (PRIZ4 5.0)" ) // (PRIZ4 5.0)  // Jackpot key
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 5-1 (PRIZ35.1)" ) // (PRI31 5.1)
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 5-2 (PRIZ2 5.2)" ) // (PRIZ2 5.2)
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 5-3 (PRIZ1 5.3)" ) // (PRIZ1 5.3)
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+
+	PORT_MODIFY("IN-6")
+	PORT_DIPNAME( 0x01, 0x00, "IN 6-0 (PERC1 6.0)" ) // (PERC1 6.0)  // %age key
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x00, "IN 6-1 (PERC2 6.1)" ) // (PERC2 6.1)
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x00, "IN 6-2 (PERC3 6.2)" ) // (PERC3 6.2)
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x00, "IN 6-3 (PERC4 6.3)" ) // (PERC4 6.3)
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
+
+	PORT_MODIFY("IN-7")
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_7_0) PORT_NAME("IN7-0")
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_7_1) PORT_NAME("IN7-1")
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_7_2) PORT_NAME("IN7-2")
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_7_3) PORT_NAME("IN7-3")
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_7_4) PORT_NAME("IN7-4")
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_7_5) PORT_NAME("IN7-5")
+
+	PORT_MODIFY("IN-8")
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_8_0) PORT_NAME("IN8-0")
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_8_1) PORT_NAME("IN8-1")
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_8_2) PORT_NAME("IN8-2")
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_8_3) PORT_NAME("IN8-3")
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_8_4) PORT_NAME("IN8-4")
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_8_5) PORT_NAME("IN8-5")
+
+	PORT_MODIFY("IN-9")
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_9_0) PORT_NAME("IN9-0")
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_9_1) PORT_NAME("IN9-1")
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_9_2) PORT_NAME("IN9-2")
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_9_3) PORT_NAME("IN9-3")
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_9_4) PORT_NAME("IN9-4")
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_9_5) PORT_NAME("IN9-5")
+
+	PORT_MODIFY("IN-10")
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_10_0) PORT_NAME("IN10-0")
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_10_1) PORT_NAME("IN10-1")
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_10_2) PORT_NAME("IN10-2")
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_10_3) PORT_NAME("IN10-3")
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_10_4) PORT_NAME("IN10-4")
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_10_5) PORT_NAME("IN10-5")
+
+	PORT_MODIFY("IN-20")
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, SC45_BUTTON_MATRIX_20_0) PORT_NAME("Green Button")
+	PORT_DIPNAME( 0x0002, 0x0000, "Door Lock" ) // DORLOK20.1
+	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0002, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0004, 0x0000, "Service Door" ) // SERDOR20.2
+	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0004, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0008, 0x0000, "Cashbox Door" ) // CSHDOR20.3
+	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0008, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0010, 0x0000, "Hopper DMP" ) // HOPDMP20.4
+	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0010, DEF_STR( On ) )
 INPUT_PORTS_END
