@@ -89,16 +89,17 @@ ROMs    : MR96004-10.1  [125661cd] (IC5 - Samples)
 #include "emu.h"
 #include "cpu/z80/z80.h"
 #include "cpu/v60/v60.h"
-#include "sound/ymf271.h"
 #include "rendlay.h"
+#include "sound/ymf271.h"
+#include "includes/ms32.h"
 #include "machine/jalcrpt.h"
 
 
-class bnstars_state : public driver_device
+class bnstars_state : public ms32_state
 {
 public:
 	bnstars_state(const machine_config &mconfig, device_type type, const char *tag)
-		: driver_device(mconfig, type, tag),
+		: ms32_state(mconfig, type, tag),
 			m_ms32_tx0_ram(*this, "tx0_ram"),
 			m_ms32_tx1_ram(*this, "tx1_ram"),
 			m_ms32_bg0_ram(*this, "bg0_ram"),
@@ -111,8 +112,7 @@ public:
 			m_ms32_tx0_scroll(*this, "tx0_scroll"),
 			m_ms32_bg0_scroll(*this, "bg0_scroll"),
 			m_ms32_tx1_scroll(*this, "tx1_scroll"),
-			m_ms32_bg1_scroll(*this, "bg1_scroll") ,
-		m_maincpu(*this, "maincpu") { }
+			m_ms32_bg1_scroll(*this, "bg1_scroll")  { }
 
 	tilemap_t *m_ms32_tx_tilemap[2];
 	tilemap_t *m_ms32_bg_tilemap[2];
@@ -131,9 +131,6 @@ public:
 	required_shared_ptr<UINT32> m_ms32_tx1_scroll;
 	required_shared_ptr<UINT32> m_ms32_bg1_scroll;
 	UINT32 m_bnstars1_mahjong_select;
-	int m_ms32_reverse_sprite_order;
-	int m_flipscreen;
-	UINT16 m_irqreq;
 	DECLARE_WRITE32_MEMBER(ms32_tx0_ram_w);
 	DECLARE_WRITE32_MEMBER(ms32_tx1_ram_w);
 	DECLARE_WRITE32_MEMBER(ms32_bg0_ram_w);
@@ -142,10 +139,7 @@ public:
 	DECLARE_WRITE32_MEMBER(ms32_roz1_ram_w);
 	DECLARE_WRITE32_MEMBER(ms32_pal0_ram_w);
 	DECLARE_WRITE32_MEMBER(ms32_pal1_ram_w);
-	DECLARE_WRITE32_MEMBER(ms32_spramx_w);
 	DECLARE_READ32_MEMBER(bnstars1_r);
-	DECLARE_READ32_MEMBER(bnstars2_r);
-	DECLARE_READ32_MEMBER(bnstars3_r);
 	DECLARE_WRITE32_MEMBER(bnstars1_mahjong_select_w);
 	DECLARE_DRIVER_INIT(bnstars);
 	TILE_GET_INFO_MEMBER(get_ms32_tx0_tile_info);
@@ -158,14 +152,9 @@ public:
 	virtual void video_start();
 	UINT32 screen_update_bnstars_left(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	UINT32 screen_update_bnstars_right(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
-	TIMER_DEVICE_CALLBACK_MEMBER(ms32_interrupt);
 	void draw_roz(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect, int priority, int chip);
 	void update_color(int color, int screen);
 	void draw_sprites(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect, UINT32 *sprram_top, size_t sprram_size, int region);
-	void irq_init();
-	void irq_raise(int level);
-	IRQ_CALLBACK_MEMBER(irq_callback);
-	required_device<cpu_device> m_maincpu;
 };
 
 
@@ -364,7 +353,7 @@ void bnstars_state::update_color(int color, int screen)
 	g = ((m_ms32_pal_ram[screen][color*2] & 0x00ff) >>0 );
 	b = ((m_ms32_pal_ram[screen][color*2+1] & 0x00ff) >>0 );
 
-	palette_set_color(machine(),color+screen*0x8000,MAKE_RGB(r,g,b));
+	m_palette->set_pen_color(color+screen*0x8000,rgb_t(r,g,b));
 }
 
 WRITE32_MEMBER(bnstars_state::ms32_pal0_ram_w)
@@ -423,20 +412,20 @@ void bnstars_state::draw_sprites(screen_device &screen, bitmap_ind16 &bitmap, co
 	int tx, ty, sx, sy, flipx, flipy;
 	int xsize, ysize, xzoom, yzoom;
 	int code, attr, color, size, pri, pri_mask;
-	gfx_element *gfx = machine().gfx[region];
+	gfx_element *gfx = m_gfxdecode->gfx(region);
 
 	UINT32      *source = sprram_top;
 	const UINT32    *finish = sprram_top + (sprram_size - 0x10) / 4;
 
 
-	if (m_ms32_reverse_sprite_order == 1)
+	if (m_reverse_sprite_order == 1)
 	{
 		source  = sprram_top + (sprram_size - 0x10) / 4;
 		finish  = sprram_top;
 	}
 
 
-	for (;m_ms32_reverse_sprite_order ? (source>=finish) : (source<finish); m_ms32_reverse_sprite_order ? (source-=4) : (source+=4))
+	for (;m_reverse_sprite_order ? (source>=finish) : (source<finish); m_reverse_sprite_order ? (source-=4) : (source+=4))
 	{
 		attr    =   source[ 0 ];
 
@@ -497,7 +486,7 @@ void bnstars_state::draw_sprites(screen_device &screen, bitmap_ind16 &bitmap, co
 			pri_mask = 0xfe;
 
 		gfx->set_source_clip(tx, xsize, ty, ysize);
-		pdrawgfxzoom_transpen(bitmap, cliprect, gfx,
+		gfx->prio_zoom_transpen(bitmap,cliprect,
 				code,
 				color,
 				flipx, flipy,
@@ -507,27 +496,20 @@ void bnstars_state::draw_sprites(screen_device &screen, bitmap_ind16 &bitmap, co
 }
 
 
-
-WRITE32_MEMBER(bnstars_state::ms32_spramx_w)
-{
-	COMBINE_DATA(&m_ms32_spram[offset]);
-}
-
-
 void bnstars_state::video_start()
 {
-	m_ms32_tx_tilemap[0] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_tx0_tile_info),this),TILEMAP_SCAN_ROWS, 8, 8,64,64);
-	m_ms32_tx_tilemap[1] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_tx1_tile_info),this),TILEMAP_SCAN_ROWS, 8, 8,64,64);
+	m_ms32_tx_tilemap[0] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_tx0_tile_info),this),TILEMAP_SCAN_ROWS, 8, 8,64,64);
+	m_ms32_tx_tilemap[1] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_tx1_tile_info),this),TILEMAP_SCAN_ROWS, 8, 8,64,64);
 	m_ms32_tx_tilemap[0]->set_transparent_pen(0);
 	m_ms32_tx_tilemap[1]->set_transparent_pen(0);
 
-	m_ms32_bg_tilemap[0] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_bg0_tile_info),this),TILEMAP_SCAN_ROWS,16,16,64,64);
-	m_ms32_bg_tilemap[1] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_bg1_tile_info),this),TILEMAP_SCAN_ROWS,16,16,64,64);
+	m_ms32_bg_tilemap[0] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_bg0_tile_info),this),TILEMAP_SCAN_ROWS,16,16,64,64);
+	m_ms32_bg_tilemap[1] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_bg1_tile_info),this),TILEMAP_SCAN_ROWS,16,16,64,64);
 	m_ms32_bg_tilemap[0]->set_transparent_pen(0);
 	m_ms32_bg_tilemap[1]->set_transparent_pen(0);
 
-	m_ms32_roz_tilemap[0] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_roz0_tile_info),this),TILEMAP_SCAN_ROWS,16,16,128,128);
-	m_ms32_roz_tilemap[1] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_roz1_tile_info),this),TILEMAP_SCAN_ROWS,16,16,128,128);
+	m_ms32_roz_tilemap[0] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_roz0_tile_info),this),TILEMAP_SCAN_ROWS,16,16,128,128);
+	m_ms32_roz_tilemap[1] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(bnstars_state::get_ms32_roz1_tile_info),this),TILEMAP_SCAN_ROWS,16,16,128,128);
 	m_ms32_roz_tilemap[0]->set_transparent_pen(0);
 	m_ms32_roz_tilemap[1]->set_transparent_pen(0);
 
@@ -1266,34 +1248,29 @@ READ32_MEMBER(bnstars_state::bnstars1_r)
 	}
 }
 
-READ32_MEMBER(bnstars_state::bnstars2_r)
-{
-	return ioport("IN4")->read();
-}
-
-READ32_MEMBER(bnstars_state::bnstars3_r)
-{
-	return ioport("IN5")->read();
-}
-
 WRITE32_MEMBER(bnstars_state::bnstars1_mahjong_select_w)
 {
 	m_bnstars1_mahjong_select = data;
 //  printf("%08x\n",m_bnstars1_mahjong_select);
 }
 
+
 static ADDRESS_MAP_START( bnstars_map, AS_PROGRAM, 32, bnstars_state )
 	AM_RANGE(0x00000000, 0x001fffff) AM_ROM
 
+	AM_RANGE(0xfc800000, 0xfc800003) AM_WRITE(ms32_sound_w)
+
 	AM_RANGE(0xfcc00004, 0xfcc00007) AM_READ(bnstars1_r )
-	AM_RANGE(0xfcc00008, 0xfcc0000b) AM_READ(bnstars2_r )
-	AM_RANGE(0xfcc00010, 0xfcc00013) AM_READ(bnstars3_r )
+	AM_RANGE(0xfcc00008, 0xfcc0000b) AM_READ_PORT("IN4")
+	AM_RANGE(0xfcc00010, 0xfcc00013) AM_READ_PORT("IN5")
 
 	AM_RANGE(0xfce00034, 0xfce00037) AM_WRITENOP
+	AM_RANGE(0xfce00038, 0xfce0003b) AM_WRITE(reset_sub_w)
 
 	AM_RANGE(0xfce00050, 0xfce00053) AM_WRITENOP
 	AM_RANGE(0xfce00058, 0xfce0005b) AM_WRITENOP
 	AM_RANGE(0xfce0005c, 0xfce0005f) AM_WRITENOP
+	AM_RANGE(0xfce00300, 0xfce00303) AM_WRITENOP
 
 	AM_RANGE(0xfce00400, 0xfce0045f) AM_WRITEONLY AM_SHARE("roz_ctrl.0")
 	AM_RANGE(0xfce00700, 0xfce0075f) AM_WRITEONLY AM_SHARE("roz_ctrl.1") // guess
@@ -1304,6 +1281,8 @@ static ADDRESS_MAP_START( bnstars_map, AS_PROGRAM, 32, bnstars_state )
 
 	AM_RANGE(0xfce00e00, 0xfce00e03) AM_WRITE(bnstars1_mahjong_select_w) // ?
 
+	AM_RANGE(0xfd000000, 0xfd000003) AM_READ(ms32_sound_r)
+
 	/* wrote together */
 	AM_RANGE(0xfd040000, 0xfd047fff) AM_RAM // priority ram
 	AM_RANGE(0xfd080000, 0xfd087fff) AM_RAM
@@ -1311,7 +1290,7 @@ static ADDRESS_MAP_START( bnstars_map, AS_PROGRAM, 32, bnstars_state )
 	AM_RANGE(0xfd400000, 0xfd437fff) AM_RAM_WRITE(ms32_pal0_ram_w) AM_SHARE("pal_ram.0")
 	AM_RANGE(0xfe000000, 0xfe01ffff) AM_RAM_WRITE(ms32_roz1_ram_w) AM_SHARE("roz1_ram")
 	AM_RANGE(0xfe400000, 0xfe41ffff) AM_RAM_WRITE(ms32_roz0_ram_w) AM_SHARE("roz0_ram")
-	AM_RANGE(0xfe800000, 0xfe83ffff) AM_RAM_WRITE(ms32_spramx_w) AM_SHARE("spram")
+	AM_RANGE(0xfe800000, 0xfe83ffff) AM_RAM AM_SHARE("spram")
 	AM_RANGE(0xfea00000, 0xfea07fff) AM_RAM_WRITE(ms32_tx1_ram_w) AM_SHARE("tx1_ram")
 	AM_RANGE(0xfea08000, 0xfea0ffff) AM_RAM_WRITE(ms32_bg1_ram_w) AM_SHARE("bg1_ram")
 	AM_RANGE(0xfec00000, 0xfec07fff) AM_RAM_WRITE(ms32_tx0_ram_w) AM_SHARE("tx0_ram")
@@ -1321,56 +1300,24 @@ static ADDRESS_MAP_START( bnstars_map, AS_PROGRAM, 32, bnstars_state )
 	AM_RANGE(0xffe00000, 0xffffffff) AM_ROMBANK("bank1")
 ADDRESS_MAP_END
 
-#if 0
-static ADDRESS_MAP_START( bnstars_z80_map, AS_PROGRAM, 8, bnstars_state )
-	AM_RANGE(0x0000, 0x7fff) AM_ROM
+static ADDRESS_MAP_START( bnstars_sound_map, AS_PROGRAM, 8, bnstars_state )
+	AM_RANGE(0x0000, 0x3eff) AM_ROM
+	AM_RANGE(0x3f00, 0x3f0f) AM_DEVREADWRITE("ymf2", ymf271_device, read, write)
+	AM_RANGE(0x3f10, 0x3f10) AM_READWRITE(latch_r,to_main_w)
+	AM_RANGE(0x3f20, 0x3f2f) AM_DEVREADWRITE("ymf1", ymf271_device, read, write)
+	AM_RANGE(0x3f40, 0x3f40) AM_WRITENOP   /* YMF271 pin 4 (bit 1) , YMF271 pin 39 (bit 4) */
+	AM_RANGE(0x3f70, 0x3f70) AM_WRITENOP   // watchdog? banking? very noisy
+	AM_RANGE(0x3f80, 0x3f80) AM_WRITE(ms32_snd_bank_w)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM
+	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK("bank4")
+	AM_RANGE(0xc000, 0xffff) AM_ROMBANK("bank5")
 ADDRESS_MAP_END
-#endif
-
-
-IRQ_CALLBACK_MEMBER(bnstars_state::irq_callback)
-{
-	int i;
-	for(i=15; i>=0 && !(m_irqreq & (1<<i)); i--);
-	m_irqreq &= ~(1<<i);
-	if(!m_irqreq)
-		device.execute().set_input_line(0, CLEAR_LINE);
-	return i;
-}
-
-void bnstars_state::irq_init()
-{
-	m_irqreq = 0;
-	m_maincpu->set_input_line(0, CLEAR_LINE);
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(bnstars_state::irq_callback),this));
-}
-
-void bnstars_state::irq_raise(int level)
-{
-	m_irqreq |= (1<<level);
-	m_maincpu->set_input_line(0, ASSERT_LINE);
-}
-
-/* TODO: fix this arrangement (derived from old deprecat lib) */
-TIMER_DEVICE_CALLBACK_MEMBER(bnstars_state::ms32_interrupt)
-{
-	int scanline = param;
-	if( scanline == 0 ) irq_raise(10);
-	if( scanline == 8)  irq_raise(9);
-	/* hayaosi1 needs at least 12 IRQ 0 per frame to work (see code at FFE02289)
-	   kirarast needs it too, at least 8 per frame, but waits for a variable amount
-	   47pi2 needs ?? per frame (otherwise it hangs when you lose)
-	   in different points. Could this be a raster interrupt?
-	   Other games using it but not needing it to work:
-	   desertwr
-	   p47aces
-	   */
-	if( (scanline % 8) == 0 && scanline <= 224 ) irq_raise(0);
-}
 
 void bnstars_state::machine_reset()
 {
 	irq_init();
+	membank("bank4")->set_entry(0);
+	membank("bank5")->set_entry(1);
 }
 
 
@@ -1379,16 +1326,18 @@ static MACHINE_CONFIG_START( bnstars, bnstars_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", V70, 20000000) // 20MHz
 	MCFG_CPU_PROGRAM_MAP(bnstars_map)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(ms32_state,irq_callback)
+
 	MCFG_TIMER_DRIVER_ADD_SCANLINE("scantimer", bnstars_state, ms32_interrupt, "lscreen", 0, 1)
 
-//  MCFG_CPU_ADD("audiocpu", Z80, 4000000)
-//  MCFG_CPU_PROGRAM_MAP(bnstars_z80_map)
+	MCFG_CPU_ADD("audiocpu", Z80, 4000000)
+	MCFG_CPU_PROGRAM_MAP(bnstars_sound_map)
 
 	MCFG_QUANTUM_TIME(attotime::from_hz(60000))
 
 
-	MCFG_GFXDECODE(bnstars)
-	MCFG_PALETTE_LENGTH(0x8000*2)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", bnstars)
+	MCFG_PALETTE_ADD("palette", 0x8000*2)
 
 	MCFG_DEFAULT_LAYOUT(layout_dualhsxs)
 
@@ -1398,6 +1347,7 @@ static MACHINE_CONFIG_START( bnstars, bnstars_state )
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 28*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(bnstars_state, screen_update_bnstars_left)
+	MCFG_SCREEN_PALETTE("palette")
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
@@ -1405,6 +1355,7 @@ static MACHINE_CONFIG_START( bnstars, bnstars_state )
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 28*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(bnstars_state, screen_update_bnstars_right)
+	MCFG_SCREEN_PALETTE("palette")
 
 
 	/* sound hardware */
@@ -1464,7 +1415,7 @@ ROM_START( bnstars1 )
 	ROM_LOAD( "vsjanshi5.6", 0x000000, 0x080000, CRC(fdbbac21) SHA1(c77d852e53126cc8ebfe1e79d1134e42b54d1aab) )
 
 	/* Sound Program (one, driving both screen sound) */
-	ROM_REGION( 0x50000, "cpu1", 0 ) /* z80 program */
+	ROM_REGION( 0x50000, "audiocpu", 0 ) /* z80 program */
 	ROM_LOAD( "sb93145.5",  0x000000, 0x040000, CRC(0424e899) SHA1(fbcdebfa3d5f52b10cf30f7e416f5f53994e4d55) )
 	ROM_RELOAD(              0x010000, 0x40000 )
 
@@ -1489,6 +1440,7 @@ DRIVER_INIT_MEMBER(bnstars_state,bnstars)
 	decrypt_ms32_bg(machine(), 0x00001,0x9b, "gfx6");
 
 	membank("bank1")->set_base(memregion("maincpu")->base());
+	configure_banks();
 }
 
-GAME( 1997, bnstars1, 0,        bnstars, bnstars, bnstars_state, bnstars, ROT0,   "Jaleco", "Vs. Janshi Brandnew Stars", GAME_IMPERFECT_GRAPHICS | GAME_NO_SOUND )
+GAME( 1997, bnstars1, 0,        bnstars, bnstars, bnstars_state, bnstars, ROT0,   "Jaleco", "Vs. Janshi Brandnew Stars", GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
