@@ -122,9 +122,9 @@ WRITE8_MEMBER(circusc_state::circusc_sound_w)
 
 		/* CS6 */
 		case 4:
-			discrete_sound_w(m_discrete, space, NODE_05, (offset & 0x20) >> 5);
-			discrete_sound_w(m_discrete, space, NODE_06, (offset & 0x18) >> 3);
-			discrete_sound_w(m_discrete, space, NODE_07, (offset & 0x40) >> 6);
+			m_discrete->write(space, NODE_05, (offset & 0x20) >> 5);
+			m_discrete->write(space, NODE_06, (offset & 0x18) >> 3);
+			m_discrete->write(space, NODE_07, (offset & 0x40) >> 6);
 			break;
 	}
 }
@@ -291,23 +291,6 @@ static GFXDECODE_START( circusc )
 GFXDECODE_END
 
 
-/*************************************
- *
- *  Sound interface
- *
- *************************************/
-
-
-//-------------------------------------------------
-//  sn76496_config psg_intf
-//-------------------------------------------------
-
-static const sn76496_config psg_intf =
-{
-	DEVCB_NULL
-};
-
-
 static const discrete_mixer_desc circusc_mixer_desc =
 	{DISC_MIXER_IS_RESISTOR,
 		{RES_K(2.2), RES_K(2.2), RES_K(10)},
@@ -363,20 +346,20 @@ static MACHINE_CONFIG_START( circusc, circusc_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(circusc_state, screen_update_circusc)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(circusc)
-	MCFG_PALETTE_LENGTH(16*16+16*16)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", circusc)
+	MCFG_PALETTE_ADD("palette", 16*16+16*16)
+	MCFG_PALETTE_INDIRECT_ENTRIES(32)
+	MCFG_PALETTE_INIT_OWNER(circusc_state, circusc)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("sn1", SN76496, XTAL_14_31818MHz/8)
-	MCFG_SOUND_CONFIG(psg_intf)
 	MCFG_SOUND_ROUTE_EX(0, "fltdisc", 1.0, 0)
 
 	MCFG_SOUND_ADD("sn2", SN76496, XTAL_14_31818MHz/8)
-	MCFG_SOUND_CONFIG(psg_intf)
 	MCFG_SOUND_ROUTE_EX(0, "fltdisc", 1.0, 1)
 
 	MCFG_DAC_ADD("dac")
