@@ -203,6 +203,7 @@
     - Interrupts generation is unknown.
     - Touch screen hook-up.
     - Fully understand why it trigger some RTEs that should be RTS at POST.
+    - Rewrite palette system, use two RAMDAC devices
 
 
 *******************************************************************************/
@@ -214,9 +215,10 @@
 #define SND_CLOCK   XTAL_16_9344MHz
 
 #include "emu.h"
-#include "cpu/h83002/h8.h"
+#include "cpu/h8/h83006.h"
 #include "sound/ymz280b.h"
 #include "machine/nvram.h"
+#include "video/ramdac.h"
 
 
 class coinmvga_state : public driver_device
@@ -225,21 +227,24 @@ public:
 	coinmvga_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag),
 		m_vram(*this, "vram"),
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette"),
+		m_palette2(*this, "palette2") { }
 
 	required_shared_ptr<UINT16> m_vram;
-	struct { int r,g,b,offs,offs_internal; } m_bgpal, m_fgpal;
 	DECLARE_WRITE8_MEMBER(debug_w);
-	DECLARE_WRITE16_MEMBER(ramdac_bg_w);
-	DECLARE_WRITE16_MEMBER(ramdac_fg_w);
 	DECLARE_READ16_MEMBER(test_r);
 	DECLARE_DRIVER_INIT(colorama);
 	DECLARE_DRIVER_INIT(cmrltv75);
 	virtual void video_start();
-	virtual void palette_init();
 	UINT32 screen_update_coinmvga(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(vblank_irq);
 	required_device<cpu_device> m_maincpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
+	required_device<palette_device> m_palette2;
+
 };
 
 
@@ -255,7 +260,7 @@ void coinmvga_state::video_start()
 
 UINT32 coinmvga_state::screen_update_coinmvga(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
-	gfx_element *gfx = machine().gfx[0];
+	gfx_element *gfx = m_gfxdecode->gfx(0);
 	int count = 0x04000/2;
 
 	int y,x;
@@ -267,7 +272,7 @@ UINT32 coinmvga_state::screen_update_coinmvga(screen_device &screen, bitmap_ind1
 		{
 			int tile = m_vram[count];
 			//int colour = tile>>12;
-			drawgfx_opaque(bitmap,cliprect,gfx,tile,0,0,0,x*8,y*8);
+			gfx->opaque(bitmap,cliprect,tile,0,0,0,x*8,y*8);
 
 			count++;
 		}
@@ -278,11 +283,6 @@ UINT32 coinmvga_state::screen_update_coinmvga(screen_device &screen, bitmap_ind1
 }
 
 
-void coinmvga_state::palette_init()
-{
-}
-
-
 /**************************
 *  Read / Write Handlers  *
 **************************/
@@ -292,65 +292,6 @@ void coinmvga_state::palette_init()
 //  popmessage("written : %02X", data);
 //}
 
-WRITE16_MEMBER(coinmvga_state::ramdac_bg_w)
-{
-	if(ACCESSING_BITS_8_15)
-	{
-		m_bgpal.offs = data >> 8;
-		m_bgpal.offs_internal = 0;
-	}
-	else //if(mem_mask == 0x00ff)
-	{
-		switch(m_bgpal.offs_internal)
-		{
-			case 0:
-				m_bgpal.r = ((data & 0x3f) << 2) | ((data & 0x30) >> 4);
-				m_bgpal.offs_internal++;
-				break;
-			case 1:
-				m_bgpal.g = ((data & 0x3f) << 2) | ((data & 0x30) >> 4);
-				m_bgpal.offs_internal++;
-				break;
-			case 2:
-				m_bgpal.b = ((data & 0x3f) << 2) | ((data & 0x30) >> 4);
-				palette_set_color(machine(), m_bgpal.offs, MAKE_RGB(m_bgpal.r, m_bgpal.g, m_bgpal.b));
-				m_bgpal.offs_internal = 0;
-				m_bgpal.offs++;
-				break;
-		}
-	}
-}
-
-
-WRITE16_MEMBER(coinmvga_state::ramdac_fg_w)
-{
-	if(ACCESSING_BITS_8_15)
-	{
-		m_fgpal.offs = data >> 8;
-		m_fgpal.offs_internal = 0;
-	}
-	else
-	{
-		switch(m_fgpal.offs_internal)
-		{
-			case 0:
-				m_fgpal.r = ((data & 0x3f) << 2) | ((data & 0x30) >> 4);
-				m_fgpal.offs_internal++;
-				break;
-			case 1:
-				m_fgpal.g = ((data & 0x3f) << 2) | ((data & 0x30) >> 4);
-				m_fgpal.offs_internal++;
-				break;
-			case 2:
-				m_fgpal.b = ((data & 0x3f) << 2) | ((data & 0x30) >> 4);
-				palette_set_color(machine(), 0x100+m_fgpal.offs, MAKE_RGB(m_fgpal.r, m_fgpal.g, m_fgpal.b));
-				m_fgpal.offs_internal = 0;
-				m_fgpal.offs++;
-				break;
-		}
-	}
-}
-
 /*
 READ16_MEMBER(coinmvga_state::test_r)
 {
@@ -372,8 +313,12 @@ static ADDRESS_MAP_START( coinmvga_map, AS_PROGRAM, 16, coinmvga_state )
 //  AM_RANGE(0x403afa, 0x403afb) AM_READ(test_r) AM_WRITENOP //touch screen related, cmrltv75
 	AM_RANGE(0x400000, 0x40ffff) AM_RAM
 
-	AM_RANGE(0x600000, 0x600001) AM_WRITE(ramdac_bg_w)
-	AM_RANGE(0x600004, 0x600005) AM_WRITE(ramdac_fg_w)
+	AM_RANGE(0x600000, 0x600001) AM_DEVWRITE8("ramdac", ramdac_device, index_w, 0xff00)
+	AM_RANGE(0x600000, 0x600001) AM_DEVWRITE8("ramdac", ramdac_device, pal_w, 0x00ff)
+	AM_RANGE(0x600002, 0x600003) AM_DEVWRITE8("ramdac", ramdac_device, mask_w, 0xff00)
+	AM_RANGE(0x600004, 0x600005) AM_DEVWRITE8("ramdac2", ramdac_device, index_w, 0xff00)
+	AM_RANGE(0x600004, 0x600005) AM_DEVWRITE8("ramdac2", ramdac_device, pal_w, 0x00ff)
+	AM_RANGE(0x600006, 0x600007) AM_DEVWRITE8("ramdac2", ramdac_device, mask_w, 0xff00)
 	AM_RANGE(0x600008, 0x600009) AM_DEVREADWRITE8("ymz", ymz280b_device, read, write, 0xffff)
 	AM_RANGE(0x610000, 0x61000f) AM_RAM //touch screen i/o
 
@@ -384,27 +329,22 @@ static ADDRESS_MAP_START( coinmvga_map, AS_PROGRAM, 16, coinmvga_state )
 	//0x800008 "arrow" w?
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( coinmvga_io_map, AS_IO, 8, coinmvga_state )
+static ADDRESS_MAP_START( coinmvga_io_map, AS_IO, 16, coinmvga_state )
 /*  Digital I/O ports (ports 4-B are valid on 16-bit H8/3xx) */
-//  AM_RANGE(H8_PORT_4, H8_PORT_4)
-//  AM_RANGE(H8_PORT_5, H8_PORT_5)
-//  AM_RANGE(H8_PORT_6, H8_PORT_6)
-//  AM_RANGE(H8_PORT_7, H8_PORT_7) <---- 0006 RW colorama
-//  AM_RANGE(H8_PORT_8, H8_PORT_8)
-//  AM_RANGE(H8_PORT_9, H8_PORT_9)
-//  AM_RANGE(H8_PORT_A, H8_PORT_A)
-//  AM_RANGE(H8_PORT_B, H8_PORT_B)
+//  AM_RANGE(h8_device::PORT_4, h8_device::PORT_4)
+//  AM_RANGE(h8_device::PORT_5, h8_device::PORT_5)
+//  AM_RANGE(h8_device::PORT_6, h8_device::PORT_6)
+//  AM_RANGE(h8_device::PORT_7, h8_device::PORT_7) <---- 0006 RW colorama
+//  AM_RANGE(h8_device::PORT_8, h8_device::PORT_8)
+//  AM_RANGE(h8_device::PORT_9, h8_device::PORT_9)
+//  AM_RANGE(h8_device::PORT_A, h8_device::PORT_A)
+//  AM_RANGE(h8_device::PORT_B, h8_device::PORT_B)
 
 /*  Analog Inputs */
-//  AM_RANGE(H8_ADC_0_H, H8_ADC_0_L)
-//  AM_RANGE(H8_ADC_1_H, H8_ADC_1_L)
-//  AM_RANGE(H8_ADC_2_H, H8_ADC_2_L)
-//  AM_RANGE(H8_ADC_3_H, H8_ADC_3_L)
-
-/*  Serial ports */
-//  AM_RANGE(H8_SERIAL_0, H8_SERIAL_0)
-//  AM_RANGE(H8_SERIAL_1, H8_SERIAL_1)
-
+//  AM_RANGE(h8_device::ADC_0, h8_device::ADC_0)
+//  AM_RANGE(h8_device::ADC_1, h8_device::ADC_1)
+//  AM_RANGE(h8_device::ADC_2, h8_device::ADC_2)
+//  AM_RANGE(h8_device::ADC_3, h8_device::ADC_3)
 ADDRESS_MAP_END
 
 /*  unknown writes (cmrltv75):
@@ -646,8 +586,11 @@ static const gfx_layout tiles16x16_layout =
 ******************************/
 
 static GFXDECODE_START( coinmvga )
-	GFXDECODE_ENTRY( "gfx1", 0, tiles8x8_layout,   0x100, 16 )  /* Foreground GFX */
-	GFXDECODE_ENTRY( "gfx2", 0, tiles16x16_layout, 0x000, 16 )  /* Background GFX */
+	GFXDECODE_ENTRY( "gfx1", 0, tiles8x8_layout,   0x000, 16 )  /* Foreground GFX */
+GFXDECODE_END
+
+static GFXDECODE_START( coinmvga2 )
+	GFXDECODE_ENTRY( "gfx2", 0, tiles16x16_layout, 0x000, 1 )  /* Background GFX */
 GFXDECODE_END
 
 
@@ -666,6 +609,15 @@ INTERRUPT_GEN_MEMBER(coinmvga_state::vblank_irq)
 *    Machine Drivers     *
 *************************/
 
+static ADDRESS_MAP_START( ramdac_map, AS_0, 8, coinmvga_state )
+	AM_RANGE(0x000, 0x3ff) AM_DEVREADWRITE("ramdac",ramdac_device,ramdac_pal_r,ramdac_rgb666_w)
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( ramdac2_map, AS_0, 8, coinmvga_state )
+	AM_RANGE(0x000, 0x3ff) AM_DEVREADWRITE("ramdac2",ramdac_device,ramdac_pal_r,ramdac_rgb666_w)
+ADDRESS_MAP_END
+
+
 static MACHINE_CONFIG_START( coinmvga, coinmvga_state )
 
 	/* basic machine hardware */
@@ -683,11 +635,16 @@ static MACHINE_CONFIG_START( coinmvga, coinmvga_state )
 	MCFG_SCREEN_SIZE(640,480)
 	MCFG_SCREEN_VISIBLE_AREA(0, 640-1, 0, 480-1)
 	MCFG_SCREEN_UPDATE_DRIVER(coinmvga_state, screen_update_coinmvga)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(coinmvga)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", coinmvga)
+	MCFG_GFXDECODE_ADD("gfxdecode2", "palette2", coinmvga2)
 
-	MCFG_PALETTE_LENGTH(512)
+	MCFG_PALETTE_ADD("palette", 256)
+	MCFG_RAMDAC_ADD("ramdac", ramdac_map, "palette")
 
+	MCFG_PALETTE_ADD("palette2", 16)
+	MCFG_RAMDAC_ADD("ramdac2", ramdac2_map, "palette2")
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
