@@ -461,10 +461,12 @@ static MACHINE_CONFIG_START( cop01, cop01_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(cop01_state, screen_update_cop01)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(cop01)
-	MCFG_PALETTE_LENGTH(16+8*16+16*16)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", cop01)
+	MCFG_PALETTE_ADD("palette", 16+8*16+16*16)
+	MCFG_PALETTE_INDIRECT_ENTRIES(256)
+	MCFG_PALETTE_INIT_OWNER(cop01_state, cop01)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -499,10 +501,12 @@ static MACHINE_CONFIG_START( mightguy, cop01_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(cop01_state, screen_update_cop01)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(cop01)
-	MCFG_PALETTE_LENGTH(16+8*16+16*16)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", cop01)
+	MCFG_PALETTE_ADD("palette", 16+8*16+16*16)
+	MCFG_PALETTE_INDIRECT_ENTRIES(256)
+	MCFG_PALETTE_INIT_OWNER(cop01_state, cop01)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
