@@ -450,34 +450,11 @@ WRITE8_MEMBER(dassault_state::sound_bankswitch_w)
 
 /**********************************************************************************/
 
-static int dassault_bank_callback( const int bank )
+DECO16IC_BANK_CB_MEMBER(dassault_state::bank_callback)
 {
 	return ((bank >> 4) & 0xf) << 12;
 }
 
-static const deco16ic_interface dassault_deco16ic_tilegen1_intf =
-{
-	0, 1,
-	0x0f, 0x0f, /* trans masks (default values) */
-	0, 16, /* color base (default values) */
-	0x0f, 0x0f, /* color masks (default values) */
-	dassault_bank_callback,
-	dassault_bank_callback,
-	0,1,
-};
-
-static const deco16ic_interface dassault_deco16ic_tilegen2_intf =
-{
-	0, 1,
-	0x0f, 0x0f, /* trans masks (default values) */
-	0, 16, /* color base (default values) */
-	0x0f, 0x0f, /* color masks (default values) */
-	dassault_bank_callback,
-	dassault_bank_callback,
-	0,2,
-};
-
-
 static MACHINE_CONFIG_START( dassault, dassault_state )
 
 	/* basic machine hardware */
@@ -504,22 +481,58 @@ static MACHINE_CONFIG_START( dassault, dassault_state )
 	MCFG_SCREEN_UPDATE_DRIVER(dassault_state, screen_update_dassault)
 
 
-	MCFG_GFXDECODE(dassault)
-	MCFG_PALETTE_LENGTH(4096)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", dassault)
+	MCFG_PALETTE_ADD("palette", 4096)
 
 	MCFG_BUFFERED_SPRITERAM16_ADD("spriteram")
 	MCFG_BUFFERED_SPRITERAM16_ADD("spriteram2")
 
 	MCFG_DECOCOMN_ADD("deco_common")
+	MCFG_DECOCOMN_PALETTE("palette")
 
-	MCFG_DECO16IC_ADD("tilegen1", dassault_deco16ic_tilegen1_intf)
-	MCFG_DECO16IC_ADD("tilegen2", dassault_deco16ic_tilegen2_intf)
+	MCFG_DEVICE_ADD("tilegen1", DECO16IC, 0)
+	MCFG_DECO16IC_SPLIT(0)
+	MCFG_DECO16IC_WIDTH12(1)
+	MCFG_DECO16IC_PF1_TRANS_MASK(0x0f)
+	MCFG_DECO16IC_PF2_TRANS_MASK(0x0f)
+	MCFG_DECO16IC_PF1_COL_BANK(0)
+	MCFG_DECO16IC_PF2_COL_BANK(16)
+	MCFG_DECO16IC_PF1_COL_MASK(0x0f)
+	MCFG_DECO16IC_PF2_COL_MASK(0x0f)
+	MCFG_DECO16IC_BANK1_CB(dassault_state, bank_callback)
+	MCFG_DECO16IC_BANK2_CB(dassault_state, bank_callback)
+	MCFG_DECO16IC_PF12_8X8_BANK(0)
+	MCFG_DECO16IC_PF12_16X16_BANK(1)
+
+	MCFG_DECO16IC_GFXDECODE("gfxdecode")
+	MCFG_DECO16IC_PALETTE("palette")
+
+	MCFG_DEVICE_ADD("tilegen2", DECO16IC, 0)
+	MCFG_DECO16IC_SPLIT(0)
+	MCFG_DECO16IC_WIDTH12(1)
+	MCFG_DECO16IC_PF1_TRANS_MASK(0x0f)
+	MCFG_DECO16IC_PF2_TRANS_MASK(0x0f)
+	MCFG_DECO16IC_PF1_COL_BANK(0)
+	MCFG_DECO16IC_PF2_COL_BANK(16)
+	MCFG_DECO16IC_PF1_COL_MASK(0x0f)
+	MCFG_DECO16IC_PF2_COL_MASK(0x0f)
+	MCFG_DECO16IC_BANK1_CB(dassault_state, bank_callback)
+	MCFG_DECO16IC_BANK2_CB(dassault_state, bank_callback)
+	MCFG_DECO16IC_PF12_8X8_BANK(0)
+	MCFG_DECO16IC_PF12_16X16_BANK(2)
+
+	MCFG_DECO16IC_GFXDECODE("gfxdecode")
+	MCFG_DECO16IC_PALETTE("palette")
 
 	MCFG_DEVICE_ADD("spritegen1", DECO_SPRITE, 0)
-	decospr_device::set_gfx_region(*device, 3);
+	MCFG_DECO_SPRITE_GFX_REGION(3)
+	MCFG_DECO_SPRITE_GFXDECODE("gfxdecode")
+	MCFG_DECO_SPRITE_PALETTE("palette")
 
 	MCFG_DEVICE_ADD("spritegen2", DECO_SPRITE, 0)
-	decospr_device::set_gfx_region(*device, 4);
+	MCFG_DECO_SPRITE_GFX_REGION(4)
+	MCFG_DECO_SPRITE_GFXDECODE("gfxdecode")
+	MCFG_DECO_SPRITE_PALETTE("palette")
 
 
 	/* sound hardware */
@@ -961,7 +974,7 @@ DRIVER_INIT_MEMBER(dassault_state,dassault)
 {
 	const UINT8 *src = memregion("gfx1")->base();
 	UINT8 *dst = memregion("gfx2")->base();
-	UINT8 *tmp = auto_alloc_array(machine(), UINT8, 0x80000);
+	dynamic_buffer tmp(0x80000);
 
 	/* Playfield 4 also has access to the char graphics, make things easier
 	by just copying the chars to both banks (if I just used a different gfx
@@ -970,15 +983,13 @@ DRIVER_INIT_MEMBER(dassault_state,dassault)
 	memcpy(dst + 0x090000, tmp + 0x00000, 0x80000);
 	memcpy(dst + 0x080000, src + 0x00000, 0x10000);
 	memcpy(dst + 0x110000, src + 0x10000, 0x10000);
-
-	auto_free(machine(), tmp);
 }
 
 DRIVER_INIT_MEMBER(dassault_state,thndzone)
 {
 	const UINT8 *src = memregion("gfx1")->base();
 	UINT8 *dst = memregion("gfx2")->base();
-	UINT8 *tmp = auto_alloc_array(machine(), UINT8, 0x80000);
+	dynamic_buffer tmp(0x80000);
 
 	/* Playfield 4 also has access to the char graphics, make things easier
 	by just copying the chars to both banks (if I just used a different gfx
@@ -987,8 +998,6 @@ DRIVER_INIT_MEMBER(dassault_state,thndzone)
 	memcpy(dst + 0x090000, tmp + 0x00000, 0x80000);
 	memcpy(dst + 0x080000, src + 0x00000, 0x10000);
 	memcpy(dst + 0x110000, src + 0x10000, 0x10000);
-
-	auto_free(machine(), tmp);
 }
 
 /**********************************************************************************/
