@@ -317,9 +317,9 @@ static MACHINE_CONFIG_START( dgpix, dgpix_state )
 	MCFG_SCREEN_SIZE(512, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 319, 0, 239)
 	MCFG_SCREEN_UPDATE_DRIVER(dgpix_state, screen_update_dgpix)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, BBBBB_GGGGG_RRRRR)
-	MCFG_PALETTE_LENGTH(32768)
+	MCFG_PALETTE_ADD_BBBBBGGGGGRRRRR("palette")
 
 
 	/* sound hardware */
