@@ -116,7 +116,7 @@ public:
 	virtual void machine_start();
 	virtual void machine_reset();
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(famibox);
 	UINT32 screen_update_famibox(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	TIMER_CALLBACK_MEMBER(famicombox_attract_timer_callback);
 	TIMER_CALLBACK_MEMBER(famicombox_gameplay_timer_callback);
@@ -272,7 +272,7 @@ void famibox_state::famicombox_bankswitch(UINT8 bank)
 	};
 
 
-	for (int i = 0; i < sizeof(famicombox_banks)/sizeof(famicombox_banks[0]); i++ )
+	for (int i = 0; i < ARRAY_LENGTH(famicombox_banks); i++ )
 	{
 		if ( bank == famicombox_banks[i].bank ||
 				famicombox_banks[i].bank == 0 )
@@ -511,14 +511,9 @@ INPUT_PORTS_END
 
 *******************************************************/
 
-static const nesapu_interface famibox_interface_1 =
+PALETTE_INIT_MEMBER(famibox_state, famibox)
 {
-	"maincpu"
-};
-
-void famibox_state::palette_init()
-{
-	m_ppu->init_palette(machine(), 0);
+	m_ppu->init_palette(palette, 0);
 }
 
 void famibox_state::ppu_irq(int *ppu_regs)
@@ -526,15 +521,6 @@ void famibox_state::ppu_irq(int *ppu_regs)
 	m_maincpu->set_input_line(INPUT_LINE_NMI, PULSE_LINE);
 }
 
-/* our ppu interface                                            */
-static const ppu2c0x_interface ppu_interface =
-{
-	"maincpu",
-	0,                  /* gfxlayout num */
-	0,                  /* color base */
-	PPU_MIRROR_NONE     /* mirroring */
-};
-
 void famibox_state::video_start()
 {
 }
@@ -583,26 +569,27 @@ static MACHINE_CONFIG_START( famibox, famibox_state )
 	MCFG_CPU_ADD("maincpu", N2A03, N2A03_DEFAULTCLOCK)
 	MCFG_CPU_PROGRAM_MAP(famibox_map)
 
-
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_SIZE(32*8, 262)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(famibox_state, screen_update_famibox)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(famibox)
-	MCFG_PALETTE_LENGTH(8*4*16)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", famibox)
+	MCFG_PALETTE_ADD("palette", 8*4*16)
+	MCFG_PALETTE_INIT_OWNER(famibox_state, famibox)
 
-
-	MCFG_PPU2C04_ADD("ppu", ppu_interface)
+	MCFG_PPU2C04_ADD("ppu")
+	MCFG_PPU2C0X_CPU("maincpu")
 	MCFG_PPU2C0X_SET_NMI(famibox_state, ppu_irq)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("nesapu", NES_APU, N2A03_DEFAULTCLOCK)
-	MCFG_SOUND_CONFIG(famibox_interface_1)
+	MCFG_NES_APU_CPU("maincpu")
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
 	MCFG_DAC_ADD("dac")
