@@ -181,7 +181,7 @@ public:
 		m_ata(*this, "ata")
 	{ }
 
-	required_device<cpu_device> m_maincpu;
+	required_device<ppc4xx_device> m_maincpu;
 	required_shared_ptr<UINT32> m_work_ram;
 	required_device<fujitsu_29f016a_device> m_flash_main;
 	required_device<fujitsu_29f016a_device> m_flash_snd1;
@@ -603,7 +603,7 @@ UINT32 firebeat_state::update_screen(screen_device &screen, bitmap_ind16 &bitmap
 {
 	bitmap.fill(0, cliprect);
 
-	if ((mame_strnicmp(screen.machine().system().name, "popn", 4) == 0) || (mame_strnicmp(screen.machine().system().name, "bm3", 3) == 0))
+	if ((core_strnicmp(machine().system().name, "popn", 4) == 0) || (core_strnicmp(machine().system().name, "bm3", 3) == 0))
 	{
 		gcu_exec_display_list( bitmap, cliprect, chip, 0x1f80000);
 	}
@@ -633,7 +633,7 @@ UINT32 firebeat_state::update_screen(screen_device &screen, bitmap_ind16 &bitmap
 	if (m_tick >= 5)
 	{
 		m_tick = 0;
-		if (screen.machine().input().code_pressed(KEYCODE_0))
+		if (machine().input().code_pressed(KEYCODE_0))
 		{
 			m_layer++;
 			if (m_layer > 2)
@@ -643,7 +643,7 @@ UINT32 firebeat_state::update_screen(screen_device &screen, bitmap_ind16 &bitmap
 		}
 
 		/*
-		if (screen.machine().input().code_pressed_once(KEYCODE_9))
+		if (machine().input().code_pressed_once(KEYCODE_9))
 		{
 		    FILE *file = fopen("vram0.bin", "wb");
 		    int i;
@@ -751,7 +751,7 @@ void firebeat_state::GCU_w(int chip, UINT32 offset, UINT32 data, UINT32 mem_mask
 		case 0x40:      /* framebuffer config */
 			// HACK: switch display lists at the right times for the ParaParaParadise games until we
 			// do the video emulation properly
-			if (mame_strnicmp(machine().system().name, "pp", 2) == 0)
+			if (core_strnicmp(machine().system().name, "pp", 2) == 0)
 			{
 				switch (data)
 				{
@@ -771,7 +771,7 @@ void firebeat_state::GCU_w(int chip, UINT32 offset, UINT32 data, UINT32 mem_mask
 						break;
 				}
 			}
-			else if (mame_strnicmp(machine().system().name, "kbm", 3) == 0)
+			else if (core_strnicmp(machine().system().name, "kbm", 3) == 0)
 			{
 				switch (data)
 				{
@@ -1095,25 +1095,6 @@ static void comm_uart_irq_callback(running_machine &machine, int channel, int va
     //m_maincpu->set_input_line(INPUT_LINE_IRQ2, ASSERT_LINE);
 }
 */
-static const ins8250_interface firebeat_com0_interface =
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-static const ins8250_interface firebeat_com1_interface =
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
 
 /*****************************************************************************/
 
@@ -1190,25 +1171,6 @@ WRITE_LINE_MEMBER(firebeat_state::midi_uart_ch1_irq_callback)
 		m_maincpu->set_input_line(INPUT_LINE_IRQ1, CLEAR_LINE);
 }
 
-static const ins8250_interface firebeat_midi0_interface =
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(firebeat_state, midi_uart_ch0_irq_callback),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-static const ins8250_interface firebeat_midi1_interface =
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(firebeat_state, midi_uart_ch1_irq_callback),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
 /*
 static const int keyboard_notes[24] =
 {
@@ -1521,10 +1483,10 @@ READ16_MEMBER(firebeat_state::spu_unk_r)
 MACHINE_START_MEMBER(firebeat_state,firebeat)
 {
 	/* set conservative DRC options */
-	ppcdrc_set_options(m_maincpu, PPCDRC_COMPATIBLE_OPTIONS);
+	m_maincpu->ppcdrc_set_options(PPCDRC_COMPATIBLE_OPTIONS);
 
 	/* configure fast RAM regions for DRC */
-	ppcdrc_add_fastram(m_maincpu, 0x00000000, 0x01ffffff, FALSE, m_work_ram);
+	m_maincpu->ppcdrc_add_fastram(0x00000000, 0x01ffffff, FALSE, m_work_ram);
 }
 
 static ADDRESS_MAP_START( firebeat_map, AS_PROGRAM, 32, firebeat_state )
@@ -1723,11 +1685,6 @@ MACHINE_RESET_MEMBER(firebeat_state,firebeat)
 	m_layer = 0;
 }
 
-const rtc65271_interface firebeat_rtc =
-{
-	DEVCB_NULL
-};
-
 WRITE_LINE_MEMBER( firebeat_state::ata_interrupt )
 {
 	m_maincpu->set_input_line(INPUT_LINE_IRQ4, state);
@@ -1749,7 +1706,7 @@ static MACHINE_CONFIG_START( firebeat, firebeat_state )
 	MCFG_MACHINE_START_OVERRIDE(firebeat_state,firebeat)
 	MCFG_MACHINE_RESET_OVERRIDE(firebeat_state,firebeat)
 
-	MCFG_RTC65271_ADD("rtc", firebeat_rtc)
+	MCFG_DEVICE_ADD("rtc", RTC65271, 0)
 
 	MCFG_FUJITSU_29F016A_ADD("flash_main")
 	MCFG_FUJITSU_29F016A_ADD("flash_snd1")
@@ -1762,8 +1719,7 @@ static MACHINE_CONFIG_START( firebeat, firebeat_state )
 	MCFG_DEVICE_CARD_MACHINE_CONFIG( "cdrom", cdrom_config )
 
 	/* video hardware */
-	MCFG_PALETTE_LENGTH(32768)
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, RRRRR_GGGGG_BBBBB)
+	MCFG_PALETTE_ADD_RRRRRGGGGGBBBBB("palette")
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
@@ -1771,6 +1727,7 @@ static MACHINE_CONFIG_START( firebeat, firebeat_state )
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0, 639, 0, 479)
 	MCFG_SCREEN_UPDATE_DRIVER(firebeat_state, screen_update_firebeat_0)
+	MCFG_SCREEN_PALETTE("palette")
 
 	MCFG_VIDEO_START_OVERRIDE(firebeat_state,firebeat)
 
@@ -1783,8 +1740,14 @@ static MACHINE_CONFIG_START( firebeat, firebeat_state )
 	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
 	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
 
-	MCFG_PC16552D_ADD("duart_com", firebeat_com0_interface, firebeat_com1_interface, XTAL_19_6608MHz) // pgmd to 9600baud
-	MCFG_PC16552D_ADD("duart_midi", firebeat_midi0_interface, firebeat_midi1_interface, XTAL_24MHz) // in all memory maps, pgmd to 31250baud
+	MCFG_DEVICE_ADD("duart_com", PC16552D, 0)  // pgmd to 9600baud
+	MCFG_DEVICE_ADD("duart_com:chan0", NS16550, XTAL_19_6608MHz)
+	MCFG_DEVICE_ADD("duart_com:chan1", NS16550, XTAL_19_6608MHz)
+	MCFG_DEVICE_ADD("duart_midi", PC16552D, 0)  // in all memory maps, pgmd to 31250baud
+	MCFG_DEVICE_ADD("duart_midi:chan0", NS16550, XTAL_24MHz)
+	MCFG_INS8250_OUT_INT_CB(DEVWRITELINE(DEVICE_SELF_OWNER, firebeat_state, midi_uart_ch0_irq_callback))
+	MCFG_DEVICE_ADD("duart_midi:chan1", NS16550, XTAL_24MHz)
+	MCFG_INS8250_OUT_INT_CB(DEVWRITELINE(DEVICE_SELF_OWNER, firebeat_state, midi_uart_ch1_irq_callback))
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_START( firebeat2, firebeat_state )
@@ -1797,7 +1760,7 @@ static MACHINE_CONFIG_START( firebeat2, firebeat_state )
 	MCFG_MACHINE_START_OVERRIDE(firebeat_state,firebeat)
 	MCFG_MACHINE_RESET_OVERRIDE(firebeat_state,firebeat)
 
-	MCFG_RTC65271_ADD("rtc", firebeat_rtc)
+	MCFG_DEVICE_ADD("rtc", RTC65271, 0)
 
 	MCFG_FUJITSU_29F016A_ADD("flash_main")
 	MCFG_FUJITSU_29F016A_ADD("flash_snd1")
@@ -1810,8 +1773,7 @@ static MACHINE_CONFIG_START( firebeat2, firebeat_state )
 	MCFG_DEVICE_CARD_MACHINE_CONFIG( "cdrom", cdrom_config )
 
 	/* video hardware */
-	MCFG_PALETTE_LENGTH(32768)
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, RRRRR_GGGGG_BBBBB)
+	MCFG_PALETTE_ADD_RRRRRGGGGGBBBBB("palette")
 
 	MCFG_SCREEN_ADD("lscreen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
@@ -1819,6 +1781,7 @@ static MACHINE_CONFIG_START( firebeat2, firebeat_state )
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0, 639, 0, 479)
 	MCFG_SCREEN_UPDATE_DRIVER(firebeat_state, screen_update_firebeat_0)
+	MCFG_SCREEN_PALETTE("palette")
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
@@ -1826,6 +1789,7 @@ static MACHINE_CONFIG_START( firebeat2, firebeat_state )
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0, 639, 0, 479)
 	MCFG_SCREEN_UPDATE_DRIVER(firebeat_state, screen_update_firebeat_1)
+	MCFG_SCREEN_PALETTE("palette")
 
 	MCFG_VIDEO_START_OVERRIDE(firebeat_state,firebeat)
 
@@ -1838,8 +1802,14 @@ static MACHINE_CONFIG_START( firebeat2, firebeat_state )
 	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
 	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
 
-	MCFG_PC16552D_ADD("duart_com", firebeat_com0_interface, firebeat_com1_interface, XTAL_19_6608MHz)
-	MCFG_PC16552D_ADD("duart_midi", firebeat_midi0_interface, firebeat_midi1_interface, XTAL_24MHz)
+	MCFG_DEVICE_ADD("duart_com", PC16552D, 0)
+	MCFG_DEVICE_ADD("duart_com:chan0", NS16550, XTAL_19_6608MHz)
+	MCFG_DEVICE_ADD("duart_com:chan1", NS16550, XTAL_19_6608MHz)
+	MCFG_DEVICE_ADD("duart_midi", PC16552D, 0)
+	MCFG_DEVICE_ADD("duart_midi:chan0", NS16550, XTAL_24MHz)
+	MCFG_INS8250_OUT_INT_CB(DEVWRITELINE(DEVICE_SELF_OWNER, firebeat_state, midi_uart_ch0_irq_callback))
+	MCFG_DEVICE_ADD("duart_midi:chan1", NS16550, XTAL_24MHz)
+	MCFG_INS8250_OUT_INT_CB(DEVWRITELINE(DEVICE_SELF_OWNER, firebeat_state, midi_uart_ch1_irq_callback))
 	MCFG_MIDI_KBD_ADD("kbd0", DEVWRITELINE("duart_midi:chan0", ins8250_uart_device, rx_w), 31250)
 	MCFG_MIDI_KBD_ADD("kbd1", DEVWRITELINE("duart_midi:chan1", ins8250_uart_device, rx_w), 31250)
 MACHINE_CONFIG_END
@@ -1985,7 +1955,7 @@ static void security_w(device_t *device, UINT8 data)
 	firebeat_state *state = device->machine().driver_data<firebeat_state>();
 	int r = state->ibutton_w(data);
 	if (r >= 0)
-		ppc4xx_spu_receive_byte(state->m_maincpu, r);
+		state->m_maincpu->ppc4xx_spu_receive_byte(r);
 }
 
 /*****************************************************************************/
@@ -2013,7 +1983,7 @@ void firebeat_state::init_firebeat()
 
 	m_cur_cab_data = cab_data;
 
-	ppc4xx_spu_set_tx_handler(m_maincpu, security_w);
+	m_maincpu->ppc4xx_spu_set_tx_handler(security_w);
 
 	set_ibutton(rom);
 
