@@ -327,22 +327,6 @@ READ8_MEMBER(foodf_state::pot_r)
 	return (ioport("DSW")->read() >> offset) << 7;
 }
 
-static const pokey_interface pokey_config =
-{
-	{
-		DEVCB_DRIVER_MEMBER(foodf_state,pot_r),
-		DEVCB_DRIVER_MEMBER(foodf_state,pot_r),
-		DEVCB_DRIVER_MEMBER(foodf_state,pot_r),
-		DEVCB_DRIVER_MEMBER(foodf_state,pot_r),
-		DEVCB_DRIVER_MEMBER(foodf_state,pot_r),
-		DEVCB_DRIVER_MEMBER(foodf_state,pot_r),
-		DEVCB_DRIVER_MEMBER(foodf_state,pot_r),
-		DEVCB_DRIVER_MEMBER(foodf_state,pot_r)
-	}
-};
-
-
-
 /*************************************
  *
  *  Machine driver
@@ -366,28 +350,36 @@ static MACHINE_CONFIG_START( foodf, foodf_state )
 	MCFG_TIMER_DRIVER_ADD("scan_timer", foodf_state, scanline_update_timer)
 
 	/* video hardware */
-	MCFG_GFXDECODE(foodf)
-	MCFG_PALETTE_LENGTH(256)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", foodf)
+	MCFG_PALETTE_ADD("palette", 256)
 
-	MCFG_TILEMAP_ADD_STANDARD_TRANSPEN("playfield", 2, foodf_state, get_playfield_tile_info, 8,8, SCAN_COLS, 32,32, 0)
+	MCFG_TILEMAP_ADD_STANDARD_TRANSPEN("playfield", "gfxdecode", 2, foodf_state, get_playfield_tile_info, 8,8, SCAN_COLS, 32,32, 0)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS(MASTER_CLOCK/2, 384, 0, 256, 259, 0, 224)
 	MCFG_SCREEN_UPDATE_DRIVER(foodf_state, screen_update_foodf)
+	MCFG_SCREEN_PALETTE("palette")
 
 	MCFG_VIDEO_START_OVERRIDE(foodf_state,foodf)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MCFG_POKEY_ADD("pokey1", MASTER_CLOCK/2/10)
-	MCFG_POKEY_CONFIG(pokey_config)
+	MCFG_SOUND_ADD("pokey1", POKEY, MASTER_CLOCK/2/10)
+	MCFG_POKEY_POT0_R_CB(READ8(foodf_state, pot_r))
+	MCFG_POKEY_POT1_R_CB(READ8(foodf_state, pot_r))
+	MCFG_POKEY_POT2_R_CB(READ8(foodf_state, pot_r))
+	MCFG_POKEY_POT3_R_CB(READ8(foodf_state, pot_r))
+	MCFG_POKEY_POT4_R_CB(READ8(foodf_state, pot_r))
+	MCFG_POKEY_POT5_R_CB(READ8(foodf_state, pot_r))
+	MCFG_POKEY_POT6_R_CB(READ8(foodf_state, pot_r))
+	MCFG_POKEY_POT7_R_CB(READ8(foodf_state, pot_r))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
 
-	MCFG_POKEY_ADD("pokey2", MASTER_CLOCK/2/10)
+	MCFG_SOUND_ADD("pokey2", POKEY, MASTER_CLOCK/2/10)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
 
-	MCFG_POKEY_ADD("pokey3", MASTER_CLOCK/2/10)
+	MCFG_SOUND_ADD("pokey3", POKEY, MASTER_CLOCK/2/10)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
 MACHINE_CONFIG_END
 
