@@ -91,7 +91,7 @@ static ADDRESS_MAP_START( fuuki16_map, AS_PROGRAM, 16, fuuki16_state )
 	AM_RANGE(0x504000, 0x505fff) AM_RAM_WRITE(fuuki16_vram_2_w) AM_SHARE("vram.2")                  //
 	AM_RANGE(0x506000, 0x507fff) AM_RAM_WRITE(fuuki16_vram_3_w) AM_SHARE("vram.3")                  //
 	AM_RANGE(0x600000, 0x601fff) AM_MIRROR(0x008000) AM_RAM AM_SHARE("spriteram")   // Sprites, mirrored?
-	AM_RANGE(0x700000, 0x703fff) AM_RAM_WRITE(paletteram_xRRRRRGGGGGBBBBB_word_w) AM_SHARE("paletteram")    // Palette
+	AM_RANGE(0x700000, 0x703fff) AM_RAM_DEVWRITE("palette", palette_device, write) AM_SHARE("palette")    // Palette
 	AM_RANGE(0x800000, 0x800001) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x810000, 0x810001) AM_READ_PORT("P1_P2")
 	AM_RANGE(0x880000, 0x880001) AM_READ_PORT("DSW")
@@ -464,9 +464,11 @@ static MACHINE_CONFIG_START( fuuki16, fuuki16_state )
 	MCFG_SCREEN_SIZE(320, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0, 256-16-1)
 	MCFG_SCREEN_UPDATE_DRIVER(fuuki16_state, screen_update_fuuki16)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(fuuki16)
-	MCFG_PALETTE_LENGTH(0x800*4)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", fuuki16)
+	MCFG_PALETTE_ADD("palette", 0x800*4)
+	MCFG_PALETTE_FORMAT(xRRRRRGGGGGBBBBB)
 
 
 	/* sound hardware */
