@@ -176,7 +176,7 @@ WRITE8_MEMBER(grchamp_state::cpu0_outputs_w)
 			/* bit 5: n/c */
 			/* bit 6: G-Z */
 			if (diff)
-				mame_printf_debug("OUT10=%02X\n", data);
+				osd_printf_debug("OUT10=%02X\n", data);
 			break;
 
 		case 0x0d:  /* OUT13 */
@@ -300,18 +300,18 @@ WRITE8_MEMBER(grchamp_state::cpu1_outputs_w)
 			/* bit 2-4: ATTACK UP 1-3 */
 			/* bit 5-6: SIFT 1-2 */
 			/* bit 7:   ENGINE CS */
-			discrete_sound_w(m_discrete, space, GRCHAMP_ENGINE_CS_EN, data & 0x80);
-			discrete_sound_w(m_discrete, space, GRCHAMP_SIFT_DATA, (data >> 5) & 0x03);
-			discrete_sound_w(m_discrete, space, GRCHAMP_ATTACK_UP_DATA, (data >> 2) & 0x07);
-			discrete_sound_w(m_discrete, space, GRCHAMP_IDLING_EN, data & 0x02);
-			discrete_sound_w(m_discrete, space, GRCHAMP_FOG_EN, data & 0x01);
+			m_discrete->write(space, GRCHAMP_ENGINE_CS_EN, data & 0x80);
+			m_discrete->write(space, GRCHAMP_SIFT_DATA, (data >> 5) & 0x03);
+			m_discrete->write(space, GRCHAMP_ATTACK_UP_DATA, (data >> 2) & 0x07);
+			m_discrete->write(space, GRCHAMP_IDLING_EN, data & 0x02);
+			m_discrete->write(space, GRCHAMP_FOG_EN, data & 0x01);
 			break;
 
 		case 0x0d: /* OUTD */
 			/* bit 0-3: ATTACK SPEED 1-4 */
 			/* bit 4-7: PLAYER SPEED 1-4 */
-			discrete_sound_w(m_discrete, space, GRCHAMP_PLAYER_SPEED_DATA, (data >> 4) & 0x0f);
-			discrete_sound_w(m_discrete, space, GRCHAMP_ATTACK_SPEED_DATA,  data & 0x0f);
+			m_discrete->write(space, GRCHAMP_PLAYER_SPEED_DATA, (data >> 4) & 0x0f);
+			m_discrete->write(space, GRCHAMP_ATTACK_SPEED_DATA,  data & 0x0f);
 			break;
 
 		default:
@@ -409,12 +409,12 @@ READ8_MEMBER(grchamp_state::main_to_sub_comm_r)
 
 WRITE8_MEMBER(grchamp_state::grchamp_portA_0_w)
 {
-	discrete_sound_w(m_discrete, space, GRCHAMP_A_DATA, data);
+	m_discrete->write(space, GRCHAMP_A_DATA, data);
 }
 
 WRITE8_MEMBER(grchamp_state::grchamp_portB_0_w)
 {
-	discrete_sound_w(m_discrete, space, GRCHAMP_B_DATA, 255-data);
+	m_discrete->write(space, GRCHAMP_B_DATA, 255-data);
 }
 
 WRITE8_MEMBER(grchamp_state::grchamp_portA_2_w)
@@ -428,35 +428,6 @@ WRITE8_MEMBER(grchamp_state::grchamp_portB_2_w)
 }
 
 
-
-/*************************************
- *
- *  Sound interfaces
- *
- *************************************/
-
-static const ay8910_interface ay8910_interface_1 =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(grchamp_state,grchamp_portA_0_w),
-	DEVCB_DRIVER_MEMBER(grchamp_state,grchamp_portB_0_w)
-};
-
-static const ay8910_interface ay8910_interface_3 =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(grchamp_state,grchamp_portA_2_w),
-	DEVCB_DRIVER_MEMBER(grchamp_state,grchamp_portB_2_w)
-};
-
-
-
 /*************************************
  *
  *  Graphics Layouts
@@ -487,10 +458,10 @@ static const gfx_layout tile_layout =
 
 static GFXDECODE_START( grchamp )
 	GFXDECODE_ENTRY( "gfx1", 0x0000, gfx_8x8x2_planar,  0, 8 )
-	GFXDECODE_ENTRY( "gfx2", 0x0000, tile_layout,       0, 16 )
-	GFXDECODE_ENTRY( "gfx3", 0x0000, tile_layout,       0, 16 )
-	GFXDECODE_ENTRY( "gfx4", 0x0000, tile_layout,       0, 16 )
-	GFXDECODE_ENTRY( "gfx1", 0x0000, sprite_layout,     0, 32 )
+	GFXDECODE_ENTRY( "gfx2", 0x0000, tile_layout,       0, 2 )
+	GFXDECODE_ENTRY( "gfx3", 0x0000, tile_layout,       0, 2 )
+	GFXDECODE_ENTRY( "gfx4", 0x0000, tile_layout,       0, 2 )
+	GFXDECODE_ENTRY( "gfx1", 0x0000, sprite_layout,     0, 8 )
 GFXDECODE_END
 
 
@@ -680,10 +651,12 @@ static MACHINE_CONFIG_START( grchamp, grchamp_state )
 	MCFG_QUANTUM_TIME(attotime::from_hz(6000))
 
 	/* video hardware */
-	MCFG_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
-	MCFG_GFXDECODE(grchamp)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", grchamp)
+	MCFG_PALETTE_ADD("palette", 32)
+	MCFG_PALETTE_INIT_OWNER(grchamp_state, grchamp)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
 	MCFG_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
 	MCFG_SCREEN_UPDATE_DRIVER(grchamp_state, screen_update_grchamp)
 
@@ -692,14 +665,16 @@ static MACHINE_CONFIG_START( grchamp, grchamp_state )
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("ay1", AY8910, SOUND_CLOCK/4)    /* 3B */
-	MCFG_SOUND_CONFIG(ay8910_interface_1)
+	MCFG_AY8910_PORT_A_WRITE_CB(WRITE8(grchamp_state, grchamp_portA_0_w))
+	MCFG_AY8910_PORT_B_WRITE_CB(WRITE8(grchamp_state, grchamp_portB_0_w))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.2)
 
 	MCFG_SOUND_ADD("ay2", AY8910, SOUND_CLOCK/4)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.2)
 
 	MCFG_SOUND_ADD("ay3", AY8910, SOUND_CLOCK/4)    /* 1B */
-	MCFG_SOUND_CONFIG(ay8910_interface_3)
+	MCFG_AY8910_PORT_A_WRITE_CB(WRITE8(grchamp_state, grchamp_portA_2_w))
+	MCFG_AY8910_PORT_B_WRITE_CB(WRITE8(grchamp_state, grchamp_portB_2_w))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.2)
 
 	MCFG_SOUND_ADD("discrete", DISCRETE, 0)
