@@ -70,29 +70,6 @@
 #include "includes/groundfx.h"
 
 
-/***********************************************************
-                COLOR RAM
-
-Extract a standard version of this
-("taito_8bpg_palette_word_w"?) to Taitoic.c ?
-***********************************************************/
-
-WRITE32_MEMBER(groundfx_state::color_ram_w)
-{
-	int a,r,g,b;
-	COMBINE_DATA(&m_generic_paletteram_32[offset]);
-
-	{
-		a = m_generic_paletteram_32[offset];
-		r = (a &0xff0000) >> 16;
-		g = (a &0xff00) >> 8;
-		b = (a &0xff);
-
-		palette_set_color(machine(),offset,MAKE_RGB(r,g,b));
-	}
-}
-
-
 /***********************************************************
                 INTERRUPTS
 ***********************************************************/
@@ -215,7 +192,7 @@ static ADDRESS_MAP_START( groundfx_map, AS_PROGRAM, 32, groundfx_state )
 	AM_RANGE(0x830000, 0x83002f) AM_DEVREADWRITE("tc0480scp", tc0480scp_device, ctrl_long_r, ctrl_long_w)  // debugging
 	AM_RANGE(0x900000, 0x90ffff) AM_DEVREADWRITE("tc0100scn", tc0100scn_device, long_r, long_w)    /* piv tilemaps */
 	AM_RANGE(0x920000, 0x92000f) AM_DEVREADWRITE("tc0100scn", tc0100scn_device, ctrl_long_r, ctrl_long_w)
-	AM_RANGE(0xa00000, 0xa0ffff) AM_RAM_WRITE(color_ram_w) AM_SHARE("paletteram") /* palette ram */
+	AM_RANGE(0xa00000, 0xa0ffff) AM_RAM_DEVWRITE("palette", palette_device, write) AM_SHARE("palette")
 	AM_RANGE(0xb00000, 0xb003ff) AM_RAM                     // ?? single bytes, blending ??
 	AM_RANGE(0xc00000, 0xc00007) AM_READNOP /* Network? */
 	AM_RANGE(0xd00000, 0xd00003) AM_WRITE(rotate_control_w) /* perhaps port based rotate control? */
@@ -324,25 +301,6 @@ GFXDECODE_END
                  MACHINE DRIVERS
 ***********************************************************/
 
-static const tc0100scn_interface groundfx_tc0100scn_intf =
-{
-	2, 3,       /* gfxnum, txnum */
-	50, 8,      /* x_offset, y_offset */
-	0, 0,       /* flip_xoff, flip_yoff */
-	0, 0,       /* flip_text_xoff, flip_text_yoff */
-	0, 0
-};
-
-static const tc0480scp_interface groundfx_tc0480scp_intf =
-{
-	1, 4,       /* gfxnum, txnum */
-	0,      /* pixels */
-	0x24, 0,        /* x_offset, y_offset */
-	-1, 0,      /* text_xoff, text_yoff */
-	0, 0,       /* flip_xoff, flip_yoff */
-	0       /* col_base */
-};
-
 INTERRUPT_GEN_MEMBER(groundfx_state::groundfx_interrupt)
 {
 	m_frame_counter^=1;
@@ -365,13 +323,26 @@ static MACHINE_CONFIG_START( groundfx, groundfx_state )
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0, 40*8-1, 3*8, 32*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(groundfx_state, screen_update_groundfx)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(groundfx)
-	MCFG_PALETTE_LENGTH(16384)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", groundfx)
+	MCFG_PALETTE_ADD("palette", 16384)
+	MCFG_PALETTE_FORMAT(XRGB)
 
+	MCFG_DEVICE_ADD("tc0100scn", TC0100SCN, 0)
+	MCFG_TC0100SCN_GFX_REGION(2)
+	MCFG_TC0100SCN_TX_REGION(3)
+	MCFG_TC0100SCN_OFFSETS(50, 8)
+	MCFG_TC0100SCN_GFXDECODE("gfxdecode")
+	MCFG_TC0100SCN_PALETTE("palette")
 
-	MCFG_TC0100SCN_ADD("tc0100scn", groundfx_tc0100scn_intf)
-	MCFG_TC0480SCP_ADD("tc0480scp", groundfx_tc0480scp_intf)
+	MCFG_DEVICE_ADD("tc0480scp", TC0480SCP, 0)
+	MCFG_TC0480SCP_GFX_REGION(1)
+	MCFG_TC0480SCP_TX_REGION(4)
+	MCFG_TC0480SCP_OFFSETS(0x24, 0)
+	MCFG_TC0480SCP_OFFSETS_TX(-1, 0)
+	MCFG_TC0480SCP_GFXDECODE("gfxdecode")
+	MCFG_TC0480SCP_PALETTE("palette")
 
 	/* sound hardware */
 	MCFG_FRAGMENT_ADD(taito_en_sound)
