@@ -75,10 +75,10 @@ WRITE32_MEMBER(gunbustr_state::gunbustr_palette_w)
 	COMBINE_DATA(&m_generic_paletteram_32[offset]);
 
 	a = m_generic_paletteram_32[offset] >> 16;
-	palette_set_color_rgb(machine(),offset*2,pal5bit(a >> 10),pal5bit(a >> 5),pal5bit(a >> 0));
+	m_palette->set_pen_color(offset*2,pal5bit(a >> 10),pal5bit(a >> 5),pal5bit(a >> 0));
 
 	a = m_generic_paletteram_32[offset] &0xffff;
-	palette_set_color_rgb(machine(),offset*2+1,pal5bit(a >> 10),pal5bit(a >> 5),pal5bit(a >> 0));
+	m_palette->set_pen_color(offset*2+1,pal5bit(a >> 10),pal5bit(a >> 5),pal5bit(a >> 0));
 }
 
 CUSTOM_INPUT_MEMBER(gunbustr_state::coin_word_r)
@@ -284,16 +284,6 @@ GFXDECODE_END
                  MACHINE DRIVERS
 ***********************************************************/
 
-static const tc0480scp_interface gunbustr_tc0480scp_intf =
-{
-	1, 2,           /* gfxnum, txnum */
-	0,              /* pixels */
-	0x20, 0x07,     /* x_offset, y_offset */
-	-1, -1,         /* text_xoff, text_yoff */
-	-1, 0,          /* flip_xoff, flip_yoff */
-	0               /* col_base */
-};
-
 static MACHINE_CONFIG_START( gunbustr, gunbustr_state )
 
 	/* basic machine hardware */
@@ -310,12 +300,19 @@ static MACHINE_CONFIG_START( gunbustr, gunbustr_state )
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0, 40*8-1, 2*8, 32*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(gunbustr_state, screen_update_gunbustr)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(gunbustr)
-	MCFG_PALETTE_LENGTH(8192)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", gunbustr)
+	MCFG_PALETTE_ADD("palette", 8192)
 
-
-	MCFG_TC0480SCP_ADD("tc0480scp", gunbustr_tc0480scp_intf)
+	MCFG_DEVICE_ADD("tc0480scp", TC0480SCP, 0)
+	MCFG_TC0480SCP_GFX_REGION(1)
+	MCFG_TC0480SCP_TX_REGION(2)
+	MCFG_TC0480SCP_OFFSETS(0x20, 0x07)
+	MCFG_TC0480SCP_OFFSETS_TX(-1, -1)
+	MCFG_TC0480SCP_OFFSETS_FLIP(-1, 0)
+	MCFG_TC0480SCP_GFXDECODE("gfxdecode")
+	MCFG_TC0480SCP_PALETTE("palette")
 
 	/* sound hardware */
 	MCFG_FRAGMENT_ADD(taito_en_sound)
