@@ -49,7 +49,7 @@ static ADDRESS_MAP_START( hcastle_map, AS_PROGRAM, 8, hcastle_state )
 	AM_RANGE(0x0414, 0x0414) AM_READ_PORT("DSW1")
 	AM_RANGE(0x0415, 0x0415) AM_READ_PORT("DSW2")
 	AM_RANGE(0x0418, 0x0418) AM_READWRITE(hcastle_gfxbank_r, hcastle_gfxbank_w)
-	AM_RANGE(0x0600, 0x06ff) AM_RAM AM_SHARE("paletteram")
+	AM_RANGE(0x0600, 0x06ff) AM_RAM_DEVWRITE("palette", palette_device, write_indirect) AM_SHARE("palette")
 	AM_RANGE(0x0700, 0x1fff) AM_RAM
 	AM_RANGE(0x2000, 0x2fff) AM_RAM_WRITE(hcastle_pf1_video_w) AM_SHARE("pf1_videoram")
 	AM_RANGE(0x3000, 0x3fff) AM_RAM AM_SHARE("spriteram")
@@ -154,8 +154,7 @@ GFXDECODE_END
 
 WRITE_LINE_MEMBER(hcastle_state::irqhandler)
 {
-//  hcastle_state *state = device->machine().driver_data<hcastle_state>();
-//  state->m_audiocpu->set_input_line(linestate);
+//  m_audiocpu->set_input_line(state);
 }
 
 WRITE8_MEMBER(hcastle_state::volume_callback)
@@ -164,11 +163,6 @@ WRITE8_MEMBER(hcastle_state::volume_callback)
 	m_k007232->set_volume(1, 0, (data & 0x0f) * 0x11);
 }
 
-static const k007232_interface k007232_config =
-{
-	DEVCB_DRIVER_MEMBER(hcastle_state,volume_callback) /* external port callback */
-};
-
 void hcastle_state::machine_start()
 {
 	UINT8 *ROM = memregion("maincpu")->base();
@@ -212,19 +206,25 @@ static MACHINE_CONFIG_START( hcastle, hcastle_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(hcastle_state, screen_update_hcastle)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(hcastle)
-	MCFG_PALETTE_LENGTH(2*8*16*16)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", hcastle)
+	MCFG_PALETTE_ADD("palette", 2*8*16*16)
+	MCFG_PALETTE_INDIRECT_ENTRIES(128)
+	MCFG_PALETTE_FORMAT(xBBBBBGGGGGRRRRR)
+	MCFG_PALETTE_INIT_OWNER(hcastle_state, hcastle)
 
 
 	MCFG_K007121_ADD("k007121_1")
+	MCFG_K007121_PALETTE("palette")
 	MCFG_K007121_ADD("k007121_2")
+	MCFG_K007121_PALETTE("palette")
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("k007232", K007232, 3579545)
-	MCFG_SOUND_CONFIG(k007232_config)
+	MCFG_K007232_PORT_WRITE_HANDLER(WRITE8(hcastle_state, volume_callback))
 	MCFG_SOUND_ROUTE(0, "mono", 0.44)
 	MCFG_SOUND_ROUTE(1, "mono", 0.50)
 
