@@ -341,7 +341,15 @@ public:
 		m_eeprom(*this, "eeprom"),
 		m_k037122_1(*this, "k037122_1"),
 		m_k037122_2(*this, "k037122_2" ),
-		m_adc12138(*this, "adc12138") { }
+		m_adc12138(*this, "adc12138"),
+		m_in0(*this, "IN0"),
+		m_in1(*this, "IN1"),
+		m_in2(*this, "IN2"),
+		m_dsw(*this, "DSW"),
+		m_eepromout(*this, "EEPROMOUT"),
+		m_analog1(*this, "ANALOG1"),
+		m_analog2(*this, "ANALOG2"),
+		m_konppc(*this, "konppc"){ }
 
 	// TODO: Needs verification on real hardware
 	static const int m_sound_timer_usec = 2800;
@@ -349,7 +357,7 @@ public:
 	required_shared_ptr<UINT32> m_workram;
 	required_shared_ptr<UINT32> m_sharc_dataram0;
 	optional_shared_ptr<UINT32> m_sharc_dataram1;
-	required_device<cpu_device> m_maincpu;
+	required_device<ppc4xx_device> m_maincpu;
 	required_device<cpu_device> m_audiocpu;
 	required_device<k056800_device> m_k056800;
 	optional_device<cpu_device> m_gn680;
@@ -359,6 +367,9 @@ public:
 	optional_device<k037122_device> m_k037122_1;
 	optional_device<k037122_device> m_k037122_2;
 	required_device<adc12138_device> m_adc12138;
+	required_ioport m_in0, m_in1, m_in2, m_dsw, m_eepromout;
+	optional_ioport m_analog1, m_analog2;
+	required_device<konppc_device> m_konppc;
 
 	emu_timer *m_sound_irq_timer;
 	UINT8 m_led_reg0;
@@ -393,6 +404,7 @@ public:
 	DECLARE_WRITE_LINE_MEMBER(voodoo_vblank_1);
 	DECLARE_WRITE16_MEMBER(soundtimer_en_w);
 	DECLARE_WRITE16_MEMBER(soundtimer_count_w);
+	ADC12138_IPT_CONVERT_CB(adc12138_input_callback);
 
 	DECLARE_DRIVER_INIT(hornet);
 	DECLARE_DRIVER_INIT(hornet_2board);
@@ -412,38 +424,38 @@ public:
 
 READ32_MEMBER(hornet_state::hornet_k037122_sram_r)
 {
-	k037122_device *k037122 = get_cgboard_id() ? m_k037122_2 : m_k037122_1;
+	k037122_device *k037122 = m_konppc->get_cgboard_id() ? m_k037122_2 : m_k037122_1;
 	return k037122->sram_r(space, offset, mem_mask);
 }
 
 WRITE32_MEMBER(hornet_state::hornet_k037122_sram_w)
 {
-	k037122_device *k037122 = get_cgboard_id() ? m_k037122_2 : m_k037122_1;
+	k037122_device *k037122 = m_konppc->get_cgboard_id() ? m_k037122_2 : m_k037122_1;
 	k037122->sram_w(space, offset, data, mem_mask);
 }
 
 
 READ32_MEMBER(hornet_state::hornet_k037122_char_r)
 {
-	k037122_device *k037122 = get_cgboard_id() ? m_k037122_2 : m_k037122_1;
+	k037122_device *k037122 = m_konppc->get_cgboard_id() ? m_k037122_2 : m_k037122_1;
 	return k037122->char_r(space, offset, mem_mask);
 }
 
 WRITE32_MEMBER(hornet_state::hornet_k037122_char_w)
 {
-	k037122_device *k037122 = get_cgboard_id() ? m_k037122_2 : m_k037122_1;
+	k037122_device *k037122 = m_konppc->get_cgboard_id() ? m_k037122_2 : m_k037122_1;
 	k037122->char_w(space, offset, data, mem_mask);
 }
 
 READ32_MEMBER(hornet_state::hornet_k037122_reg_r)
 {
-	k037122_device *k037122 = get_cgboard_id() ? m_k037122_2 : m_k037122_1;
+	k037122_device *k037122 = m_konppc->get_cgboard_id() ? m_k037122_2 : m_k037122_1;
 	return k037122->reg_r(space, offset, mem_mask);
 }
 
 WRITE32_MEMBER(hornet_state::hornet_k037122_reg_w)
 {
-	k037122_device *k037122 = get_cgboard_id() ? m_k037122_2 : m_k037122_1;
+	k037122_device *k037122 = m_konppc->get_cgboard_id() ? m_k037122_2 : m_k037122_1;
 	k037122->reg_w(space, offset, data, mem_mask);
 }
 
@@ -498,13 +510,17 @@ UINT32 hornet_state::screen_update_hornet_2board(screen_device &screen, bitmap_r
 READ8_MEMBER(hornet_state::sysreg_r)
 {
 	UINT8 r = 0;
-	static const char *const portnames[] = { "IN0", "IN1", "IN2" };
+
 	switch (offset)
 	{
 		case 0: /* I/O port 0 */
+			r = m_in0->read();
+			break;
 		case 1: /* I/O port 1 */
+			r = m_in1->read();
+			break;
 		case 2: /* I/O port 2 */
-			r = ioport(portnames[offset])->read();
+			r = m_in2->read();
 			break;
 
 		case 3: /* I/O port 3 */
@@ -522,7 +538,7 @@ READ8_MEMBER(hornet_state::sysreg_r)
 			break;
 
 		case 4: /* I/O port 4 - DIP switches */
-			r = ioport("DSW")->read();
+			r = m_dsw->read();
 			break;
 	}
 	return r;
@@ -541,7 +557,7 @@ WRITE8_MEMBER(hornet_state::sysreg_w)
 			break;
 
 		case 2: /* Parallel data register */
-			mame_printf_debug("Parallel data = %02X\n", data);
+			osd_printf_debug("Parallel data = %02X\n", data);
 			break;
 
 		case 3: /* System Register 0 */
@@ -555,8 +571,8 @@ WRITE8_MEMBER(hornet_state::sysreg_w)
 			    0x02 = LAMP1
 			    0x01 = LAMP0
 			*/
-			ioport("EEPROMOUT")->write(data, 0xff);
-			mame_printf_debug("System register 0 = %02X\n", data);
+			m_eepromout->write(data, 0xff);
+			osd_printf_debug("System register 0 = %02X\n", data);
 			break;
 
 		case 4: /* System Register 1 */
@@ -576,7 +592,7 @@ WRITE8_MEMBER(hornet_state::sysreg_w)
 			m_adc12138->sclk_w(space, 0, data & 0x1);
 
 			m_audiocpu->set_input_line(INPUT_LINE_RESET, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
-			mame_printf_debug("System register 1 = %02X\n", data);
+			osd_printf_debug("System register 1 = %02X\n", data);
 			break;
 
 		case 5: /* Sound Control Register */
@@ -590,7 +606,7 @@ WRITE8_MEMBER(hornet_state::sysreg_w)
 			    0x02 = DEEN0
 			    0x01 = ATCK0
 			*/
-			mame_printf_debug("Sound control register = %02X\n", data);
+			osd_printf_debug("Sound control register = %02X\n", data);
 			break;
 
 		case 6: /* WDT Register */
@@ -613,7 +629,7 @@ WRITE8_MEMBER(hornet_state::sysreg_w)
 				m_maincpu->set_input_line(INPUT_LINE_IRQ1, CLEAR_LINE);
 			if (data & 0x40)
 				m_maincpu->set_input_line(INPUT_LINE_IRQ0, CLEAR_LINE);
-			set_cgboard_id((data >> 4) & 3);
+			m_konppc->set_cgboard_id((data >> 4) & 3);
 			break;
 	}
 }
@@ -692,8 +708,8 @@ static ADDRESS_MAP_START( hornet_map, AS_PROGRAM, 32, hornet_state )
 	AM_RANGE(0x74020000, 0x7403ffff) AM_READWRITE(hornet_k037122_sram_r, hornet_k037122_sram_w)
 	AM_RANGE(0x74040000, 0x7407ffff) AM_READWRITE(hornet_k037122_char_r, hornet_k037122_char_w)
 	AM_RANGE(0x74080000, 0x7408000f) AM_READWRITE(gun_r, gun_w)
-	AM_RANGE(0x78000000, 0x7800ffff) AM_READWRITE_LEGACY(cgboard_dsp_shared_r_ppc, cgboard_dsp_shared_w_ppc)
-	AM_RANGE(0x780c0000, 0x780c0003) AM_READWRITE_LEGACY(cgboard_dsp_comm_r_ppc, cgboard_dsp_comm_w_ppc)
+	AM_RANGE(0x78000000, 0x7800ffff) AM_DEVREADWRITE("konppc", konppc_device, cgboard_dsp_shared_r_ppc, cgboard_dsp_shared_w_ppc)
+	AM_RANGE(0x780c0000, 0x780c0003) AM_DEVREADWRITE("konppc", konppc_device, cgboard_dsp_comm_r_ppc, cgboard_dsp_comm_w_ppc)
 	AM_RANGE(0x7d000000, 0x7d00ffff) AM_READ8(sysreg_r, 0xffffffff)
 	AM_RANGE(0x7d010000, 0x7d01ffff) AM_WRITE8(sysreg_w, 0xffffffff)
 	AM_RANGE(0x7d020000, 0x7d021fff) AM_DEVREADWRITE8("m48t58", timekeeper_device, read, write, 0xffffffff)  /* M48T58Y RTC/NVRAM */
@@ -783,22 +799,22 @@ WRITE32_MEMBER(hornet_state::dsp_dataram1_w)
 }
 
 static ADDRESS_MAP_START( sharc0_map, AS_DATA, 32, hornet_state )
-	AM_RANGE(0x0400000, 0x041ffff) AM_READWRITE_LEGACY(cgboard_0_shared_sharc_r, cgboard_0_shared_sharc_w)
+	AM_RANGE(0x0400000, 0x041ffff) AM_DEVREADWRITE("konppc", konppc_device, cgboard_0_shared_sharc_r, cgboard_0_shared_sharc_w)
 	AM_RANGE(0x0500000, 0x05fffff) AM_READWRITE(dsp_dataram0_r, dsp_dataram0_w) AM_SHARE("sharc_dataram0")
 	AM_RANGE(0x1400000, 0x14fffff) AM_RAM
-	AM_RANGE(0x2400000, 0x27fffff) AM_DEVREADWRITE_LEGACY("voodoo0", voodoo_r, voodoo_w)
-	AM_RANGE(0x3400000, 0x34000ff) AM_READWRITE_LEGACY(cgboard_0_comm_sharc_r, cgboard_0_comm_sharc_w)
-	AM_RANGE(0x3500000, 0x35000ff) AM_READWRITE_LEGACY(K033906_0_r, K033906_0_w)
+	AM_RANGE(0x2400000, 0x27fffff) AM_DEVREADWRITE("voodoo0", voodoo_device, voodoo_r, voodoo_w)
+	AM_RANGE(0x3400000, 0x34000ff) AM_DEVREADWRITE("konppc", konppc_device, cgboard_0_comm_sharc_r, cgboard_0_comm_sharc_w)
+	AM_RANGE(0x3500000, 0x35000ff) AM_DEVREADWRITE("konppc", konppc_device, K033906_0_r, K033906_0_w)
 	AM_RANGE(0x3600000, 0x37fffff) AM_ROMBANK("bank5")
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sharc1_map, AS_DATA, 32, hornet_state )
-	AM_RANGE(0x0400000, 0x041ffff) AM_READWRITE_LEGACY(cgboard_1_shared_sharc_r, cgboard_1_shared_sharc_w)
+	AM_RANGE(0x0400000, 0x041ffff) AM_DEVREADWRITE("konppc", konppc_device, cgboard_1_shared_sharc_r, cgboard_1_shared_sharc_w)
 	AM_RANGE(0x0500000, 0x05fffff) AM_READWRITE(dsp_dataram1_r, dsp_dataram1_w) AM_SHARE("sharc_dataram1")
 	AM_RANGE(0x1400000, 0x14fffff) AM_RAM
-	AM_RANGE(0x2400000, 0x27fffff) AM_DEVREADWRITE_LEGACY("voodoo1", voodoo_r, voodoo_w)
-	AM_RANGE(0x3400000, 0x34000ff) AM_READWRITE_LEGACY(cgboard_1_comm_sharc_r, cgboard_1_comm_sharc_w)
-	AM_RANGE(0x3500000, 0x35000ff) AM_READWRITE_LEGACY(K033906_1_r, K033906_1_w)
+	AM_RANGE(0x2400000, 0x27fffff) AM_DEVREADWRITE("voodoo1", voodoo_device, voodoo_r, voodoo_w)
+	AM_RANGE(0x3400000, 0x34000ff) AM_DEVREADWRITE("konppc", konppc_device, cgboard_1_comm_sharc_r, cgboard_1_comm_sharc_w)
+	AM_RANGE(0x3500000, 0x35000ff) AM_DEVREADWRITE("konppc", konppc_device, K033906_1_r, K033906_1_w)
 	AM_RANGE(0x3600000, 0x37fffff) AM_ROMBANK("bank6")
 ADDRESS_MAP_END
 
@@ -885,10 +901,6 @@ static INPUT_PORTS_START( sscope )
 	PORT_BIT( 0x7ff, 0x3ff, IPT_AD_STICK_Y ) PORT_MINMAX(0x000, 0x7ff) PORT_SENSITIVITY(35) PORT_KEYDELTA(5) PORT_INVERT
 INPUT_PORTS_END
 
-static const sharc_config sharc_cfg =
-{
-	BOOT_MODE_EPROM
-};
 
 /* PowerPC interrupts
 
@@ -907,10 +919,10 @@ void hornet_state::machine_start()
 	m_jvs_sdata = auto_alloc_array_clear(machine(), UINT8, 1024);
 
 	/* set conservative DRC options */
-	ppcdrc_set_options(m_maincpu, PPCDRC_COMPATIBLE_OPTIONS);
+	m_maincpu->ppcdrc_set_options(PPCDRC_COMPATIBLE_OPTIONS);
 
 	/* configure fast RAM regions for DRC */
-	ppcdrc_add_fastram(m_maincpu, 0x00000000, 0x003fffff, FALSE, m_workram);
+	m_maincpu->ppcdrc_add_fastram(0x00000000, 0x003fffff, FALSE, m_workram);
 
 	save_item(NAME(m_led_reg0));
 	save_item(NAME(m_led_reg1));
@@ -936,43 +948,18 @@ void hornet_state::machine_reset()
 		membank("bank5")->set_base(usr5);
 }
 
-static double adc12138_input_callback( device_t *device, UINT8 input )
+ADC12138_IPT_CONVERT_CB(hornet_state::adc12138_input_callback)
 {
 	int value = 0;
 	switch (input)
 	{
-		case 0: value = device->machine().root_device().ioport("ANALOG1")->read(); break;
-		case 1: value = device->machine().root_device().ioport("ANALOG2")->read(); break;
+		case 0: value = (m_analog1) ? m_analog1->read() : 0; break;
+		case 1: value = (m_analog2) ? m_analog2->read() : 0; break;
 	}
 
 	return (double)(value) / 2047.0;
 }
 
-static const adc12138_interface hornet_adc_interface = {
-	adc12138_input_callback
-};
-
-static const k033906_interface hornet_k033906_intf_0 =
-{
-	"voodoo0"
-};
-
-static const k033906_interface hornet_k033906_intf_1 =
-{
-	"voodoo1"
-};
-
-static const voodoo_config hornet_voodoo_intf =
-{
-	2, //               fbmem;
-	4,//                tmumem0;
-	0,//                tmumem1;
-	"screen",//         screen;
-	"dsp",//            cputag;
-	DEVCB_DRIVER_LINE_MEMBER(hornet_state,voodoo_vblank_0),//  vblank;
-	DEVCB_NULL//             stall;
-};
-
 static MACHINE_CONFIG_START( hornet, hornet_state )
 
 	/* basic machine hardware */
@@ -984,7 +971,7 @@ static MACHINE_CONFIG_START( hornet, hornet_state )
 	MCFG_CPU_PROGRAM_MAP(sound_memmap)
 
 	MCFG_CPU_ADD("dsp", ADSP21062, XTAL_36MHz)
-	MCFG_CPU_CONFIG(sharc_cfg)
+	MCFG_SHARC_BOOT_MODE(BOOT_MODE_EPROM)
 	MCFG_CPU_DATA_MAP(sharc0_map)
 
 	MCFG_QUANTUM_TIME(attotime::from_hz(6000))
@@ -992,9 +979,15 @@ static MACHINE_CONFIG_START( hornet, hornet_state )
 
 	MCFG_EEPROM_SERIAL_93C46_ADD("eeprom")
 
-	MCFG_3DFX_VOODOO_1_ADD("voodoo0", STD_VOODOO_1_CLOCK, hornet_voodoo_intf)
+	MCFG_DEVICE_ADD("voodoo0", VOODOO_1, STD_VOODOO_1_CLOCK)
+	MCFG_VOODOO_FBMEM(2)
+	MCFG_VOODOO_TMUMEM(4,0)
+	MCFG_VOODOO_SCREEN_TAG("screen")
+	MCFG_VOODOO_CPU_TAG("dsp")
+	MCFG_VOODOO_VBLANK_CB(WRITELINE(hornet_state,voodoo_vblank_0))
 
-	MCFG_K033906_ADD("k033906_1", hornet_k033906_intf_0)
+	MCFG_DEVICE_ADD("k033906_1", K033906, 0)
+	MCFG_K033906_VOODOO("voodoo0")
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
@@ -1003,9 +996,13 @@ static MACHINE_CONFIG_START( hornet, hornet_state )
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 48*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(hornet_state, screen_update_hornet)
 
-	MCFG_PALETTE_LENGTH(65536)
+	MCFG_PALETTE_ADD("palette", 65536)
+
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", empty)
 
 	MCFG_K037122_ADD("k037122_1", "screen", 0)
+	MCFG_K037122_GFXDECODE("gfxdecode")
+	MCFG_K037122_PALETTE("palette")
 
 	MCFG_K056800_ADD("k056800", XTAL_16_9344MHz)
 	MCFG_K056800_INT_HANDLER(INPUTLINE("audiocpu", M68K_IRQ_2))
@@ -1018,7 +1015,12 @@ static MACHINE_CONFIG_START( hornet, hornet_state )
 
 	MCFG_M48T58_ADD( "m48t58" )
 
-	MCFG_ADC12138_ADD( "adc12138", hornet_adc_interface )
+	MCFG_DEVICE_ADD("adc12138", ADC12138, 0)
+	MCFG_ADC1213X_IPT_CONVERT_CB(hornet_state, adc12138_input_callback)
+
+	MCFG_DEVICE_ADD("konppc", KONPPC, 0)
+	MCFG_KONPPC_CGBOARD_NUMBER(1)
+	MCFG_KONPPC_CGBOARD_TYPE(CGBOARD_TYPE_HORNET)
 MACHINE_CONFIG_END
 
 
@@ -1042,32 +1044,10 @@ MACHINE_RESET_MEMBER(hornet_state,hornet_2board)
 	}
 }
 
-static const voodoo_config voodoo_l_intf =
-{
-	2, //               fbmem;
-	4,//                tmumem0;
-	0,//                tmumem1;
-	"lscreen",//        screen;
-	"dsp",//            cputag;
-	DEVCB_DRIVER_LINE_MEMBER(hornet_state,voodoo_vblank_0),//  vblank;
-	DEVCB_NULL//             stall;
-};
-
-static const voodoo_config voodoo_r_intf =
-{
-	2, //               fbmem;
-	4,//                tmumem0;
-	0,//                tmumem1;
-	"rscreen",//        screen;
-	"dsp2",//           cputag;
-	DEVCB_DRIVER_LINE_MEMBER(hornet_state,voodoo_vblank_1),//  vblank;
-	DEVCB_NULL//             stall;
-};
-
 static MACHINE_CONFIG_DERIVED( hornet_2board, hornet )
 
 	MCFG_CPU_ADD("dsp2", ADSP21062, XTAL_36MHz)
-	MCFG_CPU_CONFIG(sharc_cfg)
+	MCFG_SHARC_BOOT_MODE(BOOT_MODE_EPROM)
 	MCFG_CPU_DATA_MAP(sharc1_map)
 
 	MCFG_MACHINE_RESET_OVERRIDE(hornet_state,hornet_2board)
@@ -1075,16 +1055,35 @@ static MACHINE_CONFIG_DERIVED( hornet_2board, hornet )
 
 	MCFG_DEVICE_REMOVE("k037122_1")
 	MCFG_K037122_ADD("k037122_1", "lscreen", 0)
+	MCFG_K037122_GFXDECODE("gfxdecode")
+	MCFG_K037122_PALETTE("palette")
+
 	MCFG_K037122_ADD("k037122_2", "rscreen", 1)
+	MCFG_K037122_GFXDECODE("gfxdecode")
+	MCFG_K037122_PALETTE("palette")
 
 	MCFG_DEVICE_REMOVE("voodoo0")
-	MCFG_3DFX_VOODOO_1_ADD("voodoo0", STD_VOODOO_1_CLOCK, voodoo_l_intf)
-	MCFG_3DFX_VOODOO_1_ADD("voodoo1", STD_VOODOO_1_CLOCK, voodoo_r_intf)
 
-	MCFG_K033906_ADD("k033906_2", hornet_k033906_intf_1)
+	MCFG_DEVICE_ADD("voodoo0", VOODOO_1, STD_VOODOO_1_CLOCK)
+	MCFG_VOODOO_FBMEM(2)
+	MCFG_VOODOO_TMUMEM(4,0)
+	MCFG_VOODOO_SCREEN_TAG("lscreen")
+	MCFG_VOODOO_CPU_TAG("dsp")
+	MCFG_VOODOO_VBLANK_CB(WRITELINE(hornet_state,voodoo_vblank_0))
+
+	MCFG_DEVICE_ADD("voodoo1", VOODOO_1, STD_VOODOO_1_CLOCK)
+	MCFG_VOODOO_FBMEM(2)
+	MCFG_VOODOO_TMUMEM(4,0)
+	MCFG_VOODOO_SCREEN_TAG("rscreen")
+	MCFG_VOODOO_CPU_TAG("dsp2")
+	MCFG_VOODOO_VBLANK_CB(WRITELINE(hornet_state,voodoo_vblank_1))
+
+	MCFG_DEVICE_ADD("k033906_2", K033906, 0)
+	MCFG_K033906_VOODOO("voodoo1")
 
 	/* video hardware */
-	MCFG_PALETTE_LENGTH(65536)
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_ENTRIES(65536)
 
 	MCFG_DEVICE_REMOVE("screen")
 
@@ -1099,6 +1098,11 @@ static MACHINE_CONFIG_DERIVED( hornet_2board, hornet )
 	MCFG_SCREEN_SIZE(512, 384)
 	MCFG_SCREEN_VISIBLE_AREA(0, 511, 0, 383)
 	MCFG_SCREEN_UPDATE_DRIVER(hornet_state, screen_update_hornet_2board)
+
+	MCFG_DEVICE_REMOVE("konppc")
+	MCFG_DEVICE_ADD("konppc", KONPPC, 0)
+	MCFG_KONPPC_CGBOARD_NUMBER(2)
+	MCFG_KONPPC_CGBOARD_TYPE(CGBOARD_TYPE_HORNET)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( terabrst, hornet_2board )
@@ -1108,12 +1112,21 @@ static MACHINE_CONFIG_DERIVED( terabrst, hornet_2board )
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( hornet_2board_v2, hornet_2board )
-
 	MCFG_DEVICE_REMOVE("voodoo0")
-	MCFG_3DFX_VOODOO_2_ADD("voodoo0", STD_VOODOO_2_CLOCK, voodoo_l_intf)
+	MCFG_DEVICE_ADD("voodoo0", VOODOO_2, STD_VOODOO_2_CLOCK)
+	MCFG_VOODOO_FBMEM(2)
+	MCFG_VOODOO_TMUMEM(4,0)
+	MCFG_VOODOO_SCREEN_TAG("lscreen")
+	MCFG_VOODOO_CPU_TAG("dsp")
+	MCFG_VOODOO_VBLANK_CB(WRITELINE(hornet_state,voodoo_vblank_0))
 
 	MCFG_DEVICE_REMOVE("voodoo1")
-	MCFG_3DFX_VOODOO_2_ADD("voodoo1", STD_VOODOO_2_CLOCK, voodoo_r_intf)
+	MCFG_DEVICE_ADD("voodoo1", VOODOO_2, STD_VOODOO_2_CLOCK)
+	MCFG_VOODOO_FBMEM(2)
+	MCFG_VOODOO_TMUMEM(4,0)
+	MCFG_VOODOO_SCREEN_TAG("rscreen")
+	MCFG_VOODOO_CPU_TAG("dsp2")
+	MCFG_VOODOO_VBLANK_CB(WRITELINE(hornet_state,voodoo_vblank_1))
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( sscope2, hornet_2board_v2)
@@ -1148,19 +1161,19 @@ int hornet_state::jvs_encode_data(UINT8 *in, int length)
 		if (b == 0xe0)
 		{
 			sum += 0xd0 + 0xdf;
-			ppc4xx_spu_receive_byte(m_maincpu, 0xd0);
-			ppc4xx_spu_receive_byte(m_maincpu, 0xdf);
+			m_maincpu->ppc4xx_spu_receive_byte(0xd0);
+			m_maincpu->ppc4xx_spu_receive_byte(0xdf);
 		}
 		else if (b == 0xd0)
 		{
 			sum += 0xd0 + 0xcf;
-			ppc4xx_spu_receive_byte(m_maincpu, 0xd0);
-			ppc4xx_spu_receive_byte(m_maincpu, 0xcf);
+			m_maincpu->ppc4xx_spu_receive_byte(0xd0);
+			m_maincpu->ppc4xx_spu_receive_byte(0xcf);
 		}
 		else
 		{
 			sum += b;
-			ppc4xx_spu_receive_byte(m_maincpu, b);
+			m_maincpu->ppc4xx_spu_receive_byte(b);
 		}
 	}
 	return sum;
@@ -1253,11 +1266,11 @@ void hornet_state::jamma_jvs_cmd_exec()
 
 	// write jvs return data
 	sum = 0x00 + (rdata_ptr+1);
-	ppc4xx_spu_receive_byte(m_maincpu, 0xe0);           // sync
-	ppc4xx_spu_receive_byte(m_maincpu, 0x00);           // node
-	ppc4xx_spu_receive_byte(m_maincpu, rdata_ptr + 1);  // num of bytes
+	m_maincpu->ppc4xx_spu_receive_byte(0xe0);           // sync
+	m_maincpu->ppc4xx_spu_receive_byte(0x00);           // node
+	m_maincpu->ppc4xx_spu_receive_byte(rdata_ptr + 1);  // num of bytes
 	sum += jvs_encode_data(rdata, rdata_ptr);
-	ppc4xx_spu_receive_byte(m_maincpu, sum - 1);        // checksum
+	m_maincpu->ppc4xx_spu_receive_byte(sum - 1);        // checksum
 
 	m_jvs_sdata_ptr = 0;
 }
@@ -1267,23 +1280,19 @@ void hornet_state::jamma_jvs_cmd_exec()
 
 DRIVER_INIT_MEMBER(hornet_state,hornet)
 {
-	init_konami_cgboard(machine(), 1, CGBOARD_TYPE_HORNET);
-	set_cgboard_texture_bank(machine(), 0, "bank5", memregion("user5")->base());
-
+	m_konppc->set_cgboard_texture_bank(0, "bank5", memregion("user5")->base());
 	m_led_reg0 = m_led_reg1 = 0x7f;
 
-	ppc4xx_spu_set_tx_handler(m_maincpu, jamma_jvs_w);
+	m_maincpu->ppc4xx_spu_set_tx_handler(jamma_jvs_w);
 }
 
 DRIVER_INIT_MEMBER(hornet_state,hornet_2board)
 {
-	init_konami_cgboard(machine(), 2, CGBOARD_TYPE_HORNET);
-	set_cgboard_texture_bank(machine(), 0, "bank5", memregion("user5")->base());
-	set_cgboard_texture_bank(machine(), 1, "bank6", memregion("user5")->base());
-
+	m_konppc->set_cgboard_texture_bank(0, "bank5", memregion("user5")->base());
+	m_konppc->set_cgboard_texture_bank(1, "bank6", memregion("user5")->base());
 	m_led_reg0 = m_led_reg1 = 0x7f;
 
-	ppc4xx_spu_set_tx_handler(m_maincpu, jamma_jvs_w);
+	m_maincpu->ppc4xx_spu_set_tx_handler(jamma_jvs_w);
 }
 
 /*****************************************************************************/
