@@ -82,7 +82,6 @@ Stephh's notes (based on the games M68000 code and some tests) :
 #include "sound/2203intf.h"
 #include "sound/3526intf.h"
 #include "includes/karnov.h"
-#include "video/deckarn.h"
 
 /*************************************
  *
@@ -802,12 +801,16 @@ static MACHINE_CONFIG_START( karnov, karnov_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(karnov_state, screen_update_karnov)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(karnov)
-	MCFG_PALETTE_LENGTH(1024)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", karnov)
+	MCFG_PALETTE_ADD("palette", 1024)
+	MCFG_PALETTE_INIT_OWNER(karnov_state, karnov)
 
 	MCFG_DEVICE_ADD("spritegen", DECO_KARNOVSPRITES, 0)
 	deco_karnovsprites_device::set_gfx_region(*device, 2);
+	MCFG_DECO_KARNOVSPRITES_GFXDECODE("gfxdecode")
+	MCFG_DECO_KARNOVSPRITES_PALETTE("palette")
 
 	MCFG_VIDEO_START_OVERRIDE(karnov_state,karnov)
 
@@ -843,12 +846,16 @@ static MACHINE_CONFIG_START( wndrplnt, karnov_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(karnov_state, screen_update_karnov)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(karnov)
-	MCFG_PALETTE_LENGTH(1024)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", karnov)
+	MCFG_PALETTE_ADD("palette", 1024)
+	MCFG_PALETTE_INIT_OWNER(karnov_state, karnov)
 
 	MCFG_DEVICE_ADD("spritegen", DECO_KARNOVSPRITES, 0)
 	deco_karnovsprites_device::set_gfx_region(*device, 2);
+	MCFG_DECO_KARNOVSPRITES_GFXDECODE("gfxdecode")
+	MCFG_DECO_KARNOVSPRITES_PALETTE("palette")
 
 	MCFG_VIDEO_START_OVERRIDE(karnov_state,wndrplnt)
 
