@@ -77,7 +77,7 @@ UINT32 m79amb_state::screen_update_ramtek(screen_device &screen, bitmap_rgb32 &b
 
 		for (i = 0; i < 8; i++)
 		{
-			pen_t pen = (data & 0x80) ? RGB_WHITE : RGB_BLACK;
+			pen_t pen = (data & 0x80) ? rgb_t::white : rgb_t::black;
 			bitmap.pix32(y, x) = pen;
 
 			x++;
