@@ -322,10 +322,11 @@ static MACHINE_CONFIG_START( matmania, matmania_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(matmania_state, screen_update_matmania)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(matmania)
-	MCFG_PALETTE_LENGTH(64+16)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", matmania)
+	MCFG_PALETTE_ADD("palette", 64+16)
+	MCFG_PALETTE_INIT_OWNER(matmania_state, matmania)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -403,10 +404,11 @@ static MACHINE_CONFIG_START( maniach, matmania_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(matmania_state, screen_update_maniach)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(maniach)
-	MCFG_PALETTE_LENGTH(64+16)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", maniach)
+	MCFG_PALETTE_ADD("palette", 64+16)
+	MCFG_PALETTE_INIT_OWNER(matmania_state, matmania)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
