@@ -18,17 +18,15 @@
 #include "sound/pokey.h"
 #include "machine/6821pia.h"
 #include "video/gtia.h"
-#include "drivlgcy.h"
-#include "scrlegcy.h"
 
 #include "maxaflex.lh"
 
 
-class maxaflex_state : public driver_device
+class maxaflex_state : public atari_common_state
 {
 public:
 	maxaflex_state(const machine_config &mconfig, device_type type, const char *tag)
-		: driver_device(mconfig, type, tag),
+		: atari_common_state(mconfig, type, tag),
 		m_maincpu(*this, "maincpu"),
 		m_mcu(*this, "mcu"),
 		m_speaker(*this, "speaker") { }
@@ -62,10 +60,13 @@ public:
 	DECLARE_INPUT_CHANGED_MEMBER(coin_inserted);
 	DECLARE_READ8_MEMBER(maxaflex_atari_pia_pa_r);
 	DECLARE_READ8_MEMBER(maxaflex_atari_pia_pb_r);
+	WRITE8_MEMBER(a600xl_pia_pb_w) { a600xl_mmu(data); }
+	WRITE_LINE_MEMBER(atari_pia_cb2_w) { }  // This is used by Floppy drive on Atari 8bits Home Computers
 	DECLARE_DRIVER_INIT(a600xl);
 	DECLARE_MACHINE_RESET(supervisor_board);
 	TIMER_DEVICE_CALLBACK_MEMBER(mcu_timer_proc);
 	int atari_input_disabled();
+	virtual void machine_start();
 	required_device<cpu_device> m_maincpu;
 	required_device<cpu_device> m_mcu;
 	required_device<speaker_sound_device> m_speaker;
@@ -284,11 +285,11 @@ static ADDRESS_MAP_START(a600xl_mem, AS_PROGRAM, 8, maxaflex_state )
 	AM_RANGE(0x5000, 0x57ff) AM_ROM AM_REGION("maincpu", 0x5000)    /* self test */
 	AM_RANGE(0x8000, 0xbfff) AM_ROM /* game cartridge */
 	AM_RANGE(0xc000, 0xcfff) AM_ROM /* OS */
-	AM_RANGE(0xd000, 0xd0ff) AM_READWRITE_LEGACY(atari_gtia_r, atari_gtia_w)
+	AM_RANGE(0xd000, 0xd0ff) AM_READWRITE(atari_gtia_r, atari_gtia_w)
 	AM_RANGE(0xd100, 0xd1ff) AM_NOP
 	AM_RANGE(0xd200, 0xd2ff) AM_DEVREADWRITE("pokey", pokey_device, read, write)
 	AM_RANGE(0xd300, 0xd3ff) AM_DEVREADWRITE("pia", pia6821_device, read_alt, write_alt)
-	AM_RANGE(0xd400, 0xd4ff) AM_READWRITE_LEGACY(atari_antic_r, atari_antic_w)
+	AM_RANGE(0xd400, 0xd4ff) AM_READWRITE(atari_antic_r, atari_antic_w)
 	AM_RANGE(0xd500, 0xd7ff) AM_NOP
 	AM_RANGE(0xd800, 0xffff) AM_ROM /* OS */
 ADDRESS_MAP_END
@@ -373,12 +374,6 @@ static INPUT_PORTS_START( a600xl )
 INPUT_PORTS_END
 
 
-static const pokey_interface pokey_config = {
-	{ DEVCB_NULL },
-	DEVCB_NULL,
-	DEVCB_NULL,DEVCB_NULL,
-};
-
 READ8_MEMBER(maxaflex_state::maxaflex_atari_pia_pa_r)
 {
 	return atari_input_disabled() ? 0xFF : ioport("djoy_0_1")->read_safe(0);
@@ -390,34 +385,26 @@ READ8_MEMBER(maxaflex_state::maxaflex_atari_pia_pb_r)
 }
 
 
-const pia6821_interface maxaflex_atarixl_pia_interface =
+void maxaflex_state::machine_start()
 {
-	DEVCB_DRIVER_MEMBER(maxaflex_state,maxaflex_atari_pia_pa_r),        /* port A in */
-	DEVCB_DRIVER_MEMBER(maxaflex_state,maxaflex_atari_pia_pb_r),    /* port B in */
-	DEVCB_NULL,     /* line CA1 in */
-	DEVCB_NULL,     /* line CB1 in */
-	DEVCB_NULL,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_NULL,     /* port A out */
-	DEVCB_HANDLER(a600xl_pia_pb_w),     /* port B out */
-	DEVCB_NULL,     /* line CA2 out */
-	DEVCB_LINE(atari_pia_cb2_w),        /* port CB2 out */
-	DEVCB_NULL,     /* IRQA */
-	DEVCB_NULL      /* IRQB */
-};
-
-
+	atari_machine_start();
+}
 
 static MACHINE_CONFIG_START( a600xl, maxaflex_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6502, FREQ_17_EXACT)
 	MCFG_CPU_PROGRAM_MAP(a600xl_mem)
-	MCFG_TIMER_ADD_SCANLINE("scantimer", a800xl_interrupt, "screen", 0, 1)
+	MCFG_TIMER_DRIVER_ADD_SCANLINE("scantimer", atari_common_state, a800xl_interrupt, "screen", 0, 1)
 
 	MCFG_CPU_ADD("mcu", M68705, 3579545)
 	MCFG_CPU_PROGRAM_MAP(mcu_mem)
 
-	MCFG_PIA6821_ADD("pia", maxaflex_atarixl_pia_interface)
+	MCFG_DEVICE_ADD("pia", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(maxaflex_state, maxaflex_atari_pia_pa_r))
+	MCFG_PIA_READPB_HANDLER(READ8(maxaflex_state, maxaflex_atari_pia_pb_r))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(maxaflex_state, a600xl_pia_pb_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(maxaflex_state, atari_pia_cb2_w))
+
 	MCFG_TIMER_DRIVER_ADD("mcu_timer", maxaflex_state, mcu_timer_proc)
 
 	/* video hardware */
@@ -426,19 +413,17 @@ static MACHINE_CONFIG_START( a600xl, maxaflex_state )
 	MCFG_SCREEN_VISIBLE_AREA(MIN_X, MAX_X, MIN_Y, MAX_Y)
 	MCFG_SCREEN_REFRESH_RATE(FRAME_RATE_60HZ)
 	MCFG_SCREEN_SIZE(HWIDTH*8, TOTAL_LINES_60HZ)
-	MCFG_SCREEN_UPDATE_STATIC(atari)
+	MCFG_SCREEN_UPDATE_DRIVER(atari_common_state, screen_update_atari)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_PALETTE_LENGTH(256)
-	MCFG_PALETTE_INIT(atari)
+	MCFG_PALETTE_ADD("palette", 256)
+	MCFG_PALETTE_INIT_OWNER(atari_common_state, atari)
 	MCFG_DEFAULT_LAYOUT(layout_maxaflex)
 
-	MCFG_VIDEO_START(atari)
-
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MCFG_POKEY_ADD("pokey", FREQ_17_EXACT)
-	MCFG_POKEY_CONFIG(pokey_config)
+	MCFG_SOUND_ADD("pokey", POKEY, FREQ_17_EXACT)
 	MCFG_POKEY_INTERRUPT_HANDLER(atari_interrupt_cb)
 	MCFG_POKEY_OUTPUT_RC(RES_K(1), CAP_U(0.0), 5.0)
 
@@ -446,8 +431,6 @@ static MACHINE_CONFIG_START( a600xl, maxaflex_state )
 
 	MCFG_SOUND_ADD("speaker", SPEAKER_SOUND, 0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-
-	MCFG_MACHINE_START( atarixl )
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( maxaflex, a600xl )
