@@ -136,13 +136,15 @@ public:
 		: driver_device(mconfig, type, tag),
 		m_maincpu(*this, "maincpu"),
 		m_subcpu(*this, "sub"),
-		m_vcu(*this,"vcu")
+		m_vcu(*this,"vcu"),
+		m_screen(*this, "screen")
 		{ }
 
 	/* devices */
 	required_device<cpu_device> m_maincpu;
 	required_device<cpu_device> m_subcpu;
 	required_device<mb_vcu_device> m_vcu;
+	required_device<screen_device> m_screen;
 
 	/* video-related */
 	bitmap_ind16 m_tmpbitmaps[4];
@@ -221,7 +223,7 @@ public:
 	virtual void machine_start();
 	virtual void machine_reset();
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(mazerbla);
 	UINT32 screen_update_mazerbla(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
 	void screen_eof(screen_device &screen, bool state);
 	INTERRUPT_GEN_MEMBER(sound_interrupt);
@@ -251,7 +253,7 @@ public:
 
 ***************************************************************************/
 
-void mazerbla_state::palette_init()
+PALETTE_INIT_MEMBER(mazerbla_state, mazerbla)
 {
 	static const int resistances_r[2]  = { 4700, 2200 };
 	static const int resistances_gb[3] = { 10000, 4700, 2200 };
@@ -328,7 +330,7 @@ WRITE8_MEMBER(mazerbla_state::cfb_backgnd_color_w)
 		bit0 = BIT(data, 0);
 		b = combine_3_weights(m_weights_b, bit0, bit1, bit2);
 
-		palette_set_color(machine(), 255, MAKE_RGB(r, g, b));
+		m_palette->set_pen_color(255, rgb_t(r, g, b));
 		//logerror("background color (port 01) write=%02x\n",data);
 	}
 }
@@ -674,7 +676,7 @@ READ8_MEMBER(mazerbla_state::vcu_set_clr_addr_r)
 						b = combine_3_weights(m_weights_b, bit0, bit1, bit2);
 
 						if ((x + y * 16) < 255)//keep color 255 free for use as background color
-							palette_set_color(machine(), x + y * 16, MAKE_RGB(r, g, b));
+							m_palette->set_pen_color(x + y * 16, rgb_t(r, g, b));
 
 						m_lookup_ram[lookup_offs + x + y * 16] = colour;
 					}
@@ -1344,27 +1346,6 @@ INPUT_PORTS_END
  *
  *************************************/
 
-/* only Great Guns */
-static const ay8910_interface ay8912_interface_1 =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(mazerbla_state,soundcommand_r),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-static const ay8910_interface ay8912_interface_2 =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(mazerbla_state,gg_led_ctrl_w)
-};
-
 IRQ_CALLBACK_MEMBER(mazerbla_state::irq_callback)
 {
 	/* all data lines are tied to +5V via 10K resistors */
@@ -1460,21 +1441,15 @@ void mazerbla_state::machine_reset()
 	}
 
 	memset(m_lookup_ram, 0, ARRAY_LENGTH(m_lookup_ram));
-
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(mazerbla_state::irq_callback),this));
 }
 
-static const mb_vcu_interface vcu_interface =
-{
-	"sub2"
-};
-
 static MACHINE_CONFIG_START( mazerbla, mazerbla_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, MASTER_CLOCK)  /* 4 MHz, no NMI, IM2 - vectors at 0xf8, 0xfa, 0xfc */
 	MCFG_CPU_PROGRAM_MAP(mazerbla_map)
 	MCFG_CPU_IO_MAP(mazerbla_io_map)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(mazerbla_state,irq_callback)
 
 	MCFG_CPU_ADD("sub", Z80, MASTER_CLOCK)  /* 4 MHz, NMI, IM1 INT */
 	MCFG_CPU_PROGRAM_MAP(mazerbla_cpu2_map)
@@ -1491,7 +1466,9 @@ static MACHINE_CONFIG_START( mazerbla, mazerbla_state )
 	MCFG_CPU_VBLANK_INT_DRIVER("screen", mazerbla_state,  irq0_line_hold)
 
 	/* synchronization forced on the fly */
-	MCFG_MB_VCU_ADD("vcu",SOUND_CLOCK/4,vcu_interface)
+	MCFG_DEVICE_ADD("vcu", MB_VCU, SOUND_CLOCK/4)
+	MCFG_MB_VCU_CPU("sub2")
+	MCFG_MB_VCU_PALETTE("palette")
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
@@ -1501,8 +1478,8 @@ static MACHINE_CONFIG_START( mazerbla, mazerbla_state )
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 28*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(mazerbla_state, screen_update_mazerbla)
 
-	MCFG_PALETTE_LENGTH(256+1)
-
+	MCFG_PALETTE_ADD("palette", 256+1)
+	MCFG_PALETTE_INIT_OWNER(mazerbla_state, mazerbla)
 
 	/* sound hardware */
 MACHINE_CONFIG_END
@@ -1514,6 +1491,7 @@ static MACHINE_CONFIG_START( greatgun, mazerbla_state )
 	MCFG_CPU_ADD("maincpu", Z80, MASTER_CLOCK)  /* 4 MHz, no NMI, IM2 - vectors at 0xf8, 0xfa, 0xfc */
 	MCFG_CPU_PROGRAM_MAP(mazerbla_map)
 	MCFG_CPU_IO_MAP(greatgun_io_map)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(mazerbla_state,irq_callback)
 
 	MCFG_CPU_ADD("sub", Z80, SOUND_CLOCK / 4)   /* 3.579500 MHz, NMI - caused by sound command write, periodic INT */
 	MCFG_CPU_PROGRAM_MAP(greatgun_sound_map)
@@ -1528,7 +1506,9 @@ static MACHINE_CONFIG_START( greatgun, mazerbla_state )
     */
 	MCFG_CPU_VBLANK_INT_DRIVER("screen", mazerbla_state,  irq0_line_hold)
 
-	MCFG_MB_VCU_ADD("vcu",SOUND_CLOCK/4,vcu_interface)
+	MCFG_DEVICE_ADD("vcu", MB_VCU, SOUND_CLOCK/4)
+	MCFG_MB_VCU_CPU("sub2")
+	MCFG_MB_VCU_PALETTE("palette")
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
@@ -1539,18 +1519,18 @@ static MACHINE_CONFIG_START( greatgun, mazerbla_state )
 	MCFG_SCREEN_UPDATE_DRIVER(mazerbla_state, screen_update_mazerbla)
 	MCFG_SCREEN_VBLANK_DRIVER(mazerbla_state, screen_eof)
 
-	MCFG_PALETTE_LENGTH(256+1)
-
+	MCFG_PALETTE_ADD("palette", 256+1)
+	MCFG_PALETTE_INIT_OWNER(mazerbla_state, mazerbla)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("ay1", AY8910, SOUND_CLOCK / 8)
-	MCFG_SOUND_CONFIG(ay8912_interface_1)
+	MCFG_AY8910_PORT_B_READ_CB(READ8(mazerbla_state, soundcommand_r))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
 	MCFG_SOUND_ADD("ay2", AY8910, SOUND_CLOCK / 8)
-	MCFG_SOUND_CONFIG(ay8912_interface_2)
+	MCFG_AY8910_PORT_B_WRITE_CB(WRITE8(mazerbla_state, gg_led_ctrl_w))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_CONFIG_END
 
