@@ -54,58 +54,73 @@ Bugs:
 #include "sound/sn76496.h"
 
 #include "includes/megadriv.h"
-#include "includes/segamsys.h"
-#include "scrlegcy.h"
 
 #define MASTER_CLOCK        53693100
 
-// Interrupt handler - from drivers/segasyse.c
-#if 0
-static UINT8 segae_vintpending;
-static UINT8 segae_hintpending;
-static UINT8 *segae_vdp_regs[];     /* pointer to vdp's registers */
+#define MP_ROM  1
+#define MP_GAME 0
 
-static UINT8 hintcount;           /* line interrupt counter, decreased each scanline */
 
-static INTERRUPT_GEN (megaplay_bios_irq)
+class mplay_state : public md_base_state
 {
-	int sline;
-	sline = device->m_screen->vpos();
+public:
+	mplay_state(const machine_config &mconfig, device_type type, const char *tag)
+	: md_base_state(mconfig, type, tag),
+	m_ic3_ram(*this, "ic3_ram"),
+	m_vdp1(*this, "vdp1"),
+	m_bioscpu(*this, "mtbios")
+	{ }
 
-	if (sline ==0) {
-		hintcount = segae_vdp_regs[0][10];
-	}
+	DECLARE_READ16_MEMBER(extra_ram_r);
+	DECLARE_WRITE16_MEMBER(extra_ram_w);
+	DECLARE_READ8_MEMBER(bios_banksel_r);
+	DECLARE_WRITE8_MEMBER(bios_banksel_w);
+	DECLARE_READ8_MEMBER(bios_gamesel_r);
+	DECLARE_WRITE8_MEMBER(bios_gamesel_w);
+	DECLARE_WRITE16_MEMBER(mp_io_write);
+	DECLARE_READ16_MEMBER(mp_io_read);
+	DECLARE_READ8_MEMBER(bank_r);
+	DECLARE_WRITE8_MEMBER(bank_w);
+	DECLARE_READ8_MEMBER(bios_6402_r);
+	DECLARE_WRITE8_MEMBER(bios_6402_w);
+	DECLARE_READ8_MEMBER(bios_6204_r);
+	DECLARE_WRITE8_MEMBER(bios_width_w);
+	DECLARE_READ8_MEMBER(bios_6404_r);
+	DECLARE_WRITE8_MEMBER(bios_6404_w);
+	DECLARE_READ8_MEMBER(bios_6600_r);
+	DECLARE_WRITE8_MEMBER(bios_6600_w);
+	DECLARE_WRITE8_MEMBER(game_w);
+	DECLARE_READ8_MEMBER(vdp_count_r);
+	DECLARE_WRITE_LINE_MEMBER(bios_int_callback);
 
-	if (sline <= 192) {
-//      if (sline != 192) segae_drawscanline(sline,1,1);
+	DECLARE_DRIVER_INIT(megaplay);
+	DECLARE_VIDEO_START(megplay);
+	DECLARE_MACHINE_RESET(megaplay);
+	UINT32 screen_update_megplay(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
 
-		if (sline == 192)
-			segae_vintpending = 1;
+private:
 
-		if (hintcount == 0) {
-			hintcount = segae_vdp_regs[0][10];
-			segae_hintpending = 1;
+	UINT32 m_bios_mode;  // determines whether ROM banks or Game data is to read from 0x8000-0xffff
 
-			if  ((segae_vdp_regs[0][0] & 0x10)) {
-				device->execute().set_input_line(0, HOLD_LINE);
-				return;
-			}
+	UINT32 m_bios_bank; // ROM bank selection
+	UINT16 m_game_banksel;  // Game bank selection
+	UINT32 m_readpos;  // serial bank selection position (9-bit)
+	UINT32 m_bios_bank_addr;
 
-		} else {
-			hintcount--;
-		}
-	}
+	UINT32 m_bios_width;  // determines the way the game info ROM is read
+	UINT8 m_bios_ctrl[6];
+	UINT8 m_bios_6600;
+	UINT8 m_bios_6403;
+	UINT8 m_bios_6404;
 
-	if (sline > 192) {
-		hintcount = segae_vdp_regs[0][10];
+	UINT16 *m_ic36_ram;
+	UINT8* m_ic37_ram;
 
-		if ( (sline<0xe0) && (segae_vintpending) ) {
-			device->execute().set_input_line(0, HOLD_LINE);
-		}
-	}
+	required_shared_ptr<UINT8>           m_ic3_ram;
+	optional_device<sega315_5124_device> m_vdp1;
+	required_device<cpu_device>          m_bioscpu;
+};
 
-}
-#endif
 
 static INPUT_PORTS_START ( megaplay )
 	PORT_INCLUDE( md_common )
@@ -374,12 +389,12 @@ INPUT_PORTS_END
 
 /*MEGAPLAY specific*/
 
-READ8_MEMBER(mplay_state::megaplay_bios_banksel_r )
+READ8_MEMBER(mplay_state::bios_banksel_r)
 {
 	return m_bios_bank;
 }
 
-WRITE8_MEMBER(mplay_state::megaplay_bios_banksel_w )
+WRITE8_MEMBER(mplay_state::bios_banksel_w)
 {
 /*  Multi-slot note:
     Bits 0 and 1 appear to determine the selected game slot.
@@ -391,20 +406,20 @@ WRITE8_MEMBER(mplay_state::megaplay_bios_banksel_w )
 //  logerror("BIOS: ROM bank %i selected [0x%02x]\n",bios_bank >> 6, data);
 }
 
-READ8_MEMBER(mplay_state::megaplay_bios_gamesel_r )
+READ8_MEMBER(mplay_state::bios_gamesel_r)
 {
 	return m_bios_6403;
 }
 
-WRITE8_MEMBER(mplay_state::megaplay_bios_gamesel_w )
+WRITE8_MEMBER(mplay_state::bios_gamesel_w)
 {
 	m_bios_6403 = data;
 
 //  logerror("BIOS: 0x6403 write: 0x%02x\n",data);
-	m_bios_mode = data & 0x10;
+	m_bios_mode = BIT(data, 4);
 }
 
-WRITE16_MEMBER(mplay_state::megaplay_io_write )
+WRITE16_MEMBER(mplay_state::mp_io_write)
 {
 	if (offset == 0x03)
 		m_megadrive_io_data_regs[2] = (data & m_megadrive_io_ctrl_regs[2]) | (m_megadrive_io_data_regs[2] & ~m_megadrive_io_ctrl_regs[2]);
@@ -412,7 +427,7 @@ WRITE16_MEMBER(mplay_state::megaplay_io_write )
 		megadriv_68k_io_write(space, offset & 0x1f, data, 0xffff);
 }
 
-READ16_MEMBER(mplay_state::megaplay_io_read )
+READ16_MEMBER(mplay_state::mp_io_read)
 {
 	if (offset == 0x03)
 		return m_megadrive_io_data_regs[2];
@@ -420,21 +435,17 @@ READ16_MEMBER(mplay_state::megaplay_io_read )
 		return megadriv_68k_io_read(space, offset & 0x1f, 0xffff);
 }
 
-READ8_MEMBER(mplay_state::bank_r )
+READ8_MEMBER(mplay_state::bank_r)
 {
 	UINT8* bank = memregion("mtbios")->base();
-	UINT32 fulladdress = m_mp_bios_bank_addr + offset;
+	UINT32 fulladdress = m_bios_bank_addr + offset;
 
-	if (fulladdress <= 0x3fffff) // ROM Addresses
+	if (fulladdress <= 0x3fffff) // ROM addresses
 	{
-		if (m_bios_mode & MP_ROM)
+		if (m_bios_mode == MP_ROM)
 		{
 			int sel = (m_bios_bank >> 6) & 0x03;
-
-			if (sel == 0)
-				return 0xff;
-			else
-				return bank[0x10000 + (sel - 1) * 0x8000 + offset];
+			return bank[sel * 0x8000 + offset];
 		}
 		else if (m_bios_width & 0x08)
 		{
@@ -448,9 +459,9 @@ READ8_MEMBER(mplay_state::bank_r )
 			return memregion("maincpu")->base()[fulladdress ^ 1];
 		}
 	}
-	else if (fulladdress >= 0xa10000 && fulladdress <= 0xa1001f) // IO Acess
+	else if (fulladdress >= 0xa10000 && fulladdress <= 0xa1001f) // IO access
 	{
-		return megaplay_io_read(space, (offset & 0x1f) / 2, 0xffff);
+		return mp_io_read(space, (offset & 0x1f) / 2, 0xffff);
 	}
 	else
 	{
@@ -460,26 +471,20 @@ READ8_MEMBER(mplay_state::bank_r )
 
 }
 
-WRITE8_MEMBER(mplay_state::bank_w )
+WRITE8_MEMBER(mplay_state::bank_w)
 {
-	UINT32 fulladdress = m_mp_bios_bank_addr + offset;
+	UINT32 fulladdress = m_bios_bank_addr + offset;
 
-	if (fulladdress <= 0x3fffff) // ROM / Megaplay Custom Addresses
+	if (fulladdress <= 0x3fffff && m_bios_width & 0x08) // ROM / Megaplay Custom Addresses
 	{
-		if (offset <= 0x1fff && (m_bios_width & 0x08))
-		{
-			m_ic37_ram[(0x2000 * (m_bios_bank & 0x03)) + offset] = data;
-		}
-
-		if(offset >= 0x2000 && (m_bios_width & 0x08))
-		{
-	//      ic36_ram[offset] = data;
+		if (offset >= 0x2000)
 			m_ic36_ram[offset - 0x2000] = data;
-		}
+		else
+			m_ic37_ram[(0x2000 * (m_bios_bank & 0x03)) + offset] = data;
 	}
 	else if (fulladdress >= 0xa10000 && fulladdress <=0xa1001f) // IO Access
 	{
-		megaplay_io_write(space, (offset & 0x1f) / 2, data, 0xffff);
+		mp_io_write(space, (offset & 0x1f) / 2, data, 0xffff);
 	}
 	else
 	{
@@ -491,38 +496,38 @@ WRITE8_MEMBER(mplay_state::bank_w )
 /* Megaplay BIOS handles regs[2] at start in a different way compared to megadrive */
 /* other io data/ctrl regs are dealt with exactly like in the console              */
 
-READ8_MEMBER(mplay_state::megaplay_bios_6402_r )
+READ8_MEMBER(mplay_state::bios_6402_r)
 {
 	return m_megadrive_io_data_regs[2];// & 0xfe;
 }
 
-WRITE8_MEMBER(mplay_state::megaplay_bios_6402_w )
+WRITE8_MEMBER(mplay_state::bios_6402_w)
 {
 	m_megadrive_io_data_regs[2] = (m_megadrive_io_data_regs[2] & 0x07) | ((data & 0x70) >> 1);
 //  logerror("BIOS: 0x6402 write: 0x%02x\n", data);
 }
 
-READ8_MEMBER(mplay_state::megaplay_bios_6204_r )
+READ8_MEMBER(mplay_state::bios_6204_r)
 {
 	return m_megadrive_io_data_regs[2];
 //  return (m_bios_width & 0xf8) + (m_bios_6204 & 0x07);
 }
 
-WRITE8_MEMBER(mplay_state::megaplay_bios_width_w )
+WRITE8_MEMBER(mplay_state::bios_width_w)
 {
 	m_bios_width = data;
 	m_megadrive_io_data_regs[2] = (m_megadrive_io_data_regs[2] & 0x07) | ((data & 0xf8));
 //  logerror("BIOS: 0x6204 - Width write: %02x\n", data);
 }
 
-READ8_MEMBER(mplay_state::megaplay_bios_6404_r )
+READ8_MEMBER(mplay_state::bios_6404_r)
 {
 //  logerror("BIOS: 0x6404 read: returned 0x%02x\n",bios_6404 | (bios_6403 & 0x10) >> 4);
 	return (m_bios_6404 & 0xfe) | ((m_bios_6403 & 0x10) >> 4);
 //  return m_bios_6404 | (m_bios_6403 & 0x10) >> 4;
 }
 
-WRITE8_MEMBER(mplay_state::megaplay_bios_6404_w )
+WRITE8_MEMBER(mplay_state::bios_6404_w)
 {
 	if(((m_bios_6404 & 0x0c) == 0x00) && ((data & 0x0c) == 0x0c))
 		m_maincpu->set_input_line(INPUT_LINE_RESET, PULSE_LINE);
@@ -531,7 +536,7 @@ WRITE8_MEMBER(mplay_state::megaplay_bios_6404_w )
 //  logerror("BIOS: 0x6404 write: 0x%02x\n", data);
 }
 
-READ8_MEMBER(mplay_state::megaplay_bios_6600_r )
+READ8_MEMBER(mplay_state::bios_6600_r)
 {
 /*  Multi-slot note:
     0x6600 appears to be used to check for extra slots being used.
@@ -542,13 +547,13 @@ READ8_MEMBER(mplay_state::megaplay_bios_6600_r )
 	return m_bios_6600;// & 0xfe;
 }
 
-WRITE8_MEMBER(mplay_state::megaplay_bios_6600_w )
+WRITE8_MEMBER(mplay_state::bios_6600_w)
 {
 	m_bios_6600 = data;
 //  logerror("BIOS: 0x6600 write: 0x%02x\n",data);
 }
 
-WRITE8_MEMBER(mplay_state::megaplay_game_w )
+WRITE8_MEMBER(mplay_state::game_w)
 {
 	if (m_readpos == 1)
 		m_game_banksel = 0;
@@ -564,78 +569,85 @@ WRITE8_MEMBER(mplay_state::megaplay_game_w )
 		logerror("BIOS [0x%04x]: 68K address space bank selected: 0x%03x\n", space.device().safe_pcbase(), m_game_banksel);
 	}
 
-	m_mp_bios_bank_addr = ((m_mp_bios_bank_addr >> 1) | (data << 23)) & 0xff8000;
+	m_bios_bank_addr = ((m_bios_bank_addr >> 1) | (data << 23)) & 0xff8000;
 }
 
 static ADDRESS_MAP_START( megaplay_bios_map, AS_PROGRAM, 8, mplay_state )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x4fff) AM_RAM
 	AM_RANGE(0x5000, 0x5fff) AM_RAM
-	AM_RANGE(0x6000, 0x6000) AM_WRITE(megaplay_game_w)
+	AM_RANGE(0x6000, 0x6000) AM_WRITE(game_w)
 	AM_RANGE(0x6200, 0x6200) AM_READ_PORT("DSW0")
 	AM_RANGE(0x6201, 0x6201) AM_READ_PORT("DSW1")
-	AM_RANGE(0x6203, 0x6203) AM_READWRITE(megaplay_bios_banksel_r, megaplay_bios_banksel_w)
-	AM_RANGE(0x6204, 0x6204) AM_READWRITE(megaplay_bios_6204_r, megaplay_bios_width_w)
+	AM_RANGE(0x6203, 0x6203) AM_READWRITE(bios_banksel_r, bios_banksel_w)
+	AM_RANGE(0x6204, 0x6204) AM_READWRITE(bios_6204_r, bios_width_w)
 	AM_RANGE(0x6400, 0x6400) AM_READ_PORT("TEST")
 	AM_RANGE(0x6401, 0x6401) AM_READ_PORT("COIN")
-	AM_RANGE(0x6402, 0x6402) AM_READWRITE(megaplay_bios_6402_r, megaplay_bios_6402_w)
-	AM_RANGE(0x6403, 0x6403) AM_READWRITE(megaplay_bios_gamesel_r, megaplay_bios_gamesel_w)
-	AM_RANGE(0x6404, 0x6404) AM_READWRITE(megaplay_bios_6404_r, megaplay_bios_6404_w)
-	AM_RANGE(0x6600, 0x6600) AM_READWRITE(megaplay_bios_6600_r, megaplay_bios_6600_w)
+	AM_RANGE(0x6402, 0x6402) AM_READWRITE(bios_6402_r, bios_6402_w)
+	AM_RANGE(0x6403, 0x6403) AM_READWRITE(bios_gamesel_r, bios_gamesel_w)
+	AM_RANGE(0x6404, 0x6404) AM_READWRITE(bios_6404_r, bios_6404_w)
+	AM_RANGE(0x6600, 0x6600) AM_READWRITE(bios_6600_r, bios_6600_w)
 	AM_RANGE(0x6001, 0x67ff) AM_WRITEONLY
 	AM_RANGE(0x6800, 0x77ff) AM_RAM AM_SHARE("ic3_ram")
 	AM_RANGE(0x8000, 0xffff) AM_READWRITE(bank_r, bank_w)
 ADDRESS_MAP_END
 
-/* basically from src/drivers/segasyse.c */
+
+READ8_MEMBER(mplay_state::vdp_count_r)
+{
+	address_space &prg = m_bioscpu->space(AS_PROGRAM);
+	if (offset & 0x01)
+		return m_vdp->hcount_read(prg, offset);
+	else
+		return m_vdp->vcount_read(prg, offset);
+}
+
 static ADDRESS_MAP_START( megaplay_bios_io_map, AS_IO, 8, mplay_state )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x7f, 0x7f) AM_DEVWRITE("sn2", sn76496_device, write)  /* SN76489 */
-	AM_RANGE(0xbe, 0xbe) AM_READWRITE_LEGACY(sms_vdp_data_r, sms_vdp_data_w)    /* VDP */
-	AM_RANGE(0xbf, 0xbf) AM_READWRITE_LEGACY(sms_vdp_ctrl_r, sms_vdp_ctrl_w)    /* VDP */
+	AM_RANGE(0x7f, 0x7f) AM_DEVWRITE("sn2", sn76496_device, write)
+
+	AM_RANGE(0x40, 0x41) AM_MIRROR(0x3e) AM_READ(vdp_count_r)
+	AM_RANGE(0x80, 0x80) AM_MIRROR(0x3e) AM_DEVREADWRITE("gen_vdp", sega315_5124_device, vram_read, vram_write)
+	AM_RANGE(0x81, 0x81) AM_MIRROR(0x3e) AM_DEVREADWRITE("gen_vdp", sega315_5124_device, register_read, register_write)
 ADDRESS_MAP_END
 
 
-
-
-VIDEO_START_MEMBER(mplay_state,megplay)
-{
-	//printf("megplay vs\n");
-	VIDEO_START_CALL_MEMBER(megadriv);
-//  VIDEO_START_CALL_MEMBER(megaplay_normal);
-}
-
 UINT32 mplay_state::screen_update_megplay(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
 {
 	//printf("megplay vu\n");
-	screen_update_megadriv(screen,bitmap,cliprect);
-//  SCREEN_UPDATE32_CALL(megaplay_normal);
-	SCREEN_UPDATE32_CALL(megaplay_bios);
+	screen_update_megadriv(screen, bitmap, cliprect);
+//  m_vdp->screen_update(screen, bitmap, cliprect);
+
+	// overlay, only drawn for pixels != 0
+	for (int y = 0; y < 224; y++)
+	{
+		UINT32* lineptr = &bitmap.pix32(y);
+		UINT32* srcptr =  &m_vdp->get_bitmap().pix32(y + SEGA315_5124_TBORDER_START + SEGA315_5124_NTSC_224_TBORDER_HEIGHT);
+
+		for (int x = 0; x < SEGA315_5124_WIDTH; x++)
+		{
+			UINT32 src = srcptr[x] & 0xffffff;
+
+			if (src)
+				lineptr[x] = src;
+		}
+	}
 	return 0;
 }
 
-
 MACHINE_RESET_MEMBER(mplay_state,megaplay)
 {
 	m_bios_mode = MP_ROM;
-	m_mp_bios_bank_addr = 0;
+	m_bios_bank_addr = 0;
 	m_readpos = 1;
 	MACHINE_RESET_CALL_MEMBER(megadriv);
-	MACHINE_RESET_CALL_LEGACY(megatech_bios);
 }
 
-void mplay_state::screen_eof_megaplay(screen_device &screen, bool state)
+WRITE_LINE_MEMBER( mplay_state::bios_int_callback )
 {
-	bool vblank_on = state;
-	screen_eof_megadriv(screen,state);
-	SCREEN_VBLANK_CALL(megatech_bios);
+	m_bioscpu->set_input_line(0, state);
 }
 
-static const sn76496_config psg_intf =
-{
-	DEVCB_NULL
-};
-
 static MACHINE_CONFIG_START( megaplay, mplay_state )
 	/* basic machine hardware */
 	MCFG_FRAGMENT_ADD(md_ntsc)
@@ -646,20 +658,21 @@ static MACHINE_CONFIG_START( megaplay, mplay_state )
 	MCFG_CPU_PROGRAM_MAP(megaplay_bios_map)
 	MCFG_CPU_IO_MAP(megaplay_bios_io_map)
 
-	MCFG_MACHINE_RESET_OVERRIDE(mplay_state, megaplay )
-
 	MCFG_QUANTUM_TIME(attotime::from_hz(6000))
 
 	MCFG_SOUND_ADD("sn2", SN76496, MASTER_CLOCK/15)
-	MCFG_SOUND_CONFIG(psg_intf)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.25) /* 3.58 MHz */
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker",0.25) /* 3.58 MHz */
 
 	/* New update functions to handle the extra layer */
-	MCFG_VIDEO_START_OVERRIDE(mplay_state,megplay)
 	MCFG_SCREEN_MODIFY("megadriv")
+	MCFG_SCREEN_RAW_PARAMS(XTAL_10_738635MHz/2, \
+		SEGA315_5124_WIDTH , SEGA315_5124_LBORDER_START + SEGA315_5124_LBORDER_WIDTH, SEGA315_5124_LBORDER_START + SEGA315_5124_LBORDER_WIDTH + 256, \
+		SEGA315_5124_HEIGHT_NTSC, SEGA315_5124_TBORDER_START + SEGA315_5124_NTSC_224_TBORDER_HEIGHT, SEGA315_5124_TBORDER_START + SEGA315_5124_NTSC_224_TBORDER_HEIGHT + 224)
 	MCFG_SCREEN_UPDATE_DRIVER(mplay_state, screen_update_megplay)
-	MCFG_SCREEN_VBLANK_DRIVER(mplay_state, screen_eof_megaplay)
+
+	MCFG_DEVICE_MODIFY("gen_vdp")
+	MCFG_SEGA315_5313_INT_CB(WRITELINE(mplay_state, bios_int_callback))
 MACHINE_CONFIG_END
 
 
@@ -678,7 +691,7 @@ ROM_START( megaplay )
 
 	ROM_REGION( 0x8000, "user1", ROMREGION_ERASEFF )
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -697,7 +710,7 @@ ROM_START( mp_sonic ) /* Sonic */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "ep15175-01.ic3", 0x000000, 0x08000, CRC(99246889) SHA1(184aa3b7fdedcf578c5e34edb7ed44f57f832258) )
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -713,7 +726,7 @@ ROM_START( mp_col3 ) /* Columns 3 */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "1.ic3", 0x000000, 0x08000,  CRC(dac9bf91) SHA1(0117972a7181f8aaf942a259cc8764b821031253) )
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -726,7 +739,7 @@ ROM_START( mp_gaxe2 ) /* Golden Axe 2 */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "ep15175-02b.ic3", 0x000000, 0x08000, CRC(3039b653) SHA1(b19874c74d0fc0cca1169f62e5e74f0e8ca83679) ) // 15175-02b.ic3
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -739,7 +752,7 @@ ROM_START( mp_gslam ) /* Grand Slam */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "epr-15175-03.ic3", 0x000000, 0x08000, CRC(70ea1aec) SHA1(0d9d82a1f8aa51d02707f7b343e7cfb6591efccd) ) // 15175-02b.ic3
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -753,7 +766,7 @@ ROM_START( mp_twc ) /* Tecmo World Cup */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "ep15175-04.ic3", 0x000000, 0x08000, CRC(faf7c030) SHA1(16ef405335b4d3ecb0b7d97b088dafc4278d4726) )
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -765,7 +778,7 @@ ROM_START( mp_sor2 ) /* Streets of Rage 2 */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "epr-15175-05.ic2", 0x000000, 0x08000, CRC(1df5347c) SHA1(faced2e875e1914392f61577b5256d006eebeef9) )
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -777,7 +790,7 @@ ROM_START( mp_bio ) /* Bio Hazard Battle */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "epr-15175-06.ic2", 0x000000, 0x08000, CRC(1ef64e41) SHA1(13984b714b014ea41963b70de74a5358ed223bc5) )
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -789,7 +802,7 @@ ROM_START( mp_soni2 ) /* Sonic The Hedgehog 2 */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "epr-15175-07.ic1", 0x000000, 0x08000, CRC(bb5f67f0) SHA1(33b7a5d14015a5fcf41976a8f648f8f48ce9bb03) )
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -801,7 +814,7 @@ ROM_START( mp_mazin ) /* Mazin Wars */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "epr-15175-11.ic2", 0x000000, 0x08000, CRC(bb651120) SHA1(81cb736f2732373e260dde162249c1d29a3489c3) )
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
@@ -813,37 +826,17 @@ ROM_START( mp_shnb3 ) /* Shinobi 3 */
 	ROM_REGION( 0x8000, "user1", 0 ) /* Game Instructions */
 	ROM_LOAD( "epr-15175-09.ic2", 0x000000, 0x08000, CRC(6254e45a) SHA1(8667922a6eade03c964ce224f7fa39ba871c60a4) )
 
-	ROM_REGION( 0x28000, "mtbios", 0 ) /* Bios */
+	ROM_REGION( 0x20000, "mtbios", 0 ) /* Bios */
 	MEGAPLAY_BIOS
 ROM_END
 
 
-void mplay_state::mplay_start()
-{
-	UINT8 *src = memregion("mtbios")->base();
-	UINT8 *instruction_rom = memregion("user1")->base();
-	UINT8 *game_rom = memregion("maincpu")->base();
-	int offs;
-
-	memmove(src + 0x10000, src + 0x8000, 0x18000); // move bios..
-
-	/* copy game instruction rom to main map.. maybe this should just be accessed
-	  through a handler instead?.. */
-	for (offs = 0; offs < 0x8000; offs++)
-	{
-		UINT8 dat = instruction_rom[offs];
-
-		game_rom[0x300000 + offs * 2] = dat;
-		game_rom[0x300001 + offs * 2] = dat;
-	}
-}
-
-READ16_MEMBER(mplay_state::megadriv_68k_read_z80_extra_ram )
+READ16_MEMBER(mplay_state::extra_ram_r )
 {
 	return m_ic36_ram[(offset << 1) ^ 1] | (m_ic36_ram[(offset << 1)] << 8);
 }
 
-WRITE16_MEMBER(mplay_state::megadriv_68k_write_z80_extra_ram )
+WRITE16_MEMBER(mplay_state::extra_ram_w )
 {
 	if (!ACCESSING_BITS_0_7) // byte (MSB) access
 	{
@@ -862,26 +855,35 @@ WRITE16_MEMBER(mplay_state::megadriv_68k_write_z80_extra_ram )
 
 DRIVER_INIT_MEMBER(mplay_state,megaplay)
 {
-	/* to support the old code.. */
+	// copy game instruction rom to main map. maybe this should just be accessed
+	// through a handler instead?
+	UINT8 *instruction_rom = memregion("user1")->base();
+	UINT8 *game_rom = memregion("maincpu")->base();
+
+	for (int offs = 0; offs < 0x8000; offs++)
+	{
+		UINT8 dat = instruction_rom[offs];
+
+		game_rom[0x300000 + offs * 2] = dat;
+		game_rom[0x300001 + offs * 2] = dat;
+	}
+
+	// to support the old code
 	m_ic36_ram = auto_alloc_array(machine(), UINT16, 0x10000 / 2);
 	m_ic37_ram = auto_alloc_array(machine(), UINT8, 0x10000);
-	m_genesis_io_ram = auto_alloc_array(machine(), UINT16, 0x20 / 2);
 
-	DRIVER_INIT_CALL(mpnew);
+	DRIVER_INIT_CALL(megadrij);
+	m_megadrive_io_read_data_port_ptr = read8_delegate(FUNC(md_base_state::megadrive_io_read_data_port_3button),this);
+	m_megadrive_io_write_data_port_ptr = write16_delegate(FUNC(md_base_state::megadrive_io_write_data_port_3button),this);
 
-	mplay_start();
+	// for now ...
+	m_maincpu->space(AS_PROGRAM).install_readwrite_handler(0xa10000, 0xa1001f, read16_delegate(FUNC(mplay_state::mp_io_read),this), write16_delegate(FUNC(mplay_state::mp_io_write),this));
 
-	/* for now ... */
-	m_maincpu->space(AS_PROGRAM).install_readwrite_handler(0xa10000, 0xa1001f, read16_delegate(FUNC(mplay_state::megaplay_io_read),this), write16_delegate(FUNC(mplay_state::megaplay_io_write),this));
-
-	/* megaplay has ram shared with the bios cpu here */
+	// megaplay has ram shared with the bios cpu here
 	m_z80snd->space(AS_PROGRAM).install_ram(0x2000, 0x3fff, &m_ic36_ram[0]);
 
-	/* instead of a RAM mirror the 68k sees the extra ram of the 2nd z80 too */
-	m_maincpu->space(AS_PROGRAM).install_readwrite_handler(0xa02000, 0xa03fff, read16_delegate(FUNC(mplay_state::megadriv_68k_read_z80_extra_ram),this), write16_delegate(FUNC(mplay_state::megadriv_68k_write_z80_extra_ram),this));
-
-	init_megatech_bios(machine());
-
+	// instead of a RAM mirror the 68k sees the extra ram of the 2nd z80 too
+	m_maincpu->space(AS_PROGRAM).install_readwrite_handler(0xa02000, 0xa03fff, read16_delegate(FUNC(mplay_state::extra_ram_r),this), write16_delegate(FUNC(mplay_state::extra_ram_w),this));
 }
 
 /*
