@@ -73,14 +73,85 @@ Sonic Hedgehog 2           171-6215A   837-6963-62       610-0239-62         MPR
 #include "sound/sn76496.h"
 #include "rendlay.h"
 
-#include "includes/segamsys.h"
 #include "includes/megadriv.h"
 #include "imagedev/cartslot.h"
 
-#include "scrlegcy.h"
-
 #define MASTER_CLOCK        53693100
 
+
+
+class mtech_state : public md_base_state
+{
+public:
+	enum
+	{
+		TIMER_Z80_RUN_STATE,
+		TIMER_Z80_STOP_STATE
+	};
+
+	mtech_state(const machine_config &mconfig, device_type type, const char *tag)
+	: md_base_state(mconfig, type, tag),
+	m_vdp1(*this, "vdp1"),
+	m_bioscpu(*this, "mtbios")
+	{ }
+
+	DECLARE_WRITE_LINE_MEMBER( snd_int_callback );
+	DECLARE_WRITE_LINE_MEMBER( bios_int_callback );
+	DECLARE_READ8_MEMBER(cart_select_r);
+	DECLARE_WRITE8_MEMBER(cart_select_w);
+	DECLARE_READ8_MEMBER(bios_ctrl_r);
+	DECLARE_WRITE8_MEMBER(bios_ctrl_w);
+	DECLARE_READ8_MEMBER(read_68k_banked_data);
+	DECLARE_WRITE8_MEMBER(write_68k_banked_data);
+	DECLARE_WRITE8_MEMBER(mt_z80_bank_w);
+	DECLARE_READ8_MEMBER(banked_ram_r);
+	DECLARE_WRITE8_MEMBER(banked_ram_w);
+	DECLARE_WRITE8_MEMBER(bios_port_ctrl_w);
+	DECLARE_READ8_MEMBER(bios_joypad_r);
+	DECLARE_WRITE8_MEMBER(bios_port_7f_w);
+	DECLARE_READ8_MEMBER(vdp1_count_r);
+	DECLARE_READ8_MEMBER(sms_count_r);
+	DECLARE_READ8_MEMBER(sms_ioport_dc_r);
+	DECLARE_READ8_MEMBER(sms_ioport_dd_r);
+	DECLARE_WRITE8_MEMBER(mt_sms_standard_rom_bank_w);
+
+	DECLARE_DRIVER_INIT(mt_crt);
+	DECLARE_DRIVER_INIT(mt_slot);
+	DECLARE_MACHINE_RESET(megatech);
+	DECLARE_DEVICE_IMAGE_LOAD_MEMBER(megatech_cart);
+	UINT32 screen_update_main(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
+	UINT32 screen_update_menu(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
+	void screen_eof_main(screen_device &screen, bool state);
+
+protected:
+	virtual void device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr);
+
+private:
+	UINT8 m_mt_cart_select_reg;
+	UINT32 m_bios_port_ctrl;
+	int m_current_game_is_sms; // is the current game SMS based (running on genesis z80, in VDP compatibility mode)
+	UINT32 m_bios_ctrl_inputs;
+	UINT8 m_bios_ctrl[6];
+	int m_mt_bank_addr;
+
+	int m_cart_is_genesis[8];
+
+	void set_genz80_as_md();
+	void set_genz80_as_sms();
+
+	TIMER_CALLBACK_MEMBER(z80_run_state);
+	TIMER_CALLBACK_MEMBER(z80_stop_state);
+
+	UINT8* m_banked_ram;
+	UINT8* sms_mainram;
+	UINT8* sms_rom;
+
+	required_device<sega315_5124_device> m_vdp1;
+	required_device<cpu_device>          m_bioscpu;
+};
+
+
+
 /* not currently used */
 static INPUT_PORTS_START( megatech ) /* Genesis Input Ports */
 	PORT_INCLUDE(megadriv)
@@ -205,33 +276,134 @@ static INPUT_PORTS_START( megatech ) /* Genesis Input Ports */
 	PORT_DIPNAME( 0x0080, 0x0080, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(      0x0080, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-
 INPUT_PORTS_END
 
 /* MEGATECH specific */
-READ8_MEMBER(mtech_state::megatech_cart_select_r )
+READ8_MEMBER(mtech_state::cart_select_r )
 {
 	return m_mt_cart_select_reg;
 }
 
-
 void mtech_state::device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr)
 {
 	switch (id)
 	{
 	case TIMER_Z80_RUN_STATE:
-		megatech_z80_run_state(ptr, param);
+		z80_run_state(ptr, param);
 		break;
 	case TIMER_Z80_STOP_STATE:
-		megatech_z80_stop_state(ptr, param);
+		z80_stop_state(ptr, param);
 		break;
 	default:
 		assert_always(FALSE, "Unknown id in mtech_state::device_timer");
 	}
 }
 
+READ8_MEMBER(mtech_state::sms_count_r)
+{
+	address_space &prg = m_z80snd->space(AS_PROGRAM);
+	if (offset & 0x01)
+		return m_vdp->hcount_read(prg, offset);
+	else
+		return m_vdp->vcount_read(prg, offset);
+}
 
-TIMER_CALLBACK_MEMBER(mtech_state::megatech_z80_run_state )
+
+READ8_MEMBER (mtech_state::sms_ioport_dc_r)
+{
+	/* 2009-05 FP: would it be worth to give separate inputs to SMS? SMS has only 2 keys A,B (which are B,C on megadrive) */
+	/* bit 4: TL-A; bit 5: TR-A */
+	return (machine().root_device().ioport("PAD1")->read() & 0x3f) | ((machine().root_device().ioport("PAD2")->read() & 0x03) << 6);
+}
+
+READ8_MEMBER (mtech_state::sms_ioport_dd_r)
+{
+	/* 2009-05 FP: would it be worth to give separate inputs to SMS? SMS has only 2 keys A,B (which are B,C on megadrive) */
+	/* bit 2: TL-B; bit 3: TR-B; bit 4: RESET; bit 5: unused; bit 6: TH-A; bit 7: TH-B*/
+	return ((machine().root_device().ioport("PAD2")->read() & 0x3c) >> 2) | 0x10;
+}
+
+
+WRITE8_MEMBER( mtech_state::mt_sms_standard_rom_bank_w )
+{
+	int bank = data & 0x1f;
+	//logerror("bank w %02x %02x\n", offset, data);
+
+	sms_mainram[0x1ffc + offset] = data;
+	switch (offset)
+	{
+		case 0:
+			logerror("bank w %02x %02x\n", offset, data);
+			space.install_rom(0x0000, 0xbfff, sms_rom);
+			space.unmap_write(0x0000, 0xbfff);
+			//printf("bank ram??\n");
+			break;
+		case 1:
+			memcpy(sms_rom+0x0000, space.machine().root_device().memregion("maincpu")->base()+bank*0x4000, 0x4000);
+			break;
+		case 2:
+			memcpy(sms_rom+0x4000, space.machine().root_device().memregion("maincpu")->base()+bank*0x4000, 0x4000);
+			break;
+		case 3:
+			memcpy(sms_rom+0x8000, space.machine().root_device().memregion("maincpu")->base()+bank*0x4000, 0x4000);
+			break;
+
+	}
+}
+
+void mtech_state::set_genz80_as_sms()
+{
+	address_space &prg = machine().device("genesis_snd_z80")->memory().space(AS_PROGRAM);
+	address_space &io = machine().device("genesis_snd_z80")->memory().space(AS_IO);
+	sn76496_base_device *sn = machine().device<sn76496_base_device>("snsnd");
+
+	// main ram area
+	sms_mainram = (UINT8 *)prg.install_ram(0xc000, 0xdfff, 0, 0x2000);
+	memset(sms_mainram,0x00,0x2000);
+
+	// fixed rom bank area
+	sms_rom = (UINT8 *)prg.install_rom(0x0000, 0xbfff, NULL);
+
+	memcpy(sms_rom, machine().root_device().memregion("maincpu")->base(), 0xc000);
+
+	prg.install_write_handler(0xfffc, 0xffff, write8_delegate(FUNC(mtech_state::mt_sms_standard_rom_bank_w),this));
+
+	// ports
+	io.install_read_handler      (0x40, 0x41, 0xff, 0x3e, read8_delegate(FUNC(mtech_state::sms_count_r),this));
+	io.install_write_handler     (0x40, 0x41, 0xff, 0x3e, write8_delegate(FUNC(sn76496_device::write),sn));
+	io.install_readwrite_handler (0x80, 0x80, 0xff, 0x3e, read8_delegate(FUNC(sega315_5124_device::vram_read),(sega315_5124_device *)m_vdp), write8_delegate(FUNC(sega315_5124_device::vram_write),(sega315_5124_device *)m_vdp));
+	io.install_readwrite_handler (0x81, 0x81, 0xff, 0x3e, read8_delegate(FUNC(sega315_5124_device::register_read),(sega315_5124_device *)m_vdp), write8_delegate(FUNC(sega315_5124_device::register_write),(sega315_5124_device *)m_vdp));
+
+	io.install_read_handler      (0x10, 0x10, read8_delegate(FUNC(mtech_state::sms_ioport_dd_r),this)); // super tetris
+
+	io.install_read_handler      (0xdc, 0xdc, read8_delegate(FUNC(mtech_state::sms_ioport_dc_r),this));
+	io.install_read_handler      (0xdd, 0xdd, read8_delegate(FUNC(mtech_state::sms_ioport_dd_r),this));
+	io.install_read_handler      (0xde, 0xde, read8_delegate(FUNC(mtech_state::sms_ioport_dd_r),this));
+	io.install_read_handler      (0xdf, 0xdf, read8_delegate(FUNC(mtech_state::sms_ioport_dd_r),this)); // adams family
+}
+
+
+/* sets the megadrive z80 to it's normal ports / map */
+void mtech_state::set_genz80_as_md()
+{
+	address_space &prg = machine().device("genesis_snd_z80")->memory().space(AS_PROGRAM);
+	ym2612_device *ym2612 = machine().device<ym2612_device>("ymsnd");
+
+	prg.install_readwrite_bank(0x0000, 0x1fff, "bank1");
+	machine().root_device().membank("bank1")->set_base(m_genz80.z80_prgram);
+
+	prg.install_ram(0x0000, 0x1fff, m_genz80.z80_prgram);
+
+	prg.install_readwrite_handler(0x4000, 0x4003, read8_delegate(FUNC(ym2612_device::read),ym2612), write8_delegate(FUNC(ym2612_device::write),ym2612));
+	prg.install_write_handler    (0x6000, 0x6000, write8_delegate(FUNC(mtech_state::megadriv_z80_z80_bank_w),this));
+	prg.install_write_handler    (0x6001, 0x6001, write8_delegate(FUNC(mtech_state::megadriv_z80_z80_bank_w),this));
+	prg.install_read_handler     (0x6100, 0x7eff, read8_delegate(FUNC(mtech_state::megadriv_z80_unmapped_read),this));
+	prg.install_readwrite_handler(0x7f00, 0x7fff, read8_delegate(FUNC(mtech_state::megadriv_z80_vdp_read),this), write8_delegate(FUNC(mtech_state::megadriv_z80_vdp_write),this));
+	prg.install_readwrite_handler(0x8000, 0xffff, read8_delegate(FUNC(mtech_state::z80_read_68k_banked_data),this), write8_delegate(FUNC(mtech_state::z80_write_68k_banked_data),this));
+}
+
+
+TIMER_CALLBACK_MEMBER(mtech_state::z80_run_state )
 {
 	char tempname[20];
 	UINT8* game_region;
@@ -243,28 +415,27 @@ TIMER_CALLBACK_MEMBER(mtech_state::megatech_z80_run_state )
 
 	if (!m_cart_is_genesis[param])
 	{
-		printf("enabling SMS Z80\n");
+		logerror("enabling SMS Z80\n");
 		m_current_game_is_sms = 1;
-		megatech_set_genz80_as_sms_standard_map(machine(), "genesis_snd_z80", MAPPER_STANDARD);
+		set_genz80_as_sms();
 		//m_z80snd->set_input_line(INPUT_LINE_HALT, CLEAR_LINE);
 		m_z80snd->set_input_line(INPUT_LINE_RESET, CLEAR_LINE);
 	}
 	else
 	{
-		printf("disabling SMS Z80\n");
+		logerror("disabling SMS Z80\n");
 		m_current_game_is_sms = 0;
-		megatech_set_megadrive_z80_as_megadrive_z80("genesis_snd_z80");
+		set_genz80_as_md();
 		m_maincpu->set_input_line(INPUT_LINE_RESET, CLEAR_LINE);
 		//m_maincpu->set_input_line(INPUT_LINE_HALT, CLEAR_LINE);
 	}
 }
 
-TIMER_CALLBACK_MEMBER(mtech_state::megatech_z80_stop_state )
+TIMER_CALLBACK_MEMBER(mtech_state::z80_stop_state )
 {
 	UINT8* game_region;
 	char tempname[20];
-
-	printf("megatech_select_game %d\n", param+1);
+	logerror("select game %d\n", param + 1);
 
 	sprintf(tempname, "game%d", param);
 	game_region = memregion(tempname)->base();
@@ -276,15 +447,12 @@ TIMER_CALLBACK_MEMBER(mtech_state::megatech_z80_stop_state )
 	machine().device("ymsnd")->reset();
 
 	megadriv_stop_scanline_timer();// stop the scanline timer for the genesis vdp... it can be restarted in video eof when needed
-	segae_md_sms_stop_scanline_timer();// stop the scanline timer for the sms vdp
-
+	m_vdp->reset();
 
 	/* if the regions exist we're fine */
 	if (game_region)
 	{
-		{
-			timer_set(attotime::zero, TIMER_Z80_RUN_STATE, param);
-		}
+		timer_set(attotime::zero, TIMER_Z80_RUN_STATE, param);
 	}
 	else
 	{
@@ -296,20 +464,14 @@ TIMER_CALLBACK_MEMBER(mtech_state::megatech_z80_stop_state )
 	return;
 }
 
-void mtech_state::megatech_select_game(int gameno)
-{
-	timer_set(attotime::zero, TIMER_Z80_STOP_STATE, gameno);
-}
-
-WRITE8_MEMBER(mtech_state::megatech_cart_select_w )
+WRITE8_MEMBER(mtech_state::cart_select_w )
 {
 	/* seems to write the slot number..
 	  but it stores something in (banked?) ram
 	  because it always seems to show the
 	  same instructions ... */
 	m_mt_cart_select_reg = data;
-
-	megatech_select_game(m_mt_cart_select_reg);
+	timer_set(attotime::zero, TIMER_Z80_STOP_STATE, m_mt_cart_select_reg);
 }
 
 
@@ -327,13 +489,11 @@ WRITE8_MEMBER(mtech_state::bios_ctrl_w )
 {
 	if (offset == 1)
 	{
-		output_set_value("Alarm_sound", data>>7 & 0x01);
+		output_set_value("Alarm_sound", BIT(data, 7));
 		m_bios_ctrl_inputs = data & 0x04;  // Genesis/SMS input ports disable bit
 	}
 	else if (offset == 2)
-	{
-		output_set_value("Flash_screen", data>>1 & 0x01);
-	}
+		output_set_value("Flash_screen", BIT(data, 1));
 
 	m_bios_ctrl[offset] = data;
 }
@@ -341,92 +501,112 @@ WRITE8_MEMBER(mtech_state::bios_ctrl_w )
 /* this sets 0x300000 which may indicate that the 68k can see the instruction rom
    there, this limiting the max game rom capacity to 3meg. */
 
-READ8_MEMBER(mtech_state::megatech_z80_read_68k_banked_data )
+READ8_MEMBER(mtech_state::read_68k_banked_data )
 {
 	address_space &space68k = m_maincpu->space();
 	UINT8 ret = space68k.read_byte(m_mt_bank_addr + offset);
 	return ret;
 }
 
-WRITE8_MEMBER(mtech_state::megatech_z80_write_68k_banked_data )
+WRITE8_MEMBER(mtech_state::write_68k_banked_data )
 {
 	address_space &space68k = m_maincpu->space();
 	space68k.write_byte(m_mt_bank_addr + offset,data);
 }
 
-void mtech_state::megatech_z80_bank_w(UINT16 data)
+WRITE8_MEMBER(mtech_state::mt_z80_bank_w )
 {
 	m_mt_bank_addr = ((m_mt_bank_addr >> 1) | (data << 23)) & 0xff8000;
 }
 
-WRITE8_MEMBER(mtech_state::mt_z80_bank_w )
+READ8_MEMBER(mtech_state::banked_ram_r )
 {
-	megatech_z80_bank_w(data & 1);
+	return m_banked_ram[offset + 0x1000 * (m_mt_cart_select_reg & 0x07)];
 }
 
-READ8_MEMBER(mtech_state::megatech_banked_ram_r )
+WRITE8_MEMBER(mtech_state::banked_ram_w )
 {
-	return m_megatech_banked_ram[offset + 0x1000 * (m_mt_cart_select_reg & 0x07)];
-}
-
-WRITE8_MEMBER(mtech_state::megatech_banked_ram_w )
-{
-	m_megatech_banked_ram[offset + 0x1000 * (m_mt_cart_select_reg & 0x07)] = data;
+	m_banked_ram[offset + 0x1000 * (m_mt_cart_select_reg & 0x07)] = data;
 }
 
 
 
 static ADDRESS_MAP_START( megatech_bios_map, AS_PROGRAM, 8, mtech_state )
 	AM_RANGE(0x0000, 0x2fff) AM_ROM // from bios rom (0x0000-0x2fff populated in ROM)
-	AM_RANGE(0x3000, 0x3fff) AM_READWRITE(megatech_banked_ram_r, megatech_banked_ram_w) // copies instruction data here at startup, must be banked
+	AM_RANGE(0x3000, 0x3fff) AM_READWRITE(banked_ram_r, banked_ram_w) // copies instruction data here at startup, must be banked
 	AM_RANGE(0x4000, 0x5fff) AM_RAM // plain ram?
 	AM_RANGE(0x6000, 0x6000) AM_WRITE(mt_z80_bank_w )
 	AM_RANGE(0x6400, 0x6400) AM_READ_PORT("BIOS_DSW0")
 	AM_RANGE(0x6401, 0x6401) AM_READ_PORT("BIOS_DSW1")
-	AM_RANGE(0x6404, 0x6404) AM_READWRITE(megatech_cart_select_r, megatech_cart_select_w) // cart select & ram bank
+	AM_RANGE(0x6404, 0x6404) AM_READWRITE(cart_select_r, cart_select_w) // cart select & ram bank
 	AM_RANGE(0x6800, 0x6800) AM_READ_PORT("BIOS_IN0")
 	AM_RANGE(0x6801, 0x6801) AM_READ_PORT("BIOS_IN1")
 	AM_RANGE(0x6802, 0x6807) AM_READWRITE(bios_ctrl_r, bios_ctrl_w)
 //  AM_RANGE(0x6805, 0x6805) AM_READ_PORT("???")
 	AM_RANGE(0x7000, 0x77ff) AM_ROM // from bios rom (0x7000-0x77ff populated in ROM)
 	//AM_RANGE(0x7800, 0x7fff) AM_RAM // ?
-	AM_RANGE(0x8000, 0x9fff) AM_READWRITE(megatech_z80_read_68k_banked_data, megatech_z80_write_68k_banked_data) // window into 68k address space, reads instr rom and writes to reset banks on z80 carts?
+	AM_RANGE(0x8000, 0x9fff) AM_READWRITE(read_68k_banked_data, write_68k_banked_data) // window into 68k address space, reads instr rom and writes to reset banks on z80 carts?
 ADDRESS_MAP_END
 
 
-WRITE8_MEMBER(mtech_state::megatech_bios_port_ctrl_w )
+WRITE8_MEMBER(mtech_state::bios_port_ctrl_w )
 {
 	m_bios_port_ctrl = data;
 }
 
-READ8_MEMBER(mtech_state::megatech_bios_joypad_r )
+/* the test mode accesses the joypad/stick inputs like this */
+READ8_MEMBER(mtech_state::bios_joypad_r )
 {
-	return megatech_bios_port_cc_dc_r(offset, m_bios_port_ctrl);
+	UINT8 retdata = 0;
+
+	if (m_bios_port_ctrl == 0x55)
+	{
+		/* A keys */
+		retdata = ((m_io_pad_3b[0]->read() & 0x40) >> 2) | ((m_io_pad_3b[1]->read() & 0x40) >> 4) | 0xeb;
+	}
+	else
+	{
+		if (offset == 0)
+			retdata = (m_io_pad_3b[0]->read() & 0x3f) | ((m_io_pad_3b[1]->read() & 0x03) << 6);
+		else
+			retdata = ((m_io_pad_3b[1]->read() & 0x3c) >> 2) | 0xf0;
+
+	}
+	return retdata;
 }
 
-WRITE8_MEMBER(mtech_state::megatech_bios_port_7f_w)
+WRITE8_MEMBER(mtech_state::bios_port_7f_w)
 {
 //  popmessage("CPU #3: I/O port 0x7F write, data %02x", data);
 }
 
 
+READ8_MEMBER(mtech_state::vdp1_count_r)
+{
+	address_space &prg = m_bioscpu->space(AS_PROGRAM);
+	if (offset & 0x01)
+		return m_vdp1->hcount_read(prg, offset);
+	else
+		return m_vdp1->vcount_read(prg, offset);
+}
 
 static ADDRESS_MAP_START( megatech_bios_portmap, AS_IO, 8, mtech_state )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x3f, 0x3f) AM_WRITE(megatech_bios_port_ctrl_w)
+	AM_RANGE(0x3f, 0x3f) AM_WRITE(bios_port_ctrl_w)
+	AM_RANGE(0x7f, 0x7f) AM_WRITE(bios_port_7f_w)
 
-	AM_RANGE(0x7f, 0x7f) AM_READ_LEGACY(sms_vcounter_r) AM_WRITE(megatech_bios_port_7f_w)
-	AM_RANGE(0xbe, 0xbe) AM_DEVREADWRITE( "vdp1", sega315_5124_device, vram_read, vram_write )
-	AM_RANGE(0xbf, 0xbf) AM_DEVREADWRITE( "vdp1", sega315_5124_device, register_read, register_write )
+	AM_RANGE(0x40, 0x41) AM_MIRROR(0x3e) AM_READ(vdp1_count_r)
+	AM_RANGE(0x80, 0x80) AM_MIRROR(0x3e) AM_DEVREADWRITE("vdp1", sega315_5124_device, vram_read, vram_write)
+	AM_RANGE(0x81, 0x81) AM_MIRROR(0x3e) AM_DEVREADWRITE("vdp1", sega315_5124_device, register_read, register_write)
 
-	AM_RANGE(0xdc, 0xdd) AM_READ(megatech_bios_joypad_r)  // player inputs
+	AM_RANGE(0xdc, 0xdd) AM_READ(bios_joypad_r)  // player inputs
 ADDRESS_MAP_END
 
 
 
 DRIVER_INIT_MEMBER(mtech_state,mt_slot)
 {
-	m_megatech_banked_ram = auto_alloc_array(machine(), UINT8, 0x1000*8);
+	m_banked_ram = auto_alloc_array(machine(), UINT8, 0x1000*8);
 
 	DRIVER_INIT_CALL(megadriv);
 
@@ -442,68 +622,60 @@ DRIVER_INIT_MEMBER(mtech_state,mt_crt)
 	m_cart_is_genesis[0] = !pin[0] ? 1 : 0;;
 }
 
-VIDEO_START_MEMBER(mtech_state,mtnew)
-{
-	init_for_megadrive(machine()); // create an sms vdp too, for compatibility mode
-	VIDEO_START_CALL_MEMBER(megadriv);
-}
 
-//attotime::never
-UINT32 mtech_state::screen_update_mtnew(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
+UINT32 mtech_state::screen_update_main(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
 {
-	/* if we're running an sms game then use the SMS update.. maybe this should be moved to the megadrive emulation core as compatibility mode is a feature of the chip */
+	// if we're running an sms game then use the SMS update.. maybe this should be moved to the megadrive emulation core as compatibility mode is a feature of the chip
 	if (!m_current_game_is_sms)
 		screen_update_megadriv(screen, bitmap, cliprect);
 	else
-		SCREEN_UPDATE32_CALL(megatech_md_sms);
+	{
+		m_vdp->screen_update(screen, bitmap, cliprect);
+#if 0
+		// when launching megatech + both sms and megadrive games, the following would be needed...
+		for (int y = 0; y < 224; y++)
+		{
+			UINT32* lineptr = &bitmap.pix32(y);
+			UINT32* srcptr =  &m_vdp->get_bitmap().pix32(y + SEGA315_5124_TBORDER_START + SEGA315_5124_NTSC_224_TBORDER_HEIGHT);
+
+			for (int x = 0; x < SEGA315_5124_WIDTH; x++)
+				lineptr[x] = srcptr[x];
+		}
+#endif
+	}
 	return 0;
 }
 
-void mtech_state::screen_eof_mtnew(screen_device &screen, bool state)
+void mtech_state::screen_eof_main(screen_device &screen, bool state)
 {
-	bool vblank_on = state;
 	if (!m_current_game_is_sms)
 		screen_eof_megadriv(screen, state);
-	else
-		SCREEN_VBLANK_CALL(megatech_md_sms);
 }
 
-MACHINE_RESET_MEMBER(mtech_state,mtnew)
+MACHINE_RESET_MEMBER(mtech_state, megatech)
 {
 	m_mt_bank_addr = 0;
-
 	MACHINE_RESET_CALL_MEMBER(megadriv);
-	MACHINE_RESET_CALL_LEGACY(megatech_md_sms);
-	megatech_select_game(0);
+	timer_set(attotime::zero, TIMER_Z80_STOP_STATE, 0);
 }
 
-UINT32 mtech_state::screen_update_megatech_menu(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
+UINT32 mtech_state::screen_update_menu(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
 {
-	m_vdp1->screen_update(screen,bitmap,cliprect);
+	m_vdp1->screen_update(screen, bitmap, cliprect);
 	return 0;
 }
 
 
 
-WRITE_LINE_MEMBER( mtech_state::int_callback )
+WRITE_LINE_MEMBER( mtech_state::bios_int_callback )
 {
 	m_bioscpu->set_input_line(0, state);
 }
 
-
-static const sega315_5124_interface _vdp_intf =
+WRITE_LINE_MEMBER( mtech_state::snd_int_callback )
 {
-	false,
-	DEVCB_DRIVER_LINE_MEMBER(mtech_state, int_callback),
-	DEVCB_NULL,
-};
-
-
-static const sn76496_config psg_intf =
-{
-	DEVCB_NULL
-};
-
+	m_z80snd->set_input_line(0, state);
+}
 
 static MACHINE_CONFIG_START( megatech, mtech_state )
 	/* basic machine hardware */
@@ -514,32 +686,34 @@ static MACHINE_CONFIG_START( megatech, mtech_state )
 	MCFG_CPU_PROGRAM_MAP(megatech_bios_map)
 	MCFG_CPU_IO_MAP(megatech_bios_portmap)
 
-	MCFG_MACHINE_RESET_OVERRIDE(mtech_state,mtnew)
-
-	MCFG_VIDEO_START_OVERRIDE(mtech_state,mtnew)
+	MCFG_MACHINE_RESET_OVERRIDE(mtech_state, megatech)
 
 	MCFG_DEFAULT_LAYOUT(layout_dualhovu)
 
+	MCFG_SCREEN_MODIFY("megadriv")
+	MCFG_SCREEN_RAW_PARAMS(XTAL_10_738635MHz/2, \
+		SEGA315_5124_WIDTH , SEGA315_5124_LBORDER_START + SEGA315_5124_LBORDER_WIDTH, SEGA315_5124_LBORDER_START + SEGA315_5124_LBORDER_WIDTH + 256, \
+		SEGA315_5124_HEIGHT_NTSC, SEGA315_5124_TBORDER_START + SEGA315_5124_NTSC_224_TBORDER_HEIGHT, SEGA315_5124_TBORDER_START + SEGA315_5124_NTSC_224_TBORDER_HEIGHT + 224)
+	MCFG_SCREEN_UPDATE_DRIVER(mtech_state, screen_update_main)
+	MCFG_SCREEN_VBLANK_DRIVER(mtech_state, screen_eof_main)
+
+	MCFG_DEVICE_MODIFY("gen_vdp")
+	MCFG_SEGA315_5313_INT_CB(WRITELINE(mtech_state, snd_int_callback))
+
 	MCFG_SCREEN_ADD("menu", RASTER)
 	// check frq
 	MCFG_SCREEN_RAW_PARAMS(XTAL_10_738635MHz/2, \
 		SEGA315_5124_WIDTH , SEGA315_5124_LBORDER_START + SEGA315_5124_LBORDER_WIDTH, SEGA315_5124_LBORDER_START + SEGA315_5124_LBORDER_WIDTH + 256, \
 		SEGA315_5124_HEIGHT_NTSC, SEGA315_5124_TBORDER_START + SEGA315_5124_NTSC_224_TBORDER_HEIGHT, SEGA315_5124_TBORDER_START + SEGA315_5124_NTSC_224_TBORDER_HEIGHT + 224)
-	MCFG_SCREEN_UPDATE_DRIVER(mtech_state, screen_update_megatech_menu)
+	MCFG_SCREEN_UPDATE_DRIVER(mtech_state, screen_update_menu)
 
-	MCFG_PALETTE_LENGTH(SEGA315_5124_PALETTE_SIZE)
-
-	MCFG_SEGA315_5246_ADD("vdp1", _vdp_intf)
+	MCFG_DEVICE_ADD("vdp1", SEGA315_5246, 0)
 	MCFG_SEGA315_5246_SET_SCREEN("menu")
-
-
-	MCFG_SCREEN_MODIFY("megadriv")
-	MCFG_SCREEN_UPDATE_DRIVER(mtech_state, screen_update_mtnew)
-	MCFG_SCREEN_VBLANK_DRIVER(mtech_state, screen_eof_mtnew)
+	MCFG_SEGA315_5246_IS_PAL(false)
+	MCFG_SEGA315_5246_INT_CB(WRITELINE(mtech_state, bios_int_callback))
 
 	/* sound hardware */
 	MCFG_SOUND_ADD("sn2", SN76496, MASTER_CLOCK/15)
-	MCFG_SOUND_CONFIG(psg_intf)
 	MCFG_SOUND_ROUTE(0, "lspeaker", 0.50)
 	MCFG_SOUND_ROUTE(1, "rspeaker", 0.50)
 MACHINE_CONFIG_END
@@ -594,19 +768,19 @@ DEVICE_IMAGE_LOAD_MEMBER( mtech_state, megatech_cart )
 		return IMAGE_INIT_FAIL;
 	else
 	{
-		if (!mame_stricmp("genesis", pcb_name))
+		if (!core_stricmp("genesis", pcb_name))
 		{
-			mame_printf_debug("%s is genesis\n", mt_cart->tag);
+			osd_printf_debug("%s is genesis\n", mt_cart->tag);
 			m_cart_is_genesis[this_cart->slot] = 1;
 		}
-		else if (!mame_stricmp("sms", pcb_name))
+		else if (!core_stricmp("sms", pcb_name))
 		{
-			mame_printf_debug("%s is sms\n", mt_cart->tag);
+			osd_printf_debug("%s is sms\n", mt_cart->tag);
 			m_cart_is_genesis[this_cart->slot] = 0;
 		}
 		else
 		{
-			mame_printf_debug("%s is invalid\n", mt_cart->tag);
+			osd_printf_debug("%s is invalid\n", mt_cart->tag);
 		}
 
 	}
