@@ -182,7 +182,9 @@ public:
 	mpoker_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag),
 		m_video(*this, "video"),
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	UINT8 m_output[8];
 	required_shared_ptr<UINT8> m_video;
@@ -199,9 +201,11 @@ public:
 	DECLARE_WRITE8_MEMBER(outport7_w);
 	DECLARE_WRITE8_MEMBER(sound_w);
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(mpoker);
 	UINT32 screen_update_mpoker(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	required_device<cpu_device> m_maincpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 };
 
 
@@ -213,7 +217,7 @@ UINT32 mpoker_state::screen_update_mpoker(screen_device &screen, bitmap_ind16 &b
 {
 	int y,x;
 	int count;
-	gfx_element *gfx = machine().gfx[0];
+	gfx_element *gfx = m_gfxdecode->gfx(0);
 
 	count = 0;
 	for (y=0;y<32;y++)
@@ -222,7 +226,7 @@ UINT32 mpoker_state::screen_update_mpoker(screen_device &screen, bitmap_ind16 &b
 		{
 			UINT16 dat = m_video[count];
 			UINT16 col = m_video[count+0x400] & 0x7f;
-			drawgfx_opaque(bitmap,cliprect,gfx,dat,col,0,0,x*16,y*16);
+			gfx->opaque(bitmap,cliprect,dat,col,0,0,x*16,y*16);
 			count++;
 		}
 
@@ -230,7 +234,7 @@ UINT32 mpoker_state::screen_update_mpoker(screen_device &screen, bitmap_ind16 &b
 	return 0;
 }
 
-void mpoker_state::palette_init()
+PALETTE_INIT_MEMBER(mpoker_state, mpoker)
 {
 	int i;
 
@@ -239,11 +243,11 @@ void mpoker_state::palette_init()
 		rgb_t color;
 
 		if (i & 0x01)
-			color = MAKE_RGB(pal2bit((i & 0x6) >> 1),pal2bit((i & 0x18) >> 3),pal2bit((i & 0x60) >> 5));
+			color = rgb_t(pal2bit((i & 0x6) >> 1),pal2bit((i & 0x18) >> 3),pal2bit((i & 0x60) >> 5));
 		else
-			color = RGB_BLACK;
+			color = rgb_t::black;
 
-		palette_set_color(machine(), i, color);
+		palette.set_pen_color(i, color);
 	}
 }
 
@@ -600,10 +604,11 @@ static MACHINE_CONFIG_START( mpoker, mpoker_state )
 	MCFG_SCREEN_SIZE(512, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 512-1, 0, 256-1)
 	MCFG_SCREEN_UPDATE_DRIVER(mpoker_state, screen_update_mpoker)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(mpoker)
-	MCFG_PALETTE_LENGTH(0x200)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", mpoker)
+	MCFG_PALETTE_ADD("palette", 0x200)
+	MCFG_PALETTE_INIT_OWNER(mpoker_state, mpoker)
 
 	/* sound hardware */
 //  MCFG_SPEAKER_STANDARD_MONO("mono")
