@@ -301,12 +301,17 @@ public:
 		: snes_state(mconfig, type, tag),
 		m_m50458(*this,"m50458"),
 		m_s3520cf(*this, "s3520cf"),
-		m_rp5h01(*this,"rp5h01")
+		m_rp5h01(*this,"rp5h01"),
+		m_screen(*this, "screen"),
+		m_palette(*this, "palette")
 		{ }
 
 	required_device<m50458_device> m_m50458;
 	required_device<s3520cf_device> m_s3520cf;
 	required_device<rp5h01_device> m_rp5h01;
+	required_device<screen_device> m_screen;
+	optional_device<palette_device> m_palette;
+
 	UINT8 m_wram_wp_flag;
 	UINT8 *m_wram;
 	UINT8 m_nmi_enable;
@@ -839,6 +844,10 @@ static MACHINE_CONFIG_START( nss, nss_state )
 	MCFG_SCREEN_RAW_PARAMS(DOTCLK_NTSC, SNES_HTOTAL, 0, SNES_SCR_WIDTH, SNES_VTOTAL_NTSC, 0, SNES_SCR_HEIGHT_NTSC)
 	MCFG_SCREEN_UPDATE_DRIVER( snes_state, screen_update )
 
+	MCFG_DEVICE_ADD("ppu", SNES_PPU, 0)
+	MCFG_SNES_PPU_OPENBUS_CB(READ8(snes_state, snes_open_bus_r))
+	MCFG_VIDEO_SET_SCREEN("screen")
+
 	// NSS
 	MCFG_SCREEN_ADD("osd", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
