@@ -17,7 +17,7 @@ TODO:
 - 02851: tetriskr: Corrupt game graphics after some time of gameplay, caused by a wrong
   reading of the i/o $3c8 bit 1.
 - Add a proper FDC device.
-- Filetto: Add UM5100 sound chip ,might be connected to the prototyping card;
+- Filetto: Add UM5100 sound chip, might be connected to the prototyping card;
 - buzzer sound has issues in both games
 
 ********************************************************************************************
@@ -64,9 +64,8 @@ the main program is 9th October 1990.
 #include "machine/pic8259.h"
 #include "sound/hc55516.h"
 #include "sound/speaker.h"
-#include "video/pc_cga.h"
-#include "drivlgcy.h"
-#include "scrlegcy.h"
+#include "bus/isa/isa.h"
+#include "bus/isa/cga.h"
 
 
 class pcxt_state : public driver_device
@@ -74,13 +73,12 @@ class pcxt_state : public driver_device
 public:
 	pcxt_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag),
-			m_pit8253(*this,"pit8253"),
-			m_pic8259_1(*this,"pic8259_1"),
-			m_dma8237_1(*this,"dma8237_1") ,
+			m_pit8253(*this, "pit8253"),
+			m_pic8259_1(*this, "pic8259_1"),
+			m_dma8237_1(*this, "dma8237_1") ,
 		m_maincpu(*this, "maincpu"),
 		m_speaker(*this, "speaker") { }
 
-	UINT8 m_bg_bank;
 	int m_bank;
 	int m_lastvalue;
 	UINT8 m_disk_data[2];
@@ -92,7 +90,7 @@ public:
 	int m_dma_channel;
 	UINT8 m_dma_offset[2][4];
 	UINT8 m_at_pages[0x10];
-	UINT8 m_pc_spkrdata, m_pc_input;
+	UINT8 m_pc_spkrdata, m_pit_out2;
 
 	required_device<pit8253_device> m_pit8253;
 	required_device<pic8259_device> m_pic8259_1;
@@ -126,15 +124,93 @@ public:
 	DECLARE_DRIVER_INIT(filetto);
 	virtual void machine_reset();
 	UINT32 screen_update_tetriskr(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
-	IRQ_CALLBACK_MEMBER(irq_callback);
 	UINT8 pcxt_speaker_get_spk();
 	void pcxt_speaker_set_spkrdata(UINT8 data);
-	void pcxt_speaker_set_input(UINT8 data);
 	required_device<cpu_device> m_maincpu;
 	required_device<speaker_sound_device> m_speaker;
 };
 
-UINT32 pcxt_state::screen_update_tetriskr(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
+
+class isa8_cga_filetto_device : public isa8_cga_device
+{
+public:
+	// construction/destruction
+	isa8_cga_filetto_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+
+	virtual const rom_entry *device_rom_region() const;
+};
+
+const device_type ISA8_CGA_FILETTO = &device_creator<isa8_cga_filetto_device>;
+
+//-------------------------------------------------
+//  isa8_cga_filetto_device - constructor
+//-------------------------------------------------
+
+isa8_cga_filetto_device::isa8_cga_filetto_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock) :
+		isa8_cga_device( mconfig, ISA8_CGA_FILETTO, "ISA8_CGA_FILETTO", tag, owner, clock, "filetto_cga", __FILE__)
+{
+}
+
+ROM_START( filetto_cga )
+	ROM_REGION( 0x2000, "gfx1", 0 )
+	ROM_LOAD("u67.bin", 0x0000, 0x2000, CRC(09710122) SHA1(de84bdd9245df287bbd3bb808f0c3531d13a3545) )
+ROM_END
+
+const rom_entry *isa8_cga_filetto_device::device_rom_region() const
+{
+	return ROM_NAME( filetto_cga );
+}
+
+
+
+class isa8_cga_tetriskr_device : public isa8_cga_superimpose_device
+{
+public:
+	// construction/destruction
+	isa8_cga_tetriskr_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
+
+	virtual UINT32 screen_update(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
+	virtual void device_start();
+	virtual const rom_entry *device_rom_region() const;
+
+	DECLARE_READ8_MEMBER(bg_bank_r);
+	DECLARE_WRITE8_MEMBER(bg_bank_w);
+private:
+	UINT8 m_bg_bank;
+};
+
+
+/* for superimposing CGA over a different source video (i.e. tetriskr) */
+const device_type ISA8_CGA_TETRISKR = &device_creator<isa8_cga_tetriskr_device>;
+
+//-------------------------------------------------
+//  isa8_cga_tetriskr_device - constructor
+//-------------------------------------------------
+
+isa8_cga_tetriskr_device::isa8_cga_tetriskr_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock) :
+		isa8_cga_superimpose_device( mconfig, ISA8_CGA_TETRISKR, "ISA8_CGA_TETRISKR", tag, owner, clock, "tetriskr_cga", __FILE__)
+{
+}
+
+
+void isa8_cga_tetriskr_device::device_start()
+{
+	isa8_cga_superimpose_device::device_start();
+	m_isa->install_device(0x3c0, 0x3c0, 0, 0,  read8_delegate( FUNC(isa8_cga_tetriskr_device::bg_bank_r), this ), write8_delegate( FUNC(isa8_cga_tetriskr_device::bg_bank_w), this ) );
+}
+
+WRITE8_MEMBER(isa8_cga_tetriskr_device::bg_bank_w)
+{
+	m_bg_bank = (data & 0x0f) ^ 8;
+}
+
+READ8_MEMBER(isa8_cga_tetriskr_device::bg_bank_r)
+{
+	return 0xff;
+}
+
+
+UINT32 isa8_cga_tetriskr_device::screen_update(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
 {
 	int x,y;
 	int yi;
@@ -142,7 +218,7 @@ UINT32 pcxt_state::screen_update_tetriskr(screen_device &screen, bitmap_rgb32 &b
 
 	//popmessage("%04x",m_start_offs);
 
-	bitmap.fill(RGB_BLACK, cliprect);
+	bitmap.fill(rgb_t::black, cliprect);
 
 	for(y=0;y<200/8;y++)
 	{
@@ -161,17 +237,38 @@ UINT32 pcxt_state::screen_update_tetriskr(screen_device &screen, bitmap_rgb32 &b
 						color |= ((bg_rom[y*320/8+x+(pen_i*0x20000)+yi*0x400+m_bg_bank*0x2000+1] >> (7-xi)) & 1) << pen_i;
 
 					if(cliprect.contains(x*8+xi, y*8+yi))
-						bitmap.pix32(y*8+yi, x*8+xi) = machine().pens[color];
+						bitmap.pix32(y*8+yi, x*8+xi) = m_palette->pen(color);
 				}
 			}
 		}
 	}
 
-	SCREEN_UPDATE32_CALL(mc6845_cga);
+	isa8_cga_device::screen_update(screen, bitmap, cliprect);
 	return 0;
 }
 
 
+ROM_START( tetriskr_cga )
+	ROM_REGION( 0x2000, "gfx1",ROMREGION_ERASE00 ) /* gfx - 1bpp font*/
+	ROM_LOAD( "b-3.u36", 0x1800, 0x0800, CRC(1a636f9a) SHA1(a356cc57914d0c9b9127670b55d1f340e64b1ac9) )
+	ROM_IGNORE( 0x1800 )
+
+	ROM_REGION( 0x80000+1, "gfx2",ROMREGION_INVERT | ROMREGION_ERASEFF )
+	ROM_LOAD( "b-1.u59", 0x00000, 0x10000, CRC(4719d986) SHA1(6e0499944b968d96fbbfa3ead6237d69c769d634))
+	ROM_LOAD( "b-2.u58", 0x10000, 0x10000, CRC(599e1154) SHA1(14d99f90b4fedeab0ac24ffa9b1fd9ad0f0ba699))
+	ROM_LOAD( "b-4.u54", 0x20000, 0x10000, CRC(e112c450) SHA1(dfdecfc6bd617ec520b7563b7caf44b79d498bd3))
+	ROM_LOAD( "b-5.u53", 0x30000, 0x10000, CRC(050b7650) SHA1(5981dda4ed43b6e81fbe48bfba90a8775d5ecddf))
+	ROM_LOAD( "b-6.u49", 0x40000, 0x10000, CRC(d596ceb0) SHA1(8c82fb638688971ef11159a6b240253e63f0949d))
+	ROM_LOAD( "b-7.u48", 0x50000, 0x10000, CRC(79336b6c) SHA1(7a95875f3071bdc3ee25c0e6a5a3c00ef02dc977))
+	ROM_LOAD( "b-8.u44", 0x60000, 0x10000, CRC(1f82121a) SHA1(106da0f39f1260d0761217ed0a24c1611bfd7f05))
+	ROM_LOAD( "b-9.u43", 0x70000, 0x10000, CRC(4ea22349) SHA1(14dfd3dbd51f8bd6f3290293b8ea1c165e8cf7fd))
+ROM_END
+
+const rom_entry *isa8_cga_tetriskr_device::device_rom_region() const
+{
+	return ROM_NAME( tetriskr_cga );
+}
+
 READ8_MEMBER(pcxt_state::disk_iobank_r)
 {
 	//printf("Read Prototyping card [%02x] @ PC=%05x\n",offset,space.device().safe_pc());
@@ -243,7 +340,7 @@ Pit8253
 // pc_speaker_get_spk, pc_speaker_set_spkrdata, and pc_speaker_set_input already exists in MESS, can the implementations be merged?
 UINT8 pcxt_state::pcxt_speaker_get_spk()
 {
-	return m_pc_spkrdata & m_pc_input;
+	return m_pc_spkrdata & m_pit_out2;
 }
 
 void pcxt_state::pcxt_speaker_set_spkrdata(UINT8 data)
@@ -252,39 +349,14 @@ void pcxt_state::pcxt_speaker_set_spkrdata(UINT8 data)
 	m_speaker->level_w(pcxt_speaker_get_spk());
 }
 
-void pcxt_state::pcxt_speaker_set_input(UINT8 data)
-{
-	m_pc_input = data ? 1 : 0;
-	m_speaker->level_w(pcxt_speaker_get_spk());
-}
-
 
 WRITE_LINE_MEMBER(pcxt_state::ibm5150_pit8253_out2_changed)
 {
-	pcxt_speaker_set_input(state);
+	m_pit_out2 = state ? 1 : 0;
+	m_speaker->level_w(pcxt_speaker_get_spk());
 }
 
 
-static const struct pit8253_interface pc_pit8253_config =
-{
-	{
-		{
-			XTAL_14_31818MHz/12,                /* heartbeat IRQ */
-			DEVCB_NULL,
-			DEVCB_DEVICE_LINE_MEMBER("pic8259_1", pic8259_device, ir0_w)
-		}, {
-			XTAL_14_31818MHz/12,                /* dram refresh */
-			DEVCB_NULL,
-			DEVCB_NULL
-		}, {
-			XTAL_14_31818MHz/12,                /* pio port c pin 4, and speaker polling enough */
-			DEVCB_NULL,
-			DEVCB_DRIVER_LINE_MEMBER(pcxt_state,ibm5150_pit8253_out2_changed)
-		}
-	}
-};
-
-
 READ8_MEMBER(pcxt_state::port_a_r)
 {
 	if(!(m_port_b_data & 0x80))//???
@@ -314,12 +386,11 @@ READ8_MEMBER(pcxt_state::port_b_r)
 
 READ8_MEMBER(pcxt_state::port_c_r)
 {
-	int timer2_output = m_pit8253->get_output(2);
 	if ( m_port_b_data & 0x01 )
 	{
-		m_wss2_data = ( m_wss2_data & ~0x10 ) | ( timer2_output ? 0x10 : 0x00 );
+		m_wss2_data = ( m_wss2_data & ~0x10 ) | ( m_pit_out2 ? 0x10 : 0x00 );
 	}
-	m_wss2_data = ( m_wss2_data & ~0x20 ) | ( timer2_output ? 0x20 : 0x00 );
+	m_wss2_data = ( m_wss2_data & ~0x20 ) | ( m_pit_out2 ? 0x20 : 0x00 );
 
 	return m_wss2_data;//TODO
 }
@@ -330,7 +401,7 @@ READ8_MEMBER(pcxt_state::port_c_r)
 WRITE8_MEMBER(pcxt_state::port_b_w)
 {
 	/* PPI controller port B*/
-	m_pit8253->gate2_w(BIT(data, 0));
+	m_pit8253->write_gate2(BIT(data, 0));
 	pcxt_speaker_set_spkrdata( data & 0x02 );
 	m_port_b_data = data;
 // device_t *beep = machine().device<beep_device>("beep");
@@ -357,26 +428,6 @@ WRITE8_MEMBER(pcxt_state::sys_reset_w)
 	m_maincpu->set_input_line(INPUT_LINE_RESET, PULSE_LINE);
 }
 
-static I8255A_INTERFACE( ppi8255_0_intf )
-{
-	DEVCB_DRIVER_MEMBER(pcxt_state,port_a_r),           /* Port A read */
-	DEVCB_NULL,                         /* Port A write */
-	DEVCB_DRIVER_MEMBER(pcxt_state,port_b_r),           /* Port B read */
-	DEVCB_DRIVER_MEMBER(pcxt_state,port_b_w),           /* Port B write */
-	DEVCB_DRIVER_MEMBER(pcxt_state,port_c_r),           /* Port C read */
-	DEVCB_NULL                          /* Port C write */
-};
-
-static I8255A_INTERFACE( ppi8255_1_intf )
-{
-	DEVCB_NULL,                         /* Port A read */
-	DEVCB_DRIVER_MEMBER(pcxt_state,wss_1_w),                /* Port A write */
-	DEVCB_NULL,                         /* Port B read */
-	DEVCB_DRIVER_MEMBER(pcxt_state,wss_2_w),                /* Port B write */
-	DEVCB_NULL,                         /* Port C read */
-	DEVCB_DRIVER_MEMBER(pcxt_state,sys_reset_w)         /* Port C write */
-};
-
 
 /*Floppy Disk Controller 765 device*/
 /*Currently we only emulate it at a point that the BIOS will pass the checks*/
@@ -502,26 +553,10 @@ WRITE_LINE_MEMBER(pcxt_state::pc_dack1_w){ set_dma_channel(m_dma8237_1, 1, state
 WRITE_LINE_MEMBER(pcxt_state::pc_dack2_w){ set_dma_channel(m_dma8237_1, 2, state); }
 WRITE_LINE_MEMBER(pcxt_state::pc_dack3_w){ set_dma_channel(m_dma8237_1, 3, state); }
 
-static I8237_INTERFACE( dma8237_1_config )
-{
-	DEVCB_DRIVER_LINE_MEMBER(pcxt_state,pc_dma_hrq_changed),
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(pcxt_state, pc_dma_read_byte),
-	DEVCB_DRIVER_MEMBER(pcxt_state, pc_dma_write_byte),
-	{ DEVCB_NULL, DEVCB_NULL, DEVCB_NULL, DEVCB_NULL },
-	{ DEVCB_NULL, DEVCB_NULL, DEVCB_NULL, DEVCB_NULL },
-	{ DEVCB_DRIVER_LINE_MEMBER(pcxt_state,pc_dack0_w), DEVCB_DRIVER_LINE_MEMBER(pcxt_state,pc_dack1_w), DEVCB_DRIVER_LINE_MEMBER(pcxt_state,pc_dack2_w), DEVCB_DRIVER_LINE_MEMBER(pcxt_state,pc_dack3_w) }
-};
-
 /******************
 8259 IRQ controller
 ******************/
 
-IRQ_CALLBACK_MEMBER(pcxt_state::irq_callback)
-{
-	return m_pic8259_1->acknowledge();
-}
-
 static ADDRESS_MAP_START( filetto_map, AS_PROGRAM, 8, pcxt_state )
 	AM_RANGE(0x00000, 0x9ffff) AM_RAM //work RAM 640KB
 	AM_RANGE(0xa0000, 0xbffff) AM_RAM //CGA VRAM
@@ -557,16 +592,10 @@ static ADDRESS_MAP_START( filetto_io, AS_IO, 8, pcxt_state )
 	AM_RANGE(0x0312, 0x0312) AM_READ_PORT("IN0") //Prototyping card,read only
 ADDRESS_MAP_END
 
-WRITE8_MEMBER(pcxt_state::tetriskr_bg_bank_w)
-{
-	m_bg_bank = (data & 0x0f) ^ 8;
-}
-
 static ADDRESS_MAP_START( tetriskr_io, AS_IO, 8, pcxt_state )
 	ADDRESS_MAP_GLOBAL_MASK(0x3ff)
 	AM_IMPORT_FROM( pcxt_io_common )
 	AM_RANGE(0x0200, 0x020f) AM_RAM //game port
-	AM_RANGE(0x03c0, 0x03c0) AM_WRITE(tetriskr_bg_bank_w)
 	AM_RANGE(0x03c8, 0x03c8) AM_READ_PORT("IN0")
 	AM_RANGE(0x03c9, 0x03c9) AM_READ_PORT("IN1")
 //  AM_RANGE(0x03ce, 0x03ce) AM_READ_PORT("IN1") //read then discarded?
@@ -649,70 +678,69 @@ static INPUT_PORTS_START( tetriskr )
 	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
 INPUT_PORTS_END
 
-
-
-/* F4 Character Displayer */
-static const gfx_layout pc_16_charlayout =
-{
-	8, 16,                  /* 8 x 16 characters */
-	256,                    /* 256 characters */
-	1,                  /* 1 bits per pixel */
-	{ 0 },                  /* no bitplanes */
-	/* x offsets */
-	{ 0, 1, 2, 3, 4, 5, 6, 7 },
-	/* y offsets */
-	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8, 2048*8, 2049*8, 2050*8, 2051*8, 2052*8, 2053*8, 2054*8, 2055*8 },
-	8*8                 /* every char takes 2 x 8 bytes */
-};
-
-static const gfx_layout pc_8_charlayout =
-{
-	8, 8,                   /* 8 x 8 characters */
-	512,                    /* 512 characters */
-	1,                  /* 1 bits per pixel */
-	{ 0 },                  /* no bitplanes */
-	/* x offsets */
-	{ 0, 1, 2, 3, 4, 5, 6, 7 },
-	/* y offsets */
-	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8 },
-	8*8                 /* every char takes 8 bytes */
-};
-
-static GFXDECODE_START( pcxt )
-	GFXDECODE_ENTRY( "gfx1", 0x0000, pc_16_charlayout,    3, 1 )
-	GFXDECODE_ENTRY( "gfx1", 0x1000, pc_8_charlayout,   3, 1 )
-GFXDECODE_END
-
-
 void pcxt_state::machine_reset()
 {
 	m_bank = -1;
 	m_lastvalue = -1;
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(pcxt_state::irq_callback),this));
 
 	m_pc_spkrdata = 0;
-	m_pc_input = 0;
+	m_pit_out2 = 0;
 	m_wss2_data = 0;
 	m_speaker->level_w(0);
 }
 
-static MACHINE_CONFIG_START( filetto, pcxt_state )
+SLOT_INTERFACE_START( filetto_isa8_cards )
+	SLOT_INTERFACE_INTERNAL("filetto",  ISA8_CGA_FILETTO)
+	SLOT_INTERFACE_INTERNAL("tetriskr", ISA8_CGA_TETRISKR)
+SLOT_INTERFACE_END
+
+
+static MACHINE_CONFIG_FRAGMENT(pcxt)
 	MCFG_CPU_ADD("maincpu", I8088, XTAL_14_31818MHz/3)
 	MCFG_CPU_PROGRAM_MAP(filetto_map)
 	MCFG_CPU_IO_MAP(filetto_io)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DEVICE("pic8259_1", pic8259_device, inta_cb)
 
+	MCFG_DEVICE_ADD("pit8253", PIT8253, 0)
+	MCFG_PIT8253_CLK0(XTAL_14_31818MHz/12) /* heartbeat IRQ */
+	MCFG_PIT8253_OUT0_HANDLER(DEVWRITELINE("pic8259_1", pic8259_device, ir0_w))
+	MCFG_PIT8253_CLK1(XTAL_14_31818MHz/12) /* dram refresh */
+	MCFG_PIT8253_CLK2(XTAL_14_31818MHz/12) /* pio port c pin 4, and speaker polling enough */
+	MCFG_PIT8253_OUT2_HANDLER(WRITELINE(pcxt_state, ibm5150_pit8253_out2_changed))
 
-	MCFG_PIT8253_ADD( "pit8253", pc_pit8253_config )
+	MCFG_DEVICE_ADD("ppi8255_0", I8255A, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(pcxt_state, port_a_r))
+	MCFG_I8255_IN_PORTB_CB(READ8(pcxt_state, port_b_r))
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(pcxt_state, port_b_w))
+	MCFG_I8255_IN_PORTC_CB(READ8(pcxt_state, port_c_r))
 
-	MCFG_I8255A_ADD( "ppi8255_0", ppi8255_0_intf )
-	MCFG_I8255A_ADD( "ppi8255_1", ppi8255_1_intf )
+	MCFG_DEVICE_ADD("ppi8255_1", I8255A, 0)
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(pcxt_state, wss_1_w))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(pcxt_state, wss_2_w))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(pcxt_state, sys_reset_w))
 
-	MCFG_I8237_ADD( "dma8237_1", XTAL_14_31818MHz/3, dma8237_1_config )
+	MCFG_DEVICE_ADD("dma8237_1", AM9517A, XTAL_14_31818MHz/3)
+	MCFG_I8237_OUT_HREQ_CB(WRITELINE(pcxt_state, pc_dma_hrq_changed))
+	MCFG_I8237_IN_MEMR_CB(READ8(pcxt_state, pc_dma_read_byte))
+	MCFG_I8237_OUT_MEMW_CB(WRITE8(pcxt_state, pc_dma_write_byte))
+	MCFG_I8237_OUT_DACK_0_CB(WRITELINE(pcxt_state, pc_dack0_w))
+	MCFG_I8237_OUT_DACK_1_CB(WRITELINE(pcxt_state, pc_dack1_w))
+	MCFG_I8237_OUT_DACK_2_CB(WRITELINE(pcxt_state, pc_dack2_w))
+	MCFG_I8237_OUT_DACK_3_CB(WRITELINE(pcxt_state, pc_dack3_w))
 
 	MCFG_PIC8259_ADD( "pic8259_1", INPUTLINE("maincpu", 0), VCC, NULL )
 
-	MCFG_FRAGMENT_ADD( pcvideo_cga )
-	MCFG_GFXDECODE(pcxt)
+	MCFG_DEVICE_ADD("isa", ISA8, 0)
+	MCFG_ISA8_CPU(":maincpu")
+	MCFG_ISA_OUT_IRQ2_CB(DEVWRITELINE("pic8259_1", pic8259_device, ir2_w))
+	MCFG_ISA_OUT_IRQ3_CB(DEVWRITELINE("pic8259_1", pic8259_device, ir3_w))
+	MCFG_ISA_OUT_IRQ4_CB(DEVWRITELINE("pic8259_1", pic8259_device, ir4_w))
+	MCFG_ISA_OUT_IRQ5_CB(DEVWRITELINE("pic8259_1", pic8259_device, ir5_w))
+	MCFG_ISA_OUT_IRQ6_CB(DEVWRITELINE("pic8259_1", pic8259_device, ir6_w))
+	MCFG_ISA_OUT_IRQ7_CB(DEVWRITELINE("pic8259_1", pic8259_device, ir7_w))
+	MCFG_ISA_OUT_DRQ1_CB(DEVWRITELINE("dma8237_1", am9517a_device, dreq1_w))
+	MCFG_ISA_OUT_DRQ2_CB(DEVWRITELINE("dma8237_1", am9517a_device, dreq2_w))
+	MCFG_ISA_OUT_DRQ3_CB(DEVWRITELINE("dma8237_1", am9517a_device, dreq3_w))
 
 	/*Sound Hardware*/
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -725,13 +753,18 @@ static MACHINE_CONFIG_START( filetto, pcxt_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 MACHINE_CONFIG_END
 
-static MACHINE_CONFIG_DERIVED( tetriskr, filetto )
+static MACHINE_CONFIG_START( filetto, pcxt_state )
+	MCFG_FRAGMENT_ADD( pcxt )
+	MCFG_ISA8_SLOT_ADD("isa", "isa1", filetto_isa8_cards, "filetto", true)
+MACHINE_CONFIG_END
+
+static MACHINE_CONFIG_START( tetriskr, pcxt_state )
+	MCFG_FRAGMENT_ADD( pcxt )
+
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_IO_MAP(tetriskr_io)
 
-	MCFG_DEVICE_MODIFY("screen")
-	MCFG_VIDEO_START(pc_cga_superimpose)
-	MCFG_SCREEN_UPDATE_DRIVER(pcxt_state, screen_update_tetriskr)
+	MCFG_ISA8_SLOT_ADD("isa", "isa1", filetto_isa8_cards, "tetriskr", true)
 
 	MCFG_DEVICE_REMOVE("voice")
 MACHINE_CONFIG_END
@@ -753,9 +786,6 @@ ROM_START( filetto )
 	ROM_LOAD( "m2.u3", 0x20000, 0x10000, CRC(abc64869) SHA1(564fc9d90d241a7b7776160b3fd036fb08037355) )
 	ROM_LOAD( "m3.u4", 0x30000, 0x10000, CRC(0c1e8a67) SHA1(f1b9280c65fcfcb5ec481cae48eb6f52d6cdbc9d) )
 
-	ROM_REGION( 0x2000, "gfx1", 0 )
-	ROM_LOAD("u67.bin", 0x0000, 0x2000, CRC(09710122) SHA1(de84bdd9245df287bbd3bb808f0c3531d13a3545) )
-
 	ROM_REGION( 0x40000, "samples", 0 ) // UM5100 sample roms?
 	ROM_LOAD16_BYTE("v1.u15",  0x00000, 0x20000, CRC(613ddd07) SHA1(ebda3d559315879819cb7034b5696f8e7861fe42) )
 	ROM_LOAD16_BYTE("v2.u14",  0x00001, 0x20000, CRC(427e012e) SHA1(50514a6307e63078fe7444a96e39d834684db7df) )
@@ -764,20 +794,6 @@ ROM_END
 ROM_START( tetriskr )
 	ROM_REGION( 0x100000, "maincpu", 0 ) /* code */
 	ROM_LOAD( "b-10.u10", 0xf0000, 0x10000, CRC(efc2a0f6) SHA1(5f0f1e90237bee9b78184035a32055b059a91eb3) )
-
-	ROM_REGION( 0x2000, "gfx1",ROMREGION_ERASE00 ) /* gfx - 1bpp font*/
-	ROM_LOAD( "b-3.u36", 0x1800, 0x0800, CRC(1a636f9a) SHA1(a356cc57914d0c9b9127670b55d1f340e64b1ac9) )
-	ROM_IGNORE( 0x1800 )
-
-	ROM_REGION( 0x80000+1, "gfx2",ROMREGION_INVERT | ROMREGION_ERASEFF )
-	ROM_LOAD( "b-1.u59", 0x00000, 0x10000, CRC(4719d986) SHA1(6e0499944b968d96fbbfa3ead6237d69c769d634))
-	ROM_LOAD( "b-2.u58", 0x10000, 0x10000, CRC(599e1154) SHA1(14d99f90b4fedeab0ac24ffa9b1fd9ad0f0ba699))
-	ROM_LOAD( "b-4.u54", 0x20000, 0x10000, CRC(e112c450) SHA1(dfdecfc6bd617ec520b7563b7caf44b79d498bd3))
-	ROM_LOAD( "b-5.u53", 0x30000, 0x10000, CRC(050b7650) SHA1(5981dda4ed43b6e81fbe48bfba90a8775d5ecddf))
-	ROM_LOAD( "b-6.u49", 0x40000, 0x10000, CRC(d596ceb0) SHA1(8c82fb638688971ef11159a6b240253e63f0949d))
-	ROM_LOAD( "b-7.u48", 0x50000, 0x10000, CRC(79336b6c) SHA1(7a95875f3071bdc3ee25c0e6a5a3c00ef02dc977))
-	ROM_LOAD( "b-8.u44", 0x60000, 0x10000, CRC(1f82121a) SHA1(106da0f39f1260d0761217ed0a24c1611bfd7f05))
-	ROM_LOAD( "b-9.u43", 0x70000, 0x10000, CRC(4ea22349) SHA1(14dfd3dbd51f8bd6f3290293b8ea1c165e8cf7fd))
 ROM_END
 
 DRIVER_INIT_MEMBER(pcxt_state,filetto)
