@@ -660,12 +660,6 @@ INTERRUPT_GEN_MEMBER(playch10_state::playch10_interrupt){
 		device.execute().set_input_line(INPUT_LINE_NMI, PULSE_LINE);
 }
 
-static const nesapu_interface nes_config =
-{
-	"cart"
-};
-
-
 static MACHINE_CONFIG_START( playch10, playch10_state )
 	// basic machine hardware
 	MCFG_CPU_ADD("maincpu", Z80, 8000000/2) // 4 MHz
@@ -678,8 +672,9 @@ static MACHINE_CONFIG_START( playch10, playch10_state )
 
 
 	// video hardware
-	MCFG_GFXDECODE(playch10)
-	MCFG_PALETTE_LENGTH(256+8*4*16)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", playch10)
+	MCFG_PALETTE_ADD("palette", 256+8*4*16)
+	MCFG_PALETTE_INIT_OWNER(playch10_state, playch10)
 	MCFG_DEFAULT_LAYOUT(layout_dualhuov)
 
 	MCFG_SCREEN_ADD("top", RASTER)
@@ -687,22 +682,25 @@ static MACHINE_CONFIG_START( playch10, playch10_state )
 	MCFG_SCREEN_SIZE(32*8, 262)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(playch10_state, screen_update_playch10_top)
+	MCFG_SCREEN_PALETTE("palette")
 
 	MCFG_SCREEN_ADD("bottom", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_SIZE(32*8, 262)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(playch10_state, screen_update_playch10_bottom)
+	MCFG_SCREEN_PALETTE("palette")
 
-
-	MCFG_PPU2C03B_ADD("ppu", playch10_ppu_interface)
+	MCFG_PPU2C03B_ADD("ppu")
 	MCFG_PPU2C0X_SET_SCREEN("bottom")
+	MCFG_PPU2C0X_CPU("cart")
+	MCFG_PPU2C0X_COLORBASE(256)
 	MCFG_PPU2C0X_SET_NMI(playch10_state, ppu_irq)
 
 	// sound hardware
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD("nesapu", NES_APU, N2A03_DEFAULTCLOCK)
-	MCFG_SOUND_CONFIG(nes_config)
+	MCFG_NES_APU_CPU("cart")
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
 	MCFG_DAC_ADD("dac")
