@@ -196,10 +196,12 @@ static MACHINE_CONFIG_START( pooyan, pooyan_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(pooyan_state, screen_update_pooyan)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(pooyan)
-	MCFG_PALETTE_LENGTH(16*16+16*16)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", pooyan)
+	MCFG_PALETTE_ADD("palette", 16*16+16*16)
+	MCFG_PALETTE_INDIRECT_ENTRIES(32)
+	MCFG_PALETTE_INIT_OWNER(pooyan_state, pooyan)
 
 	/* sound hardware */
 	MCFG_FRAGMENT_ADD(timeplt_sound)
