@@ -20,7 +20,7 @@
 #include "machine/mc146818.h"
 #include "machine/nscsi_hd.h"
 #include "sound/dac.h"
-#include "mcfglgcy.h"
+#include "machine/nvram.h"
 
 
 /*************************************
@@ -53,7 +53,9 @@ public:
 			m_dac_l(*this, "dac_l"),
 			m_dac_r(*this, "dac_r"),
 			m_tms_timer1(*this, "tms_timer1"),
-			m_tms_tx_timer(*this, "tms_tx_timer")
+			m_tms_tx_timer(*this, "tms_tx_timer"),
+			m_palette(*this, "palette"),
+			m_nvram(*this, "nvram")
 	{}
 
 	#define VIDEO_ADDR_MASK     0x3fffffff
@@ -99,6 +101,8 @@ public:
 	required_device<dac_device>     m_dac_r;
 	required_device<timer_device>   m_tms_timer1;
 	required_device<timer_device>   m_tms_tx_timer;
+	required_device<palette_device> m_palette;
+	required_device<nvram_device>   m_nvram;
 
 	DECLARE_WRITE32_MEMBER(cyrix_cache_w);
 	DECLARE_READ8_MEMBER(nvram_r);
@@ -126,7 +130,7 @@ public:
 	UINT8   m_io_reg;
 	UINT8   m_irq_status;
 	UINT32  m_dpyaddr;
-	UINT16 *m_palette;
+	UINT16 *m_paletteram;
 	UINT32  m_speedup_count;
 	UINT32  m_tms_io_regs[0x80];
 	bitmap_ind16 m_update_bitmap;
@@ -152,11 +156,9 @@ protected:
 
 void rastersp_state::machine_start()
 {
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(rastersp_state::irq_callback),this));
-
 	m_nvram8 = auto_alloc_array(machine(), UINT8, NVRAM_SIZE);
-
-	m_palette = auto_alloc_array(machine(), UINT16, 0x8000);
+	m_nvram->set_base(m_nvram8,NVRAM_SIZE);
+	m_paletteram = auto_alloc_array(machine(), UINT16, 0x8000);
 
 	membank("bank1")->set_base(m_dram);
 	membank("bank2")->set_base(&m_dram[0x10000/4]);
@@ -207,7 +209,7 @@ WRITE32_MEMBER( rastersp_state::dpylist_w )
 	// TODO: This should probably be done in sync with the video scan
 	if (m_dpyaddr == 0)
 	{
-		m_update_bitmap.fill(get_black_pen(machine()));
+		m_update_bitmap.fill(m_palette->black_pen());
 		return;
 	}
 
@@ -244,7 +246,7 @@ WRITE32_MEMBER( rastersp_state::dpylist_w )
 				UINT32 pixels = (word2 >> 16) & 0x1ff;
 				UINT32 palbase = (word2 >> 4) & 0xf00;
 
-				UINT16* palptr = &m_palette[palbase];
+				UINT16* palptr = &m_paletteram[palbase];
 				UINT8* srcptr = reinterpret_cast<UINT8*>(&m_dram[0]);
 
 				UINT32 acc = srcaddr << 8;
@@ -300,7 +302,7 @@ void rastersp_state::upload_palette(UINT32 word1, UINT32 word2)
 	while (entries--)
 	{
 		UINT32 data = m_dram[addr / 4];
-		m_palette[index++] = data & 0xffff;
+		m_paletteram[index++] = data & 0xffff;
 		addr += 4;
 	}
 }
@@ -452,25 +454,6 @@ WRITE32_MEMBER( rastersp_state:: port3_w )
  *
  *************************************/
 
-static NVRAM_HANDLER( rastersp )
-{
-	rastersp_state *state = machine.driver_data<rastersp_state>();
-
-	if (read_or_write)
-	{
-		file->write(state->m_nvram8, NVRAM_SIZE);
-	}
-	else if (file)
-	{
-		file->read(state->m_nvram8, NVRAM_SIZE);
-	}
-	else
-	{
-		memcpy(state->m_nvram8, machine.root_device().memregion("nvram")->base(), NVRAM_SIZE);
-	}
-}
-
-
 WRITE8_MEMBER( rastersp_state::nvram_w )
 {
 	offset *= 4;
@@ -882,6 +865,7 @@ static MACHINE_CONFIG_START( rastersp, rastersp_state )
 	MCFG_CPU_PROGRAM_MAP(cpu_map)
 	MCFG_CPU_IO_MAP(io_map)
 	MCFG_CPU_VBLANK_INT_DRIVER("screen", rastersp_state, vblank_irq)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(rastersp_state,irq_callback)
 
 	MCFG_CPU_ADD("dsp", TMS32031, 33330000)
 	MCFG_TMS3203X_CONFIG(tms_config)
@@ -891,7 +875,7 @@ static MACHINE_CONFIG_START( rastersp, rastersp_state )
 	MCFG_TIMER_DRIVER_ADD("tms_timer1", rastersp_state, tms_timer1)
 	MCFG_TIMER_DRIVER_ADD("tms_tx_timer", rastersp_state, tms_tx_timer)
 	MCFG_MC146818_ADD( "rtc", XTAL_32_768kHz )
-	MCFG_NVRAM_HANDLER(rastersp)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
 	MCFG_NSCSI_BUS_ADD("scsibus")
 	MCFG_NSCSI_ADD("scsibus:0", rastersp_scsi_devices, "harddisk", true)
@@ -905,9 +889,9 @@ static MACHINE_CONFIG_START( rastersp, rastersp_state )
 	MCFG_SCREEN_UPDATE_DRIVER(rastersp_state, screen_update)
 	MCFG_SCREEN_REFRESH_RATE(50)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500)) /* not accurate */
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, RRRRR_GGGGGG_BBBBB)
-	MCFG_PALETTE_LENGTH(65536)
+	MCFG_PALETTE_ADD_RRRRRGGGGGGBBBBB("palette")
 
 	/* Sound */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
