@@ -168,11 +168,6 @@ static ADDRESS_MAP_START( ramdac_map, AS_0, 8, rltennis_state )
 	AM_RANGE(0x000, 0x3ff) AM_DEVREADWRITE("ramdac",ramdac_device,ramdac_pal_r,ramdac_rgb888_w)
 ADDRESS_MAP_END
 
-static RAMDAC_INTERFACE( ramdac_intf )
-{
-	1
-};
-
 static MACHINE_CONFIG_START( rltennis, rltennis_state )
 
 	MCFG_CPU_ADD("maincpu", M68000, RLT_XTAL/2) /* 68000P8  ??? */
@@ -183,13 +178,15 @@ static MACHINE_CONFIG_START( rltennis, rltennis_state )
 	MCFG_SCREEN_REFRESH_RATE( RLT_REFRESH_RATE )
 	MCFG_SCREEN_SIZE(320, 240)
 	MCFG_SCREEN_VISIBLE_AREA(0,319, 0, 239)
-
 	MCFG_SCREEN_UPDATE_DRIVER(rltennis_state, screen_update_rltennis)
-	MCFG_PALETTE_LENGTH(256)
+	MCFG_SCREEN_PALETTE("palette")
+
+	MCFG_PALETTE_ADD("palette", 256)
 
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MCFG_RAMDAC_ADD("ramdac", ramdac_intf, ramdac_map)
+	MCFG_RAMDAC_ADD("ramdac", ramdac_map, "palette")
+	MCFG_RAMDAC_SPLIT_READ(1)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
