@@ -145,38 +145,6 @@ MACHINE_RESET_MEMBER( s11a_state, s11a )
 	membank("bgbank")->set_entry(0);
 }
 
-static const pia6821_interface pia21_intf =
-{
-	DEVCB_DRIVER_MEMBER(s11_state, dac_r),      /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_NULL,     /* line CA1 in */
-	DEVCB_LINE_GND,     /* line CB1 in */
-	DEVCB_NULL,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s11_state, sound_w),        /* port A out */
-	DEVCB_DRIVER_MEMBER(s11_state, sol2_w),     /* port B out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia21_ca2_w),       /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia21_cb2_w),       /* line CB2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq),       /* IRQA */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq)        /* IRQB */
-};
-
-static const pia6821_interface pia24_intf =
-{
-	DEVCB_NULL,     /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_LINE_GND,     /* line CA1 in */
-	DEVCB_LINE_GND,     /* line CB1 in */
-	DEVCB_LINE_VCC,     /* line CA2 in */
-	DEVCB_LINE_VCC,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s11_state, lamp0_w),        /* port A out */
-	DEVCB_DRIVER_MEMBER(s11_state, lamp1_w),        /* port B out */
-	DEVCB_NULL,     /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia24_cb2_w),       /* line CB2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq),       /* IRQA */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq)        /* IRQB */
-};
-
 WRITE8_MEMBER( s11a_state::dig0_w )
 {
 	data &= 0x7f;
@@ -189,107 +157,11 @@ WRITE8_MEMBER( s11a_state::dig0_w )
 	set_segment2(0);
 }
 
-static const pia6821_interface pia28_intf =
-{
-	DEVCB_DRIVER_MEMBER(s11_state, pia28_w7_r),     /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_NULL,     /* line CA1 in */
-	DEVCB_NULL,     /* line CB1 in */
-	DEVCB_NULL,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s11a_state, dig0_w),        /* port A out */
-	DEVCB_DRIVER_MEMBER(s11_state, dig1_w),     /* port B out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia28_ca2_w),       /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia28_cb2_w),       /* line CB2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq),       /* IRQA */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq)        /* IRQB */
-};
-
-static const pia6821_interface pia2c_intf =
-{
-	DEVCB_NULL,     /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_NULL,     /* line CA1 in */
-	DEVCB_NULL,     /* line CB1 in */
-	DEVCB_NULL,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s11_state, pia2c_pa_w),     /* port A out */
-	DEVCB_DRIVER_MEMBER(s11_state, pia2c_pb_w),     /* port B out */
-	DEVCB_NULL,     /* line CA2 out */
-	DEVCB_NULL,     /* line CB2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq),       /* IRQA */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq)        /* IRQB */
-};
-
-static const pia6821_interface pia30_intf =
-{
-	DEVCB_DRIVER_MEMBER(s11_state, switch_r),       /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_LINE_GND,     /* line CA1 in */
-	DEVCB_LINE_GND,     /* line CB1 in */
-	DEVCB_LINE_VCC,     /* line CA2 in */
-	DEVCB_LINE_VCC,     /* line CB2 in */
-	DEVCB_NULL,     /* port A out */
-	DEVCB_DRIVER_MEMBER(s11_state, switch_w),       /* port B out */
-	DEVCB_NULL,     /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia30_cb2_w),       /* line CB2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq),       /* IRQA */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq)        /* IRQB */
-};
-
-static const pia6821_interface pia34_intf =
-{
-	DEVCB_NULL,     /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_NULL,     /* line CA1 in */
-	DEVCB_NULL,     /* line CB1 in */
-	DEVCB_NULL,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s11_state, pia34_pa_w),     /* port A out */
-	DEVCB_DRIVER_MEMBER(s11_state, pia34_pb_w),     /* port B out */
-	DEVCB_NULL,     /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia34_cb2_w),       /* line CB2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq),       /* IRQA */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia_irq)        /* IRQB */
-};
-
 WRITE8_MEMBER( s11a_state::bgbank_w )
 {
 	membank("bgbank")->set_entry(data & 0x03);
 }
 
-static const pia6821_interface pias_intf =
-{
-	DEVCB_DRIVER_MEMBER(s11_state, dac_r),      /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pias_ca1_r),        /* line CA1 in */
-	DEVCB_NULL,     /* line CB1 in */
-	DEVCB_NULL,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s11_state, sound_w),        /* port A out */
-	DEVCB_DRIVER_MEMBER(s11_state, dac_w),      /* port B out */
-	DEVCB_NULL,     /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pia40_cb2_w),       /* line CB2 out */
-	DEVCB_CPU_INPUT_LINE("audiocpu", M6800_IRQ_LINE),       /* IRQA */
-	DEVCB_CPU_INPUT_LINE("audiocpu", M6800_IRQ_LINE)        /* IRQB */
-};
-
-static const pia6821_interface pia40_intf =
-{
-	DEVCB_NULL,     /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pias_ca1_r),        /* line CA1 in */
-	DEVCB_NULL,     /* line CB1 in */
-	DEVCB_LINE_VCC,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s11_state, pia40_pa_w),     /* port A out */
-	DEVCB_DRIVER_MEMBER(s11_state, pia40_pb_w),     /* port B out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pias_ca2_w),        /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s11_state, pias_cb2_w),        /* line CB2 out */
-	DEVCB_CPU_INPUT_LINE("bgcpu", M6809_FIRQ_LINE),     /* IRQA */
-	DEVCB_CPU_INPUT_LINE("bgcpu", INPUT_LINE_NMI)       /* IRQB */
-};
-
 DRIVER_INIT_MEMBER( s11a_state, s11a )
 {
 	UINT8 *BGROM = memregion("bgcpu")->base();
@@ -311,12 +183,51 @@ static MACHINE_CONFIG_START( s11a, s11a_state )
 	MCFG_FRAGMENT_ADD( genpin_audio )
 
 	/* Devices */
-	MCFG_PIA6821_ADD("pia21", pia21_intf)
-	MCFG_PIA6821_ADD("pia24", pia24_intf)
-	MCFG_PIA6821_ADD("pia28", pia28_intf)
-	MCFG_PIA6821_ADD("pia2c", pia2c_intf)
-	MCFG_PIA6821_ADD("pia30", pia30_intf)
-	MCFG_PIA6821_ADD("pia34", pia34_intf)
+	MCFG_DEVICE_ADD("pia21", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(s11_state, dac_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s11_state, sound_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s11_state, sol2_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(s11_state, pia21_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s11_state, pia21_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(s11_state, pia_irq))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(s11_state, pia_irq))
+
+	MCFG_DEVICE_ADD("pia24", PIA6821, 0)
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s11_state, lamp0_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s11_state, lamp1_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s11_state, pia24_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(s11_state, pia_irq))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(s11_state, pia_irq))
+
+	MCFG_DEVICE_ADD("pia28", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(s11_state, pia28_w7_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s11a_state, dig0_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s11_state, dig1_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(s11_state, pia28_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s11_state, pia28_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(s11_state, pia_irq))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(s11_state, pia_irq))
+
+	MCFG_DEVICE_ADD("pia2c", PIA6821, 0)
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s11_state, pia2c_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s11_state, pia2c_pb_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(s11_state, pia_irq))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(s11_state, pia_irq))
+
+	MCFG_DEVICE_ADD("pia30", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(s11_state, switch_r))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s11_state, switch_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s11_state, pia30_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(s11_state, pia_irq))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(s11_state, pia_irq))
+
+	MCFG_DEVICE_ADD("pia34", PIA6821, 0)
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s11_state, pia34_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s11_state, pia34_pb_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s11_state, pia34_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(s11_state, pia_irq))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(s11_state, pia_irq))
+
 	MCFG_NVRAM_ADD_1FILL("nvram")
 
 	/* Add the soundcard */
@@ -331,7 +242,13 @@ static MACHINE_CONFIG_START( s11a, s11a_state )
 	MCFG_SOUND_ADD("hc55516", HC55516, 0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "speech", 0.50)
 
-	MCFG_PIA6821_ADD("pias", pias_intf)
+	MCFG_DEVICE_ADD("pias", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(s11_state, dac_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s11_state, sound_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s11_state, dac_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s11_state, pia40_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(DEVWRITELINE("audiocpu", m6802_cpu_device, irq_line))
+	MCFG_PIA_IRQB_HANDLER(DEVWRITELINE("audiocpu", m6802_cpu_device, irq_line))
 
 	/* Add the background music card */
 	MCFG_CPU_ADD("bgcpu", M6809E, 8000000) // MC68B09E
@@ -345,7 +262,13 @@ static MACHINE_CONFIG_START( s11a, s11a_state )
 	MCFG_DAC_ADD("dac1")
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "bg", 0.50)
 
-	MCFG_PIA6821_ADD("pia40", pia40_intf)
+	MCFG_DEVICE_ADD("pia40", PIA6821, 0)
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s11_state, pia40_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s11_state, pia40_pb_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(s11_state, pias_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s11_state, pias_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(DEVWRITELINE("bgcpu", m6809e_device, firq_line))
+	MCFG_PIA_IRQB_HANDLER(DEVWRITELINE("bgcpu", m6809e_device, nmi_line))
 MACHINE_CONFIG_END
 
 /*------------------------
@@ -380,6 +303,20 @@ ROM_START(f14_p4)
 	ROM_LOAD("f14_u19.l1", 0x18000, 0x8000, CRC(d0de4a7c) SHA1(46ecd5786653add47751cc56b38d9db7c4622377))
 ROM_END
 
+ROM_START(f14_p5)
+	ROM_REGION(0x10000, "maincpu", 0)
+	ROM_LOAD("f14_u26.p5", 0x4000, 0x4000, CRC(f5d9b132) SHA1(b6a5edf8f015ae86513cd28ce2436f3c07199d47))
+	ROM_LOAD("f14_u27.p5", 0x8000, 0x8000, CRC(45de7e15) SHA1(a3160cbc0d3a5eb4cdd301251c40806e7c1d3ee8))
+
+	ROM_REGION(0x20000, "audiocpu", ROMREGION_ERASEFF)
+	ROM_LOAD("f14_u21.l1", 0x18000, 0x8000, CRC(e412300c) SHA1(382d0cfa47abea295f0c7501bc0a010473e9d73b))
+	ROM_LOAD("f14_u22.l1", 0x10000, 0x8000, CRC(c9dd7496) SHA1(de3cb855d87033274cc912578b02d1593d2d69f9))
+
+	ROM_REGION(0x30000, "bgcpu", ROMREGION_ERASEFF)
+	ROM_LOAD("f14_u4.l1", 0x10000, 0x8000, CRC(43ecaabf) SHA1(64b50dbff03cd556130d0cff47b951fdf37d397d))
+	ROM_LOAD("f14_u19.l1", 0x18000, 0x8000, CRC(d0de4a7c) SHA1(46ecd5786653add47751cc56b38d9db7c4622377))
+ROM_END
+
 ROM_START(f14_l1)
 	ROM_REGION(0x10000, "maincpu", 0)
 	ROM_LOAD("f14_u26.l1", 0x4000, 0x4000, CRC(62c2e615) SHA1(456ce0d1f74fa5e619c272880ba8ac6819848ddc))
@@ -476,11 +413,27 @@ ROM_START(pb_l3)
 	ROM_LOAD("pbot_u19.l1", 0x18000, 0x8000, CRC(40eb4e9f) SHA1(07b0557b35599a2dd5aa66a306fbbe8f50eed998))
 ROM_END
 
+ROM_START(pb_p4)
+	ROM_REGION(0x10000, "maincpu", 0)
+	ROM_LOAD("u26-l2.rom", 0x4000, 0x4000, CRC(e3b94ca4) SHA1(1db2acb025941cc165cc7ec70a160e07ab1eeb2e))
+	ROM_LOAD("u27_p4.bin", 0x8000, 0x8000, CRC(fbe2c466) SHA1(ac6c8f953b00e0ec7626cd1ccf4e16851ab905d0))
+
+	ROM_REGION(0x20000, "audiocpu", ROMREGION_ERASEFF)
+	ROM_LOAD("pbot_u21.l1", 0x18000, 0x8000, CRC(3eab88d9) SHA1(667e3b675e2ae8fec6a6faddb9b0dd5531d64f8f))
+	ROM_LOAD("pbot_u22.l1", 0x10000, 0x8000, CRC(a2d2c9cb) SHA1(46437dc54538f1626caf41a2818ddcf8000c44e4))
+
+	ROM_REGION(0x30000, "bgcpu", ROMREGION_ERASEFF)
+	ROM_LOAD("pbot_u4.l1", 0x10000, 0x8000, CRC(de5926bd) SHA1(3d111e27c5f0c8c0afc5fe5cc45bf77c12b69228))
+	ROM_LOAD("pbot_u19.l1", 0x18000, 0x8000, CRC(40eb4e9f) SHA1(07b0557b35599a2dd5aa66a306fbbe8f50eed998))
+ROM_END
+
 GAME(1987, f14_l1,   0,      s11a, s11a, s11a_state, s11a, ROT0, "Williams", "F14 Tomcat (L-1)", GAME_IS_SKELETON_MECHANICAL)
 GAME(1987, f14_p3,   f14_l1, s11a, s11a, s11a_state, s11a, ROT0, "Williams", "F14 Tomcat (P-3)", GAME_IS_SKELETON_MECHANICAL)
 GAME(1987, f14_p4,   f14_l1, s11a, s11a, s11a_state, s11a, ROT0, "Williams", "F14 Tomcat (P-4)", GAME_IS_SKELETON_MECHANICAL)
+GAME(1987, f14_p5,   f14_l1, s11a, s11a, s11a_state, s11a, ROT0, "Williams", "F14 Tomcat (P-5)", GAME_IS_SKELETON_MECHANICAL)
 GAME(1987, fire_l3,  0,      s11a, s11a, s11a_state, s11a, ROT0, "Williams", "Fire! (L-3)", GAME_IS_SKELETON_MECHANICAL)
 GAME(1987, milln_l3, 0,      s11a, s11a, s11a_state, s11a, ROT0, "Williams", "Millionaire (L-3)", GAME_IS_SKELETON_MECHANICAL)
 GAME(1986, pb_l5,    0,      s11a, s11a, s11a_state, s11a, ROT0, "Williams", "Pin-Bot (L-5)", GAME_IS_SKELETON_MECHANICAL)
 GAME(1986, pb_l2,    pb_l5,  s11a, s11a, s11a_state, s11a, ROT0, "Williams", "Pin-Bot (L-2)", GAME_IS_SKELETON_MECHANICAL)
 GAME(1986, pb_l3,    pb_l5,  s11a, s11a, s11a_state, s11a, ROT0, "Williams", "Pin-Bot (L-3)", GAME_IS_SKELETON_MECHANICAL)
+GAME(1986, pb_p4,    pb_l5,  s11a, s11a, s11a_state, s11a, ROT0, "Williams", "Pin-Bot (P-4)", GAME_IS_SKELETON_MECHANICAL)
