@@ -278,59 +278,11 @@ WRITE8_MEMBER( s7_state::sound_w )
 	m_pias->cb1_w(m_cb1);
 }
 
-static const pia6821_interface pia21_intf =
-{
-	DEVCB_DRIVER_MEMBER(s7_state, dac_r),       /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_NULL,     /* line CA1 in */
-	DEVCB_LINE_GND,     /* line CB1 in */
-	DEVCB_LINE_VCC,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s7_state, sound_w),     /* port A out */
-	DEVCB_DRIVER_MEMBER(s7_state, sol2_w),      /* port B out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia21_ca2_w),        /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia21_cb2_w),        /* line CB2 out */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE),        /* IRQA */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE)     /* IRQB */
-};
-
-static const pia6821_interface pia22_intf =
-{
-	DEVCB_NULL,     /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_LINE_GND,     /* line CA1 in */
-	DEVCB_LINE_GND,     /* line CB1 in */
-	DEVCB_NULL,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s7_state, sol0_w),      /* port A out */
-	DEVCB_DRIVER_MEMBER(s7_state, sol1_w),      /* port B out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia22_ca2_w),        /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia22_cb2_w),        /* line CB2 out */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE),        /* IRQA */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE)     /* IRQB */
-};
-
 WRITE8_MEMBER( s7_state::lamp0_w )
 {
 	m_maincpu->set_input_line(M6800_IRQ_LINE, CLEAR_LINE);
 }
 
-static const pia6821_interface pia24_intf =
-{
-	DEVCB_NULL,     /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_LINE_GND,     /* line CA1 in */
-	DEVCB_LINE_GND,     /* line CB1 in */
-	DEVCB_LINE_VCC,     /* line CA2 in */
-	DEVCB_LINE_VCC,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s7_state, lamp0_w),     /* port A out */
-	DEVCB_DRIVER_MEMBER(s7_state, lamp1_w),     /* port B out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia24_ca2_w),        /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia24_cb2_w),        /* line CB2 out */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE),        /* IRQA */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE)     /* IRQB */
-};
-
 READ_LINE_MEMBER( s7_state::pia28_ca1_r )
 {
 	return BIT(ioport("DIAGS")->read(), 2); // advance button
@@ -379,22 +331,6 @@ READ8_MEMBER( s7_state::dips_r )
 	return 0xff;
 }
 
-static const pia6821_interface pia28_intf =
-{
-	DEVCB_DRIVER_MEMBER(s7_state, dips_r),      /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia28_ca1_r),        /* line CA1 in */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia28_cb1_r),        /* line CB1 in */
-	DEVCB_NULL,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s7_state, dig0_w),      /* port A out */
-	DEVCB_DRIVER_MEMBER(s7_state, dig1_w),      /* port B out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia28_ca2_w),        /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia28_cb2_w),        /* line CB2 out */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE),        /* IRQA */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE)     /* IRQB */
-};
-
 READ8_MEMBER( s7_state::switch_r )
 {
 	char kbdrow[8];
@@ -407,22 +343,6 @@ WRITE8_MEMBER( s7_state::switch_w )
 	m_kbdrow = data;
 }
 
-static const pia6821_interface pia30_intf =
-{
-	DEVCB_DRIVER_MEMBER(s7_state, switch_r),        /* port A in */
-	DEVCB_NULL,     /* port B in */
-	DEVCB_LINE_GND,     /* line CA1 in */
-	DEVCB_LINE_GND,     /* line CB1 in */
-	DEVCB_LINE_VCC,     /* line CA2 in */
-	DEVCB_LINE_VCC,     /* line CB2 in */
-	DEVCB_NULL,     /* port A out */
-	DEVCB_DRIVER_MEMBER(s7_state, switch_w),        /* port B out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia30_ca2_w),        /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pia30_cb2_w),        /* line CB2 out */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE),    /* IRQA */
-	DEVCB_CPU_INPUT_LINE("maincpu", M6800_IRQ_LINE)     /* IRQB */
-};
-
 WRITE_LINE_MEMBER( s7_state::pias_cb2_w )
 {
 // speech clock
@@ -445,22 +365,6 @@ WRITE8_MEMBER( s7_state::dac_w )
 	m_dac->write_unsigned8(data);
 }
 
-static const pia6821_interface pias_intf =
-{
-	DEVCB_NULL,     /* port A in */
-	DEVCB_DRIVER_MEMBER(s7_state, dac_r),       /* port B in */
-	DEVCB_LINE_VCC,     /* line CA1 in */
-	DEVCB_LINE_GND,     /* line CB1 in */
-	DEVCB_NULL,     /* line CA2 in */
-	DEVCB_NULL,     /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(s7_state, dac_w),       /* port A out */
-	DEVCB_NULL,     /* port B out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pias_ca2_w),     /* line CA2 out */
-	DEVCB_DRIVER_LINE_MEMBER(s7_state, pias_cb2_w),     /* line CB2 out */
-	DEVCB_CPU_INPUT_LINE("audiocpu", M6800_IRQ_LINE),       /* IRQA */
-	DEVCB_CPU_INPUT_LINE("audiocpu", M6800_IRQ_LINE)        /* IRQB */
-};
-
 TIMER_DEVICE_CALLBACK_MEMBER( s7_state::irq)
 {
 	if (m_t_c > 0x70)
@@ -483,12 +387,52 @@ static MACHINE_CONFIG_START( s7, s7_state )
 	MCFG_FRAGMENT_ADD( genpin_audio )
 
 	/* Devices */
-	MCFG_PIA6821_ADD("pia21", pia21_intf)
-	MCFG_PIA6821_ADD("pia22", pia22_intf)
-	MCFG_PIA6821_ADD("pia24", pia24_intf)
-	MCFG_PIA6821_ADD("pia28", pia28_intf)
-	MCFG_PIA6821_ADD("pia30", pia30_intf)
+	MCFG_DEVICE_ADD("pia21", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(s7_state, dac_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s7_state, sound_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s7_state, sol2_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(s7_state, pia21_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s7_state, pia21_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+	MCFG_PIA_IRQB_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+
+	MCFG_DEVICE_ADD("pia22", PIA6821, 0)
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s7_state, sol0_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s7_state, sol1_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(s7_state, pia22_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s7_state, pia22_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+	MCFG_PIA_IRQB_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+
+	MCFG_DEVICE_ADD("pia24", PIA6821, 0)
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s7_state, lamp0_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s7_state, lamp1_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(s7_state, pia24_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s7_state, pia24_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+	MCFG_PIA_IRQB_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+
+	MCFG_DEVICE_ADD("pia28", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(s7_state, dips_r))
+	MCFG_PIA_READCA1_HANDLER(READLINE(s7_state, pia28_ca1_r))
+	MCFG_PIA_READCB1_HANDLER(READLINE(s7_state, pia28_cb1_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s7_state, dig0_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s7_state, dig1_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(s7_state, pia28_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s7_state, pia28_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+	MCFG_PIA_IRQB_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+
+	MCFG_DEVICE_ADD("pia30", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(s7_state, switch_r))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(s7_state, switch_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(s7_state, pia30_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s7_state, pia30_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+	MCFG_PIA_IRQB_HANDLER(DEVWRITELINE("maincpu", m6808_cpu_device, irq_line))
+
 	MCFG_NVRAM_ADD_1FILL("nvram")
+
 	/* Add the soundcard */
 	MCFG_CPU_ADD("audiocpu", M6808, 4000000)
 	MCFG_CPU_PROGRAM_MAP(s7_audio_map)
@@ -498,7 +442,14 @@ static MACHINE_CONFIG_START( s7, s7_state )
 	MCFG_SPEAKER_STANDARD_MONO("speech")
 	MCFG_SOUND_ADD("hc55516", HC55516, 0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "speech", 0.50)
-	MCFG_PIA6821_ADD("pias", pias_intf)
+
+	MCFG_DEVICE_ADD("pias", PIA6821, 0)
+	MCFG_PIA_READPB_HANDLER(READ8(s7_state, dac_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(s7_state, dac_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(s7_state, pias_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(s7_state, pias_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(DEVWRITELINE("audiocpu", m6808_cpu_device, irq_line))
+	MCFG_PIA_IRQB_HANDLER(DEVWRITELINE("audiocpu", m6808_cpu_device, irq_line))
 MACHINE_CONFIG_END
 
 
@@ -582,6 +533,20 @@ ROM_START(jngld_l2)
 	ROM_LOAD("sound3.716", 0xf800, 0x0800, CRC(55a10d13) SHA1(521d4cdfb0ed8178b3594cedceae93b772a951a4))
 ROM_END
 
+ROM_START(jngld_l1)
+	ROM_REGION(0x10000, "maincpu", 0)
+	ROM_LOAD("ic26-l1.716", 0x5800, 0x0800, CRC(df37bb45) SHA1(60a0670e73f2370d6269ef241b581f5b0ade6ea0) )
+	ROM_LOAD("ic14-l1.716", 0x6000, 0x0800, CRC(0144af0d) SHA1(2e5b6e35613decbac10f9b99c7a8cbe7f63b6b07) )
+	ROM_LOAD("ic20.716", 0x6800, 0x0800, CRC(dfb4b75a) SHA1(bcf017b01236f755cee419e398bbd8955ae3576a) )
+	ROM_LOAD("ic17.532", 0x7000, 0x1000, CRC(bb571a17) SHA1(fb0b7f247673dae0744d4188e1a03749a2237165) )
+
+	ROM_REGION(0x10000, "audiocpu", 0)
+	ROM_LOAD("speech7.532", 0xb000, 0x1000, CRC(83ffb695) SHA1(f9151bdfdefd5c178ca7eb5122f62b700d64f41a))
+	ROM_LOAD("speech5.532", 0xc000, 0x1000, CRC(754bd474) SHA1(c05f48bb07085683de469603880eafd28dffd9f5))
+	ROM_LOAD("speech6.532", 0xd000, 0x1000, CRC(f2ac6a52) SHA1(5b3e743eac382d571fd049f92ea9955342b9ffa0))
+	ROM_LOAD("sound3.716", 0xf800, 0x0800, CRC(55a10d13) SHA1(521d4cdfb0ed8178b3594cedceae93b772a951a4))
+ROM_END
+
 /*--------------------------------
 / Pharaoh - Sys.7 (Game #504)
 /--------------------------------*/
@@ -617,7 +582,7 @@ ROM_END
 /*-----------------------------------
 / Thunderball - Sys.7 (Game #508) - Prototype
 /-----------------------------------*/
-ROM_START(thund_p1)
+ROM_START(thund_p1)  // dated 6/22
 	ROM_REGION(0x10000, "maincpu", 0)
 	ROM_LOAD("ic20.532", 0x5000, 0x1000, CRC(aa3f07dc) SHA1(f31662972046f9a874380a8dcd1bc9259de5f6ba))
 	ROM_LOAD("ic14.532", 0x6000, 0x1000, CRC(1cd34f1f) SHA1(3f5b5a319570c26a3d34d640fef2ac6c04b83b70))
@@ -631,6 +596,35 @@ ROM_START(thund_p1)
 	ROM_LOAD("sound12.532", 0xf000, 0x1000, CRC(cc70af52) SHA1(d9c2840acdcd69aab39fc647dd4819eccc06af33))
 ROM_END
 
+ROM_START(thund_p2)  // dated 8/31
+	ROM_REGION(0x10000, "maincpu", 0)
+	ROM_LOAD("ic20_831.532", 0x5000, 0x1000, CRC(91ed089b) SHA1(0e47f5a87cb227a6ee8645931bfa807219b388ef))
+	ROM_LOAD("ic14_831.532", 0x6000, 0x1000, CRC(873ccf24) SHA1(2723aa7d059a111374d8145391fbef0c81043e4b))
+	ROM_LOAD("ic17.532", 0x7000, 0x1000, CRC(bb571a17) SHA1(fb0b7f247673dae0744d4188e1a03749a2237165))
+
+	ROM_REGION(0x10000, "audiocpu", 0)
+	ROM_LOAD("speech7.532", 0xb000, 0x1000, CRC(33e1b041) SHA1(f50c0311bde69fa6e8071e297a81cc3ef3dcf44f))
+	ROM_LOAD("speech5.532", 0xc000, 0x1000, CRC(11780c80) SHA1(bcc5efcd69b4f776feef32484a872863847d64cd))
+	ROM_LOAD("speech6.532", 0xd000, 0x1000, CRC(ab688698) SHA1(e0cbac44a6fe30a49da478c32500a0b43903cc2b))
+	ROM_LOAD("speech4.532", 0xe000, 0x1000, CRC(2a4d6f4b) SHA1(e6f8a1a6e6abc81f980a4938d98abb250e8e1e3b))
+	ROM_LOAD("sound12.532", 0xf000, 0x1000, CRC(cc70af52) SHA1(d9c2840acdcd69aab39fc647dd4819eccc06af33))
+ROM_END
+
+ROM_START(thund_p3) // dated 9/08
+	ROM_REGION(0x10000, "maincpu", 0)
+	ROM_LOAD("ic20_908.532", 0x5000, 0x1000, CRC(21f87917) SHA1(6cfdd5aadafb2d137f2e959fa047ffbe5c09ac2c))
+	ROM_LOAD("ic14_908.532", 0x6000, 0x1000, CRC(099e798e) SHA1(38d79622b4d68c69308ee109f47509e0733828ba))
+	ROM_LOAD("ic17.532", 0x7000, 0x1000, CRC(bb571a17) SHA1(fb0b7f247673dae0744d4188e1a03749a2237165))
+
+	ROM_REGION(0x10000, "audiocpu", 0)
+	ROM_LOAD("speech7.532", 0xb000, 0x1000, CRC(33e1b041) SHA1(f50c0311bde69fa6e8071e297a81cc3ef3dcf44f))
+	ROM_LOAD("speech5.532", 0xc000, 0x1000, CRC(11780c80) SHA1(bcc5efcd69b4f776feef32484a872863847d64cd))
+	ROM_LOAD("speech6.532", 0xd000, 0x1000, CRC(ab688698) SHA1(e0cbac44a6fe30a49da478c32500a0b43903cc2b))
+	ROM_LOAD("speech4.532", 0xe000, 0x1000, CRC(2a4d6f4b) SHA1(e6f8a1a6e6abc81f980a4938d98abb250e8e1e3b))
+	ROM_LOAD("sound12.532", 0xf000, 0x1000, CRC(cc70af52) SHA1(d9c2840acdcd69aab39fc647dd4819eccc06af33))
+ROM_END
+
+
 /*-------------------------------
 / Hyperball - Sys.7 - (Game #509)
 /-------------------------------*/
@@ -644,6 +638,17 @@ ROM_START(hypbl_l4)
 	ROM_LOAD("sound12.532", 0xf000, 0x1000, CRC(06051e5e) SHA1(f0ab4be812ceaf771829dd549f2a612156102a93))
 ROM_END
 
+ROM_START(hypbl_l2)
+	ROM_REGION(0x10000, "maincpu", 0)
+	ROM_LOAD("ic20-l2.532", 0x5000, 0x1000, CRC(f5f66cf1) SHA1(885b4961b6ec712b7445001d448d881245be1234))
+	ROM_LOAD("ic14-l2.532", 0x6000, 0x1000, CRC(8eb82df4) SHA1(854b3f1fa2112fbdba19f4c843f67989c0572d8c))
+	ROM_LOAD("ic17.532", 0x7000, 0x1000, CRC(6f4c0c4c) SHA1(1036067e2c85da867983e6e51ee2a7b5135000df))
+
+	ROM_REGION(0x10000, "audiocpu", 0)
+	ROM_LOAD("sound12.532", 0xf000, 0x1000, CRC(06051e5e) SHA1(f0ab4be812ceaf771829dd549f2a612156102a93))
+ROM_END
+
+
 /*----------------------------
 / Barracora- Sys.7 (Game #510)
 /----------------------------*/
@@ -728,6 +733,17 @@ ROM_START(jst_l2)
 	ROM_LOAD("sound12.532", 0xf000, 0x1000, CRC(3bbc90bf) SHA1(82154e719ceca5c72d1ab034bc4ff5e3ebb36832))
 ROM_END
 
+ROM_START(jst_l1)
+	ROM_REGION(0x10000, "maincpu", 0)
+	ROM_LOAD("ic26-l1.716", 0x5800, 0x0800, CRC(123d8ffc) SHA1(c227a53653525269ea77203d4d1b14132058c073) )
+	ROM_LOAD("ic14-l1.716", 0x6000, 0x0800, CRC(9871ebb2) SHA1(75c639a26d3bf7e05de7b5be063742f7448284ac) )
+	ROM_LOAD("ic20.716", 0x6800, 0x0800, CRC(dfb4b75a) SHA1(bcf017b01236f755cee419e398bbd8955ae3576a) )
+	ROM_LOAD("ic17.532", 0x7000, 0x1000, CRC(bb571a17) SHA1(fb0b7f247673dae0744d4188e1a03749a2237165) )
+
+	ROM_REGION(0x10000, "audiocpu", 0)
+	ROM_LOAD("sound12.532", 0xf000, 0x1000, CRC(3bbc90bf) SHA1(82154e719ceca5c72d1ab034bc4ff5e3ebb36832))
+ROM_END
+
 /*---------------------------
 / Laser Cue - Sys.7 (Game #520)
 /--------------------------*/
@@ -780,8 +796,11 @@ GAME( 1980, csmic_l1, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Cosmic
 GAME( 1982, dfndr_l4, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Defender (L-4)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME( 1983, fpwr2_l2, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Firepower II (L-2)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME( 1981, hypbl_l4, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "HyperBall (L-4)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
+GAME( 1981, hypbl_l2, hypbl_l4, s7, s7, driver_device, 0, ROT0, "Williams", "HyperBall (L-2)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME( 1983, jst_l2,   0,     s7, s7, driver_device, 0, ROT0, "Williams", "Joust (L-2)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
+GAME( 1983, jst_l1,   jst_l2,s7, s7, driver_device, 0, ROT0, "Williams", "Joust (L-1)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME( 1981, jngld_l2, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Jungle Lord (L-2)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
+GAME( 1981, jngld_l1, jngld_l2,s7, s7, driver_device, 0, ROT0, "Williams", "Jungle Lord (L-1)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME( 1983, lsrcu_l2, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Laser Cue (L-2)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME( 1981, pharo_l2, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Pharaoh (L-2)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME( 1981, solar_l2, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Solar Fire (L-2)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
@@ -789,3 +808,5 @@ GAME( 1984, strlt_l1, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Star L
 GAME( 1982, tmfnt_l5, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Time Fantasy (L-5)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME( 1982, wrlok_l3, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Warlok (L-3)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
 GAME( 1982, thund_p1, 0,     s7, s7, driver_device, 0, ROT0, "Williams", "Thunderball (P-1)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
+GAME( 1982, thund_p2, thund_p1,s7, s7, driver_device, 0, ROT0, "Williams", "Thunderball (P-2)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
+GAME( 1982, thund_p3, thund_p1,s7, s7, driver_device, 0, ROT0, "Williams", "Thunderball (P-3)", GAME_MECHANICAL | GAME_NOT_WORKING | GAME_NO_SOUND)
