@@ -120,7 +120,7 @@ public:
 static UINT8 mxtc_config_r(device_t *busdevice, device_t *device, int function, int reg)
 {
 	savquest_state *state = busdevice->machine().driver_data<savquest_state>();
-//  mame_printf_debug("MXTC: read %d, %02X\n", function, reg);
+//  osd_printf_debug("MXTC: read %d, %02X\n", function, reg);
 
 	if((reg & 0xfe) == 0)
 		return (reg & 1) ? 0x80 : 0x86; // Vendor ID, Intel
@@ -134,7 +134,7 @@ static UINT8 mxtc_config_r(device_t *busdevice, device_t *device, int function,
 static void mxtc_config_w(device_t *busdevice, device_t *device, int function, int reg, UINT8 data)
 {
 	savquest_state *state = busdevice->machine().driver_data<savquest_state>();
-//  mame_printf_debug("%s:MXTC: write %d, %02X, %02X\n", machine.describe_context(), function, reg, data);
+//  osd_printf_debug("%s:MXTC: write %d, %02X, %02X\n", machine.describe_context(), function, reg, data);
 
 	#if 1
 	switch(reg)
@@ -259,7 +259,7 @@ static void intel82439tx_pci_w(device_t *busdevice, device_t *device, int functi
 static UINT8 piix4_config_r(device_t *busdevice, device_t *device, int function, int reg)
 {
 	savquest_state *state = busdevice->machine().driver_data<savquest_state>();
-//  mame_printf_debug("PIIX4: read %d, %02X\n", function, reg);
+//  osd_printf_debug("PIIX4: read %d, %02X\n", function, reg);
 
 	if((reg & 0xfe) == 0)
 		return (reg & 1) ? 0x80 : 0x86; // Vendor ID, Intel
@@ -279,7 +279,7 @@ static UINT8 piix4_config_r(device_t *busdevice, device_t *device, int function,
 static void piix4_config_w(device_t *busdevice, device_t *device, int function, int reg, UINT8 data)
 {
 	savquest_state *state = busdevice->machine().driver_data<savquest_state>();
-//  mame_printf_debug("%s:PIIX4: write %d, %02X, %02X\n", machine.describe_context(), function, reg, data);
+//  osd_printf_debug("%s:PIIX4: write %d, %02X, %02X\n", machine.describe_context(), function, reg, data);
 	state->m_piix4_config_reg[function][reg] = data;
 }
 
@@ -643,7 +643,6 @@ void savquest_state::machine_start()
 	m_bios_e8000_ram = auto_alloc_array(machine(), UINT32, 0x4000/4);
 	m_bios_ec000_ram = auto_alloc_array(machine(), UINT32, 0x4000/4);
 
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(savquest_state::irq_callback),this));
 	intel82439tx_init();
 }
 
@@ -660,21 +659,11 @@ WRITE_LINE_MEMBER(savquest_state::vblank_assert)
 {
 }
 
-static const voodoo_config voodoo_intf =
-{
-	2, //               fbmem;
-	4,//                tmumem0;
-	4,//                tmumem1;
-	"screen",//     screen;
-	"maincpu",//            cputag;
-	DEVCB_DRIVER_LINE_MEMBER(savquest_state,vblank_assert),//    vblank;
-	DEVCB_NULL//             stall;
-};
-
 static MACHINE_CONFIG_START( savquest, savquest_state )
 	MCFG_CPU_ADD("maincpu", PENTIUM2, 450000000) // actually Pentium II 450
 	MCFG_CPU_PROGRAM_MAP(savquest_map)
 	MCFG_CPU_IO_MAP(savquest_io)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DEVICE("pic8259_1", pic8259_device, inta_cb)
 
 	MCFG_FRAGMENT_ADD( pcat_common )
 
@@ -691,7 +680,12 @@ static MACHINE_CONFIG_START( savquest, savquest_state )
 	/* video hardware */
 	MCFG_FRAGMENT_ADD( pcvideo_s3_vga )
 
-	MCFG_3DFX_VOODOO_2_ADD("voodoo", STD_VOODOO_2_CLOCK, voodoo_intf)
+	MCFG_DEVICE_ADD("voodoo", VOODOO_2, STD_VOODOO_2_CLOCK)
+	MCFG_VOODOO_FBMEM(2)
+	MCFG_VOODOO_TMUMEM(4,4)
+	MCFG_VOODOO_SCREEN_TAG("screen")
+	MCFG_VOODOO_CPU_TAG("maincpu")
+	MCFG_VOODOO_VBLANK_CB(WRITELINE(savquest_state,vblank_assert))
 MACHINE_CONFIG_END
 
 ROM_START( savquest )
