@@ -378,9 +378,11 @@ static MACHINE_CONFIG_START( sidepckt, sidepckt_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(sidepckt_state, screen_update_sidepckt)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(sidepckt)
-	MCFG_PALETTE_LENGTH(256)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", sidepckt)
+	MCFG_PALETTE_ADD("palette", 256)
+	MCFG_PALETTE_INIT_OWNER(sidepckt_state, sidepckt)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
