@@ -247,10 +247,11 @@ static MACHINE_CONFIG_START( skyfox, skyfox_state )
 	MCFG_SCREEN_SIZE(512, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0+0x60, 320-1+0x60, 0+16, 256-1-16)    // from $30*2 to $CC*2+8
 	MCFG_SCREEN_UPDATE_DRIVER(skyfox_state, screen_update_skyfox)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(skyfox)
-	MCFG_PALETTE_LENGTH(256+256)    /* 256 static colors (+256 for the background??) */
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", skyfox)
+	MCFG_PALETTE_ADD("palette", 256+256)    /* 256 static colors (+256 for the background??) */
+	MCFG_PALETTE_INIT_OWNER(skyfox_state, skyfox)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
