@@ -182,7 +182,8 @@ public:
 		m_videoram(*this, "videoram"),
 		m_io9400(*this, "io9400"),
 		m_io9401(*this, "io9401"),
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_palette(*this, "palette") { }
 
 	required_shared_ptr<UINT8> m_colorram;
 	required_shared_ptr<UINT8> m_videoram;
@@ -190,9 +191,10 @@ public:
 	required_shared_ptr<UINT8> m_io9401;
 	DECLARE_WRITE8_MEMBER(zvideoram_w);
 	DECLARE_READ8_MEMBER(spaceg_colorram_r);
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(spaceg);
 	UINT32 screen_update_spaceg(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	required_device<cpu_device> m_maincpu;
+	required_device<palette_device> m_palette;
 };
 
 /*************************************
@@ -201,31 +203,31 @@ public:
  *
  *************************************/
 
-void spaceg_state::palette_init()
+PALETTE_INIT_MEMBER(spaceg_state, spaceg)
 {
 	int i;
 
 	for (i = 0; i < 128; i++)
-		palette_set_color (machine(), i, MAKE_RGB(0x00,0x00,0x00));
+		palette.set_pen_color (i, rgb_t(0x00,0x00,0x00));
 
 	// proms are currently undumped...
-	palette_set_color (machine(), 0, MAKE_RGB(0x00,0x00,0x00)); //ok czarny
-	palette_set_color (machine(), 1, MAKE_RGB(0x7f,0x00,0x00));//???
-	palette_set_color (machine(), 2, MAKE_RGB(0xff,0xff,0xff)); //ok+ bialy
-	palette_set_color (machine(), 3, MAKE_RGB(0xff,0x00,0x00)); //ok j.czerw.
-	palette_set_color (machine(), 4, MAKE_RGB(0x3f,0x3f,0xff)); //ok j.niebieski
-	palette_set_color (machine(), 5, MAKE_RGB(0x3f,0xff,0x3f)); //ok j.zielony
-	palette_set_color (machine(), 6, MAKE_RGB(0xff,0xbf,0xbf)); //ok+ 'majtki'
-	palette_set_color (machine(), 7, MAKE_RGB(0xff,0xff,0x00)); //ok+ zolty
+	palette.set_pen_color (0, rgb_t(0x00,0x00,0x00)); //ok czarny
+	palette.set_pen_color (1, rgb_t(0x7f,0x00,0x00));//???
+	palette.set_pen_color (2, rgb_t(0xff,0xff,0xff)); //ok+ bialy
+	palette.set_pen_color (3, rgb_t(0xff,0x00,0x00)); //ok j.czerw.
+	palette.set_pen_color (4, rgb_t(0x3f,0x3f,0xff)); //ok j.niebieski
+	palette.set_pen_color (5, rgb_t(0x3f,0xff,0x3f)); //ok j.zielony
+	palette.set_pen_color (6, rgb_t(0xff,0xbf,0xbf)); //ok+ 'majtki'
+	palette.set_pen_color (7, rgb_t(0xff,0xff,0x00)); //ok+ zolty
 
-	palette_set_color (machine(), 8, MAKE_RGB(0xff,0x7f,0x00)); //ok+ pomaranczowy
-	palette_set_color (machine(), 9, MAKE_RGB(0x3f,0xbf,0xff)); //ok j.niebieski (ciemniejszy od 13)
-	palette_set_color (machine(), 10, MAKE_RGB(0x3f,0xbf,0x3f));    //ok+ c.zielony
-	palette_set_color (machine(), 11, MAKE_RGB(0x00,0xff,0x00));    //ok j.zielony
-	palette_set_color (machine(), 12, MAKE_RGB(0x7f,0x00,0x00));    //ok brazowy (c.czerw)
-	palette_set_color (machine(), 13, MAKE_RGB(0x7f,0xbf,0xff));    //ok j.niebieski (jasniejszy od 9)
-	palette_set_color (machine(), 14, MAKE_RGB(0x00,0xff,0xff));//???
-	palette_set_color (machine(), 15, MAKE_RGB(0x7f,0x7f,0x7f));//???
+	palette.set_pen_color (8, rgb_t(0xff,0x7f,0x00)); //ok+ pomaranczowy
+	palette.set_pen_color (9, rgb_t(0x3f,0xbf,0xff)); //ok j.niebieski (ciemniejszy od 13)
+	palette.set_pen_color (10, rgb_t(0x3f,0xbf,0x3f));    //ok+ c.zielony
+	palette.set_pen_color (11, rgb_t(0x00,0xff,0x00));    //ok j.zielony
+	palette.set_pen_color (12, rgb_t(0x7f,0x00,0x00));    //ok brazowy (c.czerw)
+	palette.set_pen_color (13, rgb_t(0x7f,0xbf,0xff));    //ok j.niebieski (jasniejszy od 9)
+	palette.set_pen_color (14, rgb_t(0x00,0xff,0xff));//???
+	palette.set_pen_color (15, rgb_t(0x7f,0x7f,0x7f));//???
 }
 
 WRITE8_MEMBER(spaceg_state::zvideoram_w)
@@ -281,13 +283,13 @@ READ8_MEMBER(spaceg_state::spaceg_colorram_r)
 		{
 			/* palette 1 */
 			int col_ind = offset & 0x1f;
-			palette_set_color_rgb(machine(), 0x10 + 0x00 + col_ind, pal3bit(rgbcolor >> 0), pal3bit(rgbcolor >> 6), pal3bit(rgbcolor >> 3));
+			m_palette->set_pen_color(0x10 + 0x00 + col_ind, pal3bit(rgbcolor >> 0), pal3bit(rgbcolor >> 6), pal3bit(rgbcolor >> 3));
 		}
 		else if ((offset >= 0x300) && (offset < 0x320)) /* 0xa300- 0xa31f */
 		{
 			/* palette 2 */
 			int col_ind = offset & 0x1f;
-			palette_set_color_rgb(machine(), 0x10 + 0x00 + col_ind, pal3bit(rgbcolor >> 0), pal3bit(rgbcolor >> 6), pal3bit(rgbcolor >> 3));
+			m_palette->set_pen_color(0x10 + 0x00 + col_ind, pal3bit(rgbcolor >> 0), pal3bit(rgbcolor >> 6), pal3bit(rgbcolor >> 3));
 		}
 		else
 			logerror("palette? read from colorram offset = %04x\n",offset);
@@ -402,23 +404,6 @@ static INPUT_PORTS_START( spaceg )
 INPUT_PORTS_END
 
 
-/*************************************
- *
- *  Sound interface
- *
- *************************************/
-
-
-//-------------------------------------------------
-//  sn76496_config psg_intf
-//-------------------------------------------------
-
-//static const sn76496_config psg_intf =
-//{
-//    DEVCB_NULL
-//};
-
-
 /*************************************
  *
  *  Machine config
@@ -439,23 +424,22 @@ static MACHINE_CONFIG_START( spaceg, spaceg_state )
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 255, 32, 255)
 	MCFG_SCREEN_UPDATE_DRIVER(spaceg_state, screen_update_spaceg)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_PALETTE_LENGTH(16+128-16)
+	MCFG_PALETTE_ADD("palette", 16+128-16)
+	MCFG_PALETTE_INIT_OWNER(spaceg_state, spaceg)
 
 	/* sound hardware */
 //  MCFG_SPEAKER_STANDARD_MONO("mono")
 
 //  MCFG_SOUND_ADD("sn1", SN76496, 15468480/4)
 //  MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-//  MCFG_SOUND_CONFIG(psg_intf)
 
 //  MCFG_SOUND_ADD("sn2", SN76496, 15468480/4)
 //  MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-//  MCFG_SOUND_CONFIG(psg_intf)
 
 //  MCFG_SOUND_ADD("sn3", SN76496, 15468480/4)
 //  MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-//  MCFG_SOUND_CONFIG(psg_intf)
 
 //  MCFG_DAC_ADD("dac")
 //  MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
