@@ -463,11 +463,12 @@ static MACHINE_CONFIG_START( sprint8, sprint8_state )
 	MCFG_SCREEN_VISIBLE_AREA(0, 495, 0, 231)
 	MCFG_SCREEN_UPDATE_DRIVER(sprint8_state, screen_update_sprint8)
 	MCFG_SCREEN_VBLANK_DRIVER(sprint8_state, screen_eof_sprint8)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(sprint8)
-	MCFG_PALETTE_LENGTH(36)
-
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", sprint8)
+	MCFG_PALETTE_ADD("palette", 36)
+	MCFG_PALETTE_INDIRECT_ENTRIES(18)
+	MCFG_PALETTE_INIT_OWNER(sprint8_state, sprint8)
 
 	/* sound hardware */
 	/* the proper way is to hook up 4 speakers, but they are not really
