@@ -421,9 +421,10 @@ static MACHINE_CONFIG_START( st0016, st0016_state )
 	MCFG_SCREEN_SIZE(48*8, 48*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 48*8-1, 0*8, 48*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(st0016_state, screen_update_st0016)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(st0016)
-	MCFG_PALETTE_LENGTH(16*16*4+1)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", st0016)
+	MCFG_PALETTE_ADD("palette", 16*16*4+1)
 
 	MCFG_VIDEO_START_OVERRIDE(st0016_state,st0016)
 
