@@ -219,10 +219,11 @@ static MACHINE_CONFIG_START( tagteam, tagteam_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(tagteam_state, screen_update_tagteam)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(tagteam)
-	MCFG_PALETTE_LENGTH(32)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", tagteam)
+	MCFG_PALETTE_ADD("palette", 32)
+	MCFG_PALETTE_INIT_OWNER(tagteam_state, tagteam)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
