@@ -528,10 +528,12 @@ static MACHINE_CONFIG_START( amazon, terracre_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(terracre_state, screen_update_amazon)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(terracre)
-	MCFG_PALETTE_LENGTH(1*16+16*16+16*256)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", terracre)
+	MCFG_PALETTE_ADD("palette", 1*16+16*16+16*256)
+	MCFG_PALETTE_INDIRECT_ENTRIES(256)
+	MCFG_PALETTE_INIT_OWNER(terracre_state, terracre)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
@@ -561,10 +563,12 @@ static MACHINE_CONFIG_START( ym3526, terracre_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(terracre_state, screen_update_amazon)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(terracre)
-	MCFG_PALETTE_LENGTH(1*16+16*16+16*256)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", terracre)
+	MCFG_PALETTE_ADD("palette", 1*16+16*16+16*256)
+	MCFG_PALETTE_INDIRECT_ENTRIES(256)
+	MCFG_PALETTE_INIT_OWNER(terracre_state, terracre)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
@@ -594,10 +598,12 @@ static MACHINE_CONFIG_START( ym2203, terracre_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(terracre_state, screen_update_amazon)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(terracre)
-	MCFG_PALETTE_LENGTH(1*16+16*16+16*256)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", terracre)
+	MCFG_PALETTE_ADD("palette", 1*16+16*16+16*256)
+	MCFG_PALETTE_INDIRECT_ENTRIES(256)
+	MCFG_PALETTE_INIT_OWNER(terracre_state, terracre)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
