@@ -392,13 +392,6 @@ WRITE_LINE_MEMBER(thedeep_state::irqhandler)
 	m_audiocpu->set_input_line(0, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static const ay8910_interface ay8910_config =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_NULL, DEVCB_NULL, DEVCB_NULL, DEVCB_NULL
-};
-
 TIMER_DEVICE_CALLBACK_MEMBER(thedeep_state::thedeep_interrupt)
 {
 	int scanline = param;
@@ -459,9 +452,11 @@ static MACHINE_CONFIG_START( thedeep, thedeep_state )
 	MCFG_SCREEN_SIZE(0x100, 0xf8)
 	MCFG_SCREEN_VISIBLE_AREA(0, 0x100-1, 0, 0xf8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(thedeep_state, screen_update_thedeep)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(thedeep)
-	MCFG_PALETTE_LENGTH(512)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", thedeep)
+	MCFG_PALETTE_ADD("palette", 512)
+	MCFG_PALETTE_INIT_OWNER(thedeep_state, thedeep)
 
 
 	/* sound hardware */
@@ -469,7 +464,6 @@ static MACHINE_CONFIG_START( thedeep, thedeep_state )
 
 	MCFG_SOUND_ADD("ymsnd", YM2203, XTAL_12MHz/4)  /* verified on pcb */
 	MCFG_YM2203_IRQ_HANDLER(WRITELINE(thedeep_state, irqhandler))
-	MCFG_YM2203_AY8910_INTF(&ay8910_config)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_CONFIG_END
 
