@@ -197,30 +197,6 @@ Board contains only 29 ROMs and not much else.
 #include "cbombers.lh"
 
 
-
-/***********************************************************
-                COLOR RAM
-
-Extract a standard version of this
-("taito_8bpg_palette_word_w"?) to Taitoic.c ?
-***********************************************************/
-
-WRITE32_MEMBER(undrfire_state::color_ram_w)
-{
-	int a,r,g,b;
-	COMBINE_DATA(&m_generic_paletteram_32[offset]);
-
-	{
-		a = m_generic_paletteram_32[offset];
-		r = (a & 0xff0000) >> 16;
-		g = (a & 0xff00) >> 8;
-		b = (a & 0xff);
-
-		palette_set_color(machine(),offset,MAKE_RGB(r,g,b));
-	}
-}
-
-
 /***********************************************************
                 INTERRUPTS
 ***********************************************************/
@@ -478,7 +454,7 @@ static ADDRESS_MAP_START( undrfire_map, AS_PROGRAM, 32, undrfire_state )
 	AM_RANGE(0x830000, 0x83002f) AM_DEVREADWRITE("tc0480scp", tc0480scp_device, ctrl_long_r, ctrl_long_w)
 	AM_RANGE(0x900000, 0x90ffff) AM_DEVREADWRITE("tc0100scn", tc0100scn_device, long_r, long_w)        /* piv tilemaps */
 	AM_RANGE(0x920000, 0x92000f) AM_DEVREADWRITE("tc0100scn", tc0100scn_device, ctrl_long_r, ctrl_long_w)
-	AM_RANGE(0xa00000, 0xa0ffff) AM_RAM_WRITE(color_ram_w) AM_SHARE("paletteram")
+	AM_RANGE(0xa00000, 0xa0ffff) AM_RAM_DEVWRITE("palette", palette_device, write) AM_SHARE("palette")
 	AM_RANGE(0xb00000, 0xb003ff) AM_RAM                         /* single bytes, blending ??? */
 	AM_RANGE(0xd00000, 0xd00003) AM_WRITE(rotate_control_w)     /* perhaps port based rotate control? */
 	AM_RANGE(0xf00000, 0xf00007) AM_READ(undrfire_lightgun_r)   /* stick coords read at $11b2-bc */
@@ -497,7 +473,7 @@ static ADDRESS_MAP_START( cbombers_cpua_map, AS_PROGRAM, 32, undrfire_state )
 	AM_RANGE(0x830000, 0x83002f) AM_DEVREADWRITE("tc0480scp", tc0480scp_device, ctrl_long_r, ctrl_long_w)
 	AM_RANGE(0x900000, 0x90ffff) AM_DEVREADWRITE("tc0100scn", tc0100scn_device, long_r, long_w)        /* piv tilemaps */
 	AM_RANGE(0x920000, 0x92000f) AM_DEVREADWRITE("tc0100scn", tc0100scn_device, ctrl_long_r, ctrl_long_w)
-	AM_RANGE(0xa00000, 0xa0ffff) AM_RAM_WRITE(color_ram_w) AM_SHARE("paletteram")
+	AM_RANGE(0xa00000, 0xa0ffff) AM_RAM_DEVWRITE("palette", palette_device, write) AM_SHARE("palette")
 	AM_RANGE(0xb00000, 0xb0000f) AM_RAM /* ? */
 	AM_RANGE(0xc00000, 0xc00007) AM_RAM /* LAN controller? */
 	AM_RANGE(0xd00000, 0xd00003) AM_WRITE(rotate_control_w)     /* perhaps port based rotate control? */
@@ -696,25 +672,6 @@ INTERRUPT_GEN_MEMBER(undrfire_state::undrfire_interrupt)
 	device.execute().set_input_line(4, HOLD_LINE);
 }
 
-static const tc0100scn_interface undrfire_tc0100scn_intf =
-{
-	2, 3,       /* gfxnum, txnum */
-	50, 8,      /* x_offset, y_offset */
-	0, 0,       /* flip_xoff, flip_yoff */
-	0, 0,       /* flip_text_xoff, flip_text_yoff */
-	0, 0
-};
-
-static const tc0480scp_interface undrfire_tc0480scp_intf =
-{
-	1, 4,       /* gfxnum, txnum */
-	0,      /* pixels */
-	0x24, 0,        /* x_offset, y_offset */
-	-1, 0,      /* text_xoff, text_yoff */
-	0, 0,       /* flip_xoff, flip_yoff */
-	0       /* col_base */
-};
-
 static MACHINE_CONFIG_START( undrfire, undrfire_state )
 
 	/* basic machine hardware */
@@ -731,13 +688,26 @@ static MACHINE_CONFIG_START( undrfire, undrfire_state )
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0, 40*8-1, 3*8, 32*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(undrfire_state, screen_update_undrfire)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(undrfire)
-	MCFG_PALETTE_LENGTH(16384)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", undrfire)
+	MCFG_PALETTE_ADD("palette", 16384)
+	MCFG_PALETTE_FORMAT(XRGB)
 
+	MCFG_DEVICE_ADD("tc0100scn", TC0100SCN, 0)
+	MCFG_TC0100SCN_GFX_REGION(2)
+	MCFG_TC0100SCN_TX_REGION(3)
+	MCFG_TC0100SCN_OFFSETS(50, 8)
+	MCFG_TC0100SCN_GFXDECODE("gfxdecode")
+	MCFG_TC0100SCN_PALETTE("palette")
 
-	MCFG_TC0100SCN_ADD("tc0100scn", undrfire_tc0100scn_intf)
-	MCFG_TC0480SCP_ADD("tc0480scp", undrfire_tc0480scp_intf)
+	MCFG_DEVICE_ADD("tc0480scp", TC0480SCP, 0)
+	MCFG_TC0480SCP_GFX_REGION(1)
+	MCFG_TC0480SCP_TX_REGION(4)
+	MCFG_TC0480SCP_OFFSETS(0x24, 0)
+	MCFG_TC0480SCP_OFFSETS_TX(-1, 0)
+	MCFG_TC0480SCP_GFXDECODE("gfxdecode")
+	MCFG_TC0480SCP_PALETTE("palette")
 
 	/* sound hardware */
 	MCFG_FRAGMENT_ADD(taito_en_sound)
@@ -766,13 +736,26 @@ static MACHINE_CONFIG_START( cbombers, undrfire_state )
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0, 40*8-1, 3*8, 32*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(undrfire_state, screen_update_cbombers)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(cbombers)
-	MCFG_PALETTE_LENGTH(16384)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", cbombers)
+	MCFG_PALETTE_ADD("palette", 16384)
+	MCFG_PALETTE_FORMAT(XRGB)
 
+	MCFG_DEVICE_ADD("tc0100scn", TC0100SCN, 0)
+	MCFG_TC0100SCN_GFX_REGION(2)
+	MCFG_TC0100SCN_TX_REGION(3)
+	MCFG_TC0100SCN_OFFSETS(50, 8)
+	MCFG_TC0100SCN_GFXDECODE("gfxdecode")
+	MCFG_TC0100SCN_PALETTE("palette")
 
-	MCFG_TC0100SCN_ADD("tc0100scn", undrfire_tc0100scn_intf)
-	MCFG_TC0480SCP_ADD("tc0480scp", undrfire_tc0480scp_intf)
+	MCFG_DEVICE_ADD("tc0480scp", TC0480SCP, 0)
+	MCFG_TC0480SCP_GFX_REGION(1)
+	MCFG_TC0480SCP_TX_REGION(4)
+	MCFG_TC0480SCP_OFFSETS(0x24, 0)
+	MCFG_TC0480SCP_OFFSETS_TX(-1, 0)
+	MCFG_TC0480SCP_GFXDECODE("gfxdecode")
+	MCFG_TC0480SCP_PALETTE("palette")
 
 	/* sound hardware */
 	MCFG_FRAGMENT_ADD(taito_en_sound)
