@@ -128,6 +128,7 @@ out:
 #include "cpu/z80/z80.h"
 #include "cpu/tms32010/tms32010.h"
 #include "sound/3812intf.h"
+#include "machine/bankdev.h"
 #include "includes/toaplipt.h"
 #include "includes/twincobr.h"
 
@@ -137,62 +138,47 @@ class wardner_state : public twincobr_state
 public:
 	wardner_state(const machine_config &mconfig, device_type type, const char *tag)
 		: twincobr_state(mconfig, type, tag),
-			m_rambase_c000(*this, "rambase_c000")
+		m_membank(*this, "membank")
 	{
 	}
 
-	required_shared_ptr<UINT8> m_rambase_c000;
-	UINT8 *m_ROM;
+	required_device<address_map_bank_device> m_membank;
 
-	DECLARE_WRITE8_MEMBER(wardner_ramrom_bank_sw);
-	DECLARE_READ8_MEMBER(wardner_bank_r);
+	DECLARE_WRITE8_MEMBER(wardner_bank_w);
 	DECLARE_DRIVER_INIT(wardner);
 	DECLARE_WRITE_LINE_MEMBER(irqhandler);
+
+protected:
+	virtual void driver_start();
+	virtual void machine_reset();
 };
 
 
-READ8_MEMBER( wardner_state::wardner_bank_r )
-{
-	if (m_wardner_membank == 0)
-	{
-		// RAM mapped (plus fallthroughs to bits of ROM bank 0)
-		int addr = offset + 0x8000;
-
-		// 0x8000 - 0x8fff (sprites)
-		if ((addr >= 0x8000) && (addr < 0x9000))
-			return wardner_sprite_r(space, addr - 0x8000);
-
-		// 0xa000 - 0xafff (paletteram)
-		else if ((addr >= 0xa000) && (addr < 0xb000))
-			return m_generic_paletteram_8[addr - 0xa000];
-
-		// 0xc000 - 0xc7ff (z80 shared ram)
-		else if ((addr >= 0xc000) && (addr < 0xc800))
-			return m_rambase_c000[addr - 0xc000];
-	}
-
-	// ROM bank mapped
-	return m_ROM[m_wardner_membank * 0x8000 + offset];
-}
-
-WRITE8_MEMBER(wardner_state::wardner_ramrom_bank_sw)
-{
-	m_wardner_membank = data & 7;
-}
-
-
 /***************************** Z80 Main Memory Map **************************/
 
+WRITE8_MEMBER(wardner_state::wardner_bank_w)
+{
+	m_membank->set_bank(data & 7);
+}
+
 static ADDRESS_MAP_START( main_program_map, AS_PROGRAM, 8, wardner_state )
 	AM_RANGE(0x0000, 0x6fff) AM_ROM
 	AM_RANGE(0x7000, 0x7fff) AM_RAM
-	AM_RANGE(0x8000, 0xffff) AM_READ(wardner_bank_r) /* Overlapped RAM/Banked ROM */
-	AM_RANGE(0x8000, 0x8fff) AM_WRITE(wardner_sprite_w) AM_SHARE("spriteram8")
-	AM_RANGE(0x9000, 0x9fff) AM_ROM
-	AM_RANGE(0xa000, 0xafff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_byte_le_w) AM_SHARE("paletteram")
-	AM_RANGE(0xb000, 0xbfff) AM_ROM
-	AM_RANGE(0xc000, 0xc7ff) AM_RAM AM_SHARE("rambase_c000") /* Shared RAM with Sound Z80 */
-	AM_RANGE(0xc800, 0xffff) AM_ROM
+	AM_RANGE(0x8000, 0x8fff) AM_WRITE(wardner_sprite_w)                     // AM_SHARE("spriteram8")
+	AM_RANGE(0xa000, 0xafff) AM_DEVWRITE("palette", palette_device, write)  // AM_SHARE("palette")
+	AM_RANGE(0xc000, 0xc7ff) AM_WRITEONLY AM_SHARE("sharedram")
+	AM_RANGE(0x8000, 0xffff) AM_DEVREAD("membank", address_map_bank_device, read8)
+ADDRESS_MAP_END
+
+// Overlapped RAM/Banked ROM
+// Can't use AM_RANGE(0x00000, 0x3ffff) for ROM because the shared pointers get messed up somehow
+static ADDRESS_MAP_START( main_bank_map, AS_PROGRAM, 8, wardner_state )
+	AM_RANGE(0x00000, 0x00fff) AM_READ(wardner_sprite_r) AM_SHARE("spriteram8")
+	AM_RANGE(0x01000, 0x01fff) AM_ROM AM_REGION("maincpu", 0x1000)
+	AM_RANGE(0x02000, 0x02fff) AM_READONLY AM_SHARE("palette")
+	AM_RANGE(0x03000, 0x03fff) AM_ROM AM_REGION("maincpu", 0x3000)
+	AM_RANGE(0x04000, 0x047ff) AM_READONLY AM_SHARE("sharedram")
+	AM_RANGE(0x04800, 0x3ffff) AM_ROM AM_REGION("maincpu", 0x4800)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( main_io_map, AS_IO, 8, wardner_state )
@@ -213,8 +199,8 @@ static ADDRESS_MAP_START( main_io_map, AS_IO, 8, wardner_state )
 	AM_RANGE(0x58, 0x58) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x5a, 0x5a) AM_WRITE(wardner_coin_dsp_w)       /* Machine system control */
 	AM_RANGE(0x5c, 0x5c) AM_WRITE(wardner_control_w)        /* Machine system control */
-	AM_RANGE(0x60, 0x65) AM_READWRITE(wardner_videoram_r, wardner_videoram_w)       /* data from video layer RAM */
-	AM_RANGE(0x70, 0x70) AM_WRITE(wardner_ramrom_bank_sw)   /* ROM bank select */
+	AM_RANGE(0x60, 0x65) AM_READWRITE(wardner_videoram_r, wardner_videoram_w)
+	AM_RANGE(0x70, 0x70) AM_WRITE(wardner_bank_w)
 ADDRESS_MAP_END
 
 
@@ -223,9 +209,8 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( sound_program_map, AS_PROGRAM, 8, wardner_state )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x807f) AM_RAM
-	AM_RANGE(0xc000, 0xc7ff) AM_RAM AM_SHARE("rambase_c000")    /* Shared RAM with Main Z80 */
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM AM_SHARE("sharedram")
 	AM_RANGE(0xc800, 0xcfff) AM_RAM
-
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_io_map, AS_IO, 8, wardner_state )
@@ -243,9 +228,9 @@ ADDRESS_MAP_END
 	/* $000 - 08F  TMS32010 Internal Data RAM in Data Address Space */
 
 static ADDRESS_MAP_START( DSP_io_map, AS_IO, 16, wardner_state )
-	AM_RANGE(0, 0) AM_WRITE(wardner_dsp_addrsel_w)
-	AM_RANGE(1, 1) AM_READWRITE(wardner_dsp_r, wardner_dsp_w)
-	AM_RANGE(3, 3) AM_WRITE(twincobr_dsp_bio_w)
+	AM_RANGE(0x00, 0x00) AM_WRITE(wardner_dsp_addrsel_w)
+	AM_RANGE(0x01, 0x01) AM_READWRITE(wardner_dsp_r, wardner_dsp_w)
+	AM_RANGE(0x03, 0x03) AM_WRITE(twincobr_dsp_bio_w)
 	AM_RANGE(TMS32010_BIO, TMS32010_BIO) AM_READ(twincobr_BIO_r)
 ADDRESS_MAP_END
 
@@ -351,18 +336,6 @@ static const gfx_layout tilelayout =
 	8*8     /* every tile takes 8 consecutive bytes */
 };
 
-static const gfx_layout spritelayout =
-{
-	16,16,  /* 16*16 sprites */
-	2048,   /* 2048 sprites */
-	4,      /* 4 bits per pixel */
-	{ 0*2048*32*8, 1*2048*32*8, 2*2048*32*8, 3*2048*32*8 }, /* the bitplanes are separated */
-	{ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15 },
-	{ 0*16, 1*16, 2*16, 3*16, 4*16, 5*16, 6*16, 7*16,
-			8*16, 9*16, 10*16, 11*16, 12*16, 13*16, 14*16, 15*16 },
-	32*8    /* every sprite takes 32 consecutive bytes */
-};
-
 
 /* handler called by the 3812 emulator when the internal timers cause an IRQ */
 WRITE_LINE_MEMBER(wardner_state::irqhandler)
@@ -375,11 +348,24 @@ static GFXDECODE_START( wardner )
 	GFXDECODE_ENTRY( "gfx1", 0x00000, charlayout,   1536, 32 )  /* colors 1536-1791 */
 	GFXDECODE_ENTRY( "gfx2", 0x00000, tilelayout,   1280, 16 )  /* colors 1280-1535 */
 	GFXDECODE_ENTRY( "gfx3", 0x00000, tilelayout,   1024, 16 )  /* colors 1024-1079 */
-	GFXDECODE_ENTRY( "gfx4", 0x00000, spritelayout,    0, 64 )  /* colors    0-1023 */
 GFXDECODE_END
 
 
+void wardner_state::driver_start()
+{
+	/* Save-State stuff in src/machine/twincobr.c */
+	twincobr_driver_savestate();
+}
 
+void wardner_state::machine_reset()
+{
+	MACHINE_RESET_CALL_MEMBER(twincobr);
+
+	m_toaplan_main_cpu = 1;     /* Z80 */
+	twincobr_display(1);
+
+	m_membank->set_bank(0);
+}
 
 static MACHINE_CONFIG_START( wardner, wardner_state )
 
@@ -389,6 +375,13 @@ static MACHINE_CONFIG_START( wardner, wardner_state )
 	MCFG_CPU_IO_MAP(main_io_map)
 	MCFG_CPU_VBLANK_INT_DRIVER("screen", wardner_state,  wardner_interrupt)
 
+	MCFG_DEVICE_ADD("membank", ADDRESS_MAP_BANK, 0)
+	MCFG_DEVICE_PROGRAM_MAP(main_bank_map)
+	MCFG_ADDRESS_MAP_BANK_ENDIANNESS(ENDIANNESS_LITTLE)
+	MCFG_ADDRESS_MAP_BANK_DATABUS_WIDTH(8)
+	MCFG_ADDRESS_MAP_BANK_ADDRBUS_WIDTH(18)
+	MCFG_ADDRESS_MAP_BANK_STRIDE(0x8000)
+
 	MCFG_CPU_ADD("audiocpu", Z80, XTAL_14MHz/4)     /* 3.5MHz */
 	MCFG_CPU_PROGRAM_MAP(sound_program_map)
 	MCFG_CPU_IO_MAP(sound_io_map)
@@ -400,23 +393,25 @@ static MACHINE_CONFIG_START( wardner, wardner_state )
 
 	MCFG_QUANTUM_TIME(attotime::from_hz(6000))      /* 100 CPU slices per frame */
 
-	MCFG_MACHINE_RESET_OVERRIDE(wardner_state,wardner)
-
 	/* video hardware */
-	MCFG_MC6845_ADD("crtc", HD6845, "screen", XTAL_14MHz/4, twincobr_mc6845_intf) /* 3.5MHz measured on CLKin */
+	MCFG_MC6845_ADD("crtc", HD6845, "screen", XTAL_14MHz/4) /* 3.5MHz measured on CLKin */
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(2)
 
-	MCFG_TOAPLAN_SCU_ADD("toaplan_scu")
+	MCFG_TOAPLAN_SCU_ADD("scu", "palette", 32, 14)
 
-	MCFG_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 	MCFG_BUFFERED_SPRITERAM8_ADD("spriteram8")
 
 	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 	MCFG_SCREEN_RAW_PARAMS(XTAL_14MHz/2, 446, 0, 320, 286, 0, 240)
 	MCFG_SCREEN_UPDATE_DRIVER(wardner_state, screen_update_toaplan0)
 	MCFG_SCREEN_VBLANK_DEVICE("spriteram8", buffered_spriteram8_device, vblank_copy_rising)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(wardner)
-	MCFG_PALETTE_LENGTH(1792)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", wardner)
+	MCFG_PALETTE_ADD("palette", 1792)
+	MCFG_PALETTE_FORMAT(xBBBBBGGGGGRRRRR)
 
 	MCFG_VIDEO_START_OVERRIDE(wardner_state,toaplan0)
 
@@ -430,16 +425,14 @@ MACHINE_CONFIG_END
 
 
 
-
 /***************************************************************************
 
   Game driver(s)
 
 ***************************************************************************/
 
-
 ROM_START( wardner )
-	ROM_REGION( 0x40000, "maincpu", 0 ) /* Banked Main Z80 code */
+	ROM_REGION( 0x40000, "maincpu", ROMREGION_ERASEFF ) /* Banked Main Z80 code */
 	ROM_LOAD( "wardner.17", 0x00000, 0x08000, CRC(c5dd56fd) SHA1(f0a09557150e9c1c6b9d8e125f5408fc269c9d17) )    /* Main Z80 code */
 	ROM_LOAD( "b25-18.rom", 0x10000, 0x10000, CRC(9aab8ee2) SHA1(16fa44b75f4a3a5b1ff713690a299ecec2b5a4bf) )    /* OBJ ROMs */
 	ROM_LOAD( "b25-19.rom", 0x20000, 0x10000, CRC(95b68813) SHA1(06ea1b1d6e2e6326ceb9324fc471d082fda6112e) )
@@ -475,7 +468,7 @@ ROM_START( wardner )
 	ROM_LOAD( "b25-10.rom",  0x10000, 0x08000, CRC(b9a61e81) SHA1(541e579664d583fbbf81111046115018fdaff073) )
 	ROM_LOAD( "b25-09.rom",  0x18000, 0x08000, CRC(585411b7) SHA1(67c0f4b7ab303341d5481c4024dc4199acb7c279) )
 
-	ROM_REGION( 0x40000, "gfx4", 0 )    /* sprites */
+	ROM_REGION( 0x40000, "scu", 0 )    /* sprites */
 	ROM_LOAD( "b25-01.rom",  0x00000, 0x10000, CRC(42ec01fb) SHA1(646192a2e89f795ed016860cdcdc0b5ef645fca2) )
 	ROM_LOAD( "b25-02.rom",  0x10000, 0x10000, CRC(6c0130b7) SHA1(8b6ad72848d03c3d4ee3acd35abbb3a0e678122c) )
 	ROM_LOAD( "b25-03.rom",  0x20000, 0x10000, CRC(b923db99) SHA1(2f4be81afdf200586bc44b1e94553d84d16d0b62) )
@@ -490,7 +483,7 @@ ROM_START( wardner )
 ROM_END
 
 ROM_START( pyros )
-	ROM_REGION( 0x40000, "maincpu", 0 ) /* Banked Z80 code */
+	ROM_REGION( 0x40000, "maincpu", ROMREGION_ERASEFF ) /* Banked Z80 code */
 	ROM_LOAD( "b25-29.rom", 0x00000, 0x08000, CRC(b568294d) SHA1(5d04dd006f5180fa0c9340e2efa6613625d712a8) )    /* Main Z80 code */
 	ROM_LOAD( "b25-18.rom", 0x10000, 0x10000, CRC(9aab8ee2) SHA1(16fa44b75f4a3a5b1ff713690a299ecec2b5a4bf) )    /* OBJ ROMs */
 	ROM_LOAD( "b25-19.rom", 0x20000, 0x10000, CRC(95b68813) SHA1(06ea1b1d6e2e6326ceb9324fc471d082fda6112e) )
@@ -526,7 +519,7 @@ ROM_START( pyros )
 	ROM_LOAD( "b25-10.rom",  0x10000, 0x08000, CRC(b9a61e81) SHA1(541e579664d583fbbf81111046115018fdaff073) )
 	ROM_LOAD( "b25-09.rom",  0x18000, 0x08000, CRC(585411b7) SHA1(67c0f4b7ab303341d5481c4024dc4199acb7c279) )
 
-	ROM_REGION( 0x40000, "gfx4", 0 )    /* sprites */
+	ROM_REGION( 0x40000, "scu", 0 )    /* sprites */
 	ROM_LOAD( "b25-01.rom",  0x00000, 0x10000, CRC(42ec01fb) SHA1(646192a2e89f795ed016860cdcdc0b5ef645fca2) )
 	ROM_LOAD( "b25-02.rom",  0x10000, 0x10000, CRC(6c0130b7) SHA1(8b6ad72848d03c3d4ee3acd35abbb3a0e678122c) )
 	ROM_LOAD( "b25-03.rom",  0x20000, 0x10000, CRC(b923db99) SHA1(2f4be81afdf200586bc44b1e94553d84d16d0b62) )
@@ -541,7 +534,7 @@ ROM_START( pyros )
 ROM_END
 
 ROM_START( wardnerj )
-	ROM_REGION( 0x40000, "maincpu", 0 ) /* Banked Z80 code */
+	ROM_REGION( 0x40000, "maincpu", ROMREGION_ERASEFF ) /* Banked Z80 code */
 	ROM_LOAD( "b25-17.bin",  0x00000, 0x08000, CRC(4164dca9) SHA1(1f02c0991d7c14230043e34cb4b8e089b467b234) )   /* Main Z80 code */
 	ROM_LOAD( "b25-18.rom",  0x10000, 0x10000, CRC(9aab8ee2) SHA1(16fa44b75f4a3a5b1ff713690a299ecec2b5a4bf) )   /* OBJ ROMs */
 	ROM_LOAD( "b25-19.rom",  0x20000, 0x10000, CRC(95b68813) SHA1(06ea1b1d6e2e6326ceb9324fc471d082fda6112e) )
@@ -577,7 +570,7 @@ ROM_START( wardnerj )
 	ROM_LOAD( "b25-10.rom",  0x10000, 0x08000, CRC(b9a61e81) SHA1(541e579664d583fbbf81111046115018fdaff073) )
 	ROM_LOAD( "b25-09.rom",  0x18000, 0x08000, CRC(585411b7) SHA1(67c0f4b7ab303341d5481c4024dc4199acb7c279) )
 
-	ROM_REGION( 0x40000, "gfx4", 0 )    /* sprites */
+	ROM_REGION( 0x40000, "scu", 0 )    /* sprites */
 	ROM_LOAD( "b25-01.rom",  0x00000, 0x10000, CRC(42ec01fb) SHA1(646192a2e89f795ed016860cdcdc0b5ef645fca2) )
 	ROM_LOAD( "b25-02.rom",  0x10000, 0x10000, CRC(6c0130b7) SHA1(8b6ad72848d03c3d4ee3acd35abbb3a0e678122c) )
 	ROM_LOAD( "b25-03.rom",  0x20000, 0x10000, CRC(b923db99) SHA1(2f4be81afdf200586bc44b1e94553d84d16d0b62) )
@@ -592,14 +585,6 @@ ROM_START( wardnerj )
 ROM_END
 
 
-DRIVER_INIT_MEMBER(wardner_state,wardner)
-{
-	m_ROM = memregion("maincpu")->base();
-	twincobr_driver_savestate();   /* Save-State stuff in src/machine/twincobr.c */
-}
-
-
-
-GAME( 1987, wardner,  0,       wardner, wardner, wardner_state,  wardner, ROT0, "Toaplan / Taito Corporation Japan", "Wardner (World)", GAME_SUPPORTS_SAVE )
-GAME( 1987, pyros,    wardner, wardner, pyros, wardner_state,    wardner, ROT0, "Toaplan / Taito America Corporation", "Pyros (US)", GAME_SUPPORTS_SAVE )
-GAME( 1987, wardnerj, wardner, wardner, wardnerj, wardner_state, wardner, ROT0, "Toaplan / Taito Corporation", "Wardner no Mori (Japan)", GAME_SUPPORTS_SAVE )
+GAME( 1987, wardner,  0,       wardner, wardner,  driver_device, 0, ROT0, "Toaplan / Taito Corporation Japan", "Wardner (World)", GAME_SUPPORTS_SAVE )
+GAME( 1987, pyros,    wardner, wardner, pyros,    driver_device, 0, ROT0, "Toaplan / Taito America Corporation", "Pyros (US)", GAME_SUPPORTS_SAVE )
+GAME( 1987, wardnerj, wardner, wardner, wardnerj, driver_device, 0, ROT0, "Toaplan / Taito Corporation", "Wardner no Mori (Japan)", GAME_SUPPORTS_SAVE )
