@@ -185,12 +185,12 @@ static INPUT_PORTS_START( dodgem )
 INPUT_PORTS_END
 
 
-void zac2650_state::palette_init()
+PALETTE_INIT_MEMBER(zac2650_state, zac2650)
 {
-	palette_set_color(machine(),0,RGB_BLACK);
-	palette_set_color(machine(),1,RGB_WHITE);
-	palette_set_color(machine(),2,RGB_BLACK);
-	palette_set_color(machine(),3,RGB_BLACK);
+	palette.set_pen_color(0,rgb_t::black);
+	palette.set_pen_color(1,rgb_t::white);
+	palette.set_pen_color(2,rgb_t::black);
+	palette.set_pen_color(3,rgb_t::black);
 }
 
 /************************************************************************************************
@@ -249,14 +249,17 @@ static MACHINE_CONFIG_START( tinvader, zac2650_state )
 	MCFG_SCREEN_SIZE(30*24, 32*24)
 	MCFG_SCREEN_VISIBLE_AREA(0, 719, 0, 767)
 	MCFG_SCREEN_UPDATE_DRIVER(zac2650_state, screen_update_tinvader)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(tinvader)
-	MCFG_PALETTE_LENGTH(4)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", tinvader)
+	MCFG_PALETTE_ADD("palette", 4)
+	MCFG_PALETTE_INIT_OWNER(zac2650_state, zac2650)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MCFG_SOUND_ADD("s2636snd", S2636, 0)
+	MCFG_DEVICE_ADD("s2636", S2636, 0)
+	MCFG_S2636_WORKRAM_SIZE(0x100)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_CONFIG_END
 
