@@ -508,58 +508,6 @@ static GFXDECODE_START( zaccaria )
 GFXDECODE_END
 
 
-static I8255A_INTERFACE( ppi8255_intf )
-{
-	DEVCB_INPUT_PORT("P1"),             /* Port A read */
-	DEVCB_NULL,                         /* Port A write */
-	DEVCB_INPUT_PORT("P2"),             /* Port B read */
-	DEVCB_NULL,                         /* Port B write */
-	DEVCB_INPUT_PORT("SYSTEM"),         /* Port C read */
-	DEVCB_DRIVER_MEMBER(zaccaria_state,zaccaria_dsw_sel_w)  /* Port C write */
-};
-
-static const ay8910_interface ay8910_config =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(driver_device, soundlatch2_byte_r),
-	DEVCB_DRIVER_MEMBER(zaccaria_state,ay8910_port0a_w),
-	DEVCB_NULL
-};
-
-static const pia6821_interface pia_0_config =
-{
-	DEVCB_DRIVER_MEMBER(zaccaria_state,zaccaria_port0a_r),  /* port A in */
-	DEVCB_NULL,                         /* port B in */
-	DEVCB_NULL,                         /* line CA1 in */
-	DEVCB_NULL,                         /* line CB1 in */
-	DEVCB_NULL,                         /* line CA2 in */
-	DEVCB_NULL,                         /* line CB2 in */
-	DEVCB_DRIVER_MEMBER(zaccaria_state,zaccaria_port0a_w),  /* port A out */
-	DEVCB_DRIVER_MEMBER(zaccaria_state,zaccaria_port0b_w),  /* port B out */
-	DEVCB_NULL,                         /* line CA2 out */
-	DEVCB_NULL,                         /* port CB2 out */
-	DEVCB_DRIVER_LINE_MEMBER(zaccaria_state,zaccaria_irq0a),            /* IRQA */
-	DEVCB_DRIVER_LINE_MEMBER(zaccaria_state,zaccaria_irq0b)         /* IRQB */
-};
-
-static const pia6821_interface pia_1_config =
-{
-	DEVCB_DEVICE_MEMBER("tms", tms5220_device, status_r),  /* port A in */
-	DEVCB_NULL,                                     /* port B in */
-	DEVCB_NULL,                                     /* line CA1 in */
-	DEVCB_NULL,                                     /* line CB1 in */   // tms5220_intq_r, handled below in tms5220_config
-	DEVCB_NULL,                                     /* line CA2 in */   // tms5220_readyq_r, "
-	DEVCB_NULL,                                     /* line CB2 in */
-	DEVCB_DEVICE_MEMBER("tms", tms5220_device, data_w),    /* port A out */
-	DEVCB_DRIVER_MEMBER(zaccaria_state,zaccaria_port1b_w),              /* port B out */
-	DEVCB_NULL,                                     /* line CA2 out */
-	DEVCB_NULL,                                     /* port CB2 out */
-	DEVCB_NULL,                                     /* IRQA */
-	DEVCB_NULL                                      /* IRQB */
-};
-
 INTERRUPT_GEN_MEMBER(zaccaria_state::vblank_irq)
 {
 	if(m_nmi_mask)
@@ -584,9 +532,23 @@ static MACHINE_CONFIG_START( zaccaria, zaccaria_state )
 	MCFG_CPU_PROGRAM_MAP(sound_map_2)
 	MCFG_QUANTUM_TIME(attotime::from_hz(1000000))
 
-	MCFG_I8255A_ADD( "ppi8255", ppi8255_intf )
-	MCFG_PIA6821_ADD( "pia0", pia_0_config )
-	MCFG_PIA6821_ADD( "pia1", pia_1_config )
+	MCFG_DEVICE_ADD("ppi8255", I8255A, 0)
+	MCFG_I8255_IN_PORTA_CB(IOPORT("P1"))
+	MCFG_I8255_IN_PORTB_CB(IOPORT("P2"))
+	MCFG_I8255_IN_PORTC_CB(IOPORT("SYSTEM"))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(zaccaria_state, zaccaria_dsw_sel_w))
+
+	MCFG_DEVICE_ADD( "pia0", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(zaccaria_state, zaccaria_port0a_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(zaccaria_state, zaccaria_port0a_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(zaccaria_state, zaccaria_port0b_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(zaccaria_state, zaccaria_irq0a))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(zaccaria_state, zaccaria_irq0b))
+
+	MCFG_DEVICE_ADD( "pia1", PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(DEVREAD8("tms", tms5220_device, status_r))
+	MCFG_PIA_WRITEPA_HANDLER(DEVWRITE8("tms", tms5220_device, data_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(zaccaria_state,zaccaria_port1b_w))
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
@@ -595,16 +557,19 @@ static MACHINE_CONFIG_START( zaccaria, zaccaria_state )
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(zaccaria_state, screen_update_zaccaria)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(zaccaria)
-	MCFG_PALETTE_LENGTH(32*8+32*8)
-
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", zaccaria)
+	MCFG_PALETTE_ADD("palette", 32*8+32*8)
+	MCFG_PALETTE_INDIRECT_ENTRIES(512)
+	MCFG_PALETTE_INIT_OWNER(zaccaria_state, zaccaria)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	MCFG_SOUND_ADD("ay1", AY8910, XTAL_3_579545MHz/2) /* verified on pcb */
-	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_AY8910_PORT_B_READ_CB(READ8(driver_device, soundlatch2_byte_r))
+	MCFG_AY8910_PORT_A_WRITE_CB(WRITE8(zaccaria_state, ay8910_port0a_w))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
 
 	MCFG_SOUND_ADD("ay2", AY8910, XTAL_3_579545MHz/2) /* verified on pcb */
