@@ -22,7 +22,9 @@ public:
 		m_discrete(*this, "discrete"),
 		m_speaker(*this, "speaker"),
 		m_eeprom(*this, "eeprom"),
-		m_sn(*this, "snsnd")
+		m_sn(*this, "snsnd"),
+		m_screen(*this, "screen"),
+		m_palette(*this, "palette")
 	{ }
 
 	/* devices/memory pointers */
@@ -32,7 +34,8 @@ public:
 	optional_device<speaker_sound_device> m_speaker;
 	optional_device<eeprom_serial_93cxx_device> m_eeprom;
 	optional_device<sn76477_device> m_sn;
-
+	required_device<screen_device> m_screen;
+	optional_device<palette_device> m_palette;
 
 	/* misc game specific */
 	UINT8 m_color_map;
