@@ -14,7 +14,9 @@ public:
 		m_videoram(*this, "videoram"),
 		m_paletteram(*this, "paletteram"),
 		m_audiocpu(*this, "audiocpu"),
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	/* memory pointers */
 	optional_shared_ptr<UINT16> m_shared_ram;
@@ -118,6 +120,8 @@ public:
 	void sstingry_draw_sprites( bitmap_ind16 &bitmap, const rectangle &cliprect, int c, int d );
 	DECLARE_WRITE_LINE_MEMBER(ym3812_irq);
 	required_device<cpu_device> m_maincpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 };
 
 /* game_id - used to deal with a few game specific situations */
