@@ -5,16 +5,25 @@ class armedf_state : public driver_device
 public:
 	armedf_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag),
+		m_maincpu(*this, "maincpu"),
+		m_extra(*this, "extra"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette"),
 		m_spriteram(*this, "spriteram"),
 		m_spr_pal_clut(*this, "spr_pal_clut"),
 		m_fg_videoram(*this, "fg_videoram"),
-		m_bg_videoram(*this, "bg_videoram"),
-		m_maincpu(*this, "maincpu"),
-		m_extra(*this, "extra") { }
+		m_bg_videoram(*this, "bg_videoram")
+		{ }
+
+	/* devices */
+	required_device<cpu_device> m_maincpu;
+	optional_device<cpu_device> m_extra;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
+	required_device<buffered_spriteram16_device> m_spriteram;
 
 	/* memory pointers */
-	UINT8  *  m_text_videoram;
-	required_device<buffered_spriteram16_device> m_spriteram;
+	UINT8 *m_text_videoram;
 	required_shared_ptr<UINT16> m_spr_pal_clut;
 	required_shared_ptr<UINT16> m_fg_videoram;
 	required_shared_ptr<UINT16> m_bg_videoram;
@@ -86,9 +95,6 @@ public:
 	void armedf_drawgfx(bitmap_ind16 &dest_bmp,const rectangle &clip,gfx_element *gfx,
 						UINT32 code,UINT32 color, UINT32 clut,int flipx,int flipy,int offsx,int offsy,
 						int transparent_color);
-
-	required_device<cpu_device> m_maincpu;
-	optional_device<cpu_device> m_extra;
 };
 
 class bigfghtr_state : public armedf_state
