@@ -60,12 +60,9 @@ public:
 	virtual void machine_reset();
 	UINT32 screen_update_asterix(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(asterix_interrupt);
+	K05324X_CB_MEMBER(sprite_callback);
+	K056832_CB_MEMBER(tile_callback);
 
 protected:
 	virtual void device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr);
 };
-
-/*----------- defined in video/asterix.c -----------*/
-
-extern void asterix_tile_callback(running_machine &machine, int layer, int *code, int *color, int *flags);
-extern void asterix_sprite_callback(running_machine &machine, int *code, int *color, int *priority_mask);
