@@ -11,7 +11,9 @@ public:
 		: driver_device(mconfig, type, tag),
 			m_nvram(*this, "nvram") ,
 		m_videoram(*this, "videoram"),
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_screen(*this, "screen") { }
 
 	required_shared_ptr<UINT8>  m_nvram;
 	required_shared_ptr<UINT8> m_videoram;
@@ -36,4 +38,6 @@ public:
 	TIMER_CALLBACK_MEMBER(interrupt_gen);
 	void reset_bank();
 	required_device<cpu_device> m_maincpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<screen_device> m_screen;
 };
