@@ -9,7 +9,9 @@ public:
 		m_videoram(*this, "videoram"),
 		m_discrete(*this, "discrete"),
 		m_maincpu(*this, "maincpu"),
-		m_samples(*this, "samples") { }
+		m_samples(*this, "samples"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_screen(*this, "screen") { }
 
 	required_shared_ptr<UINT8> m_videoram;
 	required_device<discrete_device> m_discrete;
@@ -28,12 +30,13 @@ public:
 	virtual void machine_start();
 	virtual void machine_reset();
 	virtual void video_start();
-	virtual void palette_init();
 	UINT32 screen_update_blockade(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(blockade_interrupt);
 	DECLARE_WRITE8_MEMBER(blockade_sound_freq_w);
 	required_device<cpu_device> m_maincpu;
 	required_device<samples_device> m_samples;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<screen_device> m_screen;
 };
 
 /*----------- defined in audio/blockade.c -----------*/
