@@ -29,7 +29,8 @@ public:
 			m_vram_bg1(*this, "vram_bg1"),
 			m_sprite_scale(*this, "sprite_scale"),
 			m_sprite_control(*this, "sprite_control") ,
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_screen(*this, "screen") { }
 
 	// in drivers/btoads
 	DECLARE_WRITE16_MEMBER( main_sound_w );
@@ -115,4 +116,5 @@ protected:
 	UINT16 m_misc_control;
 	int m_xcount;
 	required_device<cpu_device> m_maincpu;
+	required_device<screen_device> m_screen;
 };
