@@ -17,7 +17,9 @@ public:
 			m_oki_1(*this, "oki1"),
 			m_oki_2(*this, "oki2") ,
 		m_maincpu(*this, "maincpu"),
-		m_audiocpu(*this, "audiocpu") { }
+		m_audiocpu(*this, "audiocpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	/* memory pointers */
 	required_shared_ptr<UINT16> m_vidregs;
@@ -74,4 +76,6 @@ public:
 	UINT8 drgnmst_asciitohex( UINT8 data );
 	required_device<cpu_device> m_maincpu;
 	required_device<pic16c55_device> m_audiocpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 };
