@@ -23,17 +23,18 @@ public:
 		: driver_device(mconfig, type, tag),
 		m_vram(*this, "vram"),
 		m_spriteram(*this, "spriteram"),
-		m_paletteram(*this, "paletteram"),
 		m_vregs(*this, "vregs"),
 		m_priority(*this, "priority"),
 		m_tilebank(*this, "tilebank"),
 		m_maincpu(*this, "maincpu"),
-		m_soundcpu(*this, "soundcpu"){ }
+		m_soundcpu(*this, "soundcpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_screen(*this, "screen"),
+		m_palette(*this, "palette") { }
 
 	/* memory pointers */
 	required_shared_ptr_array<UINT32,4> m_vram;
 	required_shared_ptr<UINT32> m_spriteram;
-	required_shared_ptr<UINT32> m_paletteram;
 	required_shared_ptr<UINT32> m_vregs;
 	required_shared_ptr<UINT32> m_priority;
 	required_shared_ptr<UINT32> m_tilebank;
@@ -51,7 +52,11 @@ public:
 	/* devices */
 	required_device<cpu_device> m_maincpu;
 	required_device<cpu_device> m_soundcpu;
-	DECLARE_WRITE32_MEMBER(paletteram32_xRRRRRGGGGGBBBBB_dword_w);
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<screen_device> m_screen;
+	required_device<palette_device> m_palette;
+
+
 	DECLARE_READ32_MEMBER(snd_020_r);
 	DECLARE_WRITE32_MEMBER(snd_020_w);
 	DECLARE_WRITE32_MEMBER(fuuki32_vregs_w);
