@@ -18,7 +18,12 @@ public:
 		m_bgvideoram(*this, "bgvideoram"),
 		m_scroll(*this, "scroll"),
 		m_audiocpu(*this, "audiocpu"),
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette"),
+		m_sprgen(*this, "spritegen"),
+		m_screen(*this, "screen")
+		{ }
 
 	/* memory pointers */
 	required_shared_ptr<UINT16> m_spriteram;
@@ -26,15 +31,23 @@ public:
 	required_shared_ptr<UINT16> m_videoram;
 	required_shared_ptr<UINT16> m_bgvideoram;
 	required_shared_ptr<UINT16> m_scroll;
-//  UINT16 *    paletteram; // currently this uses generic palette handling
 
 	/* devices */
 	required_device<cpu_device> m_audiocpu;
 	DECLARE_WRITE16_MEMBER(soundcommand_w);
 	virtual void machine_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(galspnbl);
 	UINT32 screen_update_galspnbl(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	void draw_background( bitmap_ind16 &bitmap, const rectangle &cliprect );
 	DECLARE_WRITE_LINE_MEMBER(irqhandler);
 	required_device<cpu_device> m_maincpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
+	required_device<tecmo_spr_device> m_sprgen;
+	required_device<screen_device> m_screen;
+	bitmap_ind16 m_sprite_bitmap;
+	DECLARE_VIDEO_START(galspnbl);
+
+	void mix_sprite_layer(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect, int pri);
+
 };
