@@ -217,7 +217,11 @@ public:
 			m_knocker_sample(*this, "knocker_sam"),
 			m_videoram(*this, "videoram"),
 			m_charram(*this, "charram"),
-			m_spriteram(*this, "spriteram")
+			m_spriteram(*this, "spriteram"),
+			m_gfxdecode(*this, "gfxdecode"),
+			m_screen(*this, "screen"),
+			m_palette(*this, "palette"),
+			m_generic_paletteram_8(*this, "paletteram")
 	{ }
 
 	// devices
@@ -231,6 +235,11 @@ public:
 	required_shared_ptr<UINT8> m_charram;
 	required_shared_ptr<UINT8> m_spriteram;
 
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<screen_device> m_screen;
+	required_device<palette_device> m_palette;
+	required_shared_ptr<UINT8> m_generic_paletteram_8;
+
 	UINT8 m_knocker_prev;
 	UINT8 m_joystick_select;
 	UINT8 m_track[2];
@@ -296,7 +305,7 @@ public:
 	void draw_sprites(bitmap_rgb32 &bitmap, const rectangle &cliprect);
 	inline void audio_end_state();
 	void audio_process_clock(int logit);
-	void audio_handle_zero_crossing(attotime zerotime, int logit);
+	void audio_handle_zero_crossing(const attotime &zerotime, int logit);
 	void laserdisc_audio_process(laserdisc_device &device, int samplerate, int samples, const INT16 *ch0, const INT16 *ch1);
 
 protected:
