@@ -20,7 +20,10 @@ public:
 		m_maincpu(*this, "maincpu"),
 		m_audiocpu(*this, "audiocpu"),
 		m_subcpu(*this, "sub"),
-		m_discrete(*this, "discrete") { }
+		m_discrete(*this, "discrete"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette"),
+		m_screen(*this, "screen") { }
 
 	UINT8       m_cpu0_out[16];
 	UINT8       m_cpu1_out[16];
@@ -48,7 +51,6 @@ public:
 	tilemap_t * m_center_tilemap;
 	tilemap_t * m_right_tilemap;
 
-	rgb_t       m_bgcolor[0x20];
 	DECLARE_WRITE8_MEMBER(cpu0_outputs_w);
 	DECLARE_WRITE8_MEMBER(led_board_w);
 	DECLARE_WRITE8_MEMBER(cpu1_outputs_w);
@@ -71,10 +73,11 @@ public:
 	TILE_GET_INFO_MEMBER(get_left_tile_info);
 	TILE_GET_INFO_MEMBER(get_right_tile_info);
 	TILE_GET_INFO_MEMBER(get_center_tile_info);
+	DECLARE_PALETTE_INIT(grchamp);
 	TILEMAP_MAPPER_MEMBER(get_memory_offset);
 	virtual void machine_reset();
 	virtual void video_start();
-	virtual void palette_init();
+	void palette_generate();
 	UINT32 screen_update_grchamp(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(grchamp_cpu0_interrupt);
 	INTERRUPT_GEN_MEMBER(grchamp_cpu1_interrupt);
@@ -84,6 +87,9 @@ public:
 	required_device<cpu_device> m_audiocpu;
 	required_device<cpu_device> m_subcpu;
 	required_device<discrete_device> m_discrete;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
+	required_device<screen_device> m_screen;
 };
 
 /* Discrete Sound Input Nodes */
