@@ -10,7 +10,9 @@ public:
 		m_spriteram(*this, "spriteram"),
 		m_scratchram(*this, "scratchram"),
 		m_maincpu(*this, "maincpu"),
-		m_audiocpu(*this, "audiocpu"){ }
+		m_audiocpu(*this, "audiocpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	optional_shared_ptr<UINT8> m_paletteram;
 	optional_shared_ptr<UINT8> m_bg_vram; /* prosport */
@@ -33,6 +35,9 @@ public:
 
 	required_device<cpu_device> m_maincpu;
 	required_device<cpu_device> m_audiocpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
+
 	DECLARE_READ8_MEMBER(deco16_bank_r);
 	DECLARE_READ8_MEMBER(deco16_io_r);
 	DECLARE_WRITE8_MEMBER(deco16_bank_w);
