@@ -9,7 +9,10 @@ public:
 		m_yard_scroll_x_high(*this, "scroll_x_high"),
 		m_yard_scroll_y_low(*this, "scroll_y_low"),
 		m_yard_score_panel_disabled(*this, "score_disable"),
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_screen(*this, "screen"),
+		m_palette(*this, "palette") { }
 
 	/* memory pointers */
 	required_shared_ptr<UINT8> m_videoram;
@@ -30,9 +33,12 @@ public:
 	TILE_GET_INFO_MEMBER(yard_get_bg_tile_info);
 	TILEMAP_MAPPER_MEMBER(yard_tilemap_scan_rows);
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(m58);
 	UINT32 screen_update_yard(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	void draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect );
 	void draw_panel( bitmap_ind16 &bitmap, const rectangle &cliprect );
 	required_device<cpu_device> m_maincpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<screen_device> m_screen;
+	required_device<palette_device> m_palette;
 };
