@@ -3,6 +3,8 @@
     Meadows S2650 hardware
 
 *************************************************************************/
+#include "emu.h"
+#include "cpu/s2650/s2650.h"
 #include "sound/dac.h"
 #include "sound/samples.h"
 
@@ -14,8 +16,14 @@ public:
 		m_spriteram(*this, "spriteram"),
 		m_videoram(*this, "videoram"),
 		m_maincpu(*this, "maincpu"),
+		m_audiocpu(*this, "audiocpu"),
 		m_dac(*this, "dac"),
-		m_samples(*this, "samples") { }
+		m_samples(*this, "samples"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_screen(*this, "screen"),
+		m_palette(*this, "palette")
+	{
+	}
 
 	optional_shared_ptr<UINT8> m_spriteram;
 	required_shared_ptr<UINT8> m_videoram;
@@ -47,15 +55,18 @@ public:
 	DECLARE_DRIVER_INIT(gypsyjug);
 	TILE_GET_INFO_MEMBER(get_tile_info);
 	virtual void video_start();
-	virtual void palette_init();
 	UINT32 screen_update_meadows(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(meadows_interrupt);
 	INTERRUPT_GEN_MEMBER(minferno_interrupt);
 	INTERRUPT_GEN_MEMBER(audio_interrupt);
 	void draw_sprites(bitmap_ind16 &bitmap, const rectangle &clip);
-	required_device<cpu_device> m_maincpu;
+	required_device<s2650_device> m_maincpu;
+	optional_device<s2650_device> m_audiocpu;
 	optional_device<dac_device> m_dac;
 	optional_device<samples_device> m_samples;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<screen_device> m_screen;
+	required_device<palette_device> m_palette;
 };
 
 
