@@ -10,7 +10,9 @@ public:
 		m_rthunder_spriteram(*this, "spriteram"),
 		m_cpu1(*this, "cpu1"),
 		m_cpu2(*this, "cpu2"),
-		m_cus30(*this, "namco") { }
+		m_cus30(*this, "namco"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	UINT8 *m_spriteram;
 	int m_wdog;
@@ -20,6 +22,8 @@ public:
 	required_device<cpu_device> m_cpu1;
 	required_device<cpu_device> m_cpu2;
 	required_device<namco_cus30_device> m_cus30;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 	int m_tilebank;
 	int m_xscroll[4];
 	int m_yscroll[4];
@@ -59,7 +63,7 @@ public:
 	TILE_GET_INFO_MEMBER(get_tile_info3);
 	virtual void machine_reset();
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(namcos86);
 	UINT32 screen_update_namcos86(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	void screen_eof_namcos86(screen_device &screen, bool state);
 
