@@ -10,7 +10,9 @@ public:
 		m_videoram(*this, "videoram"),
 		m_characterram(*this, "characterram"),
 		m_maincpu(*this, "maincpu"),
-		m_samples(*this, "samples") { }
+		m_samples(*this, "samples"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette")  { }
 
 	required_shared_ptr<UINT8> m_videoram;
 	int m_freq1;
@@ -33,13 +35,15 @@ public:
 	DECLARE_WRITE8_MEMBER(polyplay_characterram_w);
 	virtual void machine_reset();
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(polyplay);
 	UINT32 screen_update_polyplay(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(periodic_interrupt);
 	INTERRUPT_GEN_MEMBER(coin_interrupt);
 	TIMER_DEVICE_CALLBACK_MEMBER(polyplay_timer_callback);
 	required_device<cpu_device> m_maincpu;
 	required_device<samples_device> m_samples;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 };
 
 
