@@ -1,5 +1,7 @@
 #include "video/bufsprite.h"
 #include "machine/eepromser.h"
+#include "cpu/sh2/sh2.h"
+
 
 #define MASTER_CLOCK 57272700   // main oscillator frequency
 
@@ -13,7 +15,7 @@
 #define BG_TYPE(n) (((m_vidregs[6] << (8*n)) & 0x7f000000 ) >> 24)
 #define BG_LINE(n) (((m_vidregs[6] << (8*n)) & 0x80000000 ) ? 1:0)
 
-#define BG_TRANSPEN MAKE_ARGB(0x00,0xff,0x00,0xff) // used for representing transparency in temporary bitmaps
+#define BG_TRANSPEN rgb_t(0x00,0xff,0x00,0xff) // used for representing transparency in temporary bitmaps
 
 #define SPRITE_PRI(n) (((m_vidregs[2] << (4*n)) & 0xf0000000 ) >> 28)
 
@@ -25,17 +27,18 @@ public:
 		: driver_device(mconfig, type, tag),
 			m_spriteram(*this, "spriteram") ,
 		m_bgram(*this, "bgram"),
-		m_paletteram(*this, "paletteram"),
 		m_zoomram(*this, "zoomram"),
 		m_vidregs(*this, "vidregs"),
 		m_ram(*this, "ram"),
 		m_maincpu(*this, "maincpu"),
-		m_eeprom(*this, "eeprom"){ }
+		m_eeprom(*this, "eeprom"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_screen(*this, "screen"),
+		m_palette(*this, "palette") { }
 
 	/* memory pointers */
 	required_device<buffered_spriteram32_device> m_spriteram;
 	required_shared_ptr<UINT32> m_bgram;
-	required_shared_ptr<UINT32> m_paletteram;
 	required_shared_ptr<UINT32> m_zoomram;
 	required_shared_ptr<UINT32> m_vidregs;
 	required_shared_ptr<UINT32> m_ram;
@@ -48,11 +51,13 @@ public:
 	UINT8          m_alphatable[256];
 
 	/* devices */
-	required_device<cpu_device> m_maincpu;
+	required_device<sh2_device> m_maincpu;
 	required_device<eeprom_serial_93cxx_device> m_eeprom;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<screen_device> m_screen;
+	required_device<palette_device> m_palette;
 
 	DECLARE_WRITE32_MEMBER(psikyosh_irqctrl_w);
-	DECLARE_WRITE32_MEMBER(paletteram32_RRRRRRRRGGGGGGGGBBBBBBBBxxxxxxxx_dword_w);
 	DECLARE_WRITE32_MEMBER(psikyosh_vidregs_w);
 	DECLARE_READ32_MEMBER(mjgtaste_input_r);
 	DECLARE_WRITE32_MEMBER(psh_eeprom_w);
@@ -69,6 +74,8 @@ public:
 	DECLARE_DRIVER_INIT(s1945ii);
 	virtual void machine_start();
 	virtual void video_start();
+	void ps3_init();
+	void ps5_init();
 	UINT32 screen_update_psikyosh(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(psikyosh_interrupt);
 	void draw_scanline32_alpha(bitmap_rgb32 &bitmap, INT32 destx, INT32 desty, INT32 length, const UINT32 *srcptr, int alpha);
