@@ -6,7 +6,9 @@ public:
 		m_videoram(*this, "videoram"),
 		m_colorram(*this, "colorram"),
 		m_spriteram(*this, "spriteram"),
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	required_shared_ptr<UINT8> m_videoram;
 	required_shared_ptr<UINT8> m_colorram;
@@ -34,9 +36,11 @@ public:
 	DECLARE_WRITE8_MEMBER(rollrace_backgroundcolor_w);
 	DECLARE_WRITE8_MEMBER(rollrace_flipy_w);
 	DECLARE_WRITE8_MEMBER(rollrace_flipx_w);
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(rollrace);
 	UINT32 screen_update_rollrace(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(vblank_irq);
 	INTERRUPT_GEN_MEMBER(sound_timer_irq);
 	required_device<cpu_device> m_maincpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 };
