@@ -8,7 +8,9 @@ public:
 		m_spriteram(*this, "spriteram"),
 		m_scroll(*this, "scroll"),
 		m_maincpu(*this, "maincpu"),
-		m_audiocpu(*this, "audiocpu")  { }
+		m_audiocpu(*this, "audiocpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette")  { }
 
 	int m_irq_enable;
 	required_shared_ptr<UINT8> m_colorram;
@@ -26,10 +28,12 @@ public:
 	DECLARE_WRITE8_MEMBER(scotrsht_palettebank_w);
 	TILE_GET_INFO_MEMBER(scotrsht_get_bg_tile_info);
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(scotrsht);
 	UINT32 screen_update_scotrsht(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(scotrsht_interrupt);
 	void draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect );
 	required_device<cpu_device> m_maincpu;
 	required_device<cpu_device> m_audiocpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 };
