@@ -1,18 +1,24 @@
 #include "machine/i8255.h"
 #include "includes/galaxold.h"
+#include "sound/tms5110.h"
 
 class scramble_state : public galaxold_state
 {
 public:
 	scramble_state(const machine_config &mconfig, device_type type, const char *tag)
 		: galaxold_state(mconfig, type, tag),
-			m_ppi8255_0(*this, "ppi8255_0"),
-			m_ppi8255_1(*this, "ppi8255_1"),
-			m_soundram(*this, "soundram")
-	{ }
+		m_konami_7474(*this, "konami_7474"),
+		m_ppi8255_0(*this, "ppi8255_0"),
+		m_ppi8255_1(*this, "ppi8255_1"),
+		m_tmsprom(*this, "tmsprom"),
+		m_soundram(*this, "soundram")
+	{
+	}
 
+	optional_device<ttl7474_device> m_konami_7474;
 	optional_device<i8255_device>  m_ppi8255_0;
 	optional_device<i8255_device>  m_ppi8255_1;
+	optional_device<tmsprom_device>  m_tmsprom;
 	optional_shared_ptr<UINT8> m_soundram;
 
 	UINT8 m_cavelon_bank;
@@ -34,11 +40,18 @@ public:
 	DECLARE_READ8_MEMBER(mars_ppi8255_0_r);
 	DECLARE_READ8_MEMBER(mars_ppi8255_1_r);
 	DECLARE_WRITE8_MEMBER(scramble_soundram_w);
+	DECLARE_READ8_MEMBER(scramble_portB_r);
+	DECLARE_READ8_MEMBER(hustler_portB_r);
 	DECLARE_WRITE8_MEMBER(hotshock_sh_irqtrigger_w);
+	DECLARE_READ8_MEMBER(hotshock_soundlatch_r);
 	DECLARE_WRITE8_MEMBER(scramble_filter_w);
 	DECLARE_WRITE8_MEMBER(frogger_filter_w);
 	DECLARE_WRITE8_MEMBER(mars_ppi8255_0_w);
 	DECLARE_WRITE8_MEMBER(mars_ppi8255_1_w);
+	DECLARE_WRITE8_MEMBER(ad2083_tms5110_ctrl_w);
+
+	DECLARE_WRITE8_MEMBER(harem_portA_w);
+	DECLARE_WRITE8_MEMBER(harem_portB_w);
 
 	DECLARE_WRITE8_MEMBER(harem_decrypt_bit_w);
 	DECLARE_WRITE8_MEMBER(harem_decrypt_clk_w);
@@ -83,29 +96,12 @@ public:
 	DECLARE_WRITE8_MEMBER( cavelon_banksw_w );
 	DECLARE_READ8_MEMBER( hunchbks_mirror_r );
 	DECLARE_WRITE8_MEMBER( hunchbks_mirror_w );
+	void sh_init();
+	DECLARE_WRITE8_MEMBER( scramble_sh_irqtrigger_w );
+	DECLARE_WRITE8_MEMBER( mrkougar_sh_irqtrigger_w );
+	IRQ_CALLBACK_MEMBER( scramble_sh_irq_callback );
 };
 
-
-/*----------- defined in machine/scramble.c -----------*/
-
-extern const i8255_interface(scramble_ppi_0_intf);
-extern const i8255_interface(scramble_ppi_1_intf);
-extern const i8255_interface(stratgyx_ppi_1_intf);
-
 /*----------- defined in audio/scramble.c -----------*/
 
-void scramble_sh_init(running_machine &machine);
-
-
-DECLARE_READ8_DEVICE_HANDLER( scramble_portB_r );
-DECLARE_READ8_DEVICE_HANDLER( frogger_portB_r );
-
-DECLARE_READ8_DEVICE_HANDLER( hotshock_soundlatch_r );
-
-DECLARE_WRITE8_DEVICE_HANDLER( scramble_sh_irqtrigger_w );
-DECLARE_WRITE8_DEVICE_HANDLER( mrkougar_sh_irqtrigger_w );
-
-DECLARE_WRITE8_DEVICE_HANDLER( harem_portA_w );
-DECLARE_WRITE8_DEVICE_HANDLER( harem_portB_w );
-
 MACHINE_CONFIG_EXTERN( ad2083_audio );
