@@ -19,12 +19,13 @@ public:
 		m_k007232_1(*this, "k007232_1"),
 		m_k007232_2(*this, "k007232_2"),
 		m_k052109(*this, "k052109"),
-		m_k051960(*this, "k051960") { }
+		m_k051960(*this, "k051960"),
+		m_palette(*this, "palette") { }
 
 	/* memory pointers */
 	required_shared_ptr<UINT8> m_ram;
 	UINT8      m_pmcram[0x800];
-//  UINT8 *    m_paletteram;    // currently this uses generic palette handling
+	dynamic_array<UINT8> m_paletteram;
 
 	/* video-related */
 	int        m_layer_colorbase[3];
@@ -43,6 +44,7 @@ public:
 	required_device<k007232_device> m_k007232_2;
 	required_device<k052109_device> m_k052109;
 	required_device<k051960_device> m_k051960;
+	required_device<palette_device> m_palette;
 	DECLARE_READ8_MEMBER(spy_bankedram1_r);
 	DECLARE_WRITE8_MEMBER(spy_bankedram1_w);
 	DECLARE_WRITE8_MEMBER(bankswitch_w);
@@ -60,8 +62,6 @@ public:
 	DECLARE_WRITE_LINE_MEMBER(irqhandler);
 	DECLARE_WRITE8_MEMBER(volume_callback0);
 	DECLARE_WRITE8_MEMBER(volume_callback1);
+	K052109_CB_MEMBER(tile_callback);
+	K051960_CB_MEMBER(sprite_callback);
 };
-
-/*----------- defined in video/spy.c -----------*/
-extern void spy_tile_callback(running_machine &machine, int layer,int bank,int *code,int *color,int *flags,int *priority);
-extern void spy_sprite_callback(running_machine &machine, int *code,int *color,int *priority_mask,int *shadow);
