@@ -8,7 +8,9 @@ public:
 		m_vram3(*this, "vram3"),
 		m_vram4(*this, "vram4"),
 		m_scrollram(*this, "scrollram"),
-		m_maincpu(*this, "maincpu") { }
+		m_maincpu(*this, "maincpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	int m_oldport;
 	tilemap_t *m_tilemap1;
@@ -29,9 +31,11 @@ public:
 	TILE_GET_INFO_MEMBER(get_tile_info4);
 	virtual void machine_reset();
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(ssrj);
 	UINT32 screen_update_ssrj(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	void screen_eof_ssrj(screen_device &screen, bool state);
 	void draw_objects(bitmap_ind16 &bitmap, const rectangle &cliprect );
 	required_device<cpu_device> m_maincpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 };
