@@ -33,7 +33,10 @@ public:
 		m_io_service(*this, "SERVICE"),
 		m_io_paddle(*this, "PADDLE"),
 		m_io_trackx(*this, "TRACKX"),
-		m_io_tracky(*this, "TRACKY")
+		m_io_tracky(*this, "TRACKY"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_screen(*this, "screen"),
+		m_palette(*this, "palette")
 	{ }
 
 	required_device<cpu_device> m_maincpu;
@@ -154,6 +157,7 @@ public:
 	TIMER_DEVICE_CALLBACK_MEMBER(gdfs_interrupt);
 	void update_irq_state();
 	IRQ_CALLBACK_MEMBER(ssv_irq_callback);
+	void ssv_drawgfx(bitmap_ind16 &bitmap, const rectangle &cliprect, gfx_element *gfx,UINT32 code,UINT32 color,int flipx,int flipy,int x0,int y0,int shadow);
 	void draw_row(bitmap_ind16 &bitmap, const rectangle &cliprect, int sx, int sy, int scroll);
 	void draw_layer(bitmap_ind16 &bitmap, const rectangle &cliprect, int  nr);
 	void draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect);
@@ -176,4 +180,7 @@ protected:
 	optional_ioport m_io_paddle;
 	optional_ioport m_io_trackx;
 	optional_ioport m_io_tracky;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<screen_device> m_screen;
+	required_device<palette_device> m_palette;
 };
