@@ -1,4 +1,5 @@
 #include "video/decbac06.h"
+#include "video/decmxc06.h"
 
 class stadhero_state : public driver_device
 {
@@ -8,14 +9,19 @@ public:
 		m_maincpu(*this, "maincpu"),
 		m_audiocpu(*this, "audiocpu"),
 		m_tilegen1(*this, "tilegen1"),
+		m_spritegen(*this, "spritegen"),
 		m_spriteram(*this, "spriteram"),
-		m_pf1_data(*this, "pf1_data") { }
+		m_pf1_data(*this, "pf1_data"),
+		m_gfxdecode(*this, "gfxdecode") { }
 
 	required_device<cpu_device> m_maincpu;
 	required_device<cpu_device> m_audiocpu;
 	required_device<deco_bac06_device> m_tilegen1;
+	required_device<deco_mxc06_device> m_spritegen;
 	required_shared_ptr<UINT16> m_spriteram;
 	required_shared_ptr<UINT16> m_pf1_data;
+	required_device<gfxdecode_device> m_gfxdecode;
+
 	tilemap_t *m_pf1_tilemap;
 	int m_flipscreen;
 	DECLARE_READ16_MEMBER(stadhero_control_r);
