@@ -11,7 +11,9 @@ public:
 		m_videoram(*this, "videoram"),
 		m_bitmapram(*this, "bitmapram"),
 		m_bitmapram2(*this, "bitmapram2"),
-		m_samples(*this, "samples"){ }
+		m_samples(*this, "samples"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	required_device<cpu_device> m_maincpu;
 	optional_device<cpu_device> m_mcu;
@@ -20,6 +22,8 @@ public:
 	optional_shared_ptr<UINT8> m_bitmapram;
 	optional_shared_ptr<UINT8> m_bitmapram2;
 	optional_device<samples_device> m_samples;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 
 	INT16 *m_samplebuf;
 	UINT8 m_port1;
