@@ -16,7 +16,9 @@ public:
 		m_maincpu(*this, "maincpu"),
 		m_audiocpu(*this, "audiocpu"),
 		m_tc0080vco(*this, "tc0080vco"),
-		m_tc0220ioc(*this, "tc0220ioc") { }
+		m_tc0220ioc(*this, "tc0220ioc"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	/* memory pointers */
 	required_shared_ptr<UINT16> m_m68000_mainram;
@@ -30,6 +32,9 @@ public:
 	required_device<cpu_device> m_audiocpu;
 	required_device<tc0080vco_device> m_tc0080vco;
 	required_device<tc0220ioc_device> m_tc0220ioc;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
+
 	DECLARE_READ8_MEMBER(syvalion_input_bypass_r);
 	DECLARE_WRITE8_MEMBER(sound_bankswitch_w);
 	virtual void machine_start();
