@@ -1,4 +1,4 @@
-#include "video/polynew.h"
+#include "video/poly.h"
 #include "machine/taitoio.h"
 
 #define TAITOJC_POLYGON_FIFO_SIZE       0x20000
@@ -48,7 +48,10 @@ public:
 		m_snd_shared_ram(*this, "snd_shared"),
 		m_main_ram(*this, "main_ram"),
 		m_dsp_shared_ram(*this, "dsp_shared"),
-		m_palette_ram(*this, "palette_ram")
+		m_palette_ram(*this, "palette_ram"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_screen(*this, "screen"),
+		m_palette(*this, "palette")
 	{
 		m_mcu_output = 0;
 		m_speed_meter = 0;
@@ -68,6 +71,10 @@ public:
 	required_shared_ptr<UINT16> m_dsp_shared_ram;
 	required_shared_ptr<UINT32> m_palette_ram;
 
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<screen_device> m_screen;
+	required_device<palette_device> m_palette;
+
 	taitojc_renderer *m_renderer;
 
 	int m_texture_x;
