@@ -1,4 +1,5 @@
 #include "sound/msm5205.h"
+#include "video/tecmo_spr.h"
 
 class tecmo_state : public driver_device
 {
@@ -11,7 +12,11 @@ public:
 		m_spriteram(*this, "spriteram"),
 		m_maincpu(*this, "maincpu"),
 		m_soundcpu(*this, "soundcpu"),
-		m_msm(*this, "msm") { }
+		m_msm(*this, "msm"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette"),
+		m_sprgen(*this, "spritegen")
+		{ }
 
 	int m_adpcm_pos;
 	int m_adpcm_end;
@@ -60,4 +65,7 @@ public:
 	required_device<cpu_device> m_maincpu;
 	required_device<cpu_device> m_soundcpu;
 	required_device<msm5205_device> m_msm;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
+	required_device<tecmo_spr_device> m_sprgen;
 };
