@@ -37,14 +37,15 @@ public:
 		m_k053936(*this, "k053936"),
 		m_k054000(*this, "k054000"),
 		m_upd7759(*this, "upd"),
-		m_samples(*this, "samples"){ }
+		m_samples(*this, "samples"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	/* memory pointers */
 	optional_shared_ptr<UINT16> m_spriteram;
 	optional_shared_ptr<UINT16> m_tmnt2_rom;
 	optional_shared_ptr<UINT16> m_sunset_104000;
 	optional_shared_ptr<UINT16> m_tmnt2_1c0800;
-//  UINT16 *    m_paletteram;    // currently this uses generic palette handling
 
 	/* video-related */
 	int        m_layer_colorbase[3];
@@ -85,6 +86,8 @@ public:
 	optional_device<k054000_device> m_k054000;
 	optional_device<upd7759_device> m_upd7759;
 	optional_device<samples_device> m_samples;
+	optional_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 
 	/* memory buffers */
 	INT16      m_sampledata[0x40000];
@@ -119,7 +122,6 @@ public:
 	DECLARE_WRITE16_MEMBER(tmnt2_1c0800_w);
 	DECLARE_READ8_MEMBER(k054539_ctrl_r);
 	DECLARE_WRITE8_MEMBER(k054539_ctrl_w);
-	DECLARE_WRITE16_MEMBER(tmnt_paletteram_word_w);
 	DECLARE_WRITE16_MEMBER(tmnt_0a0000_w);
 	DECLARE_WRITE16_MEMBER(punkshot_0a0020_w);
 	DECLARE_WRITE16_MEMBER(lgtnfght_0a0018_w);
@@ -167,23 +169,19 @@ public:
 	inline UINT32 tmnt2_get_word( UINT32 addr );
 	void tmnt2_put_word( address_space &space, UINT32 addr, UINT16 data );
 	DECLARE_WRITE8_MEMBER(volume_callback);
+	K051960_CB_MEMBER(mia_sprite_callback);
+	K051960_CB_MEMBER(tmnt_sprite_callback);
+	K051960_CB_MEMBER(punkshot_sprite_callback);
+	K051960_CB_MEMBER(thndrx2_sprite_callback);
+	K05324X_CB_MEMBER(lgtnfght_sprite_callback);
+	K05324X_CB_MEMBER(blswhstl_sprite_callback);
+	K05324X_CB_MEMBER(prmrsocr_sprite_callback);
+	K052109_CB_MEMBER(mia_tile_callback);
+	K052109_CB_MEMBER(cuebrick_tile_callback);
+	K052109_CB_MEMBER(tmnt_tile_callback);
+	K052109_CB_MEMBER(ssbl_tile_callback);
+	K052109_CB_MEMBER(blswhstl_tile_callback);
 
 protected:
 	virtual void device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr);
 };
-
-
-/*----------- defined in video/tmnt.c -----------*/
-
-extern void mia_tile_callback(running_machine &machine, int layer,int bank,int *code,int *color,int *flags,int *priority);
-extern void cuebrick_tile_callback(running_machine &machine, int layer,int bank,int *code,int *color,int *flags,int *priority);
-extern void tmnt_tile_callback(running_machine &machine, int layer,int bank,int *code,int *color,int *flags,int *priority);
-extern void ssbl_tile_callback(running_machine &machine, int layer,int bank,int *code,int *color,int *flags,int *priority);
-extern void blswhstl_tile_callback(running_machine &machine, int layer,int bank,int *code,int *color,int *flags,int *priority);
-extern void mia_sprite_callback(running_machine &machine, int *code,int *color,int *priority,int *shadow);
-extern void tmnt_sprite_callback(running_machine &machine, int *code,int *color,int *priority,int *shadow);
-extern void punkshot_sprite_callback(running_machine &machine, int *code,int *color,int *priority_mask,int *shadow);
-extern void thndrx2_sprite_callback(running_machine &machine, int *code,int *color,int *priority_mask,int *shadow);
-extern void lgtnfght_sprite_callback(running_machine &machine, int *code,int *color,int *priority_mask);
-extern void blswhstl_sprite_callback(running_machine &machine, int *code,int *color,int *priority_mask);
-extern void prmrsocr_sprite_callback(running_machine &machine, int *code,int *color,int *priority_mask);
