@@ -14,12 +14,12 @@ public:
 	required_shared_ptr<UINT8> m_battery_ram;
 	int m_trigger;
 	DECLARE_WRITE8_MEMBER(porta_w);
-	DECLARE_WRITE8_MEMBER(pia_ca2_w);
+	DECLARE_WRITE_LINE_MEMBER(pia_ca2_w);
 	DECLARE_WRITE8_MEMBER(portb_w);
-	DECLARE_WRITE8_MEMBER(pia_irqa_w);
-	DECLARE_WRITE8_MEMBER(pia_irqb_w);
+	DECLARE_WRITE_LINE_MEMBER(pia_irqa_w);
+	DECLARE_WRITE_LINE_MEMBER(pia_irqb_w);
 	virtual void machine_reset();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(truco);
 	UINT32 screen_update_truco(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(truco_interrupt);
 	required_device<cpu_device> m_maincpu;
