@@ -1,20 +1,35 @@
+/***************************************************************************
+
+  Capcom Vulgus hardware
+
+***************************************************************************/
+
 class vulgus_state : public driver_device
 {
 public:
 	vulgus_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag),
+		m_maincpu(*this, "maincpu"),
+		m_audiocpu(*this, "audiocpu"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette"),
 		m_scroll_low(*this, "scroll_low"),
 		m_scroll_high(*this, "scroll_high"),
 		m_spriteram(*this, "spriteram"),
 		m_fgvideoram(*this, "fgvideoram"),
-		m_bgvideoram(*this, "bgvideoram"),
-		m_maincpu(*this, "maincpu") { }
+		m_bgvideoram(*this, "bgvideoram")
+	{ }
 
+	required_device<cpu_device> m_maincpu;
+	required_device<cpu_device> m_audiocpu;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 	required_shared_ptr<UINT8> m_scroll_low;
 	required_shared_ptr<UINT8> m_scroll_high;
 	required_shared_ptr<UINT8> m_spriteram;
 	required_shared_ptr<UINT8> m_fgvideoram;
 	required_shared_ptr<UINT8> m_bgvideoram;
+
 	int m_palette_bank;
 	tilemap_t *m_fg_tilemap;
 	tilemap_t *m_bg_tilemap;
@@ -25,9 +40,8 @@ public:
 	TILE_GET_INFO_MEMBER(get_fg_tile_info);
 	TILE_GET_INFO_MEMBER(get_bg_tile_info);
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(vulgus);
 	UINT32 screen_update_vulgus(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	INTERRUPT_GEN_MEMBER(vulgus_vblank_irq);
 	void draw_sprites(bitmap_ind16 &bitmap,const rectangle &cliprect);
-	required_device<cpu_device> m_maincpu;
 };
