@@ -21,7 +21,11 @@ public:
 		m_k007232(*this, "k007232"),
 		m_k007232_1(*this, "k007232_1"),
 		m_k007232_2(*this, "k007232_2"),
-		m_k007232_3(*this, "k007232_3") { }
+		m_k007232_3(*this, "k007232_3"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette"),
+		m_screen(*this, "screen"),
+		m_generic_paletteram_16(*this, "paletteram") { }
 
 	optional_shared_ptr<UINT16> m_videostatus;
 	optional_shared_ptr<UINT16> m_protection_ram;
@@ -93,9 +97,19 @@ public:
 	INTERRUPT_GEN_MEMBER(hotchase_sound_timer);
 	TIMER_DEVICE_CALLBACK_MEMBER(wecleman_scanline);
 	TIMER_DEVICE_CALLBACK_MEMBER(hotchase_scanline);
+	void draw_cloud(bitmap_rgb32 &bitmap,gfx_element *gfx,UINT16 *tm_base,int x0,int y0,int xcount,int ycount,int scrollx,int scrolly,int tmw_l2,int tmh_l2,int alpha,int pal_offset);
 	void wecleman_unpack_sprites();
 	void bitswap(UINT8 *src,size_t len,int _14,int _13,int _12,int _11,int _10,int _f,int _e,int _d,int _c,int _b,int _a,int _9,int _8,int _7,int _6,int _5,int _4,int _3,int _2,int _1,int _0);
 	void hotchase_sprite_decode( int num16_banks, int bank_size );
+	void get_sprite_info();
+	void sortsprite(int *idx_array, int *key_array, int size);
+	template<class _BitmapClass> void do_blit_zoom32(_BitmapClass &bitmap, const rectangle &cliprect, struct sprite *sprite);
+	template<class _BitmapClass> void sprite_draw(_BitmapClass &bitmap, const rectangle &cliprect);
+	void wecleman_draw_road(bitmap_rgb32 &bitmap, const rectangle &cliprect, int priority);
+	void hotchase_draw_road(bitmap_ind16 &bitmap, const rectangle &cliprect);
+	K051316_CB_MEMBER(hotchase_zoom_callback_1);
+	K051316_CB_MEMBER(hotchase_zoom_callback_2);
+
 	required_device<cpu_device> m_maincpu;
 	required_device<cpu_device> m_audiocpu;
 	required_device<cpu_device> m_subcpu;
@@ -105,8 +119,8 @@ public:
 	optional_device<k007232_device> m_k007232_1;
 	optional_device<k007232_device> m_k007232_2;
 	optional_device<k007232_device> m_k007232_3;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
+	required_device<screen_device> m_screen;
+	required_shared_ptr<UINT16> m_generic_paletteram_16;
 };
-
-/*----------- defined in video/wecleman.c -----------*/
-void hotchase_zoom_callback_0(running_machine &machine, int *code,int *color,int *flags);
-void hotchase_zoom_callback_1(running_machine &machine, int *code,int *color,int *flags);
