@@ -31,7 +31,9 @@ public:
 		m_subcpu(*this, "sub"),
 		m_tc0100scn(*this, "tc0100scn"),
 		m_tc0140syt(*this, "tc0140syt"),
-		m_tc0220ioc(*this, "tc0220ioc") { }
+		m_tc0220ioc(*this, "tc0220ioc"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette") { }
 
 	/* memory pointers */
 	required_shared_ptr<UINT16> m_spritemap;
@@ -64,6 +66,9 @@ public:
 	required_device<tc0100scn_device> m_tc0100scn;
 	required_device<tc0140syt_device> m_tc0140syt;
 	required_device<tc0220ioc_device> m_tc0220ioc;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
+
 	DECLARE_READ16_MEMBER(sharedram_r);
 	DECLARE_WRITE16_MEMBER(sharedram_w);
 	DECLARE_WRITE16_MEMBER(cpua_ctrl_w);
