@@ -971,7 +971,11 @@ atarigen_state::atarigen_state(const machine_config &mconfig, device_type type,
 		m_maincpu(*this, "maincpu"),
 		m_audiocpu(*this, "audiocpu"),
 		m_oki(*this, "oki"),
-		m_soundcomm(*this, "soundcomm")
+		m_soundcomm(*this, "soundcomm"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_screen(*this, "screen"),
+		m_palette(*this, "palette"),
+		m_generic_paletteram_16(*this, "paletteram")
 {
 }
 
@@ -1396,85 +1400,6 @@ void atarigen_state::halt_until_hblank_0(device_t &device, screen_device &screen
 }
 
 
-//-------------------------------------------------
-//  paletteram_666_w: 6-6-6 RGB palette RAM handler.
-//-------------------------------------------------
-
-WRITE16_MEMBER(atarigen_state::paletteram_666_w)
-{
-	int newword, r, g, b;
-
-	COMBINE_DATA(&m_generic_paletteram_16[offset]);
-	newword = m_generic_paletteram_16[offset];
-
-	r = ((newword >> 9) & 0x3e) | ((newword >> 15) & 1);
-	g = ((newword >> 4) & 0x3e) | ((newword >> 15) & 1);
-	b = ((newword << 1) & 0x3e) | ((newword >> 15) & 1);
-
-	palette_set_color_rgb(space.machine(), offset, pal6bit(r), pal6bit(g), pal6bit(b));
-}
-
-
-//-------------------------------------------------
-//  expanded_paletteram_666_w: 6-6-6 RGB expanded
-//  palette RAM handler.
-//-------------------------------------------------
-
-WRITE16_MEMBER(atarigen_state::expanded_paletteram_666_w)
-{
-	COMBINE_DATA(&m_generic_paletteram_16[offset]);
-
-	if (ACCESSING_BITS_8_15)
-	{
-		int palentry = offset / 2;
-		int newword = (m_generic_paletteram_16[palentry * 2] & 0xff00) | (m_generic_paletteram_16[palentry * 2 + 1] >> 8);
-
-		int r, g, b;
-
-		r = ((newword >> 9) & 0x3e) | ((newword >> 15) & 1);
-		g = ((newword >> 4) & 0x3e) | ((newword >> 15) & 1);
-		b = ((newword << 1) & 0x3e) | ((newword >> 15) & 1);
-
-		palette_set_color_rgb(space.machine(), palentry & 0x1ff, pal6bit(r), pal6bit(g), pal6bit(b));
-	}
-}
-
-
-//-------------------------------------------------
-//  paletteram32_666_w: 6-6-6 RGB palette RAM handler.
-//-------------------------------------------------
-
-WRITE32_MEMBER(atarigen_state::paletteram32_666_w )
-{
-	int newword, r, g, b;
-
-	COMBINE_DATA(&m_generic_paletteram_32[offset]);
-
-	if (ACCESSING_BITS_16_31)
-	{
-		newword = m_generic_paletteram_32[offset] >> 16;
-
-		r = ((newword >> 9) & 0x3e) | ((newword >> 15) & 1);
-		g = ((newword >> 4) & 0x3e) | ((newword >> 15) & 1);
-		b = ((newword << 1) & 0x3e) | ((newword >> 15) & 1);
-
-		palette_set_color_rgb(space.machine(), offset * 2, pal6bit(r), pal6bit(g), pal6bit(b));
-	}
-
-	if (ACCESSING_BITS_0_15)
-	{
-		newword = m_generic_paletteram_32[offset] & 0xffff;
-
-		r = ((newword >> 9) & 0x3e) | ((newword >> 15) & 1);
-		g = ((newword >> 4) & 0x3e) | ((newword >> 15) & 1);
-		b = ((newword << 1) & 0x3e) | ((newword >> 15) & 1);
-
-		palette_set_color_rgb(space.machine(), offset * 2 + 1, pal6bit(r), pal6bit(g), pal6bit(b));
-	}
-}
-
-
-
 /***************************************************************************
     MISC HELPERS
 ***************************************************************************/
@@ -1486,8 +1411,8 @@ WRITE32_MEMBER(atarigen_state::paletteram32_666_w )
 
 void atarigen_state::blend_gfx(int gfx0, int gfx1, int mask0, int mask1)
 {
-	gfx_element *gx0 = machine().gfx[gfx0];
-	gfx_element *gx1 = machine().gfx[gfx1];
+	gfx_element *gx0 = m_gfxdecode->gfx(gfx0);
+	gfx_element *gx1 = m_gfxdecode->gfx(gfx1);
 	UINT8 *srcdata, *dest;
 	int c, x, y;
 
@@ -1520,8 +1445,7 @@ void atarigen_state::blend_gfx(int gfx0, int gfx1, int mask0, int mask1)
 	gx0->set_granularity(granularity);
 
 	// free the second graphics element
-	machine().gfx[gfx1] = NULL;
-	auto_free(machine(), gx1);
+	m_gfxdecode->set_gfx(gfx1, NULL);
 }
 
 
