@@ -28,7 +28,7 @@ TODO:
 const device_type MACHINE_CDI68070 = &device_creator<cdi68070_device>;
 
 #if ENABLE_VERBOSE_LOG
-INLINE void verboselog(running_machine &machine, int n_level, const char *s_fmt, ...)
+INLINE void ATTR_PRINTF(1,2) verboselog(running_machine &machine, int n_level, const char *s_fmt, ...)
 {
 	if( VERBOSE_LEVEL >= n_level )
 	{
@@ -41,7 +41,7 @@ INLINE void verboselog(running_machine &machine, int n_level, const char *s_fmt,
 	}
 }
 #else
-#define verboselog(x,y,z,...)
+#define verboselog(x,y,z, ...)
 #endif
 
 //**************************************************************************
@@ -1171,7 +1171,7 @@ WRITE16_MEMBER( cdi68070_device::periphs_w )
 }
 
 #if ENABLE_UART_PRINTING
-READ16_HANDLER( uart_loopback_enable )
+READ16_MEMBER( cdi68070_device::uart_loopback_enable )
 {
 	return 0x1234;
 }
