@@ -25,16 +25,6 @@
 #define LOG_COMMANDS        0
 
 
-
-/*************************************
- *
- *  Static globals
- *
- *************************************/
-
-static void hdds3sdsp_reset_timer(running_machine &machine);
-static void hdds3xdsp_reset_timer(running_machine &machine);
-
 #if 0
 #pragma mark * DRIVER/MULTISYNC BOARD
 #endif
@@ -156,7 +146,7 @@ READ16_MEMBER( harddriv_state::hd68k_gsp_io_r )
 	UINT16 result;
 	offset = (offset / 2) ^ 1;
 	m_hd34010_host_access = TRUE;
-	result = tms34010_host_r(m_gsp, offset);
+	result = m_gsp->host_r(space, offset, 0xffff);
 	m_hd34010_host_access = FALSE;
 	return result;
 }
@@ -166,7 +156,7 @@ WRITE16_MEMBER( harddriv_state::hd68k_gsp_io_w )
 {
 	offset = (offset / 2) ^ 1;
 	m_hd34010_host_access = TRUE;
-	tms34010_host_w(m_gsp, offset, data);
+	m_gsp->host_w(space, offset, data, 0xffff);
 	m_hd34010_host_access = FALSE;
 }
 
@@ -183,7 +173,7 @@ READ16_MEMBER( harddriv_state::hd68k_msp_io_r )
 	UINT16 result;
 	offset = (offset / 2) ^ 1;
 	m_hd34010_host_access = TRUE;
-	result = (m_msp != NULL) ? tms34010_host_r(m_msp, offset) : 0xffff;
+	result = (m_msp != NULL) ? m_msp->host_r(space, offset, 0xffff) : 0xffff;
 	m_hd34010_host_access = FALSE;
 	return result;
 }
@@ -195,7 +185,7 @@ WRITE16_MEMBER( harddriv_state::hd68k_msp_io_w )
 	if (m_msp != NULL)
 	{
 		m_hd34010_host_access = TRUE;
-		tms34010_host_w(m_msp, offset, data);
+		m_msp->host_w(space, offset, data, 0xffff);
 		m_hd34010_host_access = FALSE;
 	}
 }
@@ -498,10 +488,10 @@ WRITE16_MEMBER( harddriv_state::hdgsp_io_w )
 	}
 
 	/* detect changes to HEBLNK and HSBLNK and force an update before they change */
-	if ((offset == REG_HEBLNK || offset == REG_HSBLNK) && data != tms34010_io_register_r(space, offset, 0xffff))
+	if ((offset == REG_HEBLNK || offset == REG_HSBLNK) && data != m_gsp->io_register_r(space, offset, 0xffff))
 		m_screen->update_partial(m_screen->vpos() - 1);
 
-	tms34010_io_register_w(space, offset, data, mem_mask);
+	m_gsp->io_register_w(space, offset, data, mem_mask);
 }
 
 
@@ -1169,7 +1159,7 @@ WRITE16_MEMBER( harddriv_state::hdds3_sdsp_control_w )
 			if (m_ds3sdsp_regs[0x1b] != data)
 			{
 				m_ds3sdsp_regs[0x1b] = data;
-				hdds3sdsp_reset_timer(space.machine());
+				hdds3sdsp_reset_timer();
 			}
 			break;
 
@@ -1178,7 +1168,7 @@ WRITE16_MEMBER( harddriv_state::hdds3_sdsp_control_w )
 			if (m_ds3sdsp_regs[0x1c] != data)
 			{
 				m_ds3sdsp_regs[0x1c] = data;
-				hdds3sdsp_reset_timer(space.machine());
+				hdds3sdsp_reset_timer();
 			}
 			break;
 
@@ -1233,86 +1223,74 @@ WRITE16_MEMBER( harddriv_state::hdds3_xdsp_control_w )
 	}
 }
 
-TIMER_DEVICE_CALLBACK( ds3sdsp_internal_timer_callback )
+TIMER_DEVICE_CALLBACK_MEMBER( harddriv_state::ds3sdsp_internal_timer_callback )
 {
-	harddriv_state *state = timer.machine().driver_data<harddriv_state>();
+	UINT16 period = m_ds3sdsp_regs[0x1d];
+	UINT16 scale = m_ds3sdsp_regs[0x1b] + 1;
 
-	UINT16 period = state->m_ds3sdsp_regs[0x1d];
-	UINT16 scale = state->m_ds3sdsp_regs[0x1b] + 1;
-
-	state->m_ds3sdsp_internal_timer->adjust(state->m_ds3sdsp->cycles_to_attotime(period * scale));
+	m_ds3sdsp_internal_timer->adjust(m_ds3sdsp->cycles_to_attotime(period * scale));
 
 	/* the IRQ line is edge triggered */
-	state->m_ds3sdsp->set_input_line(ADSP2105_TIMER, ASSERT_LINE);
-	state->m_ds3sdsp->set_input_line(ADSP2105_TIMER, CLEAR_LINE);
+	m_ds3sdsp->set_input_line(ADSP2105_TIMER, ASSERT_LINE);
+	m_ds3sdsp->set_input_line(ADSP2105_TIMER, CLEAR_LINE);
 }
 
 
-static void hdds3sdsp_reset_timer(running_machine &machine)
+void harddriv_state::hdds3sdsp_reset_timer()
 {
-	harddriv_state *state = machine.driver_data<harddriv_state>();
-
-	if (!state->m_ds3sdsp_timer_en)
+	if (!m_ds3sdsp_timer_en)
 		return;
 
-	UINT16 count = state->m_ds3sdsp_regs[0x1c];
-	UINT16 scale = state->m_ds3sdsp_regs[0x1b] + 1;
+	UINT16 count = m_ds3sdsp_regs[0x1c];
+	UINT16 scale = m_ds3sdsp_regs[0x1b] + 1;
 
-	state->m_ds3sdsp_internal_timer->adjust(state->m_ds3sdsp->cycles_to_attotime(count * scale));
+	m_ds3sdsp_internal_timer->adjust(m_ds3sdsp->cycles_to_attotime(count * scale));
 }
 
-void hdds3sdsp_timer_enable_callback(adsp21xx_device &device, int enable)
+WRITE_LINE_MEMBER(harddriv_state::hdds3sdsp_timer_enable_callback)
 {
-	harddriv_state *state = device.machine().driver_data<harddriv_state>();
+	m_ds3sdsp_timer_en = state;
 
-	state->m_ds3sdsp_timer_en = enable;
-
-	if (enable)
-		hdds3sdsp_reset_timer(device.machine());
+	if (state)
+		hdds3sdsp_reset_timer();
 	else
-		state->m_ds3sdsp_internal_timer->adjust(attotime::never);
+		m_ds3sdsp_internal_timer->adjust(attotime::never);
 }
 
 
-TIMER_DEVICE_CALLBACK( ds3xdsp_internal_timer_callback )
+TIMER_DEVICE_CALLBACK_MEMBER( harddriv_state::ds3xdsp_internal_timer_callback )
 {
-	harddriv_state *state = timer.machine().driver_data<harddriv_state>();
+	UINT16 period = m_ds3xdsp_regs[0x1d];
+	UINT16 scale = m_ds3xdsp_regs[0x1b] + 1;
 
-	UINT16 period = state->m_ds3xdsp_regs[0x1d];
-	UINT16 scale = state->m_ds3xdsp_regs[0x1b] + 1;
-
-	state->m_ds3xdsp_internal_timer->adjust(state->m_ds3xdsp->cycles_to_attotime(period * scale));
+	m_ds3xdsp_internal_timer->adjust(m_ds3xdsp->cycles_to_attotime(period * scale));
 
 	/* the IRQ line is edge triggered */
-	state->m_ds3xdsp->set_input_line(ADSP2105_TIMER, ASSERT_LINE);
-	state->m_ds3xdsp->set_input_line(ADSP2105_TIMER, CLEAR_LINE);
+	m_ds3xdsp->set_input_line(ADSP2105_TIMER, ASSERT_LINE);
+	m_ds3xdsp->set_input_line(ADSP2105_TIMER, CLEAR_LINE);
 }
 
 
-static void hdds3xdsp_reset_timer(running_machine &machine)
+void harddriv_state::hdds3xdsp_reset_timer()
 {
-	harddriv_state *state = machine.driver_data<harddriv_state>();
-
-	if (!state->m_ds3xdsp_timer_en)
+	if (!m_ds3xdsp_timer_en)
 		return;
 
-	UINT16 count = state->m_ds3xdsp_regs[0x1c];
-	UINT16 scale = state->m_ds3xdsp_regs[0x1b] + 1;
+	UINT16 count = m_ds3xdsp_regs[0x1c];
+	UINT16 scale = m_ds3xdsp_regs[0x1b] + 1;
 
-	state->m_ds3xdsp_internal_timer->adjust(state->m_ds3xdsp->cycles_to_attotime(count * scale));
+	m_ds3xdsp_internal_timer->adjust(m_ds3xdsp->cycles_to_attotime(count * scale));
 }
 
 
-void hdds3xdsp_timer_enable_callback(adsp21xx_device &device, int enable)
+WRITE_LINE_MEMBER(harddriv_state::hdds3xdsp_timer_enable_callback)
 {
-	harddriv_state *state = device.machine().driver_data<harddriv_state>();
+	m_ds3xdsp_timer_en = state;
 
-	state->m_ds3xdsp_timer_en = enable;
-
-	if (enable)
-		hdds3xdsp_reset_timer(device.machine());
+	if (state)
+		hdds3xdsp_reset_timer();
 	else
-		state->m_ds3xdsp_internal_timer->adjust(attotime::never);
+		m_ds3xdsp_internal_timer->adjust(attotime::never);
 }
 
 
@@ -1326,50 +1304,42 @@ static TIMER_CALLBACK( xsdp_sport1_irq_off_callback )
 }
 
 
-void hdds3sdsp_serial_tx_callback(adsp21xx_device &device, int port, INT32 data)
+WRITE32_MEMBER(harddriv_state::hdds3sdsp_serial_tx_callback)
 {
-	harddriv_state *state = device.machine().driver_data<harddriv_state>();
-
-	if ((state->m_ds3sdsp_regs[0x1f] & 0xc00) != 0xc00)
+	if ((m_ds3sdsp_regs[0x1f] & 0xc00) != 0xc00)
 		return;
 
-	state->m_ds3sdsp_sdata = data;
+	m_ds3sdsp_sdata = data;
 
-	state->m_ds3xdsp->set_input_line(ADSP2105_SPORT1_RX, ASSERT_LINE);
-	device.machine().scheduler().timer_set(attotime::from_nsec(200), FUNC(xsdp_sport1_irq_off_callback));
+	m_ds3xdsp->set_input_line(ADSP2105_SPORT1_RX, ASSERT_LINE);
+	machine().scheduler().timer_set(attotime::from_nsec(200), FUNC(xsdp_sport1_irq_off_callback));
 }
 
 
-INT32 hdds3sdsp_serial_rx_callback(adsp21xx_device &device, int port)
+READ32_MEMBER(harddriv_state::hdds3sdsp_serial_rx_callback)
 {
-	harddriv_state *state = device.machine().driver_data<harddriv_state>();
-
-	if ((state->m_ds3sdsp_regs[0x1f] & 0xc00) != 0xc00)
+	if ((m_ds3sdsp_regs[0x1f] & 0xc00) != 0xc00)
 		return 0xff;
 
-	return state->m_ds3xdsp_sdata;
+	return m_ds3xdsp_sdata;
 }
 
 
-void hdds3xdsp_serial_tx_callback(adsp21xx_device &device, int port, INT32 data)
+WRITE32_MEMBER(harddriv_state::hdds3xdsp_serial_tx_callback)
 {
-	harddriv_state *state = device.machine().driver_data<harddriv_state>();
-
-	if ((state->m_ds3xdsp_regs[0x1f] & 0xc00) != 0xc00)
+	if ((m_ds3xdsp_regs[0x1f] & 0xc00) != 0xc00)
 		return;
 
-	state->m_ds3xdsp_sdata = data;
+	m_ds3xdsp_sdata = data;
 }
 
 
-INT32 hdds3xdsp_serial_rx_callback(adsp21xx_device &device, int port)
+READ32_MEMBER(harddriv_state::hdds3xdsp_serial_rx_callback)
 {
-	harddriv_state *state = device.machine().driver_data<harddriv_state>();
-
-	state->m_ds3xdsp->set_input_line(ADSP2105_SPORT1_RX, ASSERT_LINE);
-	state->m_ds3xdsp->set_input_line(ADSP2105_SPORT1_RX, CLEAR_LINE);
-	state->m_ds3xdsp->signal_interrupt_trigger();
-	return state->m_ds3sdsp_sdata;
+	m_ds3xdsp->set_input_line(ADSP2105_SPORT1_RX, ASSERT_LINE);
+	m_ds3xdsp->set_input_line(ADSP2105_SPORT1_RX, CLEAR_LINE);
+	m_ds3xdsp->signal_interrupt_trigger();
+	return m_ds3sdsp_sdata;
 }
 
 
@@ -1516,11 +1486,10 @@ WRITE16_MEMBER( harddriv_state::hd68k_ds3_program_w )
  *
  *************************************/
 
-void hddsk_update_pif(dsp32c_device &device, UINT32 pins)
+WRITE32_MEMBER(harddriv_state::hddsk_update_pif)
 {
-	atarigen_state *atarigen = device.machine().driver_data<atarigen_state>();
-	atarigen->m_sound_int_state = ((pins & DSP32_OUTPUT_PIF) != 0);
-	atarigen->update_interrupts();
+	m_sound_int_state = ((data & DSP32_OUTPUT_PIF) != 0);
+	update_interrupts();
 }
 
 
