@@ -6,48 +6,31 @@
 #include "video/voodoo.h"
 #include "konppc.h"
 
-#define MAX_CG_BOARDS   2
-
-static UINT32 dsp_comm_ppc[MAX_CG_BOARDS][2];
-static UINT32 dsp_comm_sharc[MAX_CG_BOARDS][2];
-static UINT8 dsp_shared_ram_bank[MAX_CG_BOARDS];
-
-static INT32 cgboard_id;
-static INT32 cgboard_type;
-static INT32 num_cgboards;
-
-static UINT32 *dsp_shared_ram[MAX_CG_BOARDS];
-
 #define DSP_BANK_SIZE           0x10000
 #define DSP_BANK_SIZE_WORD      (DSP_BANK_SIZE / 4)
 
-static UINT32 dsp_state[MAX_CG_BOARDS];
-static UINT32 nwk_device_sel[MAX_CG_BOARDS];
-static const char *texture_bank[MAX_CG_BOARDS];
-
-static int nwk_fifo_half_full_r;
-static int nwk_fifo_half_full_w;
-static int nwk_fifo_full;
-static int nwk_fifo_mask;
-
-
-static UINT32 *nwk_fifo[MAX_CG_BOARDS];
-static INT32 nwk_fifo_read_ptr[MAX_CG_BOARDS];
-static INT32 nwk_fifo_write_ptr[MAX_CG_BOARDS];
-
-static UINT32 *nwk_ram[MAX_CG_BOARDS];
-
 /*****************************************************************************/
 
-void init_konami_cgboard(running_machine &machine, int num_boards, int type)
+
+const device_type KONPPC = &device_creator<konppc_device>;
+
+konppc_device::konppc_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: device_t(mconfig, KONPPC, "KONPPC", tag, owner, clock, "konppc", __FILE__),
+	cgboard_type(0),
+	num_cgboards(0)
+{
+}
+
+//void konppc_device::init_konami_cgboard(running_machine &machine, int num_boards, int type)
+
+void konppc_device::device_start()
 {
 	int i;
-	num_cgboards = num_boards;
 
-	for (i=0; i < num_boards; i++)
+	for (i=0; i < num_cgboards; i++)
 	{
 		dsp_comm_ppc[i][0] = 0x00;
-		dsp_shared_ram[i] = auto_alloc_array(machine, UINT32, DSP_BANK_SIZE * 2/4);
+		dsp_shared_ram[i] = auto_alloc_array(machine(), UINT32, DSP_BANK_SIZE * 2/4);
 		dsp_shared_ram_bank[i] = 0;
 
 		dsp_state[i] = 0x80;
@@ -57,31 +40,30 @@ void init_konami_cgboard(running_machine &machine, int num_boards, int type)
 		nwk_fifo_read_ptr[i] = 0;
 		nwk_fifo_write_ptr[i] = 0;
 
-		nwk_fifo[i] = auto_alloc_array(machine, UINT32, 0x800);
-		nwk_ram[i] = auto_alloc_array(machine, UINT32, 0x2000);
+		nwk_fifo[i] = auto_alloc_array(machine(), UINT32, 0x800);
+		nwk_ram[i] = auto_alloc_array(machine(), UINT32, 0x2000);
 
-		state_save_register_item_array(machine, "konppc", NULL, i, dsp_comm_ppc[i]);
-		state_save_register_item_array(machine, "konppc", NULL, i, dsp_comm_sharc[i]);
-		state_save_register_item(machine, "konppc", NULL, i, dsp_shared_ram_bank[i]);
-		state_save_register_item_pointer(machine, "konppc", NULL, i, dsp_shared_ram[i], DSP_BANK_SIZE * 2 / sizeof(dsp_shared_ram[i][0]));
-		state_save_register_item(machine, "konppc", NULL, i, dsp_state[i]);
-		state_save_register_item(machine, "konppc", NULL, i, nwk_device_sel[i]);
-		state_save_register_item(machine, "konppc", NULL, i, nwk_fifo_read_ptr[i]);
-		state_save_register_item(machine, "konppc", NULL, i, nwk_fifo_write_ptr[i]);
-		state_save_register_item_pointer(machine, "konppc", NULL, i, nwk_fifo[i], 0x800);
-		state_save_register_item_pointer(machine, "konppc", NULL, i, nwk_ram[i], 0x2000);
+		state_save_register_item_array(machine(), "konppc", NULL, i, dsp_comm_ppc[i]);
+		state_save_register_item_array(machine(), "konppc", NULL, i, dsp_comm_sharc[i]);
+		state_save_register_item(machine(), "konppc", NULL, i, dsp_shared_ram_bank[i]);
+		state_save_register_item_pointer(machine(), "konppc", NULL, i, dsp_shared_ram[i], DSP_BANK_SIZE * 2 / sizeof(dsp_shared_ram[i][0]));
+		state_save_register_item(machine(), "konppc", NULL, i, dsp_state[i]);
+		state_save_register_item(machine(), "konppc", NULL, i, nwk_device_sel[i]);
+		state_save_register_item(machine(), "konppc", NULL, i, nwk_fifo_read_ptr[i]);
+		state_save_register_item(machine(), "konppc", NULL, i, nwk_fifo_write_ptr[i]);
+		state_save_register_item_pointer(machine(), "konppc", NULL, i, nwk_fifo[i], 0x800);
+		state_save_register_item_pointer(machine(), "konppc", NULL, i, nwk_ram[i], 0x2000);
 	}
-	state_save_register_item(machine, "konppc", NULL, 0, cgboard_id);
-	cgboard_type = type;
+	state_save_register_item(machine(), "konppc", NULL, 0, cgboard_id);
 
-	if (type == CGBOARD_TYPE_NWKTR)
+	if (cgboard_type == CGBOARD_TYPE_NWKTR)
 	{
 		nwk_fifo_half_full_r = 0x100;
 		nwk_fifo_half_full_w = 0xff;
 		nwk_fifo_full = 0x1ff;
 		nwk_fifo_mask = 0x1ff;
 	}
-	if (type == CGBOARD_TYPE_HANGPLT)
+	if (cgboard_type == CGBOARD_TYPE_HANGPLT)
 	{
 		nwk_fifo_half_full_r = 0x3ff;
 		nwk_fifo_half_full_w = 0x400;
@@ -90,7 +72,7 @@ void init_konami_cgboard(running_machine &machine, int num_boards, int type)
 	}
 }
 
-void set_cgboard_id(int board_id)
+void konppc_device::set_cgboard_id(int board_id)
 {
 	if (board_id > num_cgboards-1)
 	{
@@ -102,7 +84,7 @@ void set_cgboard_id(int board_id)
 	}
 }
 
-int get_cgboard_id(void)
+int konppc_device::get_cgboard_id(void)
 {
 	if (cgboard_id > num_cgboards-1)
 	{
@@ -114,22 +96,22 @@ int get_cgboard_id(void)
 	}
 }
 
-void set_cgboard_texture_bank(running_machine &machine, int board, const char *bank, UINT8 *rom)
+void konppc_device::set_cgboard_texture_bank(int board, const char *bank, UINT8 *rom)
 {
 	texture_bank[board] = bank;
 
-	machine.root_device().membank(bank)->configure_entries(0, 2, rom, 0x800000);
+	machine().root_device().membank(bank)->configure_entries(0, 2, rom, 0x800000);
 }
 
 /*****************************************************************************/
 
 /* CG Board DSP interface for PowerPC */
 
-READ32_HANDLER( cgboard_dsp_comm_r_ppc )
+READ32_MEMBER( konppc_device::cgboard_dsp_comm_r_ppc )
 {
 	if (cgboard_id < MAX_CG_BOARDS)
 	{
-//      mame_printf_debug("dsp_cmd_r: (board %d) %08X, %08X at %08X\n", cgboard_id, offset, mem_mask, space.device().safe_pc());
+//      osd_printf_debug("dsp_cmd_r: (board %d) %08X, %08X at %08X\n", cgboard_id, offset, mem_mask, space.device().safe_pc());
 		return dsp_comm_sharc[cgboard_id][offset] | (dsp_state[cgboard_id] << 16);
 	}
 	else
@@ -138,13 +120,13 @@ READ32_HANDLER( cgboard_dsp_comm_r_ppc )
 	}
 }
 
-WRITE32_HANDLER( cgboard_dsp_comm_w_ppc )
+WRITE32_MEMBER( konppc_device::cgboard_dsp_comm_w_ppc )
 {
 	const char *dsptag = (cgboard_id == 0) ? "dsp" : "dsp2";
 	const char *pcitag = (cgboard_id == 0) ? "k033906_1" : "k033906_2";
 	device_t *dsp = space.machine().device(dsptag);
 	k033906_device *k033906 = space.machine().device<k033906_device>(pcitag);
-//  mame_printf_debug("dsp_cmd_w: (board %d) %08X, %08X, %08X at %08X\n", cgboard_id, data, offset, mem_mask, space.device().safe_pc());
+//  osd_printf_debug("dsp_cmd_w: (board %d) %08X, %08X, %08X at %08X\n", cgboard_id, data, offset, mem_mask, space.device().safe_pc());
 
 	if (cgboard_id < MAX_CG_BOARDS)
 	{
@@ -158,7 +140,7 @@ WRITE32_HANDLER( cgboard_dsp_comm_w_ppc )
 					dsp_state[cgboard_id] |= 0x10;
 
 				if (k033906 != NULL)    /* zr107.c has no PCI and some games only have one PCI Bridge */
-					k033906->k033906_set_reg((data & 0x20000000) ? 1 : 0);
+					k033906->set_reg((data & 0x20000000) ? 1 : 0);
 
 				if (data & 0x10000000)
 					dsp->execute().set_input_line(INPUT_LINE_RESET, CLEAR_LINE);
@@ -182,7 +164,7 @@ WRITE32_HANDLER( cgboard_dsp_comm_w_ppc )
 
 
 
-READ32_HANDLER( cgboard_dsp_shared_r_ppc )
+READ32_MEMBER( konppc_device::cgboard_dsp_shared_r_ppc )
 {
 	if (cgboard_id < MAX_CG_BOARDS)
 	{
@@ -194,7 +176,7 @@ READ32_HANDLER( cgboard_dsp_shared_r_ppc )
 	}
 }
 
-WRITE32_HANDLER( cgboard_dsp_shared_w_ppc )
+WRITE32_MEMBER( konppc_device::cgboard_dsp_shared_w_ppc )
 {
 	if (cgboard_id < MAX_CG_BOARDS)
 	{
@@ -207,12 +189,12 @@ WRITE32_HANDLER( cgboard_dsp_shared_w_ppc )
 
 /* CG Board DSP interface for SHARC */
 
-static UINT32 dsp_comm_sharc_r(int board, int offset)
+UINT32 konppc_device::dsp_comm_sharc_r(int board, int offset)
 {
 	return dsp_comm_ppc[board][offset];
 }
 
-static void dsp_comm_sharc_w(address_space &space, int board, int offset, UINT32 data)
+void konppc_device::dsp_comm_sharc_w(address_space &space, int board, int offset, UINT32 data)
 {
 	if (offset >= 2)
 	{
@@ -225,12 +207,12 @@ static void dsp_comm_sharc_w(address_space &space, int board, int offset, UINT32
 		case CGBOARD_TYPE_GTICLUB:
 		{
 			//machine.device("dsp")->execute().set_input_line(SHARC_INPUT_FLAG0, ASSERT_LINE);
-			sharc_set_flag_input(space.machine().device("dsp"), 0, ASSERT_LINE);
+			space.machine().device<adsp21062_device>("dsp")->set_flag_input(0, ASSERT_LINE);
 
 			if (offset == 1)
 			{
 				if (data & 0x03)
-					space.machine().device("dsp")->execute().set_input_line(INPUT_LINE_IRQ2, ASSERT_LINE);
+					space.machine().device<adsp21062_device>("dsp")->set_input_line(INPUT_LINE_IRQ2, ASSERT_LINE);
 			}
 			break;
 		}
@@ -239,7 +221,7 @@ static void dsp_comm_sharc_w(address_space &space, int board, int offset, UINT32
 		case CGBOARD_TYPE_HANGPLT:
 		{
 			const char *dsptag = (board == 0) ? "dsp" : "dsp2";
-			device_t *device = space.machine().device(dsptag);
+			adsp21062_device *device = space.machine().device<adsp21062_device>(dsptag);
 
 			if (offset == 1)
 			{
@@ -247,7 +229,7 @@ static void dsp_comm_sharc_w(address_space &space, int board, int offset, UINT32
 
 				if (data & 0x01 || data & 0x10)
 				{
-					sharc_set_flag_input(device, 1, ASSERT_LINE);
+					device->set_flag_input(1, ASSERT_LINE);
 				}
 
 				if (texture_bank[board] != NULL)
@@ -280,7 +262,7 @@ static void dsp_comm_sharc_w(address_space &space, int board, int offset, UINT32
 	dsp_comm_sharc[board][offset] = data;
 }
 
-static UINT32 dsp_shared_ram_r_sharc(int board, int offset)
+UINT32 konppc_device::dsp_shared_ram_r_sharc(int board, int offset)
 {
 //  printf("dsp_shared_r: (board %d) %08X, (%08X, %08X)\n", cgboard_id, offset, (UINT32)dsp_shared_ram[(offset >> 1)], (UINT32)dsp_shared_ram[offset]);
 
@@ -294,7 +276,7 @@ static UINT32 dsp_shared_ram_r_sharc(int board, int offset)
 	}
 }
 
-static void dsp_shared_ram_w_sharc(int board, int offset, UINT32 data)
+void konppc_device::dsp_shared_ram_w_sharc(int board, int offset, UINT32 data)
 {
 //  printf("dsp_shared_w: (board %d) %08X, %08X\n", cgboard_id, offset, data);
 	if (offset & 0x1)
@@ -309,70 +291,70 @@ static void dsp_shared_ram_w_sharc(int board, int offset, UINT32 data)
 	}
 }
 
-READ32_HANDLER( cgboard_0_comm_sharc_r )
+READ32_MEMBER( konppc_device::cgboard_0_comm_sharc_r )
 {
 	return dsp_comm_sharc_r(0, offset);
 }
 
-WRITE32_HANDLER( cgboard_0_comm_sharc_w )
+WRITE32_MEMBER( konppc_device::cgboard_0_comm_sharc_w )
 {
 	dsp_comm_sharc_w(space, 0, offset, data);
 }
 
-READ32_HANDLER( cgboard_0_shared_sharc_r )
+READ32_MEMBER( konppc_device::cgboard_0_shared_sharc_r )
 {
 	return dsp_shared_ram_r_sharc(0, offset);
 }
 
-WRITE32_HANDLER( cgboard_0_shared_sharc_w )
+WRITE32_MEMBER( konppc_device::cgboard_0_shared_sharc_w )
 {
 	dsp_shared_ram_w_sharc(0, offset, data);
 }
 
-READ32_HANDLER( cgboard_1_comm_sharc_r )
+READ32_MEMBER( konppc_device::cgboard_1_comm_sharc_r )
 {
 	return dsp_comm_sharc_r(1, offset);
 }
 
-WRITE32_HANDLER( cgboard_1_comm_sharc_w )
+WRITE32_MEMBER( konppc_device::cgboard_1_comm_sharc_w )
 {
 	dsp_comm_sharc_w(space, 1, offset, data);
 }
 
-READ32_HANDLER( cgboard_1_shared_sharc_r )
+READ32_MEMBER( konppc_device::cgboard_1_shared_sharc_r )
 {
 	return dsp_shared_ram_r_sharc(1, offset);
 }
 
-WRITE32_HANDLER( cgboard_1_shared_sharc_w )
+WRITE32_MEMBER( konppc_device::cgboard_1_shared_sharc_w )
 {
 	dsp_shared_ram_w_sharc(1, offset, data);
 }
 
 /*****************************************************************************/
 
-static UINT32 nwk_fifo_r(address_space &space, int board)
+UINT32 konppc_device::nwk_fifo_r(address_space &space, int board)
 {
 	const char *dsptag = (board == 0) ? "dsp" : "dsp2";
-	device_t *device = space.machine().device(dsptag);
+	adsp21062_device *device = space.machine().device<adsp21062_device>(dsptag);
 	UINT32 data;
 
 	if (nwk_fifo_read_ptr[board] < nwk_fifo_half_full_r)
 	{
-		sharc_set_flag_input(device, 1, CLEAR_LINE);
+		device->set_flag_input(1, CLEAR_LINE);
 	}
 	else
 	{
-		sharc_set_flag_input(device, 1, ASSERT_LINE);
+		device->set_flag_input(1, ASSERT_LINE);
 	}
 
 	if (nwk_fifo_read_ptr[board] < nwk_fifo_full)
 	{
-		sharc_set_flag_input(device, 2, ASSERT_LINE);
+		device->set_flag_input(2, ASSERT_LINE);
 	}
 	else
 	{
-		sharc_set_flag_input(device, 2, CLEAR_LINE);
+		device->set_flag_input(2, CLEAR_LINE);
 	}
 
 	data = nwk_fifo[board][nwk_fifo_read_ptr[board]];
@@ -382,21 +364,21 @@ static UINT32 nwk_fifo_r(address_space &space, int board)
 	return data;
 }
 
-static void nwk_fifo_w(running_machine &machine, int board, UINT32 data)
+void konppc_device::nwk_fifo_w(int board, UINT32 data)
 {
 	const char *dsptag = (board == 0) ? "dsp" : "dsp2";
-	device_t *device = machine.device(dsptag);
+	adsp21062_device *device = machine().device<adsp21062_device>(dsptag);
 
 	if (nwk_fifo_write_ptr[board] < nwk_fifo_half_full_w)
 	{
-		sharc_set_flag_input(device, 1, ASSERT_LINE);
+		device->set_flag_input(1, ASSERT_LINE);
 	}
 	else
 	{
-		sharc_set_flag_input(device, 1, CLEAR_LINE);
+		device->set_flag_input(1, CLEAR_LINE);
 	}
 
-	sharc_set_flag_input(device, 2, ASSERT_LINE);
+	device->set_flag_input(2, ASSERT_LINE);
 
 	nwk_fifo[board][nwk_fifo_write_ptr[board]] = data;
 	nwk_fifo_write_ptr[board]++;
@@ -407,43 +389,44 @@ static void nwk_fifo_w(running_machine &machine, int board, UINT32 data)
 
 /* Konami K033906 PCI bridge (most emulation is now in src/emu/machine/k033906.c ) */
 
-READ32_HANDLER( K033906_0_r )
+READ32_MEMBER( konppc_device::K033906_0_r )
 {
 	k033906_device *k033906_1 = space.machine().device<k033906_device>("k033906_1");
 	if (nwk_device_sel[0] & 0x01)
 		return nwk_fifo_r(space, 0);
 	else
-		return k033906_1->k033906_r(space, offset, mem_mask);
+		return k033906_1->read(space, offset, mem_mask);
 }
 
-WRITE32_HANDLER( K033906_0_w )
+WRITE32_MEMBER( konppc_device::K033906_0_w )
 {
 	k033906_device *k033906_1 = space.machine().device<k033906_device>("k033906_1");
-	k033906_1->k033906_w(space, offset, data, mem_mask);
+	k033906_1->write(space, offset, data, mem_mask);
 }
 
-READ32_HANDLER( K033906_1_r )
+READ32_MEMBER( konppc_device::K033906_1_r )
 {
 	k033906_device *k033906_2 = space.machine().device<k033906_device>("k033906_2");
 	if (nwk_device_sel[1] & 0x01)
 		return nwk_fifo_r(space, 1);
 	else
-		return k033906_2->k033906_r(space, offset, mem_mask);
+		return k033906_2->read(space, offset, mem_mask);
 }
 
-WRITE32_HANDLER(K033906_1_w)
+WRITE32_MEMBER( konppc_device::K033906_1_w)
 {
 	k033906_device *k033906_2 = space.machine().device<k033906_device>("k033906_2");
-	k033906_2->k033906_w(space, offset, data, mem_mask);
+	k033906_2->write(space, offset, data, mem_mask);
 }
 
 /*****************************************************************************/
 
-WRITE32_DEVICE_HANDLER(nwk_fifo_0_w)
+WRITE32_MEMBER( konppc_device::nwk_fifo_0_w)
 {
+	voodoo_device *device = space.machine().device<voodoo_device>("voodoo0");
 	if (nwk_device_sel[0] & 0x01)
 	{
-		nwk_fifo_w(space.machine(), 0, data);
+		nwk_fifo_w(0, data);
 	}
 	else if (nwk_device_sel[0] & 0x02)
 	{
@@ -452,15 +435,16 @@ WRITE32_DEVICE_HANDLER(nwk_fifo_0_w)
 	}
 	else
 	{
-		voodoo_w(device, space, offset ^ 0x80000, data, mem_mask);
+		device->voodoo_w(space, offset ^ 0x80000, data, mem_mask);
 	}
 }
 
-WRITE32_DEVICE_HANDLER(nwk_fifo_1_w)
+WRITE32_MEMBER( konppc_device::nwk_fifo_1_w)
 {
+	voodoo_device *device = space.machine().device<voodoo_device>("voodoo1");
 	if (nwk_device_sel[1] & 0x01)
 	{
-		nwk_fifo_w(space.machine(), 1, data);
+		nwk_fifo_w(1, data);
 	}
 	else if (nwk_device_sel[1] & 0x02)
 	{
@@ -469,39 +453,42 @@ WRITE32_DEVICE_HANDLER(nwk_fifo_1_w)
 	}
 	else
 	{
-		voodoo_w(device, space, offset ^ 0x80000, data, mem_mask);
+		device->voodoo_w(space, offset ^ 0x80000, data, mem_mask);
 	}
 }
 
-READ32_DEVICE_HANDLER(nwk_voodoo_0_r)
+READ32_MEMBER( konppc_device::nwk_voodoo_0_r)
 {
+	voodoo_device *device = space.machine().device<voodoo_device>("voodoo0");
 	if ((nwk_device_sel[0] == 0x4) && offset >= 0x100000 && offset < 0x200000)
 	{
 		return nwk_ram[0][offset & 0x1fff];
 	}
 	else
 	{
-		return voodoo_r(device, space, offset, mem_mask);
+		return device->voodoo_r(space, offset, mem_mask);
 	}
 }
 
-READ32_DEVICE_HANDLER(nwk_voodoo_1_r)
+READ32_MEMBER( konppc_device::nwk_voodoo_1_r)
 {
+	voodoo_device *device = space.machine().device<voodoo_device>("voodoo1");
 	if ((nwk_device_sel[1] == 0x4) && offset >= 0x100000 && offset < 0x200000)
 	{
 		return nwk_ram[1][offset & 0x1fff];
 	}
 	else
 	{
-		return voodoo_r(device, space, offset, mem_mask);
+		return device->voodoo_r(space, offset, mem_mask);
 	}
 }
 
-WRITE32_DEVICE_HANDLER(nwk_voodoo_0_w)
+WRITE32_MEMBER( konppc_device::nwk_voodoo_0_w)
 {
+	voodoo_device *device = space.machine().device<voodoo_device>("voodoo0");
 	if (nwk_device_sel[0] & 0x01)
 	{
-		nwk_fifo_w(space.machine(), 0, data);
+		nwk_fifo_w(0, data);
 	}
 	else if (nwk_device_sel[0] & 0x02)
 	{
@@ -510,15 +497,16 @@ WRITE32_DEVICE_HANDLER(nwk_voodoo_0_w)
 	}
 	else
 	{
-		voodoo_w(device, space, offset, data, mem_mask);
+		device->voodoo_w(space, offset, data, mem_mask);
 	}
 }
 
-WRITE32_DEVICE_HANDLER(nwk_voodoo_1_w)
+WRITE32_MEMBER( konppc_device::nwk_voodoo_1_w)
 {
+	voodoo_device *device = space.machine().device<voodoo_device>("voodoo0");
 	if (nwk_device_sel[1] & 0x01)
 	{
-		nwk_fifo_w(space.machine(), 1, data);
+		nwk_fifo_w(1, data);
 	}
 	else if (nwk_device_sel[1] & 0x02)
 	{
@@ -527,7 +515,7 @@ WRITE32_DEVICE_HANDLER(nwk_voodoo_1_w)
 	}
 	else
 	{
-		voodoo_w(device, space, offset, data, mem_mask);
+		device->voodoo_w(space, offset, data, mem_mask);
 	}
 }
 
