@@ -67,12 +67,14 @@ naomi_board::naomi_board(const machine_config &mconfig, device_type type, const
 	: naomi_g1_device(mconfig, type, name, tag, owner, clock, shortname, source)
 {
 	eeprom_tag = 0;
+	rombdid_tag = 0;
 }
 
-void naomi_board::static_set_eeprom_tag(device_t &device, const char *_eeprom_tag)
+void naomi_board::static_set_eeprom_tag(device_t &device, const char *_eeprom_tag, const char *_actel_tag)
 {
 	naomi_board &dev = downcast<naomi_board &>(device);
 	dev.eeprom_tag = _eeprom_tag;
+	dev.rombdid_tag = _actel_tag;
 }
 
 
