@@ -4,16 +4,16 @@
 #include "machine/naomig1.h"
 #include "machine/naomicrypt.h"
 
-#define MCFG_NAOMI_BOARD_ADD(_tag, type, _eeprom_tag, _irq_cb)    \
+#define MCFG_NAOMI_BOARD_ADD(_tag, type, _eeprom_tag, _actel_tag, _irq_cb)    \
 	MCFG_NAOMI_G1_ADD(_tag, type, _irq_cb)                        \
-	naomi_board::static_set_eeprom_tag(*device, _eeprom_tag);
+	naomi_board::static_set_eeprom_tag(*device, _eeprom_tag, _actel_tag);
 
 class naomi_board : public naomi_g1_device
 {
 public:
 	naomi_board(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, const char *shortname, const char *source);
 
-	static void static_set_eeprom_tag(device_t &device, const char *_eeprom_tag);
+	static void static_set_eeprom_tag(device_t &device, const char *_eeprom_tag, const char *_actel_tag);
 
 	// Can be patched in the underlying class
 	virtual DECLARE_ADDRESS_MAP(submap, 16);
@@ -46,8 +46,10 @@ protected:
 	// To be optionally defined in the underlying class
 	virtual void board_write(offs_t offset, UINT16 data);
 
+	UINT32 rom_offset;
+	const char *rombdid_tag;
 private:
-	UINT32 rom_offset, dma_offset, dma_cur_offset;
+	UINT32 dma_offset, dma_cur_offset;
 	UINT16 dma_count;
 	bool pio_ready, dma_ready;
 
