@@ -3,8 +3,8 @@
 
 #include "naomibd.h"
 
-#define MCFG_NAOMI_M4_BOARD_ADD(_tag, _key_tag, _eeprom_tag, _irq_cb) \
-	MCFG_NAOMI_BOARD_ADD(_tag, NAOMI_M4_BOARD, _eeprom_tag, _irq_cb) \
+#define MCFG_NAOMI_M4_BOARD_ADD(_tag, _key_tag, _eeprom_tag, _actel_tag, _irq_cb) \
+	MCFG_NAOMI_BOARD_ADD(_tag, NAOMI_M4_BOARD, _eeprom_tag, _actel_tag, _irq_cb) \
 	naomi_m4_board::static_set_tags(*device, _key_tag);
 
 class naomi_m4_board : public naomi_board
@@ -14,6 +14,9 @@ public:
 
 	static void static_set_tags(device_t &device, const char *_key_tag);
 
+	virtual DECLARE_ADDRESS_MAP(submap, 16);
+
+	DECLARE_READ16_MEMBER(m4_id_r);
 protected:
 	virtual void device_start();
 	virtual void device_reset();
@@ -21,6 +24,7 @@ protected:
 	virtual void board_setup_address(UINT32 address, bool is_dma);
 	virtual void board_get_buffer(UINT8 *&base, UINT32 &limit);
 	virtual void board_advance(UINT32 size);
+	virtual void board_write(offs_t offset, UINT16 data);
 
 private:
 	enum { BUFFER_SIZE = 32768 };
@@ -36,6 +40,7 @@ private:
 	UINT16 cur_iv;
 	UINT8 counter;
 	bool encryption;
+	bool cfi_mode;
 
 	void enc_init();
 	void enc_reset();
