@@ -37,7 +37,7 @@ void segas32_state::decrypt_ga2_protrom()
 {
 	int i;
 	UINT8 *rom = memregion("mcu")->base();
-	UINT8* temp = auto_alloc_array(machine(), UINT8, 0x100000);
+	dynamic_buffer temp(0x100000);
 
 	// make copy of ROM so original can be overwritten
 	memcpy(temp, rom, 0x10000);
@@ -45,8 +45,6 @@ void segas32_state::decrypt_ga2_protrom()
 	// unscramble the address lines
 	for(i = 0; i < 0x10000; i++)
 		rom[i] = temp[BITSWAP16(i, 14, 11, 15, 12, 13, 4, 3, 7, 5, 10, 2, 8, 9, 6, 1, 0)];
-
-	auto_free(machine(), temp);
 }
 
 WRITE16_MEMBER(segas32_state::ga2_dpram_w)
