@@ -1,5 +1,4 @@
 #include "emu.h"
-
 #include "includes/aliens.h"
 
 /***************************************************************************
@@ -8,12 +7,10 @@
 
 ***************************************************************************/
 
-void aliens_tile_callback( running_machine &machine, int layer, int bank, int *code, int *color, int *flags, int *priority )
+K052109_CB_MEMBER(aliens_state::tile_callback)
 {
-	aliens_state *state = machine.driver_data<aliens_state>();
-
 	*code |= ((*color & 0x3f) << 8) | (bank << 14);
-	*color = state->m_layer_colorbase[layer] + ((*color & 0xc0) >> 6);
+	*color = m_layer_colorbase[layer] + ((*color & 0xc0) >> 6);
 }
 
 
@@ -23,30 +20,27 @@ void aliens_tile_callback( running_machine &machine, int layer, int bank, int *c
 
 ***************************************************************************/
 
-void aliens_sprite_callback( running_machine &machine, int *code, int *color, int *priority_mask, int *shadow )
+K051960_CB_MEMBER(aliens_state::sprite_callback)
 {
-	aliens_state *state = machine.driver_data<aliens_state>();
-
 	/* The PROM allows for mixed priorities, where sprites would have */
 	/* priority over text but not on one or both of the other two planes. */
 	switch (*color & 0x70)
 	{
-		case 0x10: *priority_mask = 0x00; break;            /* over ABF */
-		case 0x00: *priority_mask = 0xf0          ; break;  /* over AB, not F */
-		case 0x40: *priority_mask = 0xf0|0xcc     ; break;  /* over A, not BF */
+		case 0x10: *priority = 0x00; break;            /* over ABF */
+		case 0x00: *priority = 0xf0          ; break;  /* over AB, not F */
+		case 0x40: *priority = 0xf0|0xcc     ; break;  /* over A, not BF */
 		case 0x20:
-		case 0x60: *priority_mask = 0xf0|0xcc|0xaa; break;  /* over -, not ABF */
-		case 0x50: *priority_mask =      0xcc     ; break;  /* over AF, not B */
+		case 0x60: *priority = 0xf0|0xcc|0xaa; break;  /* over -, not ABF */
+		case 0x50: *priority =      0xcc     ; break;  /* over AF, not B */
 		case 0x30:
-		case 0x70: *priority_mask =      0xcc|0xaa; break;  /* over F, not AB */
+		case 0x70: *priority =      0xcc|0xaa; break;  /* over F, not AB */
 	}
 	*code |= (*color & 0x80) << 6;
-	*color = state->m_sprite_colorbase + (*color & 0x0f);
+	*color = m_sprite_colorbase + (*color & 0x0f);
 	*shadow = 0;    /* shadows are not used by this game */
 }
 
 
-
 /***************************************************************************
 
     Start the video hardware emulation.
@@ -55,8 +49,6 @@ void aliens_sprite_callback( running_machine &machine, int *code, int *color, in
 
 void aliens_state::video_start()
 {
-	m_generic_paletteram_8.allocate(0x400);
-
 	m_layer_colorbase[0] = 0;
 	m_layer_colorbase[1] = 4;
 	m_layer_colorbase[2] = 8;
