@@ -16,8 +16,7 @@ TILE_GET_INFO_MEMBER(cabal_state::get_back_tile_info)
 
 	tile &= 0xfff;
 
-	SET_TILE_INFO_MEMBER(
-			1,
+	SET_TILE_INFO_MEMBER(1,
 			tile,
 			color,
 			0);
@@ -30,8 +29,7 @@ TILE_GET_INFO_MEMBER(cabal_state::get_text_tile_info)
 
 	tile &= 0x3ff;
 
-	SET_TILE_INFO_MEMBER(
-			0,
+	SET_TILE_INFO_MEMBER(0,
 			tile,
 			color,
 			0);
@@ -40,8 +38,8 @@ TILE_GET_INFO_MEMBER(cabal_state::get_text_tile_info)
 
 void cabal_state::video_start()
 {
-	m_background_layer = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(cabal_state::get_back_tile_info),this),TILEMAP_SCAN_ROWS,16,16,16,16);
-	m_text_layer       = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(cabal_state::get_text_tile_info),this),TILEMAP_SCAN_ROWS,  8,8,32,32);
+	m_background_layer = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(cabal_state::get_back_tile_info),this),TILEMAP_SCAN_ROWS,16,16,16,16);
+	m_text_layer       = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(cabal_state::get_text_tile_info),this),TILEMAP_SCAN_ROWS,  8,8,32,32);
 
 	m_text_layer->set_transparent_pen(3);
 	m_background_layer->set_transparent_pen(15);
@@ -126,7 +124,7 @@ void cabal_state::draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect)
 				flipy = !flipy;
 			}
 
-			drawgfx_transpen( bitmap,cliprect,machine().gfx[2],
+			m_gfxdecode->gfx(2)->transpen(bitmap,cliprect,
 				tile_number,
 				color,
 				flipx,flipy,
