@@ -85,24 +85,24 @@ PALETTE_INIT_MEMBER(fuuki16_state,fuuki16)
 
 	/* The game does not initialise the palette at startup. It should
 	   be totally black */
-	for (pen = 0; pen < machine().total_colors(); pen++)
-		palette_set_color(machine(),pen,MAKE_RGB(0,0,0));
+	for (pen = 0; pen < palette.entries(); pen++)
+		palette.set_pen_color(pen,rgb_t(0,0,0));
 }
 #endif
 
 void fuuki16_state::video_start()
 {
-	m_tilemap[0] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(fuuki16_state::get_tile_info_0),this), TILEMAP_SCAN_ROWS, 16, 16, 64, 32);
-	m_tilemap[1] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(fuuki16_state::get_tile_info_1),this), TILEMAP_SCAN_ROWS, 16, 16, 64, 32);
-	m_tilemap[2] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(fuuki16_state::get_tile_info_2),this), TILEMAP_SCAN_ROWS, 8, 8, 64, 32);
-	m_tilemap[3] = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(fuuki16_state::get_tile_info_3),this), TILEMAP_SCAN_ROWS, 8, 8, 64, 32);
+	m_tilemap[0] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(fuuki16_state::get_tile_info_0),this), TILEMAP_SCAN_ROWS, 16, 16, 64, 32);
+	m_tilemap[1] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(fuuki16_state::get_tile_info_1),this), TILEMAP_SCAN_ROWS, 16, 16, 64, 32);
+	m_tilemap[2] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(fuuki16_state::get_tile_info_2),this), TILEMAP_SCAN_ROWS, 8, 8, 64, 32);
+	m_tilemap[3] = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(fuuki16_state::get_tile_info_3),this), TILEMAP_SCAN_ROWS, 8, 8, 64, 32);
 
 	m_tilemap[0]->set_transparent_pen(0x0f);    // 4 bits
 	m_tilemap[1]->set_transparent_pen(0xff);    // 8 bits
 	m_tilemap[2]->set_transparent_pen(0x0f);    // 4 bits
 	m_tilemap[3]->set_transparent_pen(0x0f);    // 4 bits
 
-	machine().gfx[2]->set_granularity(16); /* 256 colour tiles with palette selectable on 16 colour boundaries */
+	m_gfxdecode->gfx(2)->set_granularity(16); /* 256 colour tiles with palette selectable on 16 colour boundaries */
 }
 
 
@@ -136,7 +136,7 @@ void fuuki16_state::video_start()
 void fuuki16_state::draw_sprites( screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect )
 {
 	int offs;
-	gfx_element *gfx = screen.machine().gfx[0];
+	gfx_element *gfx = m_gfxdecode->gfx(0);
 	bitmap_ind8 &priority_bitmap = screen.priority();
 	const rectangle &visarea = screen.visible_area();
 	UINT16 *spriteram16 = m_spriteram;
@@ -196,7 +196,7 @@ void fuuki16_state::draw_sprites( screen_device &screen, bitmap_ind16 &bitmap, c
 			for (x = xstart; x != xend; x += xinc)
 			{
 				if (xzoom == (16*8) && yzoom == (16*8))
-					pdrawgfx_transpen(bitmap,cliprect,gfx,
+					gfx->prio_transpen(bitmap,cliprect,
 									code++,
 									attr & 0x3f,
 									flipx, flipy,
@@ -204,7 +204,7 @@ void fuuki16_state::draw_sprites( screen_device &screen, bitmap_ind16 &bitmap, c
 									priority_bitmap,
 									pri_mask,15 );
 				else
-					pdrawgfxzoom_transpen(bitmap,cliprect,gfx,
+					gfx->prio_zoom_transpen(bitmap,cliprect,
 									code++,
 									attr & 0x3f,
 									flipx, flipy,
@@ -216,7 +216,7 @@ void fuuki16_state::draw_sprites( screen_device &screen, bitmap_ind16 &bitmap, c
 
 #ifdef MAME_DEBUG
 #if 0
-if (screen.machine().input().code_pressed(KEYCODE_X))
+if (machine().input().code_pressed(KEYCODE_X))
 {   /* Display some info on each sprite */
 	char buf[40];
 	sprintf(buf, "%Xx%X %X",xnum,ynum,(attr>>6)&3);
