@@ -58,25 +58,70 @@ WRITE8_MEMBER(goldstar_state::goldstar_fg_atrram_w)
 	m_fg_tilemap->mark_tile_dirty(offset);
 }
 
+WRITE8_MEMBER(goldstar_state::sangho_fg_vidram_w)
+{
+	m_fg_vidram[offset] = data;
+	m_fg_tilemap->mark_tile_dirty(offset);
+}
+
+WRITE8_MEMBER(goldstar_state::sangho_fg_atrram_w)
+{
+	m_fg_atrram[offset] = data;
+	m_fg_tilemap->mark_tile_dirty(offset);
+}
+
+WRITE8_MEMBER(goldstar_state::sangho_bg_vidram_w)
+{
+	m_bg_vidram[offset] = data;
+	m_bg_tilemap->mark_tile_dirty(offset);
+}
+
+WRITE8_MEMBER(goldstar_state::sangho_bg_atrram_w)
+{
+	m_bg_atrram[offset] = data;
+	m_bg_tilemap->mark_tile_dirty(offset);
+}
+
+
 TILE_GET_INFO_MEMBER(goldstar_state::get_goldstar_fg_tile_info)
 {
 	int code = m_fg_vidram[tile_index];
 	int attr = m_fg_atrram[tile_index];
 
-	SET_TILE_INFO_MEMBER(
-			0,
+	SET_TILE_INFO_MEMBER(0,
 			code | (attr & 0xf0)<<4,
 			attr&0x0f,
 			0);
 }
 
+TILE_GET_INFO_MEMBER(goldstar_state::get_sangho_fg_tile_info)
+{
+	int code = m_fg_vidram[tile_index];
+	int attr = m_fg_atrram[tile_index];
+
+	SET_TILE_INFO_MEMBER(0,
+			code | (attr & 0x0f)<<8,
+			(attr&0x70)>>4,
+			0);
+}
+
+TILE_GET_INFO_MEMBER(goldstar_state::get_sangho_bg_tile_info)
+{
+	int code = m_bg_vidram[tile_index];
+	int attr = m_bg_atrram[tile_index];
+
+	SET_TILE_INFO_MEMBER(1,
+			code | (attr & 0x0f)<<8,
+			(attr&0x70)>>4,
+			0);
+}
+
 TILE_GET_INFO_MEMBER(goldstar_state::get_magical_fg_tile_info)
 {
 	int code = m_fg_vidram[tile_index];
 	int attr = m_fg_atrram[tile_index];
 
-	SET_TILE_INFO_MEMBER(
-			0,
+	SET_TILE_INFO_MEMBER(0,
 			(code | (attr & 0xf0)<<4)+m_tile_bank*0x1000,
 			attr&0x0f,
 			0);
@@ -89,8 +134,7 @@ TILE_GET_INFO_MEMBER(goldstar_state::get_cherrym_fg_tile_info)
 	int code = m_fg_vidram[tile_index];
 	int attr = m_fg_atrram[tile_index];
 
-	SET_TILE_INFO_MEMBER(
-			0,
+	SET_TILE_INFO_MEMBER(0,
 			code | (attr & 0x0f)<<8,
 			(attr&0xf0)>>4,
 			0);
@@ -108,8 +152,7 @@ TILE_GET_INFO_MEMBER(goldstar_state::get_goldstar_reel1_tile_info)
 {
 	int code = m_reel1_ram[tile_index];
 
-	SET_TILE_INFO_MEMBER(
-			1,
+	SET_TILE_INFO_MEMBER(1,
 			code,
 			m_bgcolor,
 			0);
@@ -126,8 +169,7 @@ TILE_GET_INFO_MEMBER(goldstar_state::get_goldstar_reel2_tile_info)
 {
 	int code = m_reel2_ram[tile_index];
 
-	SET_TILE_INFO_MEMBER(
-			1,
+	SET_TILE_INFO_MEMBER(1,
 			code,
 			m_bgcolor,
 			0);
@@ -143,8 +185,7 @@ TILE_GET_INFO_MEMBER(goldstar_state::get_goldstar_reel3_tile_info)
 {
 	int code = m_reel3_ram[tile_index];
 
-	SET_TILE_INFO_MEMBER(
-			1,
+	SET_TILE_INFO_MEMBER(1,
 			code,
 			m_bgcolor,
 			0);
@@ -175,8 +216,7 @@ TILE_GET_INFO_MEMBER(goldstar_state::get_unkch_reel1_tile_info)
 	int code = m_reel1_ram[tile_index];
 	int attr = m_reel1_attrram[tile_index];
 
-	SET_TILE_INFO_MEMBER(
-			1,
+	SET_TILE_INFO_MEMBER(1,
 			code | (attr & 0x0f)<<8,
 			(attr&0xf0)>>4,
 			0);
@@ -187,8 +227,7 @@ TILE_GET_INFO_MEMBER(goldstar_state::get_unkch_reel2_tile_info)
 	int code = m_reel2_ram[tile_index];
 	int attr = m_reel2_attrram[tile_index];
 
-	SET_TILE_INFO_MEMBER(
-			1,
+	SET_TILE_INFO_MEMBER(1,
 			code | (attr & 0x0f)<<8,
 			(attr&0xf0)>>4,
 			0);
@@ -199,68 +238,118 @@ TILE_GET_INFO_MEMBER(goldstar_state::get_unkch_reel3_tile_info)
 	int code = m_reel3_ram[tile_index];
 	int attr = m_reel3_attrram[tile_index];
 
-	SET_TILE_INFO_MEMBER(
-			1,
+	SET_TILE_INFO_MEMBER(1,
 			code | (attr & 0x0f)<<8,
 			(attr&0xf0)>>4,
 			0);
 }
 
 
-
-
-VIDEO_START_MEMBER(goldstar_state,goldstar)
+WRITE8_MEMBER(goldstar_state::sangho_reel1_attrram_w)
 {
-	m_reel1_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
-	m_reel2_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel2_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
-	m_reel3_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel3_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel1_attrram[offset] = data;
+	m_reel1_tilemap->mark_tile_dirty(offset);
+}
+
+WRITE8_MEMBER(goldstar_state::sangho_reel2_attrram_w)
+{
+	m_reel2_attrram[offset] = data;
+	m_reel2_tilemap->mark_tile_dirty(offset);
+}
+
+WRITE8_MEMBER(goldstar_state::sangho_reel3_attrram_w)
+{
+	m_reel3_attrram[offset] = data;
+	m_reel3_tilemap->mark_tile_dirty(offset);
+}
+
+
+TILE_GET_INFO_MEMBER(goldstar_state::get_sangho_reel1_tile_info)
+{
+	int code = m_reel1_ram[tile_index];
+	int attr = m_reel1_attrram[tile_index];
+
+	SET_TILE_INFO_MEMBER(1,
+			code | (attr & 0x0f)<<8,
+			(attr&0x70)>>4,
+			0);
+}
+
+TILE_GET_INFO_MEMBER(goldstar_state::get_sangho_reel2_tile_info)
+{
+	int code = m_reel2_ram[tile_index];
+	int attr = m_reel2_attrram[tile_index];
+
+	SET_TILE_INFO_MEMBER(1,
+			code | (attr & 0x0f)<<8,
+			(attr&0x70)>>4,
+			0);
+}
+
+TILE_GET_INFO_MEMBER(goldstar_state::get_sangho_reel3_tile_info)
+{
+	int code = m_reel3_ram[tile_index];
+	int attr = m_reel3_attrram[tile_index];
+
+	SET_TILE_INFO_MEMBER(1,
+			code | (attr & 0x0f)<<8,
+			(attr&0x70)>>4,
+			0);
+}
+
+
+VIDEO_START_MEMBER(goldstar_state, goldstar)
+{
+	m_reel1_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel2_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel2_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel3_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel3_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
 
 	m_reel1_tilemap->set_scroll_cols(64);
 	m_reel2_tilemap->set_scroll_cols(64);
 	m_reel3_tilemap->set_scroll_cols(64);
 
-	m_fg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
+	m_fg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
 	m_fg_tilemap->set_transparent_pen(0);
 
 	// is there an enable reg for this game?
 	m_cm_enable_reg = 0x0b;
 }
 
-VIDEO_START_MEMBER(goldstar_state,bingowng)
+VIDEO_START_MEMBER(goldstar_state, bingowng)
 {
-	m_reel1_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel1_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
 
 	m_reel1_tilemap->set_scroll_cols(64);
 
-	m_fg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
+	m_fg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
 	m_fg_tilemap->set_transparent_pen(0);
 
 	// is there an enable reg for this game?
 	m_cm_enable_reg = 0x0b;
 }
 
-VIDEO_START_MEMBER(goldstar_state,magical)
+VIDEO_START_MEMBER(goldstar_state, magical)
 {
-	m_reel1_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
-	m_reel2_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel2_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
-	m_reel3_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel3_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel1_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel2_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel2_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel3_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel3_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
 
 	m_reel1_tilemap->set_scroll_cols(32);
 	m_reel2_tilemap->set_scroll_cols(32);
 	m_reel3_tilemap->set_scroll_cols(32);
 
-	m_fg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_magical_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
+	m_fg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_magical_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
 	m_fg_tilemap->set_transparent_pen(0);
 
 	// is there an enable reg for this game?
 	m_cm_enable_reg = 0x0b;
 }
 
-VIDEO_START_MEMBER(goldstar_state,unkch)
+VIDEO_START_MEMBER(goldstar_state, unkch)
 {
-	m_reel1_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_unkch_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
-	m_reel2_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_unkch_reel2_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
-	m_reel3_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_unkch_reel3_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel1_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_unkch_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel2_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_unkch_reel2_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel3_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_unkch_reel3_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
 
 	m_reel1_tilemap->set_scroll_cols(32);
 	m_reel2_tilemap->set_scroll_cols(32);
@@ -270,17 +359,17 @@ VIDEO_START_MEMBER(goldstar_state,unkch)
 	m_cmaster_girl_pal = 0;
 	m_unkch_vidreg = 0x00;
 
-	m_fg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_cherrym_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
+	m_fg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_cherrym_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
 	m_fg_tilemap->set_transparent_pen(0);
 
 	m_cm_enable_reg = 0x0b;
 }
 
-VIDEO_START_MEMBER(goldstar_state,cherrym)
+VIDEO_START_MEMBER(goldstar_state, cherrym)
 {
-	m_reel1_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
-	m_reel2_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel2_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
-	m_reel3_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel3_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel1_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel2_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel2_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel3_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_goldstar_reel3_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
 
 	m_reel1_tilemap->set_scroll_cols(64);
 	m_reel2_tilemap->set_scroll_cols(64);
@@ -289,12 +378,28 @@ VIDEO_START_MEMBER(goldstar_state,cherrym)
 	m_cmaster_girl_num = 0;
 	m_cmaster_girl_pal = 0;
 
-	m_fg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(goldstar_state::get_cherrym_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
+	m_fg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_cherrym_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8, 64, 32);
 	m_fg_tilemap->set_transparent_pen(0);
 
 	m_cm_enable_reg = 0x0b;
 }
 
+VIDEO_START_MEMBER(goldstar_state, sangho)
+{
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_sangho_bg_tile_info),this),TILEMAP_SCAN_ROWS, 8, 32, 64, 8);
+
+	m_reel1_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_sangho_reel1_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel2_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_sangho_reel2_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+	m_reel3_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_sangho_reel3_tile_info),this),TILEMAP_SCAN_ROWS,8,32, 64, 8);
+
+	m_reel1_tilemap->set_scroll_cols(64);
+	m_reel2_tilemap->set_scroll_cols(64);
+	m_reel3_tilemap->set_scroll_cols(64);
+
+	m_fg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(goldstar_state::get_sangho_fg_tile_info),this),TILEMAP_SCAN_ROWS, 8, 8, 64, 32);
+	m_fg_tilemap->set_transparent_pen(0);
+}
+
 
 
 WRITE8_MEMBER(goldstar_state::goldstar_fa00_w)
@@ -350,7 +455,7 @@ UINT32 goldstar_state::screen_update_goldstar(screen_device &screen, bitmap_ind1
 {
 	int i;
 
-	bitmap.fill(get_black_pen(machine()), cliprect);
+	bitmap.fill(m_palette->black_pen(), cliprect);
 
 	if (!(m_cm_enable_reg &0x01))
 		return 0;
@@ -379,11 +484,11 @@ UINT32 goldstar_state::screen_update_goldstar(screen_device &screen, bitmap_ind1
 	{
 		if (memregion("user1")->base())
 		{
-			gfx_element *gfx = machine().gfx[2];
+			gfx_element *gfx = m_gfxdecode->gfx(2);
 			int girlyscroll = (INT8)((m_cm_girl_scroll & 0xf0));
 			int girlxscroll = (INT8)((m_cm_girl_scroll & 0x0f)<<4);
 
-			drawgfxzoom_transpen(bitmap,cliprect,gfx,m_cmaster_girl_num,m_cmaster_girl_pal,0,0,-(girlxscroll*2),-(girlyscroll), 0x20000, 0x10000,0);
+			gfx->zoom_transpen(bitmap,cliprect,m_cmaster_girl_num,m_cmaster_girl_pal,0,0,-(girlxscroll*2),-(girlyscroll), 0x20000, 0x10000,0);
 		}
 	}
 
@@ -400,7 +505,7 @@ UINT32 goldstar_state::screen_update_bingowng(screen_device &screen, bitmap_ind1
 {
 	int i;
 
-	bitmap.fill(get_black_pen(machine()), cliprect);
+	bitmap.fill(m_palette->black_pen(), cliprect);
 
 	if (!(m_cm_enable_reg &0x01))
 		return 0;
@@ -421,11 +526,11 @@ UINT32 goldstar_state::screen_update_bingowng(screen_device &screen, bitmap_ind1
 	{
 		if (memregion("user1")->base())
 		{
-			gfx_element *gfx = machine().gfx[2];
+			gfx_element *gfx = m_gfxdecode->gfx(2);
 			int girlyscroll = (INT8)((m_cm_girl_scroll & 0xf0));
 			int girlxscroll = (INT8)((m_cm_girl_scroll & 0x0f)<<4);
 
-			drawgfxzoom_transpen(bitmap,cliprect,gfx,m_cmaster_girl_num,m_cmaster_girl_pal,0,0,-(girlxscroll*2),-(girlyscroll), 0x20000, 0x10000,0);
+			gfx->zoom_transpen(bitmap,cliprect,m_cmaster_girl_num,m_cmaster_girl_pal,0,0,-(girlxscroll*2),-(girlyscroll), 0x20000, 0x10000,0);
 		}
 	}
 
@@ -442,7 +547,7 @@ UINT32 goldstar_state::screen_update_magical(screen_device &screen, bitmap_ind16
 {
 	int i;
 
-	bitmap.fill(get_black_pen(machine()), cliprect);
+	bitmap.fill(m_palette->black_pen(), cliprect);
 
 	if (!(m_cm_enable_reg &0x01))
 		return 0;
@@ -500,7 +605,7 @@ UINT32 goldstar_state::screen_update_unkch(screen_device &screen, bitmap_ind16 &
 {
 	int i;
 
-	bitmap.fill(get_black_pen(machine()), cliprect);
+	bitmap.fill(m_palette->black_pen(), cliprect);
 
 	if (!(m_cm_enable_reg &0x01))
 		return 0;
@@ -553,7 +658,7 @@ UINT32 goldstar_state::screen_update_cmast91(screen_device &screen, bitmap_ind16
 {
 	int i;
 
-	bitmap.fill(get_black_pen(machine()), cliprect);
+	bitmap.fill(m_palette->black_pen(), cliprect);
 
 	if (!(m_cm_enable_reg &0x01))
 		return 0;
@@ -588,7 +693,7 @@ UINT32 goldstar_state::screen_update_amcoe1a(screen_device &screen, bitmap_ind16
 {
 	int i;
 
-	bitmap.fill(get_black_pen(machine()), cliprect);
+	bitmap.fill(m_palette->black_pen(), cliprect);
 
 	if (!(m_cm_enable_reg &0x01))
 		return 0;
@@ -623,3 +728,47 @@ UINT32 goldstar_state::screen_update_amcoe1a(screen_device &screen, bitmap_ind16
 
 	return 0;
 }
+
+
+UINT32 goldstar_state::screen_update_sangho(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
+{
+	int i;
+
+	bitmap.fill(m_palette->black_pen(), cliprect);
+
+	if (m_sangho_enable_reg &0x01)
+	{
+		/* disable reels (only render bg and fg layers) */
+		m_bg_tilemap->set_scrolly(0, -16);
+		m_bg_tilemap->draw(screen, bitmap, cliprect, 0, 0);
+		m_fg_tilemap->draw(screen, bitmap, cliprect, 0, 0);
+
+		return 0;
+	}
+	else
+	{
+		/* enable reels (render all the five layers) */
+		m_bg_tilemap->set_scrolly(0, -16);
+		m_bg_tilemap->draw(screen, bitmap, cliprect, 0, 0);
+
+		for (i= 0;i < 64;i++)
+		{
+			m_reel1_tilemap->set_scrolly(i, m_reel1_scroll[i]);
+			m_reel2_tilemap->set_scrolly(i, m_reel2_scroll[i]);
+			m_reel3_tilemap->set_scrolly(i, m_reel3_scroll[i]);
+		}
+
+		// are these hardcoded, or registers?
+		const rectangle visible1(0*8, (15+48)*8-1,  4*8,  (4+7)*8-1);
+		const rectangle visible2(0*8, (15+48)*8-1, 12*8, (12+7)*8-1);
+		const rectangle visible3(0*8, (15+48)*8-1, 20*8, (20+7)*8-1);
+
+		m_reel1_tilemap->draw(screen, bitmap, visible1, 0, 0);
+		m_reel2_tilemap->draw(screen, bitmap, visible2, 0, 0);
+		m_reel3_tilemap->draw(screen, bitmap, visible3, 0, 0);
+
+		m_fg_tilemap->draw(screen, bitmap, cliprect, 0, 0);
+	}
+
+	return 0;
+}
