@@ -29,7 +29,7 @@
 
 ***************************************************************************/
 
-void gyruss_state::palette_init()
+PALETTE_INIT_MEMBER(gyruss_state, gyruss)
 {
 	const UINT8 *color_prom = memregion("proms")->base();
 	static const int resistances_rg[3] = { 1000, 470, 220 };
@@ -43,9 +43,6 @@ void gyruss_state::palette_init()
 			2, resistances_b,  weights_b,  470, 0,
 			0, 0, 0, 0, 0);
 
-	/* allocate the colortable */
-	machine().colortable = colortable_alloc(machine(), 32);
-
 	/* create a lookup table for the palette */
 	for (i = 0; i < 0x20; i++)
 	{
@@ -69,7 +66,7 @@ void gyruss_state::palette_init()
 		bit1 = (color_prom[i] >> 7) & 0x01;
 		b = combine_2_weights(weights_b, bit0, bit1);
 
-		colortable_palette_set_color(machine().colortable, i, MAKE_RGB(r, g, b));
+		palette.set_indirect_color(i, rgb_t(r, g, b));
 	}
 
 	/* color_prom now points to the beginning of the lookup table */
@@ -79,14 +76,14 @@ void gyruss_state::palette_init()
 	for (i = 0; i < 0x100; i++)
 	{
 		UINT8 ctabentry = color_prom[i] & 0x0f;
-		colortable_entry_set_value(machine().colortable, i, ctabentry);
+		palette.set_pen_indirect(i, ctabentry);
 	}
 
 	/* characters map to the upper 16 palette entries */
 	for (i = 0x100; i < 0x140; i++)
 	{
 		UINT8 ctabentry = color_prom[i] & 0x0f;
-		colortable_entry_set_value(machine().colortable, i, ctabentry + 0x10);
+		palette.set_pen_indirect(i, ctabentry + 0x10);
 	}
 }
 
@@ -113,7 +110,7 @@ TILE_GET_INFO_MEMBER(gyruss_state::gyruss_get_tile_info)
 
 void gyruss_state::video_start()
 {
-	m_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(gyruss_state::gyruss_get_tile_info),this), TILEMAP_SCAN_ROWS, 8, 8, 32, 32);
+	m_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(gyruss_state::gyruss_get_tile_info),this), TILEMAP_SCAN_ROWS, 8, 8, 32, 32);
 	m_tilemap->set_transmask(0, 0x00, 0);   /* opaque */
 	m_tilemap->set_transmask(1, 0x0f, 0);  /* transparent */
 }
@@ -127,7 +124,7 @@ READ8_MEMBER(gyruss_state::gyruss_scanline_r)
 }
 
 
-void gyruss_state::draw_sprites( bitmap_ind16 &bitmap, const rectangle &cliprect, gfx_element **gfx )
+void gyruss_state::draw_sprites( bitmap_ind16 &bitmap, const rectangle &cliprect )
 {
 	int offs;
 
@@ -142,7 +139,7 @@ void gyruss_state::draw_sprites( bitmap_ind16 &bitmap, const rectangle &cliprect
 		int flip_x = ~m_spriteram[offs + 2] & 0x40;
 		int flip_y =  m_spriteram[offs + 2] & 0x80;
 
-		drawgfx_transpen(bitmap, cliprect, gfx[gfx_bank], code, color, flip_x, flip_y, x, y, 0);
+			m_gfxdecode->gfx(gfx_bank)->transpen(bitmap,cliprect, code, color, flip_x, flip_y, x, y, 0);
 	}
 }
 
@@ -156,7 +153,7 @@ UINT32 gyruss_state::screen_update_gyruss(screen_device &screen, bitmap_ind16 &b
 	}
 
 	m_tilemap->draw(screen, bitmap, cliprect, TILEMAP_DRAW_OPAQUE, 0);
-	draw_sprites(bitmap, cliprect, machine().gfx);
+	draw_sprites(bitmap, cliprect);
 	m_tilemap->draw(screen, bitmap, cliprect, 0, 0);
 
 	return 0;
