@@ -31,7 +31,8 @@ class kaneko16_sprite_device : public device_t,
 public:
 	kaneko16_sprite_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock,  device_type type);
 
-	static void set_altspacing(device_t &device, int spacing);
+	// static configuration
+	static void static_set_gfxdecode_tag(device_t &device, const char *tag);
 	static void set_fliptype(device_t &device, int fliptype);
 	static void set_offsets(device_t &device, int xoffs, int yoffs);
 	static void set_priorities(device_t &device, int pri0, int pri1, int pri2, int pri3);
@@ -40,6 +41,11 @@ public:
 	virtual int get_sprite_type(void) =0;
 
 	void kaneko16_render_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, bitmap_ind8 &priority_bitmap, UINT16* spriteram16, int spriteram16_bytes);
+	void kaneko16_render_sprites(running_machine &machine, bitmap_rgb32 &bitmap, const rectangle &cliprect, bitmap_ind8 &priority_bitmap, UINT16* spriteram16, int spriteram16_bytes);
+
+
+	template<class _BitmapClass>
+	void kaneko16_render_sprites_common(running_machine &machine, _BitmapClass &bitmap, const rectangle &cliprect, bitmap_ind8 &priority_bitmap, UINT16* spriteram16, int spriteram16_bytes);
 
 
 	DECLARE_READ16_MEMBER(kaneko16_sprites_regs_r);
@@ -49,10 +55,6 @@ protected:
 	virtual void device_start();
 	virtual void device_reset();
 
-	// alt ram addressing (set when declaring device in MCFG)
-	//  used on Berlin Wall.. it's the same sprite chip, so probably just a different RAM hookup on the PCB, maybe also
-	//  related to the 'COPY BOARD' protection check on one set? investigate..
-	int m_altspacing;
 
 	// flip latching (set when declaring device in MCFG )  probably needs figuring out properly, only brapboys wants it?
 	int m_sprite_fliptype;
@@ -79,21 +81,30 @@ private:
 	int m_keep_sprites;
 	bitmap_ind16 m_sprites_bitmap;
 
-	void kaneko16_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect, bitmap_ind8 &priority_bitmap, UINT16* spriteram16, int spriteram16_bytes);
 
-	void kaneko16_draw_sprites_custom(bitmap_ind16 &dest_bmp,const rectangle &clip,gfx_element *gfx,
+	template<class _BitmapClass>
+	void kaneko16_draw_sprites(running_machine &machine, _BitmapClass &bitmap, const rectangle &cliprect, bitmap_ind8 &priority_bitmap, UINT16* spriteram16, int spriteram16_bytes);
+
+
+	template<class _BitmapClass>
+	void kaneko16_draw_sprites_custom(_BitmapClass &dest_bmp,const rectangle &clip,gfx_element *gfx,
 			UINT32 code,UINT32 color,int flipx,int flipy,int sx,int sy,
 			bitmap_ind8 &priority_bitmap, int priority);
 
 	int kaneko16_parse_sprite_type012(running_machine &machine, int i, struct tempsprite *s, UINT16* spriteram16, int spriteram16_bytes);
 
+	void kaneko16_copybitmap(bitmap_ind16 &bitmap, const rectangle &cliprect);
+	void kaneko16_copybitmap(bitmap_rgb32 &bitmap, const rectangle &cliprect);
 
-
+	required_device<gfxdecode_device> m_gfxdecode;
 
 };
 
 //extern const device_type KANEKO16_SPRITE;
 
+#define MCFG_KANEKO16_SPRITE_GFXDECODE(_gfxtag) \
+	kaneko16_sprite_device::static_set_gfxdecode_tag(*device, "^" _gfxtag);
+
 
 class kaneko_vu002_sprite_device : public kaneko16_sprite_device
 {
