@@ -37,8 +37,7 @@ inline void m90_state::get_tile_info(tile_data &tileinfo,int tile_index,int laye
 
 	tile=m_video_data[tile_index];
 	color=m_video_data[tile_index+1];
-	SET_TILE_INFO_MEMBER(
-			0,
+	SET_TILE_INFO_MEMBER(0,
 			tile,
 			color&0xf,
 			TILE_FLIPYX((color & 0xc0) >> 6));
@@ -52,8 +51,7 @@ inline void m90_state::bomblord_get_tile_info(tile_data &tileinfo,int tile_index
 
 	tile=m_video_data[tile_index];
 	color=m_video_data[tile_index+1];
-	SET_TILE_INFO_MEMBER(
-			0,
+	SET_TILE_INFO_MEMBER(0,
 			tile,
 			color&0xf,
 			TILE_FLIPYX((color & 0xc0) >> 6));
@@ -67,8 +65,7 @@ inline void m90_state::dynablsb_get_tile_info(tile_data &tileinfo,int tile_index
 
 	tile=m_video_data[tile_index];
 	color=m_video_data[tile_index+1];
-	SET_TILE_INFO_MEMBER(
-			0,
+	SET_TILE_INFO_MEMBER(0,
 			tile,
 			color&0xf,
 			TILE_FLIPYX((color & 0xc0) >> 6));
@@ -92,10 +89,10 @@ TILE_GET_INFO_MEMBER(m90_state::dynablsb_get_pf2w_tile_info){ dynablsb_get_tile_
 
 void m90_state::video_start()
 {
-	m_pf1_layer =      &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::get_pf1_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
-	m_pf1_wide_layer = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::get_pf1w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
-	m_pf2_layer =      &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::get_pf2_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
-	m_pf2_wide_layer = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::get_pf2w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
+	m_pf1_layer =      &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::get_pf1_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
+	m_pf1_wide_layer = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::get_pf1w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
+	m_pf2_layer =      &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::get_pf2_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
+	m_pf2_wide_layer = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::get_pf2w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
 
 	m_pf1_layer->set_transparent_pen(0);
 	m_pf1_wide_layer->set_transparent_pen(0);
@@ -107,10 +104,10 @@ void m90_state::video_start()
 
 VIDEO_START_MEMBER(m90_state,bomblord)
 {
-	m_pf1_layer =      &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::bomblord_get_pf1_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
-	m_pf1_wide_layer = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::bomblord_get_pf1w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
-	m_pf2_layer =      &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::bomblord_get_pf2_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
-	m_pf2_wide_layer = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::bomblord_get_pf2w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
+	m_pf1_layer =      &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::bomblord_get_pf1_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
+	m_pf1_wide_layer = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::bomblord_get_pf1w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
+	m_pf2_layer =      &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::bomblord_get_pf2_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
+	m_pf2_wide_layer = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::bomblord_get_pf2w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
 
 	m_pf2_layer->set_transparent_pen(0);
 	m_pf2_wide_layer->set_transparent_pen(0);
@@ -122,10 +119,10 @@ VIDEO_START_MEMBER(m90_state,bomblord)
 
 VIDEO_START_MEMBER(m90_state,dynablsb)
 {
-	m_pf1_layer =      &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::dynablsb_get_pf1_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
-	m_pf1_wide_layer = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::dynablsb_get_pf1w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
-	m_pf2_layer =      &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::dynablsb_get_pf2_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
-	m_pf2_wide_layer = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(m90_state::dynablsb_get_pf2w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
+	m_pf1_layer =      &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::dynablsb_get_pf1_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
+	m_pf1_wide_layer = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::dynablsb_get_pf1w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
+	m_pf2_layer =      &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::dynablsb_get_pf2_tile_info),this), TILEMAP_SCAN_ROWS,8,8,64,64);
+	m_pf2_wide_layer = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(m90_state::dynablsb_get_pf2w_tile_info),this),TILEMAP_SCAN_ROWS,8,8,128,64);
 
 	m_pf2_layer->set_transparent_pen(0);
 	m_pf2_wide_layer->set_transparent_pen(0);
@@ -160,7 +157,7 @@ void m90_state::draw_sprites(screen_device &screen, bitmap_ind16 &bitmap,const r
 		for (i = 0;i < y_multi;i++)
 
 			if (m_video_control_data[7] & 0x01)
-				pdrawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+				m_gfxdecode->gfx(1)->prio_transpen(bitmap,cliprect,
 					sprite + (fy ? y_multi-1 - i : i),
 					colour,
 					fx,fy,
@@ -168,7 +165,7 @@ void m90_state::draw_sprites(screen_device &screen, bitmap_ind16 &bitmap,const r
 					screen.priority(),
 					(colour & 0x08) ? 0x00 : 0x02,0);
 			else if (m_video_control_data[7] & 0x02)
-				pdrawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+				m_gfxdecode->gfx(1)->prio_transpen(bitmap,cliprect,
 					sprite + (fy ? y_multi-1 - i : i),
 					colour,
 					fx,fy,
@@ -176,7 +173,7 @@ void m90_state::draw_sprites(screen_device &screen, bitmap_ind16 &bitmap,const r
 					screen.priority(),
 					((colour & 0x0c)==0x0c) ? 0x00 : 0x02,0);
 			else
-				pdrawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+				m_gfxdecode->gfx(1)->prio_transpen(bitmap,cliprect,
 					sprite + (fy ? y_multi-1 - i : i),
 					colour,
 					fx,fy,
@@ -215,7 +212,7 @@ void m90_state::bomblord_draw_sprites(screen_device &screen, bitmap_ind16 &bitma
 		fx = (spriteram16[offs+3] >> 8) & 0x02;
 		fy = (spriteram16[offs+2] >> 8) & 0x80;
 
-		pdrawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+		m_gfxdecode->gfx(1)->prio_transpen(bitmap,cliprect,
 				sprite,
 				colour,
 				fx,fy,
@@ -253,7 +250,7 @@ void m90_state::dynablsb_draw_sprites(screen_device &screen, bitmap_ind16 &bitma
 		fx = (spriteram16[offs+3] >> 8) & 0x02;
 		fy = (spriteram16[offs+2] >> 8) & 0x80;
 
-		pdrawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+		m_gfxdecode->gfx(1)->prio_transpen(bitmap,cliprect,
 				sprite,
 				colour,
 				fx,fy,
@@ -444,7 +441,7 @@ UINT32 m90_state::screen_update_m90(screen_device &screen, bitmap_ind16 &bitmap,
 		draw_sprites(screen,bitmap,cliprect);
 
 	} else {
-		bitmap.fill(get_black_pen(machine()), cliprect);
+		bitmap.fill(m_palette->black_pen(), cliprect);
 	}
 
 	return 0;
@@ -454,7 +451,7 @@ UINT32 m90_state::screen_update_bomblord(screen_device &screen, bitmap_ind16 &bi
 {
 	int i;
 	screen.priority().fill(0, cliprect);
-	bitmap.fill(get_black_pen(machine()), cliprect);
+	bitmap.fill(m_palette->black_pen(), cliprect);
 
 	/* Setup scrolling */
 	if (m_video_control_data[6]&0x20) {
@@ -505,7 +502,7 @@ UINT32 m90_state::screen_update_bomblord(screen_device &screen, bitmap_ind16 &bi
 UINT32 m90_state::screen_update_dynablsb(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	screen.priority().fill(0, cliprect);
-	bitmap.fill(get_black_pen(machine()), cliprect);
+	bitmap.fill(m_palette->black_pen(), cliprect);
 
 	if (!(m_video_data[0xf008/2] & 0x4000)) {
 		m_pf1_wide_layer->mark_all_dirty();
