@@ -62,20 +62,18 @@ static const res_net_info mario_net_info_std =
   bit 0 -- 470 ohm resistor -- inverter  -- BLUE
 
 ***************************************************************************/
-void mario_state::palette_init()
+PALETTE_INIT_MEMBER(mario_state, mario)
 {
 	const UINT8 *color_prom = memregion("proms")->base();
-	rgb_t   *rgb;
+	dynamic_array<rgb_t> rgb;
 
-	rgb = compute_res_net_all(machine(), color_prom, &mario_decode_info, &mario_net_info);
-	palette_set_colors(machine(), 0, rgb, 256);
-	auto_free(machine(), rgb);
-	rgb = compute_res_net_all(machine(), color_prom+256, &mario_decode_info, &mario_net_info_std);
-	palette_set_colors(machine(), 256, rgb, 256);
-	auto_free(machine(), rgb);
+	compute_res_net_all(rgb, color_prom, mario_decode_info, mario_net_info);
+	palette.set_pen_colors(0, rgb, 256);
+	compute_res_net_all(rgb, color_prom+256, mario_decode_info, mario_net_info_std);
+	palette.set_pen_colors(256, rgb, 256);
 
-	palette_normalize_range(machine().palette, 0, 255, 0, 255);
-	palette_normalize_range(machine().palette, 256, 511, 0, 255);
+	palette.palette()->normalize_range(0, 255);
+	palette.palette()->normalize_range(256, 511);
 }
 
 WRITE8_MEMBER(mario_state::mario_videoram_w)
@@ -132,7 +130,7 @@ TILE_GET_INFO_MEMBER(mario_state::get_bg_tile_info)
 
 void mario_state::video_start()
 {
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(mario_state::get_bg_tile_info),this), TILEMAP_SCAN_ROWS,
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(mario_state::get_bg_tile_info),this), TILEMAP_SCAN_ROWS,
 			8, 8, 32, 32);
 
 	m_gfx_bank = 0;
@@ -175,7 +173,7 @@ void mario_state::draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect)
 			{
 				y -= 14;
 				x -= 7;
-				drawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+				m_gfxdecode->gfx(1)->transpen(bitmap,cliprect,
 						m_spriteram[offs + 2],
 						(m_spriteram[offs + 1] & 0x0f) + 16 * m_palette_bank + 32 * m_monitor,
 						!(m_spriteram[offs + 1] & 0x80),!(m_spriteram[offs + 1] & 0x40),
@@ -185,7 +183,7 @@ void mario_state::draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect)
 			{
 				y += 1;
 				x -= 8;
-				drawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+				m_gfxdecode->gfx(1)->transpen(bitmap,cliprect,
 						m_spriteram[offs + 2],
 						(m_spriteram[offs + 1] & 0x0f) + 16 * m_palette_bank + 32 * m_monitor,
 						(m_spriteram[offs + 1] & 0x80),(m_spriteram[offs + 1] & 0x40),
@@ -206,8 +204,7 @@ UINT32 mario_state::screen_update_mario(screen_device &screen, bitmap_ind16 &bit
 		machine().tilemap().mark_all_dirty();
 	}
 
-	m_bg_tilemap->set_scrollx(0, m_flip ? (HTOTAL-HBSTART) : 0);
-	m_bg_tilemap->set_scrolly(0, m_gfx_scroll - (m_flip ? 8 : 0));
+	m_bg_tilemap->set_scrolly(0, m_gfx_scroll);
 
 	m_bg_tilemap->draw(screen, bitmap, cliprect, 0, 0);
 	draw_sprites(bitmap, cliprect);
