@@ -301,7 +301,7 @@ WRITE16_MEMBER(midtunit_state::midtunit_paletteram_w)
 
 	COMBINE_DATA(&m_generic_paletteram_16[offset]);
 	//newword = m_generic_paletteram_16[offset];
-	palette_set_color_rgb(machine(), offset, pal5bit(data >> 10), pal5bit(data >> 5), pal5bit(data >> 0));
+	m_palette->set_pen_color(offset, pal5bit(data >> 10), pal5bit(data >> 5), pal5bit(data >> 0));
 }
 
 
