@@ -126,43 +126,23 @@ VIDEO_START_MEMBER(namcos21_state,namcos21)
 		namcos2_shared_state::c355_obj_code2tile_delegate() );
 }
 
-static void
-update_palette( running_machine &machine )
-{
-	namcos21_state *state = machine.driver_data<namcos21_state>();
-	int i;
-	INT16 data1,data2;
-	int r,g,b;
 
-	/*
-	Palette:
-	    0x0000..0x1fff  sprite palettes (0x10 sets of 0x100 colors)
+/*  Palette:
+        0x0000..0x1fff  sprite palettes (0x10 sets of 0x100 colors)
 
-	    0x2000..0x3fff  polygon palette bank0 (0x10 sets of 0x200 colors)
-	        (in starblade, some palette animation effects are performed here)
+        0x2000..0x3fff  polygon palette bank0 (0x10 sets of 0x200 colors)
+            (in starblade, some palette animation effects are performed here)
 
-	    0x4000..0x5fff  polygon palette bank1 (0x10 sets of 0x200 colors)
+        0x4000..0x5fff  polygon palette bank1 (0x10 sets of 0x200 colors)
 
-	    0x6000..0x7fff  polygon palette bank2 (0x10 sets of 0x200 colors)
+        0x6000..0x7fff  polygon palette bank2 (0x10 sets of 0x200 colors)
 
-	    The polygon-dedicated color sets within a bank typically increase in
-	    intensity from very dark to full intensity.
+        The polygon-dedicated color sets within a bank typically increase in
+        intensity from very dark to full intensity.
 
-	    Probably the selected palette is determined by most significant bits of z-code.
-	    This is not yet hooked up.
-	*/
-	for( i=0; i<NAMCOS21_NUM_COLORS; i++ )
-	{
-		data1 = state->m_generic_paletteram_16[0x00000/2+i];
-		data2 = state->m_generic_paletteram_16[0x10000/2+i];
-
-		r = data1>>8;
-		g = data1&0xff;
-		b = data2&0xff;
-
-		palette_set_color( machine,i, MAKE_RGB(r,g,b) );
-	}
-} /* update_palette */
+        Probably the selected palette is determined by most significant bits of z-code.
+        This is not yet hooked up.
+    */
 
 
 UINT32 namcos21_state::screen_update_namcos21(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
@@ -170,7 +150,6 @@ UINT32 namcos21_state::screen_update_namcos21(screen_device &screen, bitmap_ind1
 	UINT8 *videoram = m_videoram;
 	int pivot = 3;
 	int pri;
-	update_palette(machine());
 	bitmap.fill(0xff, cliprect );
 
 	if( m_gametype != NAMCOS21_WINRUN91 )
