@@ -12,29 +12,6 @@
 #include "cpu/m6809/m6809.h"
 
 
-
-/*************************************
- *
- *  Device tag
- *
- *************************************/
-
-#define MC6845_TAG      ("vid_u18")
-
-
-
-/*************************************
- *
- *  Static function prototypes
- *
- *************************************/
-
-static MC6845_BEGIN_UPDATE( begin_update );
-static MC6845_UPDATE_ROW( update_row );
-
-
-
-
 /*************************************
  *
  *  Start
@@ -46,10 +23,15 @@ VIDEO_START_MEMBER(qix_state,qix)
 	/* allocate memory for the full video RAM */
 	m_videoram.allocate(256 * 256);
 
+	/* initialize the palette */
+	for (int x = 0; x < 0x400; x++)
+		set_pen(x);
+
 	/* set up save states */
 	save_item(NAME(m_flip));
 	save_item(NAME(m_palette_bank));
 	save_item(NAME(m_leds));
+	save_item(NAME(m_pens));
 }
 
 
@@ -65,8 +47,8 @@ WRITE_LINE_MEMBER(qix_state::display_enable_changed)
 	/* on the rising edge, latch the scanline */
 	if (state)
 	{
-		UINT16 ma = downcast<mc6845_device *>(machine().device(MC6845_TAG))->get_ma();
-		UINT8 ra = downcast<mc6845_device *>(machine().device(MC6845_TAG))->get_ra();
+		UINT16 ma = m_crtc->get_ma();
+		UINT8 ra = m_crtc->get_ra();
 
 		/* RA0-RA2 goes to D0-D2 and MA5-MA9 goes to D3-D7 */
 		*m_scanline_latch = ((ma >> 2) & 0xf8) | (ra & 0x07);
@@ -81,9 +63,9 @@ WRITE_LINE_MEMBER(qix_state::display_enable_changed)
  *
  *************************************/
 
-WRITE8_MEMBER(qix_state::qix_flip_screen_w)
+WRITE_LINE_MEMBER(qix_state::qix_flip_screen_w)
 {
-	m_flip = data;
+	m_flip = state;
 }
 
 
@@ -208,6 +190,8 @@ WRITE8_MEMBER(qix_state::qix_paletteram_w)
 	if (((offset >> 8) == m_palette_bank) &&
 		(old_data != data))
 		m_screen->update_now();
+
+	set_pen(offset);
 }
 
 
@@ -225,10 +209,8 @@ WRITE8_MEMBER(qix_state::qix_palettebank_w)
 }
 
 
-void qix_state::get_pens( pen_t *pens)
+void qix_state::set_pen(int offs)
 {
-	offs_t offs;
-
 	/* this conversion table should be about right. It gives a reasonable */
 	/* gray scale in the test screen, and the red, green and blue squares */
 	/* in the same screen are barely visible, as the manual requires. */
@@ -252,24 +234,21 @@ void qix_state::get_pens( pen_t *pens)
 		0xff    /* value = 3, intensity = 3 */
 	};
 
-	for (offs = m_palette_bank << 8; offs < (m_palette_bank << 8) + NUM_PENS; offs++)
-	{
-		int bits, intensity, r, g, b;
+	int bits, intensity, r, g, b;
 
-		UINT8 data = m_paletteram[offs];
+	UINT8 data = m_paletteram[offs];
 
-		/* compute R, G, B from the table */
-		intensity = (data >> 0) & 0x03;
-		bits = (data >> 6) & 0x03;
-		r = table[(bits << 2) | intensity];
-		bits = (data >> 4) & 0x03;
-		g = table[(bits << 2) | intensity];
-		bits = (data >> 2) & 0x03;
-		b = table[(bits << 2) | intensity];
+	/* compute R, G, B from the table */
+	intensity = (data >> 0) & 0x03;
+	bits = (data >> 6) & 0x03;
+	r = table[(bits << 2) | intensity];
+	bits = (data >> 4) & 0x03;
+	g = table[(bits << 2) | intensity];
+	bits = (data >> 2) & 0x03;
+	b = table[(bits << 2) | intensity];
 
-		/* update the palette */
-		pens[offs & 0xff] = MAKE_RGB(r, g, b);
-	}
+	/* update the palette */
+	m_pens[offs] = rgb_t(r, g, b);
 }
 
 
@@ -281,40 +260,29 @@ void qix_state::get_pens( pen_t *pens)
  *
  *************************************/
 
-static MC6845_BEGIN_UPDATE( begin_update )
+MC6845_BEGIN_UPDATE( qix_state::crtc_begin_update )
 {
-	qix_state *state = device->machine().driver_data<qix_state>();
-
 #if 0
 	// note the confusing bit order!
 	popmessage("self test leds: %d%d %d%d%d%d",BIT(leds,7),BIT(leds,5),BIT(leds,6),BIT(leds,4),BIT(leds,2),BIT(leds,3));
 #endif
-
-	/* create the pens */
-	state->get_pens(state->m_pens);
-
-	return state->m_pens;
 }
 
 
-static MC6845_UPDATE_ROW( update_row )
+MC6845_UPDATE_ROW( qix_state::crtc_update_row )
 {
-	qix_state *state = device->machine().driver_data<qix_state>();
 	UINT32 *dest = &bitmap.pix32(y);
-	UINT16 x;
-
-	pen_t *pens = (pen_t *)param;
+	pen_t *pens = &m_pens[m_palette_bank << 8];
 
 	/* the memory is hooked up to the MA, RA lines this way */
 	offs_t offs = ((ma << 6) & 0xf800) | ((ra << 8) & 0x0700);
-	offs_t offs_xor = state->m_flip ? 0xffff : 0;
+	offs_t offs_xor = m_flip ? 0xffff : 0;
 
-	for (x = 0; x < x_count * 8; x++)
-		dest[x] = pens[state->m_videoram[(offs + x) ^ offs_xor]];
+	for (UINT16 x = 0; x < x_count * 8; x++)
+		dest[x] = pens[m_videoram[(offs + x) ^ offs_xor]];
 }
 
 
-
 /*************************************
  *
  *  Memory handlers
@@ -338,6 +306,23 @@ static ADDRESS_MAP_START( qix_video_map, AS_PROGRAM, 8, qix_state )
 ADDRESS_MAP_END
 
 
+static ADDRESS_MAP_START( kram3_video_map, AS_PROGRAM, 8, qix_state )
+	AM_RANGE(0x0000, 0x7fff) AM_READWRITE(qix_videoram_r, qix_videoram_w)
+	AM_RANGE(0x8000, 0x83ff) AM_RAM AM_SHARE("share1")
+	AM_RANGE(0x8400, 0x87ff) AM_RAM AM_SHARE("nvram")
+	AM_RANGE(0x8800, 0x8800) AM_MIRROR(0x03ff) AM_WRITE(qix_palettebank_w)
+	AM_RANGE(0x8c00, 0x8c00) AM_MIRROR(0x03fe) AM_READWRITE(qix_data_firq_r, qix_data_firq_w)
+	AM_RANGE(0x8c01, 0x8c01) AM_MIRROR(0x03fe) AM_READWRITE(qix_video_firq_ack_r, qix_video_firq_ack_w)
+	AM_RANGE(0x9000, 0x93ff) AM_RAM_WRITE(qix_paletteram_w) AM_SHARE("paletteram")
+	AM_RANGE(0x9400, 0x9400) AM_MIRROR(0x03fc) AM_READWRITE(qix_addresslatch_r, qix_addresslatch_w)
+	AM_RANGE(0x9402, 0x9403) AM_MIRROR(0x03fc) AM_WRITEONLY AM_SHARE("videoram_addr")
+	AM_RANGE(0x9800, 0x9800) AM_MIRROR(0x03ff) AM_READONLY AM_SHARE("scanline_latch")
+	AM_RANGE(0x9c00, 0x9c00) AM_MIRROR(0x03fe) AM_DEVWRITE("vid_u18", mc6845_device, address_w)
+	AM_RANGE(0x9c01, 0x9c01) AM_MIRROR(0x03fe) AM_DEVREADWRITE("vid_u18", mc6845_device, register_r, register_w)
+	AM_RANGE(0xa000, 0xffff) AM_ROMBANK("bank1")
+ADDRESS_MAP_END
+
+
 static ADDRESS_MAP_START( zookeep_video_map, AS_PROGRAM, 8, qix_state )
 	AM_RANGE(0x0000, 0x7fff) AM_READWRITE(qix_videoram_r, qix_videoram_w)
 	AM_RANGE(0x8000, 0x83ff) AM_RAM AM_SHARE("share1")
@@ -382,32 +367,30 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static MC6845_INTERFACE( mc6845_intf )
-{
-	false,                              /* show border area */
-	8,                                  /* number of pixels per video memory address */
-	begin_update,                       /* before pixel update callback */
-	update_row,                         /* row update callback */
-	NULL,                               /* after pixel update callback */
-	DEVCB_DRIVER_LINE_MEMBER(qix_state,display_enable_changed), /* callback for display state changes */
-	DEVCB_NULL,                         /* callback for cursor state changes */
-	DEVCB_NULL,                         /* HSYNC callback */
-	DEVCB_DRIVER_LINE_MEMBER(qix_state,qix_vsync_changed),      /* VSYNC callback */
-	NULL                                /* update address callback */
-};
-
-
 MACHINE_CONFIG_FRAGMENT( qix_video )
 	MCFG_CPU_ADD("videocpu", M6809, MAIN_CLOCK_OSC/4/4) /* 1.25 MHz */
 	MCFG_CPU_PROGRAM_MAP(qix_video_map)
 
 	MCFG_VIDEO_START_OVERRIDE(qix_state,qix)
 
-	MCFG_MC6845_ADD(MC6845_TAG, MC6845, "screen", QIX_CHARACTER_CLOCK, mc6845_intf)
+	MCFG_MC6845_ADD("vid_u18", MC6845, "screen", QIX_CHARACTER_CLOCK)
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(8)
+	MCFG_MC6845_BEGIN_UPDATE_CB(qix_state, crtc_begin_update)
+	MCFG_MC6845_UPDATE_ROW_CB(qix_state, crtc_update_row)
+	MCFG_MC6845_OUT_DE_CB(WRITELINE(qix_state, display_enable_changed))
+	MCFG_MC6845_OUT_VSYNC_CB(WRITELINE(qix_state, qix_vsync_changed))
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS(QIX_CHARACTER_CLOCK*8, 0x148, 0, 0x100, 0x111, 0, 0x100) /* from CRTC */
-	MCFG_SCREEN_UPDATE_DEVICE(MC6845_TAG, mc6845_device, screen_update)
+	MCFG_SCREEN_UPDATE_DEVICE("vid_u18", mc6845_device, screen_update)
+MACHINE_CONFIG_END
+
+
+MACHINE_CONFIG_FRAGMENT( kram3_video )
+	MCFG_CPU_REPLACE("videocpu", M6809E, MAIN_CLOCK_OSC/4) /* 1.25 MHz */
+	MCFG_CPU_PROGRAM_MAP(kram3_video_map)
+	MCFG_M6809E_LIC_CB(WRITELINE(qix_state,kram3_lic_videocpu_changed))
 MACHINE_CONFIG_END
 
 
