@@ -1,17 +1,14 @@
 #include "emu.h"
 #include "includes/rockrage.h"
 
-void rockrage_state::palette_init()
+PALETTE_INIT_MEMBER(rockrage_state, rockrage)
 {
 	const UINT8 *color_prom = memregion("proms")->base();
 	int i;
 
-	/* allocate the colortable */
-	machine().colortable = colortable_alloc(machine(), 0x40);
-
 	/* sprites */
 	for (i = 0x20; i < 0x40; i++)
-		colortable_entry_set_value(machine().colortable, i, i);
+		palette.set_pen_indirect(i, i);
 
 	/* characters */
 	for (i = 0x40; i < 0x140; i++)
@@ -19,29 +16,14 @@ void rockrage_state::palette_init()
 		UINT8 ctabentry;
 
 		ctabentry = (color_prom[(i - 0x40) + 0x000] & 0x0f) | 0x00;
-		colortable_entry_set_value(machine().colortable, i + 0x000, ctabentry);
+		palette.set_pen_indirect(i + 0x000, ctabentry);
 
 		ctabentry = (color_prom[(i - 0x40) + 0x100] & 0x0f) | 0x10;
-		colortable_entry_set_value(machine().colortable, i + 0x100, ctabentry);
+		palette.set_pen_indirect(i + 0x100, ctabentry);
 	}
 }
 
 
-static void set_pens( running_machine &machine )
-{
-	rockrage_state *state = machine.driver_data<rockrage_state>();
-	int i;
-
-	for (i = 0x00; i < 0x80; i += 2)
-	{
-		UINT16 data = state->m_paletteram[i] | (state->m_paletteram[i | 1] << 8);
-
-		rgb_t color = MAKE_RGB(pal5bit(data >> 0), pal5bit(data >> 5), pal5bit(data >> 10));
-
-		colortable_palette_set_color(machine.colortable, i >> 1, color);
-	}
-}
-
 
 /***************************************************************************
 
@@ -49,15 +31,13 @@ static void set_pens( running_machine &machine )
 
 ***************************************************************************/
 
-void rockrage_tile_callback( running_machine &machine, int layer, int bank, int *code, int *color, int *flags )
+K007342_CALLBACK_MEMBER(rockrage_state::rockrage_tile_callback)
 {
-	rockrage_state *state = machine.driver_data<rockrage_state>();
-
 	if (layer == 1)
 		*code |= ((*color & 0x40) << 2) | ((bank & 0x01) << 9);
 	else
-		*code |= ((*color & 0x40) << 2) | ((bank & 0x03) << 10) | ((state->m_vreg & 0x04) << 7) | ((state->m_vreg & 0x08) << 9);
-	*color = state->m_layer_colorbase[layer] + (*color & 0x0f);
+		*code |= ((*color & 0x40) << 2) | ((bank & 0x03) << 10) | ((m_vreg & 0x04) << 7) | ((m_vreg & 0x08) << 9);
+	*color = m_layer_colorbase[layer] + (*color & 0x0f);
 }
 
 /***************************************************************************
@@ -66,11 +46,9 @@ void rockrage_tile_callback( running_machine &machine, int layer, int bank, int
 
 ***************************************************************************/
 
-void rockrage_sprite_callback( running_machine &machine, int *code, int *color )
+K007420_CALLBACK_MEMBER(rockrage_state::rockrage_sprite_callback)
 {
-	rockrage_state *state = machine.driver_data<rockrage_state>();
-
-	*code |= ((*color & 0x40) << 2) | ((*color & 0x80) << 1) * ((state->m_vreg & 0x03) << 1);
+	*code |= ((*color & 0x40) << 2) | ((*color & 0x80) << 1) * ((m_vreg & 0x03) << 1);
 	*code = (*code << 2) | ((*color & 0x30) >> 4);
 	*color = 0;
 }
@@ -97,12 +75,10 @@ WRITE8_MEMBER(rockrage_state::rockrage_vreg_w)
 
 UINT32 rockrage_state::screen_update_rockrage(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
-	set_pens(machine());
-
 	m_k007342->tilemap_update();
 
 	m_k007342->tilemap_draw(screen, bitmap, cliprect, 0, TILEMAP_DRAW_OPAQUE, 0);
-	m_k007420->sprites_draw(bitmap, cliprect, machine().gfx[1]);
+	m_k007420->sprites_draw(bitmap, cliprect, m_gfxdecode->gfx(1));
 	m_k007342->tilemap_draw(screen, bitmap, cliprect, 0, 1 | TILEMAP_DRAW_OPAQUE, 0);
 	m_k007342->tilemap_draw(screen, bitmap, cliprect, 1, 0, 0);
 	m_k007342->tilemap_draw(screen, bitmap, cliprect, 1, 1, 0);
