@@ -20,13 +20,13 @@
   bit 0 -- 1  kohm resistor  -- RED/GREEN/BLUE
 
 ***************************************************************************/
-void rollrace_state::palette_init()
+PALETTE_INIT_MEMBER(rollrace_state, rollrace)
 {
 	const UINT8 *color_prom = memregion("proms")->base();
 	int i;
 
 
-	for (i = 0;i < machine().total_colors();i++)
+	for (i = 0;i < palette.entries();i++)
 	{
 		int bit0,bit1,bit2,bit3,r,g,b;
 
@@ -36,18 +36,18 @@ void rollrace_state::palette_init()
 		bit2 = (color_prom[0] >> 2) & 0x01;
 		bit3 = (color_prom[0] >> 3) & 0x01;
 		r = 0x0e * bit0 + 0x1f * bit1 + 0x42 * bit2 + 0x90 * bit3;
-		bit0 = (color_prom[machine().total_colors()] >> 0) & 0x01;
-		bit1 = (color_prom[machine().total_colors()] >> 1) & 0x01;
-		bit2 = (color_prom[machine().total_colors()] >> 2) & 0x01;
-		bit3 = (color_prom[machine().total_colors()] >> 3) & 0x01;
+		bit0 = (color_prom[palette.entries()] >> 0) & 0x01;
+		bit1 = (color_prom[palette.entries()] >> 1) & 0x01;
+		bit2 = (color_prom[palette.entries()] >> 2) & 0x01;
+		bit3 = (color_prom[palette.entries()] >> 3) & 0x01;
 		g = 0x0e * bit0 + 0x1f * bit1 + 0x42 * bit2 + 0x90 * bit3;
-		bit0 = (color_prom[2*machine().total_colors()] >> 0) & 0x01;
-		bit1 = (color_prom[2*machine().total_colors()] >> 1) & 0x01;
-		bit2 = (color_prom[2*machine().total_colors()] >> 2) & 0x01;
-		bit3 = (color_prom[2*machine().total_colors()] >> 3) & 0x01;
+		bit0 = (color_prom[2*palette.entries()] >> 0) & 0x01;
+		bit1 = (color_prom[2*palette.entries()] >> 1) & 0x01;
+		bit2 = (color_prom[2*palette.entries()] >> 2) & 0x01;
+		bit3 = (color_prom[2*palette.entries()] >> 3) & 0x01;
 		b = 0x0e * bit0 + 0x1f * bit1 + 0x42 * bit2 + 0x90 * bit3;
 
-		palette_set_color(machine(),i,MAKE_RGB(r,g,b));
+		palette.set_pen_color(i,rgb_t(r,g,b));
 
 		color_prom++;
 	}
@@ -123,8 +123,8 @@ UINT32 rollrace_state::screen_update_rollrace(screen_device &screen, bitmap_ind1
 			if(m_ra_flipy)
 				sy = 31-sy ;
 
-			drawgfx_transpen(bitmap,
-				cliprect,machine().gfx[RA_BGCHAR_BASE],
+			m_gfxdecode->gfx(RA_BGCHAR_BASE)->transpen(bitmap,
+				cliprect,
 				mem[offs + ( m_ra_bkgpage * 1024 )]
 				+ ((( mem[offs + 0x4000 + ( m_ra_bkgpage * 1024 )] & 0xc0 ) >> 6 ) * 256 ) ,
 				m_ra_bkgcol,
@@ -161,7 +161,7 @@ UINT32 rollrace_state::screen_update_rollrace(screen_device &screen, bitmap_ind1
 		if(bank)
 			bank += m_ra_spritebank;
 
-		drawgfx_transpen(bitmap, cliprect,machine().gfx[ RA_SP_BASE + bank ],
+		m_gfxdecode->gfx( RA_SP_BASE + bank )->transpen(bitmap,cliprect,
 			spriteram[offs+1] & 0x3f ,
 			spriteram[offs+2] & 0x1f,
 			m_ra_flipx,!(s_flipy^m_ra_flipy),
@@ -188,7 +188,7 @@ UINT32 rollrace_state::screen_update_rollrace(screen_device &screen, bitmap_ind1
 
 		if (m_ra_flipx) sx = 31 - sx;
 
-		drawgfx_transpen(bitmap,cliprect,machine().gfx[RA_FGCHAR_BASE + m_ra_chrbank]  ,
+		m_gfxdecode->gfx(RA_FGCHAR_BASE + m_ra_chrbank)  ->transpen(bitmap,cliprect,
 			m_videoram[ offs ]  ,
 			col,
 			m_ra_flipx,m_ra_flipy,
