@@ -26,7 +26,7 @@ namespace {
 UINT32 segas24_state::screen_update_system24(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	if(vmixer->get_reg(13) & 1) {
-		bitmap.fill(get_black_pen(machine()));
+		bitmap.fill(m_palette->black_pen());
 		return 0;
 	}
 
