@@ -53,7 +53,7 @@ PALETTE_INIT_MEMBER(snk_state,tnk3)
 		bit3 = (color_prom[i + num_colors] >> 1) & 0x01;
 		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
-		palette_set_color(machine(),i,MAKE_RGB(r,g,b));
+		palette.set_pen_color(i,rgb_t(r,g,b));
 	}
 }
 
@@ -174,7 +174,7 @@ TILE_GET_INFO_MEMBER(snk_state::gwar_get_bg_tile_info)
 	// bermudat, tdfever use FFFF to blank the background.
 	// (still call SET_TILE_INFO_MEMBER, otherwise problems might occur on boot when
 	// the tile data hasn't been initialised)
-	if (code >= machine().gfx[1]->elements())
+	if (code >= m_gfxdecode->gfx(1)->elements())
 		tileinfo.pen_data = m_empty_tile;
 }
 
@@ -185,23 +185,23 @@ VIDEO_START_MEMBER(snk_state,snk_3bpp_shadow)
 {
 	int i;
 
-	if(!(machine().config().m_video_attributes & VIDEO_HAS_SHADOWS))
+	if(!(m_palette->shadows_enabled()))
 		fatalerror("driver should use VIDEO_HAS_SHADOWS\n");
 
 	/* prepare shadow draw table */
 	for(i = 0; i <= 5; i++) m_drawmode_table[i] = DRAWMODE_SOURCE;
-	m_drawmode_table[6] = (machine().config().m_video_attributes & VIDEO_HAS_SHADOWS) ? DRAWMODE_SHADOW : DRAWMODE_SOURCE;
+	m_drawmode_table[6] = (m_palette->shadows_enabled()) ? DRAWMODE_SHADOW : DRAWMODE_SOURCE;
 	m_drawmode_table[7] = DRAWMODE_NONE;
 
 	for (i = 0x000;i < 0x400;i++)
-		machine().shadow_table[i] = i | 0x200;
+		m_palette->shadow_table()[i] = i | 0x200;
 }
 
 VIDEO_START_MEMBER(snk_state,snk_4bpp_shadow)
 {
 	int i;
 
-	if(!(machine().config().m_video_attributes & VIDEO_HAS_SHADOWS))
+	if(!(m_palette->shadows_enabled()))
 		fatalerror("driver should use VIDEO_HAS_SHADOWS\n");
 
 	/* prepare shadow draw table */
@@ -211,10 +211,10 @@ VIDEO_START_MEMBER(snk_state,snk_4bpp_shadow)
 
 	/* all palette entries are not affected by shadow sprites... */
 	for (i = 0x000;i < 0x400;i++)
-		machine().shadow_table[i] = i;
+		m_palette->shadow_table()[i] = i;
 	/* ... except for tilemap colors */
 	for (i = 0x200;i < 0x300;i++)
-		machine().shadow_table[i] = i + 0x100;
+		m_palette->shadow_table()[i] = i + 0x100;
 }
 
 
@@ -222,9 +222,9 @@ VIDEO_START_MEMBER(snk_state,marvins)
 {
 	VIDEO_START_CALL_MEMBER(snk_3bpp_shadow);
 
-	m_tx_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::marvins_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this), 8, 8, 36, 28);
-	m_fg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::marvins_get_fg_tile_info),this), TILEMAP_SCAN_COLS,    8, 8, 64, 32);
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::marvins_get_bg_tile_info),this), TILEMAP_SCAN_COLS,    8, 8, 64, 32);
+	m_tx_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::marvins_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this), 8, 8, 36, 28);
+	m_fg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::marvins_get_fg_tile_info),this), TILEMAP_SCAN_COLS,    8, 8, 64, 32);
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::marvins_get_bg_tile_info),this), TILEMAP_SCAN_COLS,    8, 8, 64, 32);
 
 	m_tx_tilemap->set_transparent_pen(15);
 	m_tx_tilemap->set_scrolldy(8, 8);
@@ -243,8 +243,8 @@ VIDEO_START_MEMBER(snk_state,jcross)
 {
 	VIDEO_START_CALL_MEMBER(snk_3bpp_shadow);
 
-	m_tx_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::marvins_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this), 8, 8, 36, 28);
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::aso_get_bg_tile_info),this),     TILEMAP_SCAN_COLS,    8, 8, 64, 64);
+	m_tx_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::marvins_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this), 8, 8, 36, 28);
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::aso_get_bg_tile_info),this),     TILEMAP_SCAN_COLS,    8, 8, 64, 64);
 
 	m_tx_tilemap->set_transparent_pen(15);
 	m_tx_tilemap->set_scrolldy(8, 8);
@@ -262,8 +262,8 @@ VIDEO_START_MEMBER(snk_state,sgladiat)
 {
 	VIDEO_START_CALL_MEMBER(snk_3bpp_shadow);
 
-	m_tx_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::marvins_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this), 8, 8, 36, 28);
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::aso_get_bg_tile_info),this),     TILEMAP_SCAN_COLS,    8, 8, 64, 32);
+	m_tx_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::marvins_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this), 8, 8, 36, 28);
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::aso_get_bg_tile_info),this),     TILEMAP_SCAN_COLS,    8, 8, 64, 32);
 
 	m_tx_tilemap->set_transparent_pen(15);
 	m_tx_tilemap->set_scrolldy(8, 8);
@@ -302,8 +302,8 @@ VIDEO_START_MEMBER(snk_state,tnk3)
 {
 	VIDEO_START_CALL_MEMBER(snk_3bpp_shadow);
 
-	m_tx_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::marvins_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this), 8, 8, 36, 28);
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::tnk3_get_bg_tile_info),this),    TILEMAP_SCAN_COLS,    8, 8, 64, 64);
+	m_tx_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::marvins_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this), 8, 8, 36, 28);
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::tnk3_get_bg_tile_info),this),    TILEMAP_SCAN_COLS,    8, 8, 64, 64);
 
 	m_tx_tilemap->set_transparent_pen(15);
 	m_tx_tilemap->set_scrolldy(8, 8);
@@ -320,8 +320,8 @@ VIDEO_START_MEMBER(snk_state,ikari)
 {
 	VIDEO_START_CALL_MEMBER(snk_3bpp_shadow);
 
-	m_tx_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::ikari_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this),  8,  8, 36, 28);
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::ikari_get_bg_tile_info),this), TILEMAP_SCAN_COLS,    16, 16, 32, 32);
+	m_tx_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::ikari_get_tx_tile_info),this), tilemap_mapper_delegate(FUNC(snk_state::marvins_tx_scan_cols),this),  8,  8, 36, 28);
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::ikari_get_bg_tile_info),this), TILEMAP_SCAN_COLS,    16, 16, 32, 32);
 
 	m_tx_tilemap->set_transparent_pen(15);
 	m_tx_tilemap->set_scrolldy(8, 8);
@@ -342,8 +342,8 @@ VIDEO_START_MEMBER(snk_state,gwar)
 
 	memset(m_empty_tile, 0xf, sizeof(m_empty_tile));
 
-	m_tx_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::gwar_get_tx_tile_info),this), TILEMAP_SCAN_COLS,  8,  8, 50, 32);
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(snk_state::gwar_get_bg_tile_info),this), TILEMAP_SCAN_COLS, 16, 16, 32, 32);
+	m_tx_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::gwar_get_tx_tile_info),this), TILEMAP_SCAN_COLS,  8,  8, 50, 32);
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(snk_state::gwar_get_bg_tile_info),this), TILEMAP_SCAN_COLS, 16, 16, 32, 32);
 
 	m_tx_tilemap->set_transparent_pen(15);
 
@@ -662,7 +662,7 @@ static void marvins_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap,
 		const int scrollx, const int scrolly, const int from, const int to)
 {
 	snk_state *state = machine.driver_data<snk_state>();
-	gfx_element *gfx = machine.gfx[3];
+	gfx_element *gfx = state->m_gfxdecode->gfx(3);
 	const UINT8 *source, *finish;
 
 	source = state->m_spriteram + from*4;
@@ -691,12 +691,12 @@ static void marvins_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap,
 		if (sx > 512-16) sx -= 512;
 		if (sy > 256-16) sy -= 256;
 
-		drawgfx_transtable(bitmap,cliprect,gfx,
+		gfx->transtable(bitmap,cliprect,
 			tile_number,
 			color,
 			flipx, flipy,
 			sx, sy,
-			state->m_drawmode_table, machine.shadow_table);
+			state->m_drawmode_table);
 
 		source+=4;
 	}
@@ -706,7 +706,7 @@ static void marvins_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap,
 void snk_state::tnk3_draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprect, const int xscroll, const int yscroll)
 {
 	UINT8 *spriteram = m_spriteram;
-	gfx_element *gfx = machine().gfx[2];
+	gfx_element *gfx = m_gfxdecode->gfx(2);
 	const int size = gfx->width();
 	int tile_number, attributes, color, sx, sy;
 	int xflip,yflip;
@@ -757,12 +757,12 @@ void snk_state::tnk3_draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprec
 		if (sx > 512-size) sx -= 512;
 		if (sy > (m_yscroll_mask+1)-size) sy -= (m_yscroll_mask+1);
 
-		drawgfx_transtable(bitmap,cliprect,gfx,
+		gfx->transtable(bitmap,cliprect,
 				tile_number,
 				color,
 				xflip,yflip,
 				sx,sy,
-				m_drawmode_table, machine().shadow_table);
+				m_drawmode_table);
 	}
 }
 
@@ -771,7 +771,7 @@ static void ikari_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, c
 		const int start, const int xscroll, const int yscroll, const UINT8 *source, const int gfxnum )
 {
 	snk_state *state = machine.driver_data<snk_state>();
-	gfx_element *gfx = machine.gfx[gfxnum];
+	gfx_element *gfx = state->m_gfxdecode->gfx(gfxnum);
 	const int size = gfx->width();
 	int tile_number, attributes, color, sx, sy;
 	int which, finish;
@@ -804,12 +804,12 @@ static void ikari_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap, c
 		if (sx > 512-size) sx -= 512;
 		if (sy > 512-size) sy -= 512;
 
-		drawgfx_transtable(bitmap,cliprect,gfx,
+		gfx->transtable(bitmap,cliprect,
 				tile_number,
 				color,
 				0,0,
 				sx,sy,
-				state->m_drawmode_table, machine.shadow_table);
+				state->m_drawmode_table);
 	}
 }
 
@@ -843,7 +843,7 @@ static void tdfever_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap,
 		const int xscroll, const int yscroll, const UINT8 *source, const int gfxnum, const int hw_xflip, const int from, const int to )
 {
 	snk_state *state = machine.driver_data<snk_state>();
-	gfx_element *gfx = machine.gfx[gfxnum];
+	gfx_element *gfx = state->m_gfxdecode->gfx(gfxnum);
 	const int size = gfx->width();
 	int tile_number, attributes, sx, sy, color;
 	int which;
@@ -892,12 +892,12 @@ static void tdfever_draw_sprites(running_machine &machine, bitmap_ind16 &bitmap,
 		if (sx > 512-size) sx -= 512;
 		if (sy > 512-size) sy -= 512;
 
-		drawgfx_transtable(bitmap,cliprect,gfx,
+		gfx->transtable(bitmap,cliprect,
 				tile_number,
 				color,
 				flipx,flipy,
 				sx,sy,
-				state->m_drawmode_table, machine.shadow_table);
+				state->m_drawmode_table);
 	}
 }
 
