@@ -12,14 +12,11 @@ Video hardware driver by Uki
 #include "includes/strnskil.h"
 
 
-void strnskil_state::palette_init()
+PALETTE_INIT_MEMBER(strnskil_state, strnskil)
 {
 	const UINT8 *color_prom = memregion("proms")->base();
 	int i;
 
-	/* allocate the colortable */
-	machine().colortable = colortable_alloc(machine(), 0x100);
-
 	/* create a lookup table for the palette */
 	for (i = 0; i < 0x100; i++)
 	{
@@ -27,7 +24,7 @@ void strnskil_state::palette_init()
 		int g = pal4bit(color_prom[i + 0x100]);
 		int b = pal4bit(color_prom[i + 0x200]);
 
-		colortable_palette_set_color(machine().colortable, i, MAKE_RGB(r, g, b));
+		palette.set_indirect_color(i, rgb_t(r, g, b));
 	}
 
 	/* color_prom now points to the beginning of the lookup table */
@@ -37,7 +34,7 @@ void strnskil_state::palette_init()
 	for (i = 0; i < 0x400; i++)
 	{
 		UINT8 ctabentry = color_prom[i];
-		colortable_entry_set_value(machine().colortable, i, ctabentry);
+		palette.set_pen_indirect(i, ctabentry);
 	}
 }
 
@@ -72,7 +69,7 @@ TILE_GET_INFO_MEMBER(strnskil_state::get_bg_tile_info)
 
 void strnskil_state::video_start()
 {
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(strnskil_state::get_bg_tile_info),this), TILEMAP_SCAN_COLS,
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(strnskil_state::get_bg_tile_info),this), TILEMAP_SCAN_COLS,
 			8, 8, 32, 32);
 
 	m_bg_tilemap->set_scroll_rows(32);
@@ -110,12 +107,12 @@ void strnskil_state::draw_sprites(bitmap_ind16 &bitmap, const rectangle &cliprec
 		if (sx > 248)
 			sx = sx - 256;
 
-		drawgfx_transmask(bitmap, cliprect,
-			machine().gfx[1],
+
+			m_gfxdecode->gfx(1)->transmask(bitmap,cliprect,
 			code, color,
 			flipx, flipy,
 			px, py,
-			colortable_get_transpen_mask(machine().colortable, machine().gfx[1], color, 0));
+			m_palette->transpen_mask(*m_gfxdecode->gfx(1), color, 0));
 	}
 }
 
