@@ -10,8 +10,7 @@
 
 TILE_GET_INFO_MEMBER(tecmosys_state::get_bg0tile_info)
 {
-	SET_TILE_INFO_MEMBER(
-			1,
+	SET_TILE_INFO_MEMBER(1,
 			m_bg0tilemap_ram[2*tile_index+1],
 			(m_bg0tilemap_ram[2*tile_index]&0x3f),
 			TILE_FLIPYX((m_bg0tilemap_ram[2*tile_index]&0xc0)>>6));
@@ -19,8 +18,7 @@ TILE_GET_INFO_MEMBER(tecmosys_state::get_bg0tile_info)
 
 TILE_GET_INFO_MEMBER(tecmosys_state::get_bg1tile_info)
 {
-	SET_TILE_INFO_MEMBER(
-			2,
+	SET_TILE_INFO_MEMBER(2,
 			m_bg1tilemap_ram[2*tile_index+1],
 			(m_bg1tilemap_ram[2*tile_index]&0x3f),
 			TILE_FLIPYX((m_bg1tilemap_ram[2*tile_index]&0xc0)>>6));
@@ -28,8 +26,7 @@ TILE_GET_INFO_MEMBER(tecmosys_state::get_bg1tile_info)
 
 TILE_GET_INFO_MEMBER(tecmosys_state::get_bg2tile_info)
 {
-	SET_TILE_INFO_MEMBER(
-			3,
+	SET_TILE_INFO_MEMBER(3,
 			m_bg2tilemap_ram[2*tile_index+1],
 			(m_bg2tilemap_ram[2*tile_index]&0x3f),
 			TILE_FLIPYX((m_bg2tilemap_ram[2*tile_index]&0xc0)>>6));
@@ -37,8 +34,7 @@ TILE_GET_INFO_MEMBER(tecmosys_state::get_bg2tile_info)
 
 TILE_GET_INFO_MEMBER(tecmosys_state::get_fg_tile_info)
 {
-	SET_TILE_INFO_MEMBER(
-			0,
+	SET_TILE_INFO_MEMBER(0,
 			m_fgtilemap_ram[2*tile_index+1],
 			(m_fgtilemap_ram[2*tile_index]&0x3f),
 			TILE_FLIPYX((m_fgtilemap_ram[2*tile_index]&0xc0)>>6));
@@ -72,7 +68,7 @@ WRITE16_MEMBER(tecmosys_state::fg_tilemap_w)
 
 inline void tecmosys_state::set_color_555_tecmo(pen_t color, int rshift, int gshift, int bshift, UINT16 data)
 {
-	palette_set_color_rgb(machine(), color, pal5bit(data >> rshift), pal5bit(data >> gshift), pal5bit(data >> bshift));
+	m_palette->set_pen_color(color, pal5bit(data >> rshift), pal5bit(data >> gshift), pal5bit(data >> bshift));
 }
 
 WRITE16_MEMBER(tecmosys_state::tilemap_paletteram16_xGGGGGRRRRRBBBBB_word_w)
@@ -211,7 +207,7 @@ void tecmosys_state::tecmosys_tilemap_copy_to_compose(UINT16 pri)
 
 void tecmosys_state::tecmosys_do_final_mix(bitmap_rgb32 &bitmap)
 {
-	const pen_t *paldata = machine().pens;
+	const pen_t *paldata = m_palette->pens();
 	int y,x;
 	UINT16 *srcptr;
 	UINT16 *srcptr2;
@@ -239,7 +235,7 @@ void tecmosys_state::tecmosys_do_final_mix(bitmap_rgb32 &bitmap)
 
 			if (srcptr2[x]&0x3fff)
 			{
-				penvalue2 = m_generic_paletteram_16[srcptr2[x]&0x3fff];
+				penvalue2 = m_palette->basemem().read(srcptr2[x] & 0x3fff);
 				colour2 = paldata[srcptr2[x]&0x3fff];
 			}
 			else
@@ -281,7 +277,7 @@ void tecmosys_state::tecmosys_do_final_mix(bitmap_rgb32 &bitmap)
 
 UINT32 tecmosys_state::screen_update_tecmosys(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
 {
-	bitmap.fill(machine().pens[0x4000], cliprect);
+	bitmap.fill(m_palette->pen(0x4000), cliprect);
 
 
 	m_bg0tilemap->set_scrolly(0, m_c80000regs[1]+16);
@@ -332,15 +328,15 @@ void tecmosys_state::video_start()
 	m_tmp_tilemap_renderbitmap.fill(0x0000);
 
 
-	m_txt_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(tecmosys_state::get_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8,32*2,32*2);
+	m_txt_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(tecmosys_state::get_fg_tile_info),this),TILEMAP_SCAN_ROWS,8,8,32*2,32*2);
 	m_txt_tilemap->set_transparent_pen(0);
 
-	m_bg0tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(tecmosys_state::get_bg0tile_info),this),TILEMAP_SCAN_ROWS,16,16,32,32);
+	m_bg0tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(tecmosys_state::get_bg0tile_info),this),TILEMAP_SCAN_ROWS,16,16,32,32);
 	m_bg0tilemap->set_transparent_pen(0);
 
-	m_bg1tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(tecmosys_state::get_bg1tile_info),this),TILEMAP_SCAN_ROWS,16,16,32,32);
+	m_bg1tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(tecmosys_state::get_bg1tile_info),this),TILEMAP_SCAN_ROWS,16,16,32,32);
 	m_bg1tilemap->set_transparent_pen(0);
 
-	m_bg2tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(tecmosys_state::get_bg2tile_info),this),TILEMAP_SCAN_ROWS,16,16,32,32);
+	m_bg2tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(tecmosys_state::get_bg2tile_info),this),TILEMAP_SCAN_ROWS,16,16,32,32);
 	m_bg2tilemap->set_transparent_pen(0);
 }
