@@ -29,7 +29,7 @@
 
 ***************************************************************************/
 
-void thepit_state::palette_init()
+PALETTE_INIT_MEMBER(thepit_state, thepit)
 {
 	const UINT8 *color_prom = memregion("proms")->base();
 	int i;
@@ -53,13 +53,13 @@ void thepit_state::palette_init()
 		bit2 = (color_prom[i] >> 7) & 0x01;
 		b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 
-		palette_set_color(machine(), i, MAKE_RGB(r, g, b));
+		palette.set_pen_color(i, rgb_t(r, g, b));
 	}
 
 	/* allocate primary colors for the background and foreground
 	   this is wrong, but I don't know where to pick the colors from */
 	for (i = 0; i < 8; i++)
-		palette_set_color_rgb(machine(), i + 32, pal1bit(i >> 2), pal1bit(i >> 1), pal1bit(i >> 0));
+		palette.set_pen_color(i + 32, pal1bit(i >> 2), pal1bit(i >> 1), pal1bit(i >> 0));
 }
 
 
@@ -81,13 +81,13 @@ PALETTE_INIT_MEMBER(thepit_state,suprmous)
 		UINT8 g = BITSWAP8(color_prom[i + 0x20], 0, 1, 2, 3, 4, 5, 6, 7);
 		UINT8 r = (b>>5&7)<<2 | (g>>6&3);
 
-		palette_set_color_rgb(machine(), i, pal5bit(r), pal5bit(g), pal4bit(b));
+		palette.set_pen_color(i, pal5bit(r), pal5bit(g), pal4bit(b));
 	}
 
 	/* allocate primary colors for the background and foreground
 	   this is wrong, but I don't know where to pick the colors from */
 	for (i = 0; i < 8; i++)
-		palette_set_color_rgb(machine(), i + 32, pal1bit(i >> 2), pal1bit(i >> 1), pal1bit(i >> 0));
+		palette.set_pen_color(i + 32, pal1bit(i >> 2), pal1bit(i >> 1), pal1bit(i >> 0));
 }
 
 
@@ -110,7 +110,7 @@ TILE_GET_INFO_MEMBER(thepit_state::solid_get_tile_info)
 
 TILE_GET_INFO_MEMBER(thepit_state::get_tile_info)
 {
-	UINT8 fore_color = m_colorram[tile_index] % machine().gfx[0]->colors();
+	UINT8 fore_color = m_colorram[tile_index] % m_gfxdecode->gfx(0)->colors();
 	UINT8 code = m_videoram[tile_index];
 	SET_TILE_INFO_MEMBER(2 * m_graphics_bank, code, fore_color, 0);
 }
@@ -125,9 +125,9 @@ TILE_GET_INFO_MEMBER(thepit_state::get_tile_info)
 
 void thepit_state::video_start()
 {
-	m_solid_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(thepit_state::solid_get_tile_info),this),TILEMAP_SCAN_ROWS,8,8,32,32);
+	m_solid_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(thepit_state::solid_get_tile_info),this),TILEMAP_SCAN_ROWS,8,8,32,32);
 
-	m_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(thepit_state::get_tile_info),this),TILEMAP_SCAN_ROWS,8,8,32,32);
+	m_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(thepit_state::get_tile_info),this),TILEMAP_SCAN_ROWS,8,8,32,32);
 	m_tilemap->set_transparent_pen(0);
 
 	m_solid_tilemap->set_scroll_cols(32);
@@ -266,14 +266,14 @@ static void draw_sprites(running_machine &machine,
 			/* sprites 0-3 are drawn one pixel down */
 			if (offs < 16) y++;
 
-			drawgfx_transpen(bitmap, cliprect,
-					machine.gfx[2 * state->m_graphics_bank + 1],
+
+					state->m_gfxdecode->gfx(2 * state->m_graphics_bank + 1)->transpen(bitmap,cliprect,
 					state->m_spriteram[offs + 1] & 0x3f,
 					state->m_spriteram[offs + 2],
 					flipx, flipy, x, y, 0);
 
-			drawgfx_transpen(bitmap, cliprect,
-					machine.gfx[2 * state->m_graphics_bank + 1],
+
+					state->m_gfxdecode->gfx(2 * state->m_graphics_bank + 1)->transpen(bitmap,cliprect,
 					state->m_spriteram[offs + 1] & 0x3f,
 					state->m_spriteram[offs + 2],
 					flipx, flipy, x-256, y, 0);
