@@ -9,12 +9,12 @@
 #include "includes/tryout.h"
 
 
-void tryout_state::palette_init()
+PALETTE_INIT_MEMBER(tryout_state, tryout)
 {
 	const UINT8 *color_prom = memregion("proms")->base();
 	int i;
 
-	for (i = 0;i < machine().total_colors();i++)
+	for (i = 0;i < palette.entries();i++)
 	{
 		int bit0,bit1,bit2,r,g,b;
 
@@ -34,7 +34,7 @@ void tryout_state::palette_init()
 		bit2 = (color_prom[i] >> 7) & 0x01;
 		b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 
-		palette_set_color(machine(),i,MAKE_RGB(r,g,b));
+		palette.set_pen_color(i,rgb_t(r,g,b));
 	}
 }
 
@@ -133,7 +133,7 @@ WRITE8_MEMBER(tryout_state::tryout_vram_w)
 		break;
 	}
 
-	machine().gfx[2]->mark_dirty((offset-0x400/64)&0x7f);
+	m_gfxdecode->gfx(2)->mark_dirty((offset-0x400/64)&0x7f);
 }
 
 WRITE8_MEMBER(tryout_state::tryout_vram_bankswitch_w)
@@ -159,19 +159,19 @@ TILEMAP_MAPPER_MEMBER(tryout_state::get_bg_memory_offset)
 //  else
 		a= (7 - (row & 7)) + ((0x8 - (row & 0x8)) << 4) + ((col & 0xf) << 3) + (( (  (col & 0x10) ) ) << 4) + ((( (col & 0x20))) << 4);
 
-//  mame_printf_debug("%d %d -> %d\n",col,row, a);
+//  osd_printf_debug("%d %d -> %d\n",col,row, a);
 	return a;
 }
 
 void tryout_state::video_start()
 {
-	m_fg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(tryout_state::get_fg_tile_info),this),tilemap_mapper_delegate(FUNC(tryout_state::get_fg_memory_offset),this),8,8,32,32);
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(tryout_state::get_bg_tile_info),this),tilemap_mapper_delegate(FUNC(tryout_state::get_bg_memory_offset),this),16,16,64,16);
+	m_fg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(tryout_state::get_fg_tile_info),this),tilemap_mapper_delegate(FUNC(tryout_state::get_fg_memory_offset),this),8,8,32,32);
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(tryout_state::get_bg_tile_info),this),tilemap_mapper_delegate(FUNC(tryout_state::get_bg_memory_offset),this),16,16,64,16);
 
 	m_vram=auto_alloc_array(machine(), UINT8, 8 * 0x800);
 	m_vram_gfx=auto_alloc_array(machine(), UINT8, 0x6000);
 
-	machine().gfx[2]->set_source(m_vram_gfx);
+	m_gfxdecode->gfx(2)->set_source(m_vram_gfx);
 
 	m_fg_tilemap->set_transparent_pen(0);
 }
@@ -209,17 +209,17 @@ void tryout_state::draw_sprites(bitmap_ind16 &bitmap,const rectangle &cliprect)
 		/* Double Height */
 		if(spriteram[offs] & 0x10)
 		{
-			drawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+			m_gfxdecode->gfx(1)->transpen(bitmap,cliprect,
 				sprite,
 				color,fx,fy,x,y + inc,0);
 
-			drawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+			m_gfxdecode->gfx(1)->transpen(bitmap,cliprect,
 				sprite+1,
 				color,fx,fy,x,y,0);
 		}
 		else
 		{
-			drawgfx_transpen(bitmap,cliprect,machine().gfx[1],
+			m_gfxdecode->gfx(1)->transpen(bitmap,cliprect,
 				sprite,
 				color,fx,fy,x,y,0);
 		}
@@ -246,7 +246,7 @@ UINT32 tryout_state::screen_update_tryout(screen_device &screen, bitmap_ind16 &b
 	if(!(m_gfx_control[0] & 0x8)) // screen disable
 	{
 		/* TODO: Color might be different, needs a video from an original pcb. */
-		bitmap.fill(machine().pens[0x10], cliprect);
+		bitmap.fill(m_palette->pen(0x10), cliprect);
 	}
 	else
 	{
