@@ -2,7 +2,7 @@
 #include "includes/usgames.h"
 
 
-void usgames_state::palette_init()
+PALETTE_INIT_MEMBER(usgames_state, usgames)
 {
 	int j;
 
@@ -25,7 +25,7 @@ void usgames_state::palette_init()
 		g = 0x7f * g * (i + 1);
 		b = 0x7f * b * (i + 1);
 
-		palette_set_color(machine(),j,MAKE_RGB(r, g, b));
+		palette.set_pen_color(j,rgb_t(r, g, b));
 	}
 }
 
@@ -43,8 +43,8 @@ TILE_GET_INFO_MEMBER(usgames_state::get_usgames_tile_info)
 
 void usgames_state::video_start()
 {
-	m_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(usgames_state::get_usgames_tile_info),this),TILEMAP_SCAN_ROWS, 8, 8,64,32);
-	machine().gfx[0]->set_source(m_charram);
+	m_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(usgames_state::get_usgames_tile_info),this),TILEMAP_SCAN_ROWS, 8, 8,64,32);
+	m_gfxdecode->gfx(0)->set_source(m_charram);
 }
 
 
@@ -57,7 +57,7 @@ WRITE8_MEMBER(usgames_state::usgames_videoram_w)
 WRITE8_MEMBER(usgames_state::usgames_charram_w)
 {
 	m_charram[offset] = data;
-	machine().gfx[0]->mark_dirty(offset/8);
+	m_gfxdecode->gfx(0)->mark_dirty(offset/8);
 }
 
 
