@@ -10,14 +10,14 @@
 
 static const pen_t pens_from_color_prom[] =
 {
-	RGB_BLACK,
-	MAKE_RGB(0x00, 0xff, 0x00),
-	MAKE_RGB(0x00, 0x00, 0xff),
-	MAKE_RGB(0x00, 0xff, 0xff),
-	MAKE_RGB(0xff, 0x00, 0x00),
-	MAKE_RGB(0xff, 0xff, 0x00),
-	MAKE_RGB(0xff, 0x00, 0xff),
-	RGB_WHITE
+	rgb_t::black,
+	rgb_t(0x00, 0xff, 0x00),
+	rgb_t(0x00, 0x00, 0xff),
+	rgb_t(0x00, 0xff, 0xff),
+	rgb_t(0xff, 0x00, 0x00),
+	rgb_t(0xff, 0xff, 0x00),
+	rgb_t(0xff, 0x00, 0xff),
+	rgb_t::white
 };
 
 
@@ -53,7 +53,7 @@ UINT32 vicdual_state::screen_update_vicdual_bw(screen_device &screen, bitmap_rgb
 		}
 
 		/* plot the current pixel */
-		pen = (video_data & 0x80) ? RGB_WHITE : RGB_BLACK;
+		pen = (video_data & 0x80) ? rgb_t::white : rgb_t::black;
 		bitmap.pix32(y, x) = pen;
 
 		/* next pixel */
