@@ -72,21 +72,20 @@ struct sprite
 
 ***************************************************************************/
 
-static void get_sprite_info(running_machine &machine)
+void wecleman_state::get_sprite_info()
 {
-	wecleman_state *state = machine.driver_data<wecleman_state>();
-	const pen_t *base_pal = machine.pens;
-	UINT8 *base_gfx = state->memregion("gfx1")->base();
-	int gfx_max     = state->memregion("gfx1")->bytes();
+	const pen_t *base_pal = m_palette->pens();
+	UINT8 *base_gfx = memregion("gfx1")->base();
+	int gfx_max     = memregion("gfx1")->bytes();
 
-	UINT16 *source = state->m_spriteram;
+	UINT16 *source = m_spriteram;
 
-	struct sprite *sprite = state->m_sprite_list;
-	struct sprite *finish = state->m_sprite_list + NUM_SPRITES;
+	struct sprite *sprite = m_sprite_list;
+	struct sprite *finish = m_sprite_list + NUM_SPRITES;
 
 	int bank, code, gfx, zoom;
 
-	for (state->m_spr_count=0; sprite<finish; source+=0x10/2, sprite++)
+	for (m_spr_count=0; sprite<finish; source+=0x10/2, sprite++)
 	{
 		if (source[0x00/2] == 0xffff) break;
 
@@ -109,7 +108,7 @@ static void get_sprite_info(running_machine &machine)
 		sprite->pal_base = (source[0x0e/2] & 0xff) << 4;
 		sprite->pal_data = base_pal + sprite->pal_base;
 
-		gfx = (state->m_gfx_bank[bank] << 15) + (code & 0x7fff);
+		gfx = (m_gfx_bank[bank] << 15) + (code & 0x7fff);
 
 		sprite->flags = 0;
 		if (code & 0x8000) { sprite->flags |= SPRITE_FLIPX; gfx += 1-sprite->tile_width; }
@@ -125,22 +124,22 @@ static void get_sprite_info(running_machine &machine)
 		sprite->line_offset = sprite->tile_width;
 		sprite->total_width = sprite->tile_width - (sprite->tile_width * (zoom & 0xff)) / 0x80;
 		sprite->total_height += 1;
-		sprite->x += state->m_spr_offsx;
-		sprite->y += state->m_spr_offsy;
+		sprite->x += m_spr_offsx;
+		sprite->y += m_spr_offsy;
 
-		if (state->m_gameid == 0)
+		if (m_gameid == 0)
 		{
-			state->m_spr_idx_list[state->m_spr_count] = state->m_spr_count;
-			state->m_spr_pri_list[state->m_spr_count] = source[0x0e/2] >> 8;
+			m_spr_idx_list[m_spr_count] = m_spr_count;
+			m_spr_pri_list[m_spr_count] = source[0x0e/2] >> 8;
 		}
 
-		state->m_spr_ptr_list[state->m_spr_count] = sprite;
-		state->m_spr_count++;
+		m_spr_ptr_list[m_spr_count] = sprite;
+		m_spr_count++;
 	}
 }
 
 // priority sorting, silly but good for smaller arrays
-static void sortsprite(int *idx_array, int *key_array, int size)
+void wecleman_state::sortsprite(int *idx_array, int *key_array, int size)
 {
 	int i, j, tgt_val, low_val, low_pos, src_idx, tgt_idx, hi_idx;
 
@@ -169,7 +168,7 @@ static void sortsprite(int *idx_array, int *key_array, int size)
 
 // draws a 8bpp palette sprites on a 16bpp direct RGB target (sub-par implementation)
 template<class _BitmapClass>
-static void do_blit_zoom32(wecleman_state *state, _BitmapClass &bitmap, const rectangle &cliprect, struct sprite *sprite)
+void wecleman_state::do_blit_zoom32(_BitmapClass &bitmap, const rectangle &cliprect, struct sprite *sprite)
 {
 #define PRECISION_X 20
 #define PRECISION_Y 20
@@ -282,7 +281,7 @@ static void do_blit_zoom32(wecleman_state *state, _BitmapClass &bitmap, const re
 						if (pix != 0xa)
 							dst_ptr[sx] = pal_base[pix];
 						else
-							dst_ptr[sx] = (dst_ptr[sx] >> 1) & MAKE_RGB(0x7f,0x7f,0x7f);
+							dst_ptr[sx] = (dst_ptr[sx] >> 1) & rgb_t(0x7f,0x7f,0x7f);
 					}
 					src_fpx += src_fdx;
 				}
@@ -315,7 +314,7 @@ static void do_blit_zoom32(wecleman_state *state, _BitmapClass &bitmap, const re
 							dst_ptr[sx] = base + pix;
 						else
 						{
-							if (dst_ptr[sx] != state->m_black_pen)
+							if (dst_ptr[sx] != m_black_pen)
 								dst_ptr[sx] |= 0x800;
 						}
 					}
@@ -329,20 +328,19 @@ static void do_blit_zoom32(wecleman_state *state, _BitmapClass &bitmap, const re
 }
 
 template<class _BitmapClass>
-static void sprite_draw(running_machine &machine, _BitmapClass &bitmap, const rectangle &cliprect)
+void wecleman_state::sprite_draw(_BitmapClass &bitmap, const rectangle &cliprect)
 {
-	wecleman_state *state = machine.driver_data<wecleman_state>();
 	int i;
 
-	if (state->m_gameid == 0)   // Wec Le Mans
+	if (m_gameid == 0)   // Wec Le Mans
 	{
-		sortsprite(state->m_spr_idx_list, state->m_spr_pri_list, state->m_spr_count);
+		sortsprite(m_spr_idx_list, m_spr_pri_list, m_spr_count);
 
-		for (i=0; i<state->m_spr_count; i++) do_blit_zoom32(state, bitmap, cliprect, state->m_spr_ptr_list[state->m_spr_idx_list[i]]);
+		for (i=0; i<m_spr_count; i++) do_blit_zoom32(bitmap, cliprect, m_spr_ptr_list[m_spr_idx_list[i]]);
 	}
 	else    // Hot Chase
 	{
-		for (i=0; i<state->m_spr_count; i++) do_blit_zoom32(state, bitmap, cliprect, state->m_spr_ptr_list[i]);
+		for (i=0; i<m_spr_count; i++) do_blit_zoom32(bitmap, cliprect, m_spr_ptr_list[i]);
 	}
 }
 
@@ -533,9 +531,8 @@ WRITE16_MEMBER(wecleman_state::wecleman_pageram_w)
 
 ------------------------------------------------------------------------*/
 
-static void wecleman_draw_road(running_machine &machine, bitmap_rgb32 &bitmap, const rectangle &cliprect, int priority)
+void wecleman_state::wecleman_draw_road(bitmap_rgb32 &bitmap, const rectangle &cliprect, int priority)
 {
-	wecleman_state *state = machine.driver_data<wecleman_state>();
 // must be powers of 2
 #define XSIZE 512
 #define YSIZE 256
@@ -565,7 +562,7 @@ static void wecleman_draw_road(running_machine &machine, bitmap_rgb32 &bitmap, c
 	int scrollx, sy, sx;
 	int mdy, tdy, i;
 
-	rgb_ptr = machine.pens;
+	rgb_ptr = m_palette->pens();
 
 	if (priority == 0x02)
 	{
@@ -576,10 +573,10 @@ static void wecleman_draw_road(running_machine &machine, bitmap_rgb32 &bitmap, c
 			UINT32 pix;
 			UINT16 road;
 
-			road = state->m_roadram[sy];
+			road = m_roadram[sy];
 			if ((road>>8) != 0x02) continue;
 
-			pix = rgb_ptr[(state->m_roadram[sy+(YSIZE*2)] & 0xf) + 0x7f0];
+			pix = rgb_ptr[(m_roadram[sy+(YSIZE*2)] & 0xf) + 0x7f0];
 
 			for (sx = 0; sx < DST_WIDTH; sx++)
 				dst[sx] = pix;
@@ -602,24 +599,24 @@ static void wecleman_draw_road(running_machine &machine, bitmap_rgb32 &bitmap, c
 			UINT32 pix;
 			UINT16 road;
 
-			road = state->m_roadram[sy];
+			road = m_roadram[sy];
 			if ((road>>8) != 0x04) continue;
 			road &= YMASK;
 
-			src_ptr = machine.gfx[1]->get_data((road << 3));
-			machine.gfx[1]->get_data((road << 3) + 1);
-			machine.gfx[1]->get_data((road << 3) + 2);
-			machine.gfx[1]->get_data((road << 3) + 3);
-			machine.gfx[1]->get_data((road << 3) + 4);
-			machine.gfx[1]->get_data((road << 3) + 5);
-			machine.gfx[1]->get_data((road << 3) + 6);
-			machine.gfx[1]->get_data((road << 3) + 7);
+			src_ptr = m_gfxdecode->gfx(1)->get_data((road << 3));
+			m_gfxdecode->gfx(1)->get_data((road << 3) + 1);
+			m_gfxdecode->gfx(1)->get_data((road << 3) + 2);
+			m_gfxdecode->gfx(1)->get_data((road << 3) + 3);
+			m_gfxdecode->gfx(1)->get_data((road << 3) + 4);
+			m_gfxdecode->gfx(1)->get_data((road << 3) + 5);
+			m_gfxdecode->gfx(1)->get_data((road << 3) + 6);
+			m_gfxdecode->gfx(1)->get_data((road << 3) + 7);
 			mdy = ((road * MIDCURB_DY) >> 8) * bitmap.rowpixels();
 			tdy = ((road * TOPCURB_DY) >> 8) * bitmap.rowpixels();
 
-			scrollx = state->m_roadram[sy+YSIZE] + (0x18 - 0xe00);
+			scrollx = m_roadram[sy+YSIZE] + (0x18 - 0xe00);
 
-			pal_ptr = road_rgb + ((state->m_roadram[sy+(YSIZE*2)]<<3) & 8);
+			pal_ptr = road_rgb + ((m_roadram[sy+(YSIZE*2)]<<3) & 8);
 
 			for (sx = 0; sx < DST_WIDTH; sx++, scrollx++)
 			{
@@ -651,7 +648,7 @@ static void wecleman_draw_road(running_machine &machine, bitmap_rgb32 &bitmap, c
 ------------------------------------------------------------------------*/
 
 // blends two 8x8x16bpp direct RGB tilemaps
-static void draw_cloud(bitmap_rgb32 &bitmap,
+void wecleman_state::draw_cloud(bitmap_rgb32 &bitmap,
 					gfx_element *gfx,
 					UINT16 *tm_base,
 					int x0, int y0,             // target coordinate
@@ -660,7 +657,6 @@ static void draw_cloud(bitmap_rgb32 &bitmap,
 					int tmw_l2, int tmh_l2,     // tilemap width and height in log(2)
 					int alpha, int pal_offset ) // alpha(0-3f), # of color codes to shift
 {
-	wecleman_state *state = gfx->machine().driver_data<wecleman_state>();
 	const UINT8 *src_ptr;
 	UINT16 *tmap_ptr;
 	UINT32 *dst_base, *dst_ptr;
@@ -689,7 +685,7 @@ static void draw_cloud(bitmap_rgb32 &bitmap,
 
 	dst_base = &bitmap.pix32(y0+dy, x0+dx);
 
-	pal_base = gfx->machine().pens + pal_offset * gfx->granularity();
+	pal_base = m_palette->pens() + pal_offset * gfx->granularity();
 
 	alpha <<= 6;
 
@@ -733,11 +729,11 @@ static void draw_cloud(bitmap_rgb32 &bitmap,
 						dg = (dstrgb >> 11) & 0x1f;
 						db = (dstrgb >> 19) & 0x1f;
 
-						dr = (state->m_t32x32pm[dr - sr + alpha] >> 5) + dr;
-						dg = (state->m_t32x32pm[dg - sg + alpha] >> 5) + dg;
-						db = (state->m_t32x32pm[db - sb + alpha] >> 5) + db;
+						dr = (m_t32x32pm[dr - sr + alpha] >> 5) + dr;
+						dg = (m_t32x32pm[dg - sg + alpha] >> 5) + dg;
+						db = (m_t32x32pm[db - sb + alpha] >> 5) + db;
 
-						dst_ptr[tx] = MAKE_RGB(pal5bit(db), pal5bit(dg), pal5bit(dr));
+						dst_ptr[tx] = rgb_t(pal5bit(db), pal5bit(dg), pal5bit(dr));
 					}
 					dst_ptr += bitmap.rowpixels();
 				}
@@ -786,20 +782,19 @@ static void draw_cloud(bitmap_rgb32 &bitmap,
 
 ------------------------------------------------------------------------*/
 
-static void hotchase_draw_road(running_machine &machine, bitmap_ind16 &bitmap, const rectangle &cliprect)
+void wecleman_state::hotchase_draw_road(bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
-	wecleman_state *state = machine.driver_data<wecleman_state>();
 /* Referred to what's in the ROMs */
 #define XSIZE 512
 #define YSIZE 512
 
 	int sx, sy;
-	const rectangle &visarea = machine.primary_screen->visible_area();
+	const rectangle &visarea = machine().first_screen()->visible_area();
 
 	/* Let's draw from the top to the bottom of the visible screen */
 	for (sy = visarea.min_y;sy <= visarea.max_y;sy++)
 	{
-		int code    = state->m_roadram[sy*4/2+2/2] + (state->m_roadram[sy*4/2+0/2] << 16);
+		int code    = m_roadram[sy*4/2+2/2] + (m_roadram[sy*4/2+0/2] << 16);
 		int color   = ((code & 0x00f00000) >> 20) + 0x70;
 		int scrollx = ((code & 0x0007fc00) >> 10) * 2;
 
@@ -810,7 +805,7 @@ static void hotchase_draw_road(running_machine &machine, bitmap_ind16 &bitmap, c
 
 		for (sx=0; sx<2*XSIZE; sx+=64)
 		{
-			drawgfx_transpen(bitmap,cliprect,machine.gfx[0],
+			m_gfxdecode->gfx(0)->transpen(bitmap,cliprect,
 					code++,
 					color,
 					0,0,
@@ -858,9 +853,9 @@ WRITE16_MEMBER(wecleman_state::hotchase_paletteram16_SBGRBBBBGGGGRRRR_word_w)
 	g = ((newword >> 3) & 0x1E ) | ((newword >> 13) & 0x01);
 	b = ((newword >> 7) & 0x1E ) | ((newword >> 14) & 0x01);
 
-	palette_set_color_rgb(machine(), offset, pal5bit(r), pal5bit(g), pal5bit(b));
+	m_palette->set_pen_color(offset, pal5bit(r), pal5bit(g), pal5bit(b));
 	r>>=1; g>>=1; b>>=1;
-	palette_set_color_rgb(machine(), offset+0x800, pal5bit(r)/2, pal5bit(g)/2, pal5bit(b)/2);
+	m_palette->set_pen_color(offset+0x800, pal5bit(r)/2, pal5bit(g)/2, pal5bit(b)/2);
 }
 
 WRITE16_MEMBER(wecleman_state::wecleman_paletteram16_SSSSBBBBGGGGRRRR_word_w)
@@ -869,7 +864,7 @@ WRITE16_MEMBER(wecleman_state::wecleman_paletteram16_SSSSBBBBGGGGRRRR_word_w)
 
 	// the highest nibble has some unknown functions
 //  if (newword & 0xf000) logerror("MSN set on color %03x: %1x\n", offset, newword>>12);
-	palette_set_color_rgb(machine(), offset, pal4bit(newword >> 0), pal4bit(newword >> 4), pal4bit(newword >> 8));
+	m_palette->set_pen_color(offset, pal4bit(newword >> 0), pal4bit(newword >> 4), pal4bit(newword >> 8));
 }
 
 
@@ -904,7 +899,7 @@ VIDEO_START_MEMBER(wecleman_state,wecleman)
 	m_cloud_blend = BLEND_MAX;
 	m_cloud_ds = 0;
 	m_cloud_visible = 0;
-	m_black_pen = get_black_pen(machine());
+	m_black_pen = m_palette->black_pen();
 
 	m_rgb_half     =          (UINT16*)(buffer + 0x00000);
 	m_t32x32pm     =             (int*)(buffer + 0x10020);
@@ -928,19 +923,19 @@ VIDEO_START_MEMBER(wecleman_state,wecleman)
 
 	m_sprite_list = auto_alloc_array_clear(machine(), struct sprite, NUM_SPRITES);
 
-	m_bg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(wecleman_state::wecleman_get_bg_tile_info),this),
+	m_bg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(wecleman_state::wecleman_get_bg_tile_info),this),
 								TILEMAP_SCAN_ROWS,
 									/* We draw part of the road below */
 								8,8,
 								PAGE_NX * 2, PAGE_NY * 2 );
 
-	m_fg_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(wecleman_state::wecleman_get_fg_tile_info),this),
+	m_fg_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(wecleman_state::wecleman_get_fg_tile_info),this),
 								TILEMAP_SCAN_ROWS,
 
 								8,8,
 								PAGE_NX * 2, PAGE_NY * 2);
 
-	m_txt_tilemap = &machine().tilemap().create(tilemap_get_info_delegate(FUNC(wecleman_state::wecleman_get_txt_tile_info),this),
+	m_txt_tilemap = &machine().tilemap().create(m_gfxdecode, tilemap_get_info_delegate(FUNC(wecleman_state::wecleman_get_txt_tile_info),this),
 									TILEMAP_SCAN_ROWS,
 
 									8,8,
@@ -962,23 +957,23 @@ VIDEO_START_MEMBER(wecleman_state,wecleman)
 	m_txt_tilemap->set_scrolly(0, -BMP_PAD );
 
 	// patches out a mysterious pixel floating in the sky (tile decoding bug?)
-	*const_cast<UINT8 *>(machine().gfx[0]->get_data(0xaca)+7) = 0;
+	*const_cast<UINT8 *>(m_gfxdecode->gfx(0)->get_data(0xaca)+7) = 0;
 }
 
 //  Callbacks for the K051316
 
-void hotchase_zoom_callback_0(running_machine &machine, int *code,int *color,int *flags)
+K051316_CB_MEMBER(wecleman_state::hotchase_zoom_callback_1)
 {
 	*code |= (*color & 0x03) << 8;
 	*color = (*color & 0xfc) >> 2;
 }
 
-void hotchase_zoom_callback_1(running_machine &machine, int *code,int *color,int *flags)
+K051316_CB_MEMBER(wecleman_state::hotchase_zoom_callback_2)
 {
-	*code |= (*color & 0x01) << 8;
 	*color = ((*color & 0x3f) << 1) | ((*code & 0x80) >> 7);
 }
 
+
 VIDEO_START_MEMBER(wecleman_state,hotchase)
 {
 	/*
@@ -1001,7 +996,7 @@ VIDEO_START_MEMBER(wecleman_state,hotchase)
 	m_gfx_bank = bank;
 	m_spr_offsx = -0xc0;
 	m_spr_offsy = 0;
-	m_black_pen = get_black_pen(machine());
+	m_black_pen = m_palette->black_pen();
 
 	m_spr_ptr_list = (struct sprite **)buffer;
 
@@ -1021,7 +1016,7 @@ UINT32 wecleman_state::screen_update_wecleman(screen_device &screen, bitmap_rgb3
 	int cloud_sx, cloud_sy;
 	int i, j, k;
 
-	mrct = machine().pens;
+	mrct = m_palette->pens();
 
 	video_on = m_irqctrl & 0x40;
 
@@ -1053,12 +1048,12 @@ UINT32 wecleman_state::screen_update_wecleman(screen_device &screen, bitmap_rgb3
 	/* palette hacks! */
 	((pen_t *)mrct)[0x27] = mrct[0x24];
 
-	get_sprite_info(machine());
+	get_sprite_info();
 
 	bitmap.fill(m_black_pen, cliprect);
 
 	/* Draw the road (lines which have priority 0x02) */
-	if (video_on) wecleman_draw_road(machine(), bitmap, cliprect, 0x02);
+	if (video_on) wecleman_draw_road(bitmap, cliprect, 0x02);
 
 	/* Draw the background */
 	if (video_on) m_bg_tilemap->draw(screen, bitmap, cliprect, 0, 0);
@@ -1070,9 +1065,8 @@ UINT32 wecleman_state::screen_update_wecleman(screen_device &screen, bitmap_rgb3
 		((pen_t *)mrct)[0] = ((pen_t *)mrct)[0x40] = ((pen_t *)mrct)[0x200] = ((pen_t *)mrct)[0x205];
 
 		if (video_on)
-			draw_cloud(
-			bitmap,
-			machine().gfx[0],
+			draw_cloud(bitmap,
+			m_gfxdecode->gfx(0),
 			m_pageram+0x1800,
 			BMP_PAD, BMP_PAD,
 			41, 20,
@@ -1092,10 +1086,10 @@ UINT32 wecleman_state::screen_update_wecleman(screen_device &screen, bitmap_rgb3
 	if (video_on) m_fg_tilemap->draw(screen, bitmap, cliprect, 0, 0);
 
 	/* Draw the road (lines which have priority 0x04) */
-	if (video_on) wecleman_draw_road(machine(), bitmap,cliprect, 0x04);
+	if (video_on) wecleman_draw_road(bitmap,cliprect, 0x04);
 
 	/* Draw the sprites */
-	if (video_on) sprite_draw(machine(), bitmap,cliprect);
+	if (video_on) sprite_draw(bitmap,cliprect);
 
 	/* Draw the text layer */
 	if (video_on) m_txt_tilemap->draw(screen, bitmap, cliprect, 0, 0);
@@ -1114,7 +1108,7 @@ UINT32 wecleman_state::screen_update_hotchase(screen_device &screen, bitmap_ind1
 
 	set_led_status(machine(), 0, m_selected_ip & 0x04); // Start lamp
 
-	get_sprite_info(machine());
+	get_sprite_info();
 
 	bitmap.fill(m_black_pen, cliprect);
 
@@ -1124,11 +1118,11 @@ UINT32 wecleman_state::screen_update_hotchase(screen_device &screen, bitmap_ind1
 
 	/* Draw the road */
 	if (video_on)
-		hotchase_draw_road(machine(), bitmap, cliprect);
+		hotchase_draw_road(bitmap, cliprect);
 
 	/* Draw the sprites */
 	if (video_on)
-		sprite_draw(machine(), bitmap,cliprect);
+		sprite_draw(bitmap,cliprect);
 
 	/* Draw the foreground (text) */
 	if (video_on)
