@@ -20,7 +20,7 @@ const device_type DAI_SOUND = &device_creator<dai_sound_device>;
 //-------------------------------------------------
 
 dai_sound_device::dai_sound_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: device_t(mconfig, DAI_SOUND, "DAI Custom Sound", tag, owner, clock, "dai_sound", __FILE__),
+	: device_t(mconfig, DAI_SOUND, "DAI Audio Custom", tag, owner, clock, "dai_sound", __FILE__),
 		device_sound_interface(mconfig, *this)
 {
 }
@@ -31,7 +31,7 @@ dai_sound_device::dai_sound_device(const machine_config &mconfig, const char *ta
 
 void dai_sound_device::device_start()
 {
-	m_mixer_channel = machine().sound().stream_alloc(*this, 0, 2, machine().sample_rate(), this);
+	m_mixer_channel = machine().sound().stream_alloc(*this, 0, 2, machine().sample_rate());
 }
 
 //-------------------------------------------------
