@@ -79,7 +79,7 @@ Notes:
 
 #include "includes/abc80.h"
 
-
+#define KEYBOARD_TAG "keyboard"
 
 //**************************************************************************
 //  MACROS / CONSTANTS
@@ -271,7 +271,7 @@ static const sn76477_interface csg_intf =
 
 
 //-------------------------------------------------
-//  Z80PIO_INTERFACE( pio_intf )
+//  Z80PIO
 //-------------------------------------------------
 
 READ8_MEMBER( abc80_state::pio_pa_r )
@@ -322,7 +322,7 @@ READ8_MEMBER( abc80_state::pio_pb_r )
 	UINT8 data = 0;
 
 	// receive data
-	data |= m_rs232->rx();
+	data |= m_rs232->rxd_r();
 
 	// clear to send
 	data |= m_rs232->cts_r() << 1;
@@ -356,10 +356,10 @@ WRITE8_MEMBER( abc80_state::pio_pb_w )
 	*/
 
 	// transmit data
-	m_rs232->tx(BIT(data, 3));
+	m_rs232->write_txd(BIT(data, 3));
 
 	// request to send
-	m_rs232->rts_w(BIT(data, 4));
+	m_rs232->write_rts(BIT(data, 4));
 
 	// cassette motor
 	if (BIT(data, 5))
@@ -387,20 +387,8 @@ WRITE8_MEMBER( abc80_state::pio_pb_w )
 	}
 };
 
-static Z80PIO_INTERFACE( pio_intf )
-{
-	DEVCB_CPU_INPUT_LINE(Z80_TAG, INPUT_LINE_IRQ0), /* callback when change interrupt status */
-	DEVCB_DRIVER_MEMBER(abc80_state, pio_pa_r),     /* port A read callback */
-	DEVCB_NULL,                                     /* port A write callback */
-	DEVCB_NULL,                                     /* portA ready active callback */
-	DEVCB_DRIVER_MEMBER(abc80_state, pio_pb_r),     /* port B read callback */
-	DEVCB_DRIVER_MEMBER(abc80_state, pio_pb_w),     /* port B write callback */
-	DEVCB_NULL                                      /* portB ready active callback */
-};
-
-
 //-------------------------------------------------
-//  Z80PIO_INTERFACE( pio_intf )
+//  Z80 Daisy Chain
 //-------------------------------------------------
 
 static const z80_daisy_config abc80_daisy_chain[] =
@@ -410,20 +398,6 @@ static const z80_daisy_config abc80_daisy_chain[] =
 };
 
 
-//-------------------------------------------------
-//  cassette_interface abc80_cassette_interface
-//-------------------------------------------------
-
-static const cassette_interface abc80_cassette_interface =
-{
-	cassette_default_formats,
-	NULL,
-	(cassette_state)(CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED),
-	NULL,
-	NULL
-};
-
-
 //-------------------------------------------------
 //  ABC80_KEYBOARD_INTERFACE( kb_intf )
 //-------------------------------------------------
@@ -446,13 +420,6 @@ WRITE8_MEMBER( abc80_state::kbd_w )
 	timer_set(attotime::from_msec(50), TIMER_ID_FAKE_KEYBOARD_CLEAR);
 }
 
-static ASCII_KEYBOARD_INTERFACE( keyboard_intf )
-{
-	DEVCB_DRIVER_MEMBER(abc80_state, kbd_w)
-};
-
-
-
 //**************************************************************************
 //  MACHINE INITIALIZATION
 //**************************************************************************
@@ -534,6 +501,11 @@ void abc80_state::machine_start()
 //  MACHINE DRIVERS
 //**************************************************************************
 
+DEVICE_INPUT_DEFAULTS_START( abc830_slow )
+	DEVICE_INPUT_DEFAULTS("SW1", 0x0f, 0x03)
+	DEVICE_INPUT_DEFAULTS("S1", 0x01, 0x01)
+DEVICE_INPUT_DEFAULTS_END
+
 //-------------------------------------------------
 //  MACHINE_CONFIG( abc80 )
 //-------------------------------------------------
@@ -555,13 +527,22 @@ static MACHINE_CONFIG_START( abc80, abc80_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	// devices
-	MCFG_Z80PIO_ADD(Z80PIO_TAG, XTAL_11_9808MHz/2/2, pio_intf)
-	MCFG_CASSETTE_ADD("cassette", abc80_cassette_interface)
-	MCFG_ABC80_KEYBOARD_ADD(WRITELINE(abc80_state, keydown_w))
+	MCFG_DEVICE_ADD(Z80PIO_TAG, Z80PIO, XTAL_11_9808MHz/2/2)
+	MCFG_Z80PIO_OUT_INT_CB(INPUTLINE(Z80_TAG, INPUT_LINE_IRQ0))
+	MCFG_Z80PIO_IN_PA_CB(READ8(abc80_state, pio_pa_r))
+	MCFG_Z80PIO_IN_PB_CB(READ8(abc80_state, pio_pb_r))
+	MCFG_Z80PIO_OUT_PB_CB(WRITE8(abc80_state, pio_pb_w))
+
+	MCFG_CASSETTE_ADD("cassette")
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED)
+
+	MCFG_DEVICE_ADD(ABC80_KEYBOARD_TAG, ABC80_KEYBOARD, 0)
+	MCFG_ABC80_KEYBOARD_KEYDOWN_CALLBACK(WRITELINE(abc80_state, keydown_w))
 	MCFG_ABCBUS_SLOT_ADD(ABCBUS_TAG, abcbus_cards, "slow")
 	MCFG_DEVICE_CARD_DEVICE_INPUT_DEFAULTS("slow", abc830_slow)
 	MCFG_RS232_PORT_ADD(RS232_TAG, default_rs232_devices, NULL)
-	MCFG_ASCII_KEYBOARD_ADD(KEYBOARD_TAG, keyboard_intf)
+	MCFG_DEVICE_ADD(KEYBOARD_TAG, GENERIC_KEYBOARD, 0)
+	MCFG_GENERIC_KEYBOARD_CB(WRITE8(abc80_state, kbd_w))
 
 	// internal ram
 	MCFG_RAM_ADD(RAM_TAG)
