@@ -119,25 +119,6 @@ Some bugs left :
 #define SYSTEM_GX4000 2
 
 
-/* -----------------------------
-   - amstrad_ppi8255_interface -
-   -----------------------------*/
-static I8255_INTERFACE( amstrad_ppi8255_interface )
-{
-	DEVCB_DRIVER_MEMBER(amstrad_state,amstrad_ppi_porta_r), /* port A read */
-	DEVCB_DRIVER_MEMBER(amstrad_state,amstrad_ppi_porta_w), /* port A write */
-	DEVCB_DRIVER_MEMBER(amstrad_state,amstrad_ppi_portb_r), /* port B read */
-	DEVCB_NULL,                         /* port B write */
-	DEVCB_NULL,                         /* port C read */
-	DEVCB_DRIVER_MEMBER(amstrad_state,amstrad_ppi_portc_w)  /* port C write */
-};
-
-DRIVER_INIT_MEMBER(amstrad_state,aleste)
-{
-	m_fdc->setup_intrq_cb(i8272a_device::line_cb(FUNC(amstrad_state::aleste_interrupt), this));
-}
-
-
 /* Memory is banked in 16k blocks. However, the multiface
 pages the memory in 8k blocks! The ROM can
 be paged into bank 0 and bank 3. */
@@ -295,20 +276,20 @@ INPUT_CHANGED_MEMBER(amstrad_state::cpc_monitor_changed)
 {
 	if ( (m_io_green_display->read()) & 0x01 )
 	{
-		PALETTE_INIT_CALL_MEMBER( amstrad_cpc_green );
+		PALETTE_INIT_NAME( amstrad_cpc_green )(m_palette);
 	}
 	else
 	{
-		PALETTE_INIT_CALL_MEMBER( amstrad_cpc );
+		PALETTE_INIT_NAME( amstrad_cpc )(m_palette);
 	}
 }
 
 
 static INPUT_PORTS_START( crtc_links )
 
-/* the following are defined as dipswitches, but are in fact solder links on the
- * curcuit board. The links are open or closed when the PCB is made, and are set depending on which country
- * the Amstrad system was to go to (reference: http://amstrad.cpc.free.fr/article.php?sid=26)
+/* the following are solder links on the circuit board. The links are open or closed when the
+ * PCB is made, and are set depending on which country the Amstrad system was to go to
+ * (reference: http://amstrad.cpc.free.fr/article.php?sid=26)
 
 lk1 lk2 lk3 Manufacturer Name (CPC and CPC+ only):
 
@@ -326,21 +307,18 @@ lk4     Frequency
 1       50 Hz
 */
 	PORT_START("solder_links")
-	PORT_DIPNAME(0x07, 0x07, "Manufacturer Name")
-	PORT_DIPLOCATION("LK:3,2,1")
-	PORT_DIPSETTING(0x00, "Isp")
-	PORT_DIPSETTING(0x01, "Triumph")
-	PORT_DIPSETTING(0x02, "Saisho")
-	PORT_DIPSETTING(0x03, "Solavox")
-	PORT_DIPSETTING(0x04, "Awa")
-	PORT_DIPSETTING(0x05, "Schneider")
-	PORT_DIPSETTING(0x06, "Orion")
-	PORT_DIPSETTING(0x07, "Amstrad")
-
-	PORT_DIPNAME(0x10, 0x10, "TV Refresh Rate")
-	PORT_DIPLOCATION("LK:4")
-	PORT_DIPSETTING(0x00, "60 Hz")
-	PORT_DIPSETTING(0x10, "50 Hz")
+	PORT_CONFNAME(0x07, 0x07, "Manufacturer Name")
+	PORT_CONFSETTING(0x00, "Isp")
+	PORT_CONFSETTING(0x01, "Triumph")
+	PORT_CONFSETTING(0x02, "Saisho")
+	PORT_CONFSETTING(0x03, "Solavox")
+	PORT_CONFSETTING(0x04, "Awa")
+	PORT_CONFSETTING(0x05, "Schneider")
+	PORT_CONFSETTING(0x06, "Orion")
+	PORT_CONFSETTING(0x07, "Amstrad")
+	PORT_CONFNAME(0x10, 0x10, "TV Refresh Rate")
+	PORT_CONFSETTING(0x00, "60 Hz")
+	PORT_CONFSETTING(0x10, "50 Hz")
 
 /* Part number Manufacturer Type number
    UM6845      UMC          0
@@ -367,10 +345,30 @@ As far as I know, the KC compact used HD6845S only.
 
 INPUT_PORTS_END
 
+static INPUT_PORTS_START( amx_mouse )
+	PORT_START("mouse_input1")
+	PORT_BIT(0xff , 0, IPT_MOUSE_X) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(1) PORT_CONDITION("controller_type", 0x01, EQUALS, 0x01)
+
+	PORT_START("mouse_input2")
+	PORT_BIT(0xff , 0, IPT_MOUSE_Y) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(1) PORT_CONDITION("controller_type", 0x01, EQUALS, 0x01)
+
+	PORT_START("mouse_input3")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_BUTTON4) PORT_NAME("Left mouse button") PORT_CODE(MOUSECODE_BUTTON1) PORT_CONDITION("controller_type", 0x01, EQUALS, 0x01)
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_BUTTON5) PORT_NAME("Right mouse button") PORT_CODE(MOUSECODE_BUTTON2) PORT_CONDITION("controller_type", 0x01, EQUALS, 0x01)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_BUTTON6) PORT_NAME("Middle mouse button") PORT_CODE(MOUSECODE_BUTTON3) PORT_CONDITION("controller_type", 0x01, EQUALS, 0x01)
+
+	PORT_START("controller_type")
+	PORT_CONFNAME( 0x03, 0x00, "Joystick port device" )
+	PORT_CONFSETTING(0x00, "2-button Joystick" )
+	PORT_CONFSETTING(0x01, "AMX mouse interface" )
+	PORT_CONFSETTING(0x02, "Nothing" )
+
+INPUT_PORTS_END
 
 static INPUT_PORTS_START( cpc464 )
 	PORT_INCLUDE(amstrad_keyboard)
 	PORT_INCLUDE(crtc_links)
+	PORT_INCLUDE(amx_mouse)
 INPUT_PORTS_END
 
 
@@ -396,6 +394,7 @@ static INPUT_PORTS_START( cpc664 )
 	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Keypad f4")             PORT_CODE(KEYCODE_4_PAD)      PORT_CHAR(UCHAR_MAMEKEY(4_PAD))
 
 	PORT_INCLUDE(crtc_links)
+	PORT_INCLUDE(amx_mouse)
 INPUT_PORTS_END
 
 
@@ -427,6 +426,7 @@ static INPUT_PORTS_START( cpc6128 )
 	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Control")               PORT_CODE(KEYCODE_LCONTROL)   PORT_CHAR(UCHAR_SHIFT_2)
 
 	PORT_INCLUDE(crtc_links)
+	PORT_INCLUDE(amx_mouse)
 INPUT_PORTS_END
 
 
@@ -494,6 +494,7 @@ static INPUT_PORTS_START( cpc6128f )
 	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD)                                    PORT_CODE(KEYCODE_Z)          PORT_CHAR('w') PORT_CHAR('W')
 
 	PORT_INCLUDE(crtc_links)
+	PORT_INCLUDE(amx_mouse)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( cpc6128s )
@@ -551,12 +552,14 @@ static INPUT_PORTS_START( kccomp )
 	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Control")               PORT_CODE(KEYCODE_LALT)       PORT_CHAR(UCHAR_SHIFT_2)
 
 	PORT_INCLUDE(crtc_links)
+	PORT_INCLUDE(amx_mouse)
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( plus )
 	PORT_INCLUDE(amstrad_keyboard)
 	PORT_INCLUDE(crtc_links)
+	PORT_INCLUDE(amx_mouse)
 
 	/* The CPC+ and GX4000 adds support for analogue controllers.
 	   Up to two joysticks or four paddles can be used, although the ASIC supports twice that.
@@ -738,22 +741,11 @@ static INPUT_PORTS_START( aleste )
 	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD)  PORT_NAME("Funny looking Russian symbol")     PORT_CODE(KEYCODE_END)
 
 	PORT_INCLUDE(crtc_links)
+	PORT_INCLUDE(amx_mouse)
 INPUT_PORTS_END
 
 
-/* --------------------
-   - ay8910_interface -
-   --------------------*/
-static const ay8910_interface ay8912_interface =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_DRIVER_MEMBER(amstrad_state, amstrad_psg_porta_read), /* portA read */
-	DEVCB_DRIVER_MEMBER(amstrad_state, amstrad_psg_porta_read), /* portB read */
-	DEVCB_NULL,                 /* portA write */
-	DEVCB_NULL                  /* portB write */
-};
-
+#if 0
 
 static const gfx_layout asic_sprite_layout =
 {
@@ -769,6 +761,7 @@ static const gfx_layout asic_sprite_layout =
 static GFXDECODE_START( asic_sprite )
 	GFXDECODE_ENTRY( "user1", 0, asic_sprite_layout, 32, 1 )
 GFXDECODE_END
+#endif
 
 
 
@@ -797,15 +790,6 @@ speed of 3.8 MHz */
  */
 
 
-static const cassette_interface amstrad_cassette_interface =
-{
-	cdt_cassette_formats,
-	NULL,
-	(cassette_state) (CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_ENABLED),
-	"cpc_cass",
-	NULL
-};
-
 static SLOT_INTERFACE_START( amstrad_floppies )
 	SLOT_INTERFACE( "3ssdd", FLOPPY_3_SSDD )
 SLOT_INTERFACE_END
@@ -814,15 +798,6 @@ static SLOT_INTERFACE_START( aleste_floppies )
 	SLOT_INTERFACE( "525hd", FLOPPY_525_HD )
 SLOT_INTERFACE_END
 
-CPC_EXPANSION_INTERFACE(cpc_exp_intf)
-{
-	DEVCB_CPU_INPUT_LINE("maincpu", 0),
-	DEVCB_CPU_INPUT_LINE("maincpu", INPUT_LINE_NMI),
-	DEVCB_NULL,  // RESET
-	DEVCB_LINE(cpc_romdis),  // ROMDIS
-	DEVCB_LINE(cpc_romen)  // /ROMEN
-};
-
 static MACHINE_CONFIG_FRAGMENT( cpcplus_cartslot )
 	MCFG_CARTSLOT_ADD("cart")
 	MCFG_CARTSLOT_EXTENSION_LIST("cpr,bin")
@@ -837,12 +812,18 @@ SLOT_INTERFACE_START(cpc_exp_cards)
 	SLOT_INTERFACE("dkspeech", CPC_DKSPEECH)
 	SLOT_INTERFACE("rom", CPC_ROM)
 	SLOT_INTERFACE("multiface2", CPC_MFACE2)
+	SLOT_INTERFACE("pds", CPC_PDS)
+	SLOT_INTERFACE("rs232", CPC_RS232)
+	SLOT_INTERFACE("amsrs232", CPC_RS232_AMS)
 SLOT_INTERFACE_END
 
 SLOT_INTERFACE_START(cpcplus_exp_cards)
 	SLOT_INTERFACE("ssa1", CPC_SSA1)
 	SLOT_INTERFACE("dkspeech", CPC_DKSPEECH)
 	SLOT_INTERFACE("rom", CPC_ROM)
+	SLOT_INTERFACE("pds", CPC_PDS)
+	SLOT_INTERFACE("rs232", CPC_RS232)
+	SLOT_INTERFACE("amsrs232", CPC_RS232_AMS)
 SLOT_INTERFACE_END
 
 static MACHINE_CONFIG_START( amstrad_nofdc, amstrad_state )
@@ -850,26 +831,36 @@ static MACHINE_CONFIG_START( amstrad_nofdc, amstrad_state )
 	MCFG_CPU_ADD("maincpu", Z80, XTAL_16MHz / 4)
 	MCFG_CPU_PROGRAM_MAP(amstrad_mem)
 	MCFG_CPU_IO_MAP(amstrad_io)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(amstrad_state,amstrad_cpu_acknowledge_int)
 
 	MCFG_QUANTUM_TIME(attotime::from_hz(60))
 
 	MCFG_MACHINE_START_OVERRIDE(amstrad_state, amstrad )
 	MCFG_MACHINE_RESET_OVERRIDE(amstrad_state, amstrad )
 
-	MCFG_I8255_ADD( "ppi8255", amstrad_ppi8255_interface )
+	MCFG_DEVICE_ADD("ppi8255", I8255, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(amstrad_state, amstrad_ppi_porta_r))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(amstrad_state, amstrad_ppi_porta_w))
+	MCFG_I8255_IN_PORTB_CB(READ8(amstrad_state, amstrad_ppi_portb_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(amstrad_state, amstrad_ppi_portc_w))
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS( XTAL_16MHz, 1024, 32, 32 + 640 + 64, 312, 56 + 15, 200 + 15 )
 	MCFG_SCREEN_UPDATE_DRIVER(amstrad_state, screen_update_amstrad)
 	MCFG_SCREEN_VBLANK_DRIVER(amstrad_state, screen_eof_amstrad)
+	MCFG_SCREEN_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
+	MCFG_PALETTE_ADD("palette", 32)
+	MCFG_PALETTE_INIT_OWNER(amstrad_state,amstrad_cpc)
 
-	MCFG_PALETTE_LENGTH(32)
-	MCFG_PALETTE_INIT_OVERRIDE(amstrad_state,amstrad_cpc)
-
-	MCFG_MC6845_ADD( "mc6845", MC6845, NULL, XTAL_16MHz / 16, amstrad_mc6845_intf )
+	MCFG_MC6845_ADD("mc6845", MC6845, NULL, XTAL_16MHz / 16)
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(16)
+	MCFG_MC6845_OUT_DE_CB(WRITELINE(amstrad_state, amstrad_de_changed))
+	MCFG_MC6845_OUT_HSYNC_CB(WRITELINE(amstrad_state, amstrad_hsync_changed))
+	MCFG_MC6845_OUT_VSYNC_CB(WRITELINE(amstrad_state, amstrad_vsync_changed))
 
 	MCFG_VIDEO_START_OVERRIDE(amstrad_state,amstrad)
 
@@ -878,19 +869,29 @@ static MACHINE_CONFIG_START( amstrad_nofdc, amstrad_state )
 	MCFG_SOUND_WAVE_ADD(WAVE_TAG, "cassette")
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 	MCFG_SOUND_ADD("ay", AY8912, XTAL_16MHz / 16)
-	MCFG_SOUND_CONFIG(ay8912_interface)
+	MCFG_AY8910_PORT_A_READ_CB(READ8(amstrad_state, amstrad_psg_porta_read)) /* portA read */
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	/* printer */
-	MCFG_CENTRONICS_PRINTER_ADD("centronics", standard_centronics)
+	MCFG_CENTRONICS_ADD("centronics", centronics_printers, "printer")
+	MCFG_CENTRONICS_BUSY_HANDLER(WRITELINE(amstrad_state, write_centronics_busy))
 
 	/* snapshot */
 	MCFG_SNAPSHOT_ADD("snapshot", amstrad_state, amstrad, "sna", 0)
 
-	MCFG_CASSETTE_ADD( "cassette", amstrad_cassette_interface )
+	MCFG_CASSETTE_ADD( "cassette" )
+	MCFG_CASSETTE_FORMATS(cdt_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_ENABLED)
+	MCFG_CASSETTE_INTERFACE("cpc_cass")
+
 	MCFG_SOFTWARE_LIST_ADD("cass_list","cpc_cass")
 
-	MCFG_CPC_EXPANSION_SLOT_ADD("exp",cpc_exp_intf,cpc_exp_cards,NULL)
+	MCFG_DEVICE_ADD("exp", CPC_EXPANSION_SLOT, 0)
+	MCFG_DEVICE_SLOT_INTERFACE(cpc_exp_cards, NULL, false)
+	MCFG_CPC_EXPANSION_SLOT_OUT_IRQ_CB(INPUTLINE("maincpu", 0))
+	MCFG_CPC_EXPANSION_SLOT_OUT_NMI_CB(INPUTLINE("maincpu", INPUT_LINE_NMI))
+	MCFG_CPC_EXPANSION_SLOT_OUT_ROMDIS_CB(WRITELINE(amstrad_state, cpc_romdis))  // ROMDIS
+	MCFG_CPC_EXPANSION_SLOT_OUT_ROMEN_CB(WRITELINE(amstrad_state, cpc_romen))  // /ROMEN
 
 	/* internal ram */
 	MCFG_RAM_ADD(RAM_TAG)
@@ -915,7 +916,8 @@ static MACHINE_CONFIG_DERIVED( kccomp, amstrad )
 	MCFG_MACHINE_START_OVERRIDE(amstrad_state,kccomp)
 	MCFG_MACHINE_RESET_OVERRIDE(amstrad_state,kccomp)
 
-	MCFG_PALETTE_INIT_OVERRIDE(amstrad_state,kccomp)
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_INIT_OWNER(amstrad_state,kccomp)
 MACHINE_CONFIG_END
 
 
@@ -924,26 +926,36 @@ static MACHINE_CONFIG_START( cpcplus, amstrad_state )
 	MCFG_CPU_ADD("maincpu", Z80, XTAL_40MHz / 10)
 	MCFG_CPU_PROGRAM_MAP(amstrad_mem)
 	MCFG_CPU_IO_MAP(amstrad_io)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(amstrad_state,amstrad_cpu_acknowledge_int)
 
 	MCFG_QUANTUM_TIME(attotime::from_hz(60))
 
 	MCFG_MACHINE_START_OVERRIDE(amstrad_state, plus )
 	MCFG_MACHINE_RESET_OVERRIDE(amstrad_state, plus )
 
-	MCFG_I8255_ADD( "ppi8255", amstrad_ppi8255_interface )
+	MCFG_DEVICE_ADD("ppi8255", I8255, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(amstrad_state, amstrad_ppi_porta_r))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(amstrad_state, amstrad_ppi_porta_w))
+	MCFG_I8255_IN_PORTB_CB(READ8(amstrad_state, amstrad_ppi_portb_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(amstrad_state, amstrad_ppi_portc_w))
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS( ( XTAL_40MHz * 2 ) / 5, 1024, 32, 32 + 640 + 64, 312, 56 + 15, 200 + 15 )
 	MCFG_SCREEN_UPDATE_DRIVER(amstrad_state, screen_update_amstrad)
 	MCFG_SCREEN_VBLANK_DRIVER(amstrad_state, screen_eof_amstrad)
+	MCFG_SCREEN_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
+	MCFG_PALETTE_ADD("palette", 4096)
+	MCFG_PALETTE_INIT_OWNER(amstrad_state,amstrad_plus)
 
-	MCFG_PALETTE_LENGTH(4096)
-	MCFG_PALETTE_INIT_OVERRIDE(amstrad_state,amstrad_plus)
-
-	MCFG_MC6845_ADD( "mc6845", MC6845, NULL, XTAL_40MHz / 40, amstrad_plus_mc6845_intf )
+	MCFG_MC6845_ADD("mc6845", MC6845, NULL, XTAL_40MHz / 40)
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(16)
+	MCFG_MC6845_OUT_DE_CB(WRITELINE(amstrad_state, amstrad_plus_de_changed))
+	MCFG_MC6845_OUT_HSYNC_CB(WRITELINE(amstrad_state, amstrad_plus_hsync_changed))
+	MCFG_MC6845_OUT_VSYNC_CB(WRITELINE(amstrad_state, amstrad_plus_vsync_changed))
 
 	MCFG_VIDEO_START_OVERRIDE(amstrad_state,amstrad)
 
@@ -952,16 +964,20 @@ static MACHINE_CONFIG_START( cpcplus, amstrad_state )
 	MCFG_SOUND_WAVE_ADD(WAVE_TAG, "cassette")
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 	MCFG_SOUND_ADD("ay", AY8912, XTAL_40MHz / 40)
-	MCFG_SOUND_CONFIG(ay8912_interface)
+	MCFG_AY8910_PORT_A_READ_CB(READ8(amstrad_state, amstrad_psg_porta_read)) /* portA read */
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	/* printer */
-	MCFG_CENTRONICS_PRINTER_ADD("centronics", standard_centronics)
+	MCFG_CENTRONICS_ADD("centronics", centronics_printers, "printer")
+	MCFG_CENTRONICS_BUSY_HANDLER(WRITELINE(amstrad_state, write_centronics_busy))
 
 	/* snapshot */
 	MCFG_SNAPSHOT_ADD("snapshot", amstrad_state, amstrad, "sna", 0)
 
-	MCFG_CASSETTE_ADD( "cassette", amstrad_cassette_interface )
+	MCFG_CASSETTE_ADD( "cassette" )
+	MCFG_CASSETTE_FORMATS(cdt_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_ENABLED)
+	MCFG_CASSETTE_INTERFACE("cpc_cass")
 
 	MCFG_UPD765A_ADD("upd765", true, true)
 
@@ -970,7 +986,12 @@ static MACHINE_CONFIG_START( cpcplus, amstrad_state )
 	MCFG_FLOPPY_DRIVE_ADD("upd765:0", amstrad_floppies, "3ssdd", amstrad_state::floppy_formats)
 	MCFG_FLOPPY_DRIVE_ADD("upd765:1", amstrad_floppies, "3ssdd", amstrad_state::floppy_formats)
 
-	MCFG_CPC_EXPANSION_SLOT_ADD("exp",cpc_exp_intf,cpc_exp_cards,NULL)
+	MCFG_DEVICE_ADD("exp", CPC_EXPANSION_SLOT, 0)
+	MCFG_DEVICE_SLOT_INTERFACE(cpc_exp_cards, NULL, false)
+	MCFG_CPC_EXPANSION_SLOT_OUT_IRQ_CB(INPUTLINE("maincpu", 0))
+	MCFG_CPC_EXPANSION_SLOT_OUT_NMI_CB(INPUTLINE("maincpu", INPUT_LINE_NMI))
+	MCFG_CPC_EXPANSION_SLOT_OUT_ROMDIS_CB(WRITELINE(amstrad_state, cpc_romdis))  // ROMDIS
+	MCFG_CPC_EXPANSION_SLOT_OUT_ROMEN_CB(WRITELINE(amstrad_state, cpc_romen))  // /ROMEN
 
 	/* internal ram */
 	MCFG_RAM_ADD(RAM_TAG)
@@ -983,33 +1004,43 @@ static MACHINE_CONFIG_START( gx4000, amstrad_state )
 	MCFG_CPU_ADD("maincpu", Z80, XTAL_40MHz / 10)
 	MCFG_CPU_PROGRAM_MAP(amstrad_mem)
 	MCFG_CPU_IO_MAP(amstrad_io)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(amstrad_state,amstrad_cpu_acknowledge_int)
 
 	MCFG_QUANTUM_TIME(attotime::from_hz(60))
 
 	MCFG_MACHINE_START_OVERRIDE(amstrad_state, gx4000 )
 	MCFG_MACHINE_RESET_OVERRIDE(amstrad_state, gx4000 )
 
-	MCFG_I8255_ADD( "ppi8255", amstrad_ppi8255_interface )
+	MCFG_DEVICE_ADD("ppi8255", I8255, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(amstrad_state, amstrad_ppi_porta_r))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(amstrad_state, amstrad_ppi_porta_w))
+	MCFG_I8255_IN_PORTB_CB(READ8(amstrad_state, amstrad_ppi_portb_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(amstrad_state, amstrad_ppi_portc_w))
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS( ( XTAL_40MHz * 2 ) / 5, 1024, 32, 32 + 640 + 64, 312, 56 + 15, 200 + 15 )
 	MCFG_SCREEN_UPDATE_DRIVER(amstrad_state, screen_update_amstrad)
 	MCFG_SCREEN_VBLANK_DRIVER(amstrad_state, screen_eof_amstrad)
+	MCFG_SCREEN_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
+	MCFG_PALETTE_ADD("palette", 4096)
+	MCFG_PALETTE_INIT_OWNER(amstrad_state,amstrad_plus)
 
-	MCFG_PALETTE_LENGTH(4096)
-	MCFG_PALETTE_INIT_OVERRIDE(amstrad_state,amstrad_plus)
-
-	MCFG_MC6845_ADD( "mc6845", MC6845, NULL, XTAL_40MHz / 40, amstrad_plus_mc6845_intf )
+	MCFG_MC6845_ADD("mc6845", MC6845, NULL, XTAL_40MHz / 40)
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(16)
+	MCFG_MC6845_OUT_DE_CB(WRITELINE(amstrad_state, amstrad_plus_de_changed))
+	MCFG_MC6845_OUT_HSYNC_CB(WRITELINE(amstrad_state, amstrad_plus_hsync_changed))
+	MCFG_MC6845_OUT_VSYNC_CB(WRITELINE(amstrad_state, amstrad_plus_vsync_changed))
 
 	MCFG_VIDEO_START_OVERRIDE(amstrad_state,amstrad)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD("ay", AY8912, XTAL_40MHz / 40)
-	MCFG_SOUND_CONFIG(ay8912_interface)
+	MCFG_AY8910_PORT_A_READ_CB(READ8(amstrad_state, amstrad_psg_porta_read)) /* portA read */
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	MCFG_FRAGMENT_ADD(cpcplus_cartslot)
@@ -1025,10 +1056,12 @@ static MACHINE_CONFIG_DERIVED( aleste, amstrad )
 	MCFG_MACHINE_RESET_OVERRIDE(amstrad_state,aleste)
 
 	MCFG_SOUND_REPLACE("ay", AY8912, XTAL_16MHz / 16)
-	MCFG_SOUND_CONFIG(ay8912_interface)
+	MCFG_AY8910_PORT_A_READ_CB(READ8(amstrad_state, amstrad_psg_porta_read)) /* portA read */
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
-	MCFG_PALETTE_LENGTH(32+64)
-	MCFG_PALETTE_INIT_OVERRIDE(amstrad_state,aleste)
+
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_ENTRIES(32+64)
+	MCFG_PALETTE_INIT_OWNER(amstrad_state,aleste)
 	MCFG_MC146818_ADD( "rtc", XTAL_4_194304Mhz )
 
 	MCFG_DEVICE_REMOVE("upd765")
@@ -1103,9 +1136,10 @@ ROM_END
 
 
 ROM_START( kccomp )
-	ROM_REGION(0x018000, "maincpu", 0)
+	ROM_REGION(0x01c000, "maincpu", 0)
 	ROM_LOAD("kccos.rom",  0x10000, 0x4000, CRC(7f9ab3f7) SHA1(f828045e98e767f737fd93df0af03917f936ad08))
 	ROM_LOAD("kccbas.rom", 0x14000, 0x4000, CRC(ca6af63d) SHA1(d7d03755099d0aff501fa5fffc9c0b14c0825448))
+	ROM_RELOAD(0x18000, 0x4000)  // has no AMSDOS ROM, so just reload BASIC in it's place (BASIC appears in any unused ROM slot)
 
 	ROM_REGION(0x018000+0x0800, "proms", 0)
 	ROM_LOAD("farben.rom", 0x18000, 0x0800, CRC(a50fa3cf) SHA1(2f229ac9f62d56973139dad9992c208421bc0f51))
@@ -1121,7 +1155,6 @@ ROM_START(cpc6128p)
 	ROM_REGION(0x04000, "user1", ROMREGION_ERASEFF)
 ROM_END
 
-
 #define rom_cpc464p  rom_cpc6128p
 #define rom_gx4000  rom_cpc6128p
 
@@ -1162,4 +1195,4 @@ COMP( 1990, cpc464p,  0,        0,      cpcplus, plus, driver_device,     0,
 COMP( 1990, cpc6128p, 0,        0,      cpcplus, plus, driver_device,     0,       "Amstrad plc",         "Amstrad CPC6128+",                          0 )
 CONS( 1990, gx4000,   0,        0,      gx4000,  gx4000, driver_device,   0,       "Amstrad plc",         "Amstrad GX4000",                            0 )
 COMP( 1989, kccomp,   cpc464,   0,      kccomp,  kccomp, driver_device,   0,       "VEB Mikroelektronik", "KC Compact",                                0 )
-COMP( 1993, al520ex,  cpc464,   0,      aleste,  aleste, amstrad_state,   aleste,  "Patisonic",           "Aleste 520EX",                              GAME_IMPERFECT_SOUND )
+COMP( 1993, al520ex,  cpc464,   0,      aleste,  aleste, driver_device,   0,       "Patisonic",           "Aleste 520EX",                              GAME_IMPERFECT_SOUND )
