@@ -61,6 +61,7 @@ public:
 		m_crtc(*this, "crtc"),
 		m_via(*this, "via6522"),
 		m_centronics(*this, "centronics"),
+		m_cent_data_out(*this, "cent_data_out"),
 		m_fdc(*this, "fdc"),
 		m_floppy0(*this, "fdc:0"),
 		m_floppy1(*this, "fdc:1"),
@@ -91,14 +92,14 @@ public:
 		m_io_k3a0(*this, "K3a_0"),
 		m_io_k3b0(*this, "K3b_0"),
 		m_io_k0b(*this, "K0b"),
-		m_expansion(*this, "expansion"){ }
+		m_expansion(*this, "expansion"),
+		m_palette(*this, "palette"){ }
 
 	DECLARE_READ16_MEMBER(applix_inputs_r);
 	DECLARE_WRITE16_MEMBER(palette_w);
 	DECLARE_WRITE16_MEMBER(analog_latch_w);
 	DECLARE_WRITE16_MEMBER(dac_latch_w);
 	DECLARE_WRITE16_MEMBER(video_latch_w);
-	DECLARE_READ8_MEMBER(applix_pa_r);
 	DECLARE_READ8_MEMBER(applix_pb_r);
 	DECLARE_WRITE8_MEMBER(applix_pa_w);
 	DECLARE_WRITE8_MEMBER(applix_pb_w);
@@ -131,11 +132,12 @@ public:
 	DECLARE_WRITE8_MEMBER( p3_write );
 	TIMER_DEVICE_CALLBACK_MEMBER(cass_timer);
 	DECLARE_DRIVER_INIT(applix);
+	MC6845_UPDATE_ROW(crtc_update_row);
 	UINT8 m_video_latch;
 	UINT8 m_pa;
 	virtual void machine_reset();
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(applix);
 	UINT8 m_palette_latch[4];
 	required_shared_ptr<UINT16> m_base;
 private:
@@ -157,10 +159,12 @@ private:
 	UINT8   m_p3;
 	UINT16  m_last_write_addr;
 	UINT8 m_cass_data[4];
+	int m_centronics_busy;
 	required_device<cpu_device> m_maincpu;
 	required_device<mc6845_device> m_crtc;
 	required_device<via6522_device> m_via;
 	required_device<centronics_device> m_centronics;
+	required_device<output_latch_device> m_cent_data_out;
 	required_device<wd1772_t> m_fdc;
 	required_device<floppy_connector> m_floppy0;
 	required_device<floppy_connector> m_floppy1;
@@ -192,6 +196,8 @@ private:
 	required_ioport m_io_k3b0;
 	required_ioport m_io_k0b;
 	required_shared_ptr<UINT16> m_expansion;
+public:
+	required_device<palette_device> m_palette;
 };
 
 /*
@@ -229,7 +235,9 @@ WRITE16_MEMBER( applix_state::palette_w )
 {
 	offset >>= 4;
 	if (ACCESSING_BITS_0_7)
-		m_centronics->write(space, 0, data);
+	{
+		m_cent_data_out->write(space, 0, data);
+	}
 	else
 		m_palette_latch[offset] = (data >> 8) & 15;
 }
@@ -251,11 +259,6 @@ READ16_MEMBER( applix_state::applix_inputs_r )
 	return m_io_dsw->read() | m_cass_data[2];
 }
 
-READ8_MEMBER( applix_state::applix_pa_r )
-{
-	return (m_pa & 0xfe) | m_centronics->busy_r();
-}
-
 READ8_MEMBER( applix_state::applix_pb_r )
 {
 	return m_pb;
@@ -293,7 +296,7 @@ WRITE8_MEMBER( applix_state::applix_pa_w )
 	if (!BIT(m_pa, 2) && BIT(data, 2))
 		m_maincpu->set_input_line(M68K_IRQ_4, CLEAR_LINE);
 
-	m_centronics->strobe_w(BIT(data, 1));
+	m_centronics->write_strobe(BIT(data, 1));
 
 	m_pa = data;
 }
@@ -704,7 +707,7 @@ static INPUT_PORTS_START( applix )
 	PORT_DIPNAME( 0x40, 0x00, "Switch 2") PORT_DIPLOCATION("SW2:3")
 	PORT_DIPSETTING(    0x40, DEF_STR(Off))
 	PORT_DIPSETTING(    0x00, DEF_STR(On))
-	PORT_DIPNAME( 0x80, 0x00, "Switch 3") PORT_DIPLOCATION("SW2:4")
+	PORT_DIPNAME( 0x80, 0x80, "Switch 3") PORT_DIPLOCATION("SW2:4")
 	PORT_DIPSETTING(    0x80, DEF_STR(Off))
 	PORT_DIPSETTING(    0x00, DEF_STR(On))
 
@@ -735,7 +738,7 @@ static SLOT_INTERFACE_START( applix_floppies )
 SLOT_INTERFACE_END
 
 
-void applix_state::palette_init()
+PALETTE_INIT_MEMBER(applix_state, applix)
 { // shades need to be verified - the names on the right are from the manual
 	const UINT8 colors[16*3] = {
 	0x00, 0x00, 0x00,   //  0 Black
@@ -760,7 +763,7 @@ void applix_state::palette_init()
 	for (i = 0; i < 48; color_count++)
 	{
 		r = colors[i++]; g = colors[i++]; b = colors[i++];
-		palette_set_color(machine(), color_count, MAKE_RGB(r, g, b));
+		palette.set_pen_color(color_count, rgb_t(r, g, b));
 	}
 }
 
@@ -769,28 +772,27 @@ void applix_state::video_start()
 {
 }
 
-static MC6845_UPDATE_ROW( applix_update_row )
+MC6845_UPDATE_ROW( applix_state::crtc_update_row )
 {
 // The display is bitmapped. 2 modes are supported here, 320x200x16 and 640x200x4.
 // Need to display a border colour.
 // There is a monochrome mode, but no info found as yet.
-	applix_state *state = device->machine().driver_data<applix_state>();
-	const rgb_t *palette = palette_entry_list_raw(bitmap.palette());
+	const rgb_t *palette = m_palette->palette()->entry_list_raw();
 	UINT8 i;
 	UINT16 chr,x;
-	UINT32 mem, vidbase = (state->m_video_latch & 15) << 14, *p = &bitmap.pix32(y);
+	UINT32 mem, vidbase = (m_video_latch & 15) << 14, *p = &bitmap.pix32(y);
 
 	for (x = 0; x < x_count; x++)
 	{
 		mem = vidbase + ma + x + (ra<<12);
-		chr = state->m_base[mem];
+		chr = m_base[mem];
 
-		if (BIT(state->m_pa, 3))
+		if (BIT(m_pa, 3))
 		// 640 x 200 x 4of16 mode
 		{
 			for (i = 0; i < 8; i++)
 			{
-				*p++ = palette[state->m_palette_latch[chr>>14]];
+				*p++ = palette[m_palette_latch[chr>>14]];
 				chr <<= 2;
 			}
 		}
@@ -807,42 +809,11 @@ static MC6845_UPDATE_ROW( applix_update_row )
 	}
 }
 
-static MC6845_INTERFACE( applix_crtc )
-{
-	false, // should show a border
-	8,          /* number of dots per character */
-	NULL,
-	applix_update_row,      /* handler to display a scanline */
-	NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(applix_state, vsync_w),
-	NULL
-};
-
 WRITE_LINE_MEMBER( applix_state::vsync_w )
 {
 	m_via->write_ca2(state);
 }
 
-static const via6522_interface applix_via =
-{
-	DEVCB_DRIVER_MEMBER(applix_state, applix_pa_r), // in port A
-	DEVCB_DRIVER_MEMBER(applix_state, applix_pb_r), // in port B
-	DEVCB_NULL, // in CA1 cent ack
-	DEVCB_NULL, // in CB1 kbd clk
-	DEVCB_NULL, // in CA2 vsync
-	DEVCB_NULL, // in CB2 kdb data
-	DEVCB_DRIVER_MEMBER(applix_state, applix_pa_w),// out Port A
-	DEVCB_DRIVER_MEMBER(applix_state, applix_pb_w), // out port B
-	DEVCB_NULL, // out CA1
-	DEVCB_NULL, // out CB1
-	DEVCB_NULL, // out CA2
-	DEVCB_NULL, // out CB2
-	DEVCB_CPU_INPUT_LINE("maincpu", M68K_IRQ_2) //IRQ
-};
-
 TIMER_DEVICE_CALLBACK_MEMBER(applix_state::cass_timer)
 {
 	/* cassette - turn 2500/5000Hz to a bit */
@@ -860,22 +831,6 @@ TIMER_DEVICE_CALLBACK_MEMBER(applix_state::cass_timer)
 	}
 }
 
-static const cassette_interface applix_cassette_interface =
-{
-	cassette_default_formats,
-	NULL,
-	(cassette_state)(CASSETTE_STOPPED | CASSETTE_MOTOR_ENABLED | CASSETTE_SPEAKER_MUTED),
-	NULL,
-	NULL
-};
-
-static const centronics_interface applix_centronics_config =
-{
-	DEVCB_DEVICE_LINE_MEMBER("via6522", via6522_device, write_ca1), // ack
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
 static MACHINE_CONFIG_START( applix, applix_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000, 7500000)
@@ -894,7 +849,8 @@ static MACHINE_CONFIG_START( applix, applix_state )
 	MCFG_SCREEN_SIZE(640, 200)
 	MCFG_SCREEN_VISIBLE_AREA(0, 640-1, 0, 200-1)
 	MCFG_SCREEN_UPDATE_DEVICE("crtc", mc6845_device, screen_update)
-	MCFG_PALETTE_LENGTH(16)
+	MCFG_PALETTE_ADD("palette", 16)
+	MCFG_PALETTE_INIT_OWNER(applix_state, applix)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
@@ -906,10 +862,30 @@ static MACHINE_CONFIG_START( applix, applix_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.50)
 
 	/* Devices */
-	MCFG_MC6845_ADD("crtc", MC6845, "screen", 1875000, applix_crtc) // 6545
-	MCFG_VIA6522_ADD("via6522", 0, applix_via)
-	MCFG_CENTRONICS_PRINTER_ADD("centronics", applix_centronics_config)
-	MCFG_CASSETTE_ADD("cassette", applix_cassette_interface)
+	MCFG_MC6845_ADD("crtc", MC6845, "screen", 1875000) // 6545
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(8)
+	MCFG_MC6845_UPDATE_ROW_CB(applix_state, crtc_update_row)
+	MCFG_MC6845_OUT_VSYNC_CB(WRITELINE(applix_state, vsync_w))
+
+	MCFG_DEVICE_ADD("via6522", VIA6522, 0)
+	MCFG_VIA6522_READPB_HANDLER(READ8(applix_state, applix_pb_r))
+	// in CB1 kbd clk
+	// in CA2 vsync
+	// in CB2 kdb data
+	MCFG_VIA6522_WRITEPA_HANDLER(WRITE8(applix_state, applix_pa_w))
+	MCFG_VIA6522_WRITEPB_HANDLER(WRITE8(applix_state, applix_pb_w))
+	MCFG_VIA6522_IRQ_HANDLER(DEVWRITELINE("maincpu", m68000_device, write_irq2))
+
+	MCFG_CENTRONICS_ADD("centronics", centronics_printers, "printer")
+	MCFG_CENTRONICS_ACK_HANDLER(DEVWRITELINE("via6522", via6522_device, write_ca1))
+	MCFG_CENTRONICS_BUSY_HANDLER(DEVWRITELINE("via6522", via6522_device, write_pa0))
+
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", "centronics")
+
+	MCFG_CASSETTE_ADD("cassette")
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_MOTOR_ENABLED | CASSETTE_SPEAKER_MUTED)
+
 	MCFG_WD1772x_ADD("fdc", XTAL_16MHz / 2) //connected to Z80H clock pin
 	MCFG_FLOPPY_DRIVE_ADD("fdc:0", applix_floppies, "35dd", applix_state::floppy_formats)
 	MCFG_FLOPPY_DRIVE_ADD("fdc:1", applix_floppies, "35dd", applix_state::floppy_formats)
