@@ -447,54 +447,30 @@ PALETTE_INIT_MEMBER(cgenie_state,cgenie)
 {
 	UINT8 i, r, g, b;
 
-	machine().colortable = colortable_alloc(machine(), 49);
-
 	for ( i = 0; i < 49; i++ )
 	{
 		r = cgenie_colors[i*3]; g = cgenie_colors[i*3+1]; b = cgenie_colors[i*3+2];
-		colortable_palette_set_color(machine().colortable, i, MAKE_RGB(r, g, b));
+		palette.set_indirect_color(i, rgb_t(r, g, b));
 	}
 
 	for(i=0; i<108; i++)
-		colortable_entry_set_value(machine().colortable, i, cgenie_palette[i]);
+		palette.set_pen_indirect(i, cgenie_palette[i]);
 }
 
 PALETTE_INIT_MEMBER(cgenie_state,cgenienz)
 {
 	UINT8 i, r, g, b;
 
-	machine().colortable = colortable_alloc(machine(), 49);
-
 	for ( i = 0; i < 49; i++ )
 	{
 		r = cgenienz_colors[i*3]; g = cgenienz_colors[i*3+1]; b = cgenienz_colors[i*3+2];
-		colortable_palette_set_color(machine().colortable, i, MAKE_RGB(r, g, b));
+		palette.set_indirect_color(i, rgb_t(r, g, b));
 	}
 
 	for(i=0; i<108; i++)
-		colortable_entry_set_value(machine().colortable, i, cgenie_palette[i]);
+		palette.set_pen_indirect(i, cgenie_palette[i]);
 }
 
-static const ay8910_interface cgenie_ay8910_interface =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_DRIVER_MEMBER(cgenie_state, cgenie_psg_port_a_r),
-	DEVCB_DRIVER_MEMBER(cgenie_state, cgenie_psg_port_b_r),
-	DEVCB_DRIVER_MEMBER(cgenie_state, cgenie_psg_port_a_w),
-	DEVCB_DRIVER_MEMBER(cgenie_state, cgenie_psg_port_b_w)
-};
-
-
-static const cassette_interface cgenie_cassette_interface =
-{
-	cgenie_cassette_formats,
-	NULL,
-	(cassette_state)(CASSETTE_STOPPED),
-	NULL,
-	NULL
-};
-
 // This is currently broken
 static LEGACY_FLOPPY_OPTIONS_START(cgenie )
 	LEGACY_FLOPPY_OPTION( cgd, "cgd", "Colour Genie disk image", basicdsk_identify_default, basicdsk_construct_default, NULL,
@@ -507,14 +483,8 @@ LEGACY_FLOPPY_OPTIONS_END
 
 static const floppy_interface cgenie_floppy_interface =
 {
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
 	FLOPPY_STANDARD_5_25_DSHD,
 	LEGACY_FLOPPY_OPTIONS_NAME(cgenie),
-	NULL,
 	NULL
 };
 
@@ -535,9 +505,11 @@ static MACHINE_CONFIG_START( cgenie_common, cgenie_state )
 	MCFG_SCREEN_SIZE(48*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 48*8-1,0*8,32*8-1)
 	MCFG_SCREEN_UPDATE_DRIVER(cgenie_state, screen_update_cgenie)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE( cgenie )
-	MCFG_PALETTE_LENGTH(108)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", cgenie )
+	MCFG_PALETTE_ADD("palette", 108)
+	MCFG_PALETTE_INDIRECT_ENTRIES(49)
 
 	// Actually the video is driven by an HD46505 clocked at XTAL_17_73447MHz/16
 
@@ -546,14 +518,22 @@ static MACHINE_CONFIG_START( cgenie_common, cgenie_state )
 	MCFG_SOUND_ADD("dac", DAC, 0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 	MCFG_SOUND_ADD("ay8910", AY8910, XTAL_17_73447MHz/8)
-	MCFG_SOUND_CONFIG(cgenie_ay8910_interface)
+	MCFG_AY8910_PORT_A_READ_CB(READ8(cgenie_state, cgenie_psg_port_a_r))
+	MCFG_AY8910_PORT_B_READ_CB(READ8(cgenie_state, cgenie_psg_port_b_r))
+	MCFG_AY8910_PORT_A_WRITE_CB(WRITE8(cgenie_state, cgenie_psg_port_a_w))
+	MCFG_AY8910_PORT_B_WRITE_CB(WRITE8(cgenie_state, cgenie_psg_port_b_w))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
 
-	MCFG_CASSETTE_ADD( "cassette", cgenie_cassette_interface )
+	MCFG_CASSETTE_ADD( "cassette" )
+	MCFG_CASSETTE_FORMATS(cgenie_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED)
 
-	MCFG_FD1793_ADD("wd179x", cgenie_wd17xx_interface ) // TODO confirm type
+	MCFG_DEVICE_ADD("wd179x", FD1793, 0) // TODO confirm type
+	MCFG_WD17XX_DEFAULT_DRIVE4_TAGS
+	MCFG_WD17XX_INTRQ_CALLBACK(WRITELINE(cgenie_state, cgenie_fdc_intrq_w))
 
 	MCFG_LEGACY_FLOPPY_4_DRIVES_ADD(cgenie_floppy_interface)
+
 	/* cartridge */
 	MCFG_CARTSLOT_ADD("cart")
 	MCFG_CARTSLOT_EXTENSION_LIST("rom")
@@ -566,13 +546,13 @@ static MACHINE_CONFIG_START( cgenie_common, cgenie_state )
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( cgenie, cgenie_common )
-
-	MCFG_PALETTE_INIT_OVERRIDE(cgenie_state, cgenie )
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_INIT_OWNER(cgenie_state, cgenie )
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( cgenienz, cgenie_common )
-
-	MCFG_PALETTE_INIT_OVERRIDE(cgenie_state, cgenienz )
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_INIT_OWNER(cgenie_state, cgenienz )
 MACHINE_CONFIG_END
 
 /***************************************************************************
