@@ -24,12 +24,12 @@
 #include "includes/coco12.h"
 #include "imagedev/cassette.h"
 #include "cpu/m6809/m6809.h"
-#include "machine/coco_232.h"
-#include "machine/coco_orch90.h"
-#include "machine/coco_pak.h"
-#include "machine/coco_fdc.h"
-#include "machine/coco_multi.h"
-
+#include "bus/coco/coco_232.h"
+#include "bus/coco/coco_orch90.h"
+#include "bus/coco/coco_pak.h"
+#include "bus/coco/coco_fdc.h"
+#include "bus/coco/coco_multi.h"
+#include "formats/coco_cas.h"
 
 //**************************************************************************
 //  ADDRESS MAPS
@@ -261,6 +261,13 @@ MACHINE_CONFIG_FRAGMENT( coco_sound )
 MACHINE_CONFIG_END
 
 
+static DEVICE_INPUT_DEFAULTS_START( printer )
+	DEVICE_INPUT_DEFAULTS( "RS232_RXBAUD", 0xff, RS232_BAUD_600 )
+	DEVICE_INPUT_DEFAULTS( "RS232_STARTBITS", 0xff, RS232_STARTBITS_1 )
+	DEVICE_INPUT_DEFAULTS( "RS232_DATABITS", 0xff, RS232_DATABITS_8 )
+	DEVICE_INPUT_DEFAULTS( "RS232_PARITY", 0xff, RS232_PARITY_NONE )
+	DEVICE_INPUT_DEFAULTS( "RS232_STOPBITS", 0xff, RS232_STOPBITS_1 )
+DEVICE_INPUT_DEFAULTS_END
 
 //-------------------------------------------------
 //  MACHINE_CONFIG
@@ -272,16 +279,47 @@ static MACHINE_CONFIG_START( coco, coco12_state )
 	MCFG_CPU_PROGRAM_MAP(coco_mem)
 
 	// devices
-	MCFG_PIA6821_ADD(PIA0_TAG, coco_state::pia0_config)
-	MCFG_PIA6821_ADD(PIA1_TAG, coco_state::pia1_config)
-	MCFG_SAM6883_ADD(SAM_TAG, XTAL_3_579545MHz, coco12_state::sam6883_config)
-	MCFG_CASSETTE_ADD("cassette", coco_state::coco_cassette_interface)
-	MCFG_BITBANGER_ADD(BITBANGER_TAG, coco_state::coco_bitbanger_config)
-	MCFG_COCO_CARTRIDGE_ADD(CARTRIDGE_TAG, coco_state::cartridge_config, coco_cart, "pak")
+	MCFG_DEVICE_ADD(PIA0_TAG, PIA6821, 0)
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(coco_state, pia0_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(coco_state, pia0_pb_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(coco_state, pia0_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(coco_state, pia0_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(coco_state, pia0_irq_a))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(coco_state, pia0_irq_b))
+
+	MCFG_DEVICE_ADD(PIA1_TAG, PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(coco_state, pia1_pa_r))
+	MCFG_PIA_READPB_HANDLER(READ8(coco_state, pia1_pb_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(coco_state, pia1_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(coco_state, pia1_pb_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(coco_state, pia1_ca2_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(coco_state, pia1_cb2_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(coco_state, pia1_firq_a))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(coco_state, pia1_firq_b))
+
+	MCFG_SAM6883_ADD(SAM_TAG, XTAL_3_579545MHz, MAINCPU_TAG, AS_PROGRAM)
+	MCFG_SAM6883_RES_CALLBACK(READ8(coco12_state, sam_read))
+
+	MCFG_CASSETTE_ADD("cassette")
+	MCFG_CASSETTE_FORMATS(coco_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_PLAY | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED)
+
+	MCFG_RS232_PORT_ADD(RS232_TAG, default_rs232_devices, "printer")
+	MCFG_RS232_DCD_HANDLER(DEVWRITELINE(PIA1_TAG, pia6821_device, ca1_w))
+	MCFG_DEVICE_CARD_DEVICE_INPUT_DEFAULTS("printer", printer)
+
+	MCFG_COCO_CARTRIDGE_ADD(CARTRIDGE_TAG, coco_cart, "pak")
+	MCFG_COCO_CARTRIDGE_CART_CB(WRITELINE(coco_state, cart_w))
+	MCFG_COCO_CARTRIDGE_NMI_CB(INPUTLINE(MAINCPU_TAG, INPUT_LINE_NMI))
+	MCFG_COCO_CARTRIDGE_HALT_CB(INPUTLINE(MAINCPU_TAG, INPUT_LINE_HALT))
 
 	// video hardware
 	MCFG_SCREEN_MC6847_NTSC_ADD(SCREEN_TAG, VDG_TAG)
-	MCFG_MC6847_ADD(VDG_TAG, MC6847_NTSC, XTAL_3_579545MHz, coco12_state::mc6847_config)
+
+	MCFG_DEVICE_ADD(VDG_TAG, MC6847_NTSC, XTAL_3_579545MHz)
+	MCFG_MC6847_HSYNC_CALLBACK(WRITELINE(coco12_state, horizontal_sync))
+	MCFG_MC6847_FSYNC_CALLBACK(WRITELINE(coco12_state, field_sync))
+	MCFG_MC6847_INPUT_CALLBACK(DEVREAD8(SAM_TAG, sam6883_device, display_read))
 
 	// sound hardware
 	MCFG_FRAGMENT_ADD( coco_sound )
@@ -297,26 +335,38 @@ MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( cocoe, coco )
 	MCFG_COCO_CARTRIDGE_REMOVE(CARTRIDGE_TAG)
-	MCFG_COCO_CARTRIDGE_ADD(CARTRIDGE_TAG, coco12_state::cartridge_config, coco_cart, "fdc")
+	MCFG_COCO_CARTRIDGE_ADD(CARTRIDGE_TAG, coco_cart, "fdc")
+	MCFG_COCO_CARTRIDGE_CART_CB(WRITELINE(coco_state, cart_w))
+	MCFG_COCO_CARTRIDGE_NMI_CB(INPUTLINE(MAINCPU_TAG, INPUT_LINE_NMI))
+	MCFG_COCO_CARTRIDGE_HALT_CB(INPUTLINE(MAINCPU_TAG, INPUT_LINE_HALT))
 	MCFG_COCO_VHD_ADD(VHD0_TAG)
 	MCFG_COCO_VHD_ADD(VHD1_TAG)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( coco2, coco )
 	MCFG_COCO_CARTRIDGE_REMOVE(CARTRIDGE_TAG)
-	MCFG_COCO_CARTRIDGE_ADD(CARTRIDGE_TAG, coco12_state::cartridge_config, coco_cart, "fdcv11")
+	MCFG_COCO_CARTRIDGE_ADD(CARTRIDGE_TAG, coco_cart, "fdcv11")
+	MCFG_COCO_CARTRIDGE_CART_CB(WRITELINE(coco_state, cart_w))
+	MCFG_COCO_CARTRIDGE_NMI_CB(INPUTLINE(MAINCPU_TAG, INPUT_LINE_NMI))
+	MCFG_COCO_CARTRIDGE_HALT_CB(INPUTLINE(MAINCPU_TAG, INPUT_LINE_HALT))
 	MCFG_COCO_VHD_ADD(VHD0_TAG)
 	MCFG_COCO_VHD_ADD(VHD1_TAG)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( coco2b, coco2 )
-	MCFG_MC6847_REMOVE(VDG_TAG)
-	MCFG_MC6847_ADD(VDG_TAG, MC6847T1_NTSC, XTAL_3_579545MHz, coco12_state::mc6847_config)
+	MCFG_DEVICE_REMOVE(VDG_TAG)
+	MCFG_DEVICE_ADD(VDG_TAG, MC6847T1_NTSC, XTAL_3_579545MHz)
+	MCFG_MC6847_HSYNC_CALLBACK(WRITELINE(coco12_state, horizontal_sync))
+	MCFG_MC6847_FSYNC_CALLBACK(WRITELINE(coco12_state, field_sync))
+	MCFG_MC6847_INPUT_CALLBACK(DEVREAD8(SAM_TAG, sam6883_device, display_read))
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( cp400, coco )
 	MCFG_COCO_CARTRIDGE_REMOVE(CARTRIDGE_TAG)
-	MCFG_COCO_CARTRIDGE_ADD(CARTRIDGE_TAG, coco12_state::cartridge_config, coco_cart, "cp400_fdc")
+	MCFG_COCO_CARTRIDGE_ADD(CARTRIDGE_TAG, coco_cart, "cp400_fdc")
+	MCFG_COCO_CARTRIDGE_CART_CB(WRITELINE(coco_state, cart_w))
+	MCFG_COCO_CARTRIDGE_NMI_CB(INPUTLINE(MAINCPU_TAG, INPUT_LINE_NMI))
+	MCFG_COCO_CARTRIDGE_HALT_CB(INPUTLINE(MAINCPU_TAG, INPUT_LINE_HALT))
 MACHINE_CONFIG_END
 
 
