@@ -41,6 +41,7 @@
  ******************************************************************************/
 
 #include "includes/compis.h"
+#include "bus/rs232/rs232.h"
 
 
 
@@ -452,24 +453,15 @@ INPUT_PORTS_END
 //  UPD7220_INTERFACE( hgdc_intf )
 //-------------------------------------------------
 
-static UPD7220_DISPLAY_PIXELS( hgdc_display_pixels )
+UPD7220_DISPLAY_PIXELS_MEMBER( compis_state::hgdc_display_pixels )
 {
-	compis_state *state = device->machine().driver_data<compis_state>();
-	UINT8 i,gfx = state->m_video_ram[address];
+	UINT8 i,gfx = m_video_ram[address];
+	const pen_t *pen = m_palette->pens();
 
 	for(i=0; i<8; i++)
-		bitmap.pix32(y, x + i) = RGB_MONOCHROME_GREEN_HIGHLIGHT[BIT(gfx, i)];
+		bitmap.pix32(y, x + i) = pen[BIT(gfx, i)];
 }
 
-static UPD7220_INTERFACE( hgdc_intf )
-{
-	hgdc_display_pixels,
-	NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
 
 //-------------------------------------------------
 //  I80186_INTERFACE( cpu_intf )
@@ -504,59 +496,30 @@ WRITE_LINE_MEMBER( compis_state::tmr1_w )
 
 WRITE_LINE_MEMBER( compis_state::tmr2_w )
 {
-	m_uart->rxc_w(state);
-	m_uart->txc_w(state);
+	m_uart->write_rxc(state);
+	m_uart->write_txc(state);
 }
 
 
-//-------------------------------------------------
-//  pit8253_interface pit_intf
-//-------------------------------------------------
-
-WRITE_LINE_MEMBER( compis_state::tmr3_w )
-{
-	m_mpsc->rxtxcb_w(state);
-}
-
-WRITE_LINE_MEMBER( compis_state::tmr4_w )
-{
-}
-
 WRITE_LINE_MEMBER( compis_state::tmr5_w )
 {
 	m_mpsc->rxca_w(state);
 	m_mpsc->txca_w(state);
 }
 
-static const struct pit8253_interface pit_intf =
+//-------------------------------------------------
+//  I8255A interface
+//-------------------------------------------------
+
+WRITE_LINE_MEMBER(compis_state::write_centronics_busy)
 {
-	{
-		{ XTAL_16MHz/8, DEVCB_LINE_VCC, DEVCB_DRIVER_LINE_MEMBER(compis_state, tmr3_w) },
-		{ XTAL_16MHz/8, DEVCB_LINE_VCC, DEVCB_DRIVER_LINE_MEMBER(compis_state, tmr4_w) },
-		{ XTAL_16MHz/8, DEVCB_LINE_VCC, DEVCB_DRIVER_LINE_MEMBER(compis_state, tmr5_w) }
-	}
-};
+	m_centronics_busy = state;
+}
 
-
-//-------------------------------------------------
-//  i8251_interface usart_intf
-//-------------------------------------------------
-
-static const i8251_interface usart_intf =
+WRITE_LINE_MEMBER(compis_state::write_centronics_select)
 {
-	DEVCB_DEVICE_LINE_MEMBER(COMPIS_KEYBOARD_TAG, compis_keyboard_device, si_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DEVICE_LINE_MEMBER(I80130_TAG, i80130_device, ir2_w),
-	DEVCB_NULL, //DEVCB_DEVICE_LINE_MEMBER(I80186_TAG, i80186_cpu_device, int1_w),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
-//-------------------------------------------------
-//  I8255A_INTERFACE( ppi_intf )
-//-------------------------------------------------
+	m_centronics_select = state;
+}
 
 READ8_MEMBER( compis_state::ppi_pb_r )
 {
@@ -584,8 +547,8 @@ READ8_MEMBER( compis_state::ppi_pb_r )
 	data |= (m_cassette->input() > 0.0) << 2;
 
 	/* Centronics busy */
-	data |= m_centronics->busy_r() << 5;
-	data |= m_centronics->vcc_r() << 6;
+	data |= m_centronics_busy << 5;
+	data |= m_centronics_select << 6;
 
 	// TMR0
 	data |= m_tmr0 << 7;
@@ -612,7 +575,7 @@ WRITE8_MEMBER( compis_state::ppi_pc_w )
 
 	m_isbx0->opt1_w(BIT(data, 4));
 
-	m_centronics->strobe_w(BIT(data, 5));
+	m_centronics->write_strobe(BIT(data, 5));
 
 	if (BIT(data, 6))
 	{
@@ -622,76 +585,11 @@ WRITE8_MEMBER( compis_state::ppi_pc_w )
 	m_isbx0->opt0_w(BIT(data, 7));
 }
 
-static I8255A_INTERFACE( ppi_intf )
-{
-	DEVCB_NULL,
-	DEVCB_DEVICE_MEMBER(CENTRONICS_TAG, centronics_device, write),
-	DEVCB_DRIVER_MEMBER(compis_state, ppi_pb_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(compis_state, ppi_pc_w)
-};
-
-
-//-------------------------------------------------
-//  I8274_INTERFACE( mpsc_intf )
-//-------------------------------------------------
-
-static I8274_INTERFACE( mpsc_intf )
-{
-	0, 0, 0, 0,
-
-	DEVCB_DEVICE_LINE_MEMBER(RS232_A_TAG, serial_port_device, tx),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_A_TAG, rs232_port_device, dtr_w),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_A_TAG, rs232_port_device, rts_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_LINE_MEMBER(RS232_B_TAG, serial_port_device, tx),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_B_TAG, rs232_port_device, dtr_w),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_B_TAG, rs232_port_device, rts_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_LINE_MEMBER(I80186_TAG, i80186_cpu_device, int3_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
-//-------------------------------------------------
-//  mm58274c_interface rtc_intf
-//-------------------------------------------------
-
-static const mm58274c_interface rtc_intf =
-{
-	0,  /*  mode 24*/
-	1   /*  first day of week */
-};
-
-
-//-------------------------------------------------
-//  cassette_interface compis_cassette_interface
-//-------------------------------------------------
-
 TIMER_DEVICE_CALLBACK_MEMBER( compis_state::tape_tick )
 {
 	m_maincpu->tmrin0_w(m_cassette->input() > 0.0);
 }
 
-static const cassette_interface compis_cassette_interface =
-{
-	cassette_default_formats,
-	NULL,
-	(cassette_state)(CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED),
-	NULL,
-	NULL
-};
-
-
-
 //**************************************************************************
 //  MACHINE INITIALIZATION
 //**************************************************************************
@@ -742,39 +640,81 @@ static MACHINE_CONFIG_START( compis, compis_state )
 	MCFG_80186_TMROUT1_HANDLER(DEVWRITELINE(DEVICE_SELF, compis_state, tmr1_w))
 
 	// video hardware
-	MCFG_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 	MCFG_SCREEN_ADD(SCREEN_TAG, RASTER)
+	MCFG_SCREEN_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 	MCFG_SCREEN_REFRESH_RATE(50)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500)) // not accurate
 	MCFG_SCREEN_SIZE(640, 400)
 	MCFG_SCREEN_VISIBLE_AREA(0, 640-1, 0, 400-1)
 	MCFG_SCREEN_UPDATE_DEVICE("upd7220", upd7220_device, screen_update)
-	MCFG_UPD7220_ADD("upd7220", XTAL_4_433619MHz/2, hgdc_intf, upd7220_map) //unknown clock
+
+	MCFG_DEVICE_ADD("upd7220", UPD7220, XTAL_4_433619MHz/2) // unknown clock
+	MCFG_DEVICE_ADDRESS_MAP(AS_0, upd7220_map)
+	MCFG_UPD7220_DISPLAY_PIXELS_CALLBACK_OWNER(compis_state, hgdc_display_pixels)
+	MCFG_VIDEO_SET_SCREEN(SCREEN_TAG)
+
+	MCFG_PALETTE_ADD_MONOCHROME_GREEN("palette")
 
 	// devices
-	MCFG_I80130_ADD(I80130_TAG, XTAL_16MHz/2, DEVWRITELINE(I80186_TAG, i80186_cpu_device, int0_w))
+	MCFG_DEVICE_ADD(I80130_TAG, I80130, XTAL_16MHz/2)
+	MCFG_I80130_IRQ_CALLBACK(DEVWRITELINE(I80186_TAG, i80186_cpu_device, int0_w))
 	//MCFG_I80130_SYSTICK_CALLBACK(DEVWRITELINE(I80130_TAG, i80130_device, ir3_w))
 	MCFG_I80130_DELAY_CALLBACK(DEVWRITELINE(I80130_TAG, i80130_device, ir7_w))
-	MCFG_I80130_BAUD_CALLBACK(DEVWRITELINE(DEVICE_SELF, compis_state, tmr2_w))
-	MCFG_PIT8253_ADD(I8253_TAG, pit_intf )
-	MCFG_I8255_ADD(I8255_TAG, ppi_intf )
-	MCFG_I8251_ADD(I8251A_TAG, usart_intf)
-	MCFG_I8274_ADD(I8274_TAG, XTAL_16MHz/4, mpsc_intf)
-	MCFG_MM58274C_ADD(MM58174A_TAG, rtc_intf)
-	MCFG_CASSETTE_ADD(CASSETTE_TAG, compis_cassette_interface)
+	MCFG_I80130_BAUD_CALLBACK(WRITELINE(compis_state, tmr2_w))
+
+	MCFG_DEVICE_ADD(I8253_TAG, PIT8253, 0)
+	MCFG_PIT8253_CLK0(XTAL_16MHz/8)
+	MCFG_PIT8253_OUT0_HANDLER(DEVWRITELINE(I8274_TAG, i8274_device, rxtxcb_w))
+	MCFG_PIT8253_CLK1(XTAL_16MHz/8)
+	MCFG_PIT8253_CLK2(XTAL_16MHz/8)
+	MCFG_PIT8253_OUT2_HANDLER(WRITELINE(compis_state, tmr5_w))
+
+	MCFG_DEVICE_ADD(I8255_TAG, I8255, 0)
+	MCFG_I8255_OUT_PORTA_CB(DEVWRITE8("cent_data_out", output_latch_device, write))
+	MCFG_I8255_IN_PORTB_CB(READ8(compis_state, ppi_pb_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(compis_state, ppi_pc_w))
+
+	MCFG_DEVICE_ADD(I8251A_TAG, I8251, 0)
+	MCFG_I8251_TXD_HANDLER(DEVWRITELINE(COMPIS_KEYBOARD_TAG, compis_keyboard_device, si_w))
+	MCFG_I8251_RXRDY_HANDLER(DEVWRITELINE(I80130_TAG, i80130_device, ir2_w))
+	//MCFG_I8251_TXRDY_HANDLER(DEVWRITELINE(I80186_TAG, i80186_cpu_device, int1_w))
+
+	MCFG_DEVICE_ADD(COMPIS_KEYBOARD_TAG, COMPIS_KEYBOARD, 0)
+	MCFG_COMPIS_KEYBOARD_OUT_TX_HANDLER(DEVWRITELINE(I8251A_TAG, i8251_device, write_rxd))
+
+	MCFG_I8274_ADD(I8274_TAG, XTAL_16MHz/4, 0, 0, 0, 0)
+	MCFG_Z80DART_OUT_TXDA_CB(DEVWRITELINE(RS232_A_TAG, rs232_port_device, write_txd))
+	MCFG_Z80DART_OUT_DTRA_CB(DEVWRITELINE(RS232_A_TAG, rs232_port_device, write_dtr))
+	MCFG_Z80DART_OUT_RTSA_CB(DEVWRITELINE(RS232_A_TAG, rs232_port_device, write_rts))
+	MCFG_Z80DART_OUT_TXDB_CB(DEVWRITELINE(RS232_B_TAG, rs232_port_device, write_txd))
+	MCFG_Z80DART_OUT_DTRB_CB(DEVWRITELINE(RS232_B_TAG, rs232_port_device, write_dtr))
+	MCFG_Z80DART_OUT_RTSB_CB(DEVWRITELINE(RS232_B_TAG, rs232_port_device, write_rts))
+	MCFG_Z80DART_OUT_INT_CB(DEVWRITELINE(I80186_TAG, i80186_cpu_device, int3_w))
+
+	MCFG_DEVICE_ADD(MM58174A_TAG, MM58274C, 0)
+	MCFG_MM58274C_MODE24(0) // 12 hour
+	MCFG_MM58274C_DAY1(1)   // monday
+
+	MCFG_CASSETTE_ADD(CASSETTE_TAG)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED)
+
+	MCFG_TIMER_DRIVER_ADD_PERIODIC("tape", compis_state, tape_tick, attotime::from_hz(44100))
 
 	MCFG_RS232_PORT_ADD(RS232_A_TAG, default_rs232_devices, NULL)
-	MCFG_SERIAL_OUT_RX_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, rxa_w))
-	MCFG_RS232_OUT_DCD_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, dcda_w))
-	MCFG_RS232_OUT_CTS_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, ctsa_w))
+	MCFG_RS232_RXD_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, rxa_w))
+	MCFG_RS232_DCD_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, dcda_w))
+	MCFG_RS232_CTS_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, ctsa_w))
 
 	MCFG_RS232_PORT_ADD(RS232_B_TAG, default_rs232_devices, NULL)
-	MCFG_SERIAL_OUT_RX_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, rxb_w))
-	MCFG_RS232_OUT_DCD_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, dcdb_w))
-	MCFG_RS232_OUT_CTS_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, ctsb_w))
+	MCFG_RS232_RXD_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, rxb_w))
+	MCFG_RS232_DCD_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, dcdb_w))
+	MCFG_RS232_CTS_HANDLER(DEVWRITELINE(I8274_TAG, z80dart_device, ctsb_w))
+
+	MCFG_CENTRONICS_ADD(CENTRONICS_TAG, centronics_printers, "printer")
+	MCFG_CENTRONICS_BUSY_HANDLER(WRITELINE(compis_state, write_centronics_busy))
+	MCFG_CENTRONICS_SELECT_HANDLER(WRITELINE(compis_state, write_centronics_select))
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", CENTRONICS_TAG)
 
-	MCFG_CENTRONICS_PRINTER_ADD(CENTRONICS_TAG, standard_centronics)
-	MCFG_TIMER_DRIVER_ADD_PERIODIC("tape", compis_state, tape_tick, attotime::from_hz(44100))
 	MCFG_ISBX_SLOT_ADD(ISBX_0_TAG, 0, isbx_cards, "fdc")
 	MCFG_ISBX_SLOT_MINTR0_CALLBACK(DEVWRITELINE(I80130_TAG, i80130_device, ir1_w))
 	MCFG_ISBX_SLOT_MINTR1_CALLBACK(DEVWRITELINE(I80130_TAG, i80130_device, ir0_w))
@@ -784,9 +724,6 @@ static MACHINE_CONFIG_START( compis, compis_state )
 	MCFG_ISBX_SLOT_MINTR1_CALLBACK(DEVWRITELINE(I80130_TAG, i80130_device, ir5_w))
 	MCFG_ISBX_SLOT_MDRQT_CALLBACK(DEVWRITELINE(I80186_TAG, i80186_cpu_device, drq1_w))
 
-	MCFG_DEVICE_ADD(COMPIS_KEYBOARD_TAG, COMPIS_KEYBOARD, 0)
-	MCFG_COMPIS_KEYBOARD_OUT_TX_HANDLER(DEVWRITELINE(I8251A_TAG, i8251_device, write_rx))
-
 	// software lists
 	MCFG_SOFTWARE_LIST_ADD("flop_list", "compis")
 
