@@ -20,12 +20,12 @@
 #include "sound/dac.h"
 #include "audio/gb.h"
 #include "includes/gba.h"
-#include "machine/gba_rom.h"
+#include "bus/gba/rom.h"
 #include "rendlay.h"
 
 #define VERBOSE_LEVEL   (0)
 
-INLINE void verboselog(running_machine &machine, int n_level, const char *s_fmt, ...)
+INLINE void ATTR_PRINTF(3,4) verboselog(running_machine &machine, int n_level, const char *s_fmt, ...)
 {
 	if( VERBOSE_LEVEL >= n_level )
 	{
@@ -43,7 +43,7 @@ INLINE void verboselog(running_machine &machine, int n_level, const char *s_fmt,
 static const UINT32 timer_clks[4] = { 16777216, 16777216/64, 16777216/256, 16777216/1024 };
 
 
-void gba_state::palette_init()
+PALETTE_INIT_MEMBER(gba_state, gba)
 {
 	UINT8 r, g, b;
 	for( b = 0; b < 32; b++ )
@@ -52,7 +52,7 @@ void gba_state::palette_init()
 		{
 			for( r = 0; r < 32; r++ )
 			{
-				palette_set_color_rgb( machine(), ( b << 10 ) | ( g << 5 ) | r, pal5bit(r), pal5bit(g), pal5bit(b) );
+				palette.set_pen_color( ( b << 10 ) | ( g << 5 ) | r, pal5bit(r), pal5bit(g), pal5bit(b) );
 			}
 		}
 	}
@@ -493,7 +493,7 @@ READ32_MEMBER(gba_state::gba_io_r)
 			}
 			break;
 		case 0x0004/4:
-			retval = (m_DISPSTAT & 0xffff) | (machine().primary_screen->vpos()<<16);
+			retval = (m_DISPSTAT & 0xffff) | (machine().first_screen()->vpos()<<16);
 			break;
 		case 0x0008/4:
 			if( (mem_mask) & 0x0000ffff )
@@ -1767,7 +1767,7 @@ WRITE32_MEMBER(gba_state::gba_io_w)
 		case 0x0200/4:
 			if( (mem_mask) & 0x0000ffff )
 			{
-//              printf("IE (%08x) = %04x raw %x (%08x) (scan %d PC %x)\n", 0x04000000 + ( offset << 2 ), data & mem_mask, data, ~mem_mask, machine.primary_screen->vpos(), space.device().safe_pc());
+//              printf("IE (%08x) = %04x raw %x (%08x) (scan %d PC %x)\n", 0x04000000 + ( offset << 2 ), data & mem_mask, data, ~mem_mask, machine.first_screen()->vpos(), space.device().safe_pc());
 				m_IE = ( m_IE & ~mem_mask ) | ( data & mem_mask );
 #if 0
 				if (m_IE & m_IF)
@@ -1943,7 +1943,7 @@ INPUT_PORTS_END
 TIMER_CALLBACK_MEMBER(gba_state::perform_hbl)
 {
 	int ch, ctrl;
-	int scanline = machine().primary_screen->vpos();
+	int scanline = machine().first_screen()->vpos();
 
 	// draw only visible scanlines
 	if (scanline < 160)
@@ -1977,7 +1977,7 @@ TIMER_CALLBACK_MEMBER(gba_state::perform_scan)
 	// clear hblank and raster IRQ flags
 	m_DISPSTAT &= ~(DISPSTAT_HBL|DISPSTAT_VCNT);
 
-	scanline = machine().primary_screen->vpos();
+	scanline = machine().first_screen()->vpos();
 
 	// VBL is set for scanlines 160 through 226 (but not 227, which is the last line)
 	if (scanline >= 160 && scanline < 227)
@@ -2043,8 +2043,8 @@ TIMER_CALLBACK_MEMBER(gba_state::perform_scan)
 		}
 	}
 
-	m_hbl_timer->adjust(machine().primary_screen->time_until_pos(scanline, 240));
-	m_scan_timer->adjust(machine().primary_screen->time_until_pos(( scanline + 1 ) % 228, 0));
+	m_hbl_timer->adjust(machine().first_screen()->time_until_pos(scanline, 240));
+	m_scan_timer->adjust(machine().first_screen()->time_until_pos(( scanline + 1 ) % 228, 0));
 }
 
 void gba_state::machine_reset()
@@ -2070,7 +2070,7 @@ void gba_state::machine_reset()
 
 	m_bios_protected = 0;
 
-	m_scan_timer->adjust(machine().primary_screen->time_until_pos(0, 0));
+	m_scan_timer->adjust(machine().first_screen()->time_until_pos(0, 0));
 	m_hbl_timer->adjust(attotime::never);
 	m_dma_timer[0]->adjust(attotime::never);
 	m_dma_timer[1]->adjust(attotime::never, 1);
@@ -2092,7 +2092,7 @@ void gba_state::machine_start()
 	/* create a timer to fire scanline functions */
 	m_scan_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(gba_state::perform_scan),this));
 	m_hbl_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(gba_state::perform_hbl),this));
-	m_scan_timer->adjust(machine().primary_screen->time_until_pos(0, 0));
+	m_scan_timer->adjust(machine().first_screen()->time_until_pos(0, 0));
 
 	/* and one for each DMA channel */
 	m_dma_timer[0] = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(gba_state::dma_complete),this));
@@ -2255,9 +2255,11 @@ static MACHINE_CONFIG_START( gbadv, gba_state )
 	MCFG_SCREEN_ADD("gbalcd", RASTER)   // htot hst vwid vtot vst vis
 	MCFG_SCREEN_RAW_PARAMS(16777216/4, 308, 0,  240, 228, 0,  160)
 	MCFG_SCREEN_UPDATE_DRIVER(gba_state, screen_update)
+	MCFG_SCREEN_PALETTE("palette")
 
 	MCFG_DEFAULT_LAYOUT(layout_lcd)
-	MCFG_PALETTE_LENGTH(32768)
+	MCFG_PALETTE_ADD("palette", 32768)
+	MCFG_PALETTE_INIT_OWNER(gba_state, gba)
 
 	MCFG_SPEAKER_STANDARD_STEREO("spkleft", "spkright")
 	MCFG_SOUND_ADD("custom", GAMEBOY, 0)
