@@ -643,8 +643,6 @@ static GFXDECODE_START( homelab )
 	GFXDECODE_ENTRY( "chargen", 0x0000, homelab_charlayout, 0, 1 )
 GFXDECODE_END
 
-static const mea8000_interface brailab4_speech_intf = { "speech", DEVCB_NULL };
-
 QUICKLOAD_LOAD_MEMBER( homelab_state,homelab)
 {
 	address_space &space = m_maincpu->space(AS_PROGRAM);
@@ -653,27 +651,19 @@ QUICKLOAD_LOAD_MEMBER( homelab_state,homelab)
 	UINT16 quick_addr;
 	UINT16 quick_length;
 	UINT16 quick_end;
-	UINT8 *quick_data;
+	dynamic_buffer quick_data;
 	char pgmname[256];
 	UINT16 args[2];
 	int read_;
 
 	quick_length = image.length();
-	quick_data = (UINT8*)malloc(quick_length);
-	if (!quick_data)
-	{
-		image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Cannot open file");
-		image.message(" Cannot open file");
-		free(quick_data);
-		return IMAGE_INIT_FAIL;
-	}
+	quick_data.resize(quick_length);
 
 	read_ = image.fread( quick_data, quick_length);
 	if (read_ != quick_length)
 	{
 		image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Cannot read the file");
 		image.message(" Cannot read the file");
-		free(quick_data);
 		return IMAGE_INIT_FAIL;
 	}
 
@@ -683,7 +673,6 @@ QUICKLOAD_LOAD_MEMBER( homelab_state,homelab)
 	{
 		image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Invalid header");
 		image.message(" Invalid header");
-		free(quick_data);
 		return IMAGE_INIT_FAIL;
 	}
 
@@ -693,7 +682,6 @@ QUICKLOAD_LOAD_MEMBER( homelab_state,homelab)
 		{
 			image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File name too long");
 			image.message(" File name too long");
-			free(quick_data);
 			return IMAGE_INIT_FAIL;
 		}
 
@@ -707,7 +695,6 @@ QUICKLOAD_LOAD_MEMBER( homelab_state,homelab)
 	{
 		image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Unexpected EOF while getting file size");
 		image.message(" Unexpected EOF while getting file size");
-		free(quick_data);
 		return IMAGE_INIT_FAIL;
 	}
 
@@ -719,7 +706,6 @@ QUICKLOAD_LOAD_MEMBER( homelab_state,homelab)
 	{
 		image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File too large");
 		image.message(" File too large");
-		free(quick_data);
 		return IMAGE_INIT_FAIL;
 	}
 
@@ -735,13 +721,11 @@ QUICKLOAD_LOAD_MEMBER( homelab_state,homelab)
 			snprintf(message, ARRAY_LENGTH(message), "%s: Unexpected EOF while writing byte to %04X", pgmname, (unsigned) j);
 			image.seterror(IMAGE_ERROR_INVALIDIMAGE, message);
 			image.message("%s: Unexpected EOF while writing byte to %04X", pgmname, (unsigned) j);
-			free(quick_data);
 			return IMAGE_INIT_FAIL;
 		}
 		space.write_byte(j, ch);
 	}
 
-	free(quick_data);
 	return IMAGE_INIT_PASS;
 }
 
@@ -760,9 +744,10 @@ static MACHINE_CONFIG_START( homelab, homelab_state )
 	MCFG_SCREEN_VISIBLE_AREA(0, 40*8-1, 0, 25*8-1)
 	MCFG_VIDEO_START_OVERRIDE(homelab_state,homelab2)
 	MCFG_SCREEN_UPDATE_DRIVER(homelab_state, screen_update_homelab2)
-	MCFG_GFXDECODE(homelab)
-	MCFG_PALETTE_LENGTH(2)
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, monochrome_green)
+	MCFG_SCREEN_PALETTE("palette")
+
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", homelab)
+	MCFG_PALETTE_ADD_MONOCHROME_GREEN("palette")
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -771,7 +756,7 @@ static MACHINE_CONFIG_START( homelab, homelab_state )
 	MCFG_SOUND_WAVE_ADD(WAVE_TAG, "cassette")
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MCFG_CASSETTE_ADD( "cassette", default_cassette_interface )
+	MCFG_CASSETTE_ADD( "cassette" )
 	MCFG_QUICKLOAD_ADD("quickload", homelab_state, homelab, "htp", 2)
 MACHINE_CONFIG_END
 
@@ -790,9 +775,10 @@ static MACHINE_CONFIG_START( homelab3, homelab_state )
 	MCFG_SCREEN_VISIBLE_AREA(0, 64*8-1, 0, 32*8-1)
 	MCFG_VIDEO_START_OVERRIDE(homelab_state,homelab3)
 	MCFG_SCREEN_UPDATE_DRIVER(homelab_state, screen_update_homelab3)
-	MCFG_GFXDECODE(homelab)
-	MCFG_PALETTE_LENGTH(2)
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, monochrome_green)
+	MCFG_SCREEN_PALETTE("palette")
+
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", homelab)
+	MCFG_PALETTE_ADD_MONOCHROME_GREEN("palette")
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -801,7 +787,7 @@ static MACHINE_CONFIG_START( homelab3, homelab_state )
 	MCFG_SOUND_WAVE_ADD(WAVE_TAG, "cassette")
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MCFG_CASSETTE_ADD( "cassette", default_cassette_interface )
+	MCFG_CASSETTE_ADD( "cassette" )
 	MCFG_QUICKLOAD_ADD("quickload", homelab_state, homelab, "htp", 2)
 MACHINE_CONFIG_END
 
@@ -820,9 +806,10 @@ static MACHINE_CONFIG_START( brailab4, homelab_state )
 	MCFG_SCREEN_VISIBLE_AREA(0, 64*8-1, 0, 32*8-1)
 	MCFG_VIDEO_START_OVERRIDE(homelab_state,brailab4)
 	MCFG_SCREEN_UPDATE_DRIVER(homelab_state, screen_update_homelab3)
-	MCFG_GFXDECODE(homelab)
-	MCFG_PALETTE_LENGTH(2)
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, monochrome_green)
+	MCFG_SCREEN_PALETTE("palette")
+
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", homelab)
+	MCFG_PALETTE_ADD_MONOCHROME_GREEN("palette")
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -832,9 +819,10 @@ static MACHINE_CONFIG_START( brailab4, homelab_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 	MCFG_SOUND_ADD ( "speech", DAC, 0 )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_DEVICE_ADD("mea8000", MEA8000, 0)
+	MCFG_MEA8000_DAC("speech")
 
-	MCFG_CASSETTE_ADD( "cassette", default_cassette_interface )
-	MCFG_MEA8000_ADD("mea8000", brailab4_speech_intf)
+	MCFG_CASSETTE_ADD( "cassette" )
 	MCFG_QUICKLOAD_ADD("quickload", homelab_state, homelab, "htp", 18)
 MACHINE_CONFIG_END
 
