@@ -231,7 +231,9 @@ public:
 		, m_keyrow14(*this, "ROW14")
 		, m_keyrow15(*this, "ROW15")
 		, m_keyrow16(*this, "ROW16")
-		, m_vram(*this, "vram")
+		, m_vram(*this, "vram"),
+		m_gfxdecode(*this, "gfxdecode"),
+		m_palette(*this, "palette")
 	{ }
 
 	// devices
@@ -278,6 +280,8 @@ private:
 	UINT8 m_unk;
 	UINT8 m_bank;
 	UINT8 m_kbdrow, m_kbdcol, m_kbdclk, m_kbdread;
+	required_device<gfxdecode_device> m_gfxdecode;
+	required_device<palette_device> m_palette;
 };
 
 void itt3030_state::video_start()
@@ -289,12 +293,12 @@ READ8_MEMBER(itt3030_state::vsync_r)
 {
 	UINT8 ret = 0;
 
-	if (machine().primary_screen->vblank())
+	if (machine().first_screen()->vblank())
 	{
 		ret |= 0xc0;    // set both bits 6 and 7 if vblank
 	}
 
-	if (machine().primary_screen->hblank())
+	if (machine().first_screen()->hblank())
 	{
 		ret |= 0x80;    // set only bit 7 if hblank
 	}
@@ -358,7 +362,7 @@ UINT32 itt3030_state::screen_update( screen_device &screen, bitmap_ind16 &bitmap
 		for(int x = 0; x < 80; x++ )
 		{
 			UINT8 code = m_vram[x + y*128];
-			drawgfx_opaque(bitmap, cliprect, machine().gfx[0],  code , 0, 0,0, x*8,y*16);
+			m_gfxdecode->gfx(0)->opaque(bitmap,cliprect,  code , 0, 0,0, x*8,y*16);
 		}
 	}
 
@@ -585,12 +589,6 @@ static SLOT_INTERFACE_START( itt3030_floppies )
 SLOT_INTERFACE_END
 
 
-static struct tms9927_interface crtc_intf =
-{
-	16,     // pixels per video memory address
-	NULL    // "self-load data"?
-};
-
 static MACHINE_CONFIG_START( itt3030, itt3030_state )
 
 	/* basic machine hardware */
@@ -608,6 +606,7 @@ static MACHINE_CONFIG_START( itt3030, itt3030_state )
 	MCFG_SCREEN_UPDATE_DRIVER(itt3030_state, screen_update)
 	MCFG_SCREEN_SIZE(80*8, 24*16)
 	MCFG_SCREEN_VISIBLE_AREA(0, 80*8-1, 0, 24*16-1)
+	MCFG_SCREEN_PALETTE("palette")
 
 	/* devices */
 	MCFG_DEVICE_ADD("lowerbank", ADDRESS_MAP_BANK, 0)
@@ -615,17 +614,18 @@ static MACHINE_CONFIG_START( itt3030, itt3030_state )
 	MCFG_ADDRESS_MAP_BANK_ENDIANNESS(ENDIANNESS_LITTLE)
 	MCFG_ADDRESS_MAP_BANK_DATABUS_WIDTH(8)
 	MCFG_ADDRESS_MAP_BANK_STRIDE(0x10000)
+
 	MCFG_DEVICE_ADD("crt5027", CRT5027, XTAL_6MHz)
-	MCFG_DEVICE_CONFIG(crtc_intf)
+	MCFG_TMS9927_CHAR_WIDTH(16)
+
 	MCFG_FD1791x_ADD("fdc", XTAL_20MHz / 20)
 	MCFG_WD_FDC_FORCE_READY
 	MCFG_FLOPPY_DRIVE_ADD("fdc:0", itt3030_floppies, "525dd", itt3030_state::itt3030_floppy_formats)
 	MCFG_FLOPPY_DRIVE_ADD("fdc:1", itt3030_floppies, "525dd", itt3030_state::itt3030_floppy_formats)
 
-	MCFG_GFXDECODE(itt3030)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", itt3030)
 
-	MCFG_PALETTE_LENGTH(2)
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, black_and_white)
+	MCFG_PALETTE_ADD_BLACK_AND_WHITE("palette")
 
 	/* internal ram */
 	MCFG_RAM_ADD("mainram")
@@ -654,4 +654,4 @@ ROM_START( itt3030 )
 	ROM_LOAD( "8741ad.bin", 0x0000, 0x0400, CRC(cabf4394) SHA1(e5d1416b568efa32b578ca295a29b7b5d20c0def))
 ROM_END
 
-GAME( 1982, itt3030,  0,   itt3030,  itt3030,  driver_device, 0,      ROT0, "ITT RFA",      "ITT3030", GAME_NOT_WORKING | GAME_NO_SOUND )
+COMP( 1982, itt3030,  0,   0,  itt3030,  itt3030,  driver_device, 0,  "ITT RFA",      "ITT3030", GAME_NOT_WORKING | GAME_NO_SOUND )
