@@ -125,6 +125,7 @@
 #include "includes/mbee.h"
 #include "formats/dsk_dsk.h"
 #include "formats/mbee_dsk.h"
+#include "formats/mbee_cas.h"
 
 
 #define XTAL_13_5MHz 13500000
@@ -637,14 +638,8 @@ LEGACY_FLOPPY_OPTIONS_END
 
 static const floppy_interface mbee_floppy_interface =
 {
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
 	FLOPPY_STANDARD_5_25_DSHD,
 	LEGACY_FLOPPY_OPTIONS_NAME(mbee),
-	NULL,
 	NULL
 };
 #endif
@@ -659,63 +654,6 @@ static SLOT_INTERFACE_START( mbee_floppies )
 SLOT_INTERFACE_END
 
 
-static MC6845_INTERFACE( mbee_crtc )
-{
-	false,
-	8,          /* number of dots per character */
-	NULL,
-	mbee_update_row,        /* handler to display a scanline */
-	NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	mbee_update_addr        /* handler to process transparent mode */
-};
-
-
-static MC6845_INTERFACE( mbeeic_crtc )
-{
-	false,
-	8,          /* number of dots per character */
-	NULL,
-	mbeeic_update_row,      /* handler to display a scanline */
-	NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	mbee_update_addr        /* handler to process transparent mode */
-};
-
-static MC6845_INTERFACE( mbeeppc_crtc )
-{
-	false,
-	8,          /* number of dots per character */
-	NULL,
-	mbeeppc_update_row,     /* handler to display a scanline */
-	NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	mbee_update_addr        /* handler to process transparent mode */
-};
-
-static MC6845_INTERFACE( mbee256_crtc )
-{
-	false,
-	8,          /* number of dots per character */
-	NULL,
-	mbeeppc_update_row,     /* handler to display a scanline */
-	NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	mbee256_update_addr     /* handler to process transparent mode */
-};
-
 static MACHINE_CONFIG_START( mbee, mbee_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, XTAL_12MHz / 6)         /* 2 MHz */
@@ -725,7 +663,12 @@ static MACHINE_CONFIG_START( mbee, mbee_state )
 
 	MCFG_MACHINE_RESET_OVERRIDE(mbee_state, mbee )
 
-	MCFG_Z80PIO_ADD( "z80pio", XTAL_12MHz / 6, mbee_z80pio_intf )
+	MCFG_DEVICE_ADD("z80pio", Z80PIO, XTAL_12MHz / 6)
+	MCFG_Z80PIO_OUT_INT_CB(INPUTLINE("maincpu", INPUT_LINE_IRQ0))
+	MCFG_Z80PIO_OUT_PA_CB(WRITE8(mbee_state, pio_port_a_w))
+	MCFG_Z80PIO_OUT_ARDY_CB(WRITELINE(mbee_state, pio_ardy))
+	MCFG_Z80PIO_IN_PB_CB(READ8(mbee_state, pio_port_b_r))
+	MCFG_Z80PIO_OUT_PB_CB(WRITE8(mbee_state, pio_port_b_w))
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(50)
@@ -734,9 +677,8 @@ static MACHINE_CONFIG_START( mbee, mbee_state )
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0, 19*16-1)
 	MCFG_SCREEN_UPDATE_DRIVER(mbee_state, screen_update_mbee)
 
-	MCFG_GFXDECODE(mbee)
-	MCFG_PALETTE_LENGTH(2)
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, monochrome_amber) // usually sold with amber or green monitor
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", mbee)
+	MCFG_PALETTE_ADD_MONOCHROME_AMBER("palette") // usually sold with amber or green monitor
 
 	MCFG_VIDEO_START_OVERRIDE(mbee_state,mbee)
 
@@ -748,11 +690,22 @@ static MACHINE_CONFIG_START( mbee, mbee_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
 	/* devices */
-	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_12MHz / 8, mbee_crtc)
-	MCFG_QUICKLOAD_ADD("quickload", mbee_state, mbee, "mwb,com", 2)
+	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_12MHz / 8)
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(8)
+	MCFG_MC6845_UPDATE_ROW_CB(mbee_state, mbee_update_row)
+	MCFG_MC6845_ADDR_CHANGED_CB(mbee_state, mbee_update_addr)
+
+	MCFG_QUICKLOAD_ADD("quickload", mbee_state, mbee, "mwb,com,bee", 2)
 	MCFG_QUICKLOAD_ADD("quickload2", mbee_state, mbee_z80bin, "bin", 2)
-	MCFG_CENTRONICS_PRINTER_ADD("centronics", standard_centronics)
-	MCFG_CASSETTE_ADD( "cassette", default_cassette_interface )
+
+	MCFG_CENTRONICS_ADD("centronics", centronics_printers, "printer")
+
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", "centronics")
+
+	MCFG_CASSETTE_ADD( "cassette" )
+	MCFG_CASSETTE_FORMATS(mbee_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_MOTOR_ENABLED | CASSETTE_SPEAKER_ENABLED)
 MACHINE_CONFIG_END
 
 
@@ -766,7 +719,12 @@ static MACHINE_CONFIG_START( mbeeic, mbee_state )
 
 	MCFG_MACHINE_RESET_OVERRIDE(mbee_state, mbee )
 
-	MCFG_Z80PIO_ADD( "z80pio", 3375000, mbee_z80pio_intf )
+	MCFG_DEVICE_ADD("z80pio", Z80PIO, 3375000)
+	MCFG_Z80PIO_OUT_INT_CB(INPUTLINE("maincpu", INPUT_LINE_IRQ0))
+	MCFG_Z80PIO_OUT_PA_CB(WRITE8(mbee_state, pio_port_a_w))
+	MCFG_Z80PIO_OUT_ARDY_CB(WRITELINE(mbee_state, pio_ardy))
+	MCFG_Z80PIO_IN_PB_CB(READ8(mbee_state, pio_port_b_r))
+	MCFG_Z80PIO_OUT_PB_CB(WRITE8(mbee_state, pio_port_b_w))
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(50)
@@ -775,9 +733,10 @@ static MACHINE_CONFIG_START( mbeeic, mbee_state )
 	MCFG_SCREEN_VISIBLE_AREA(0, 80*8-1, 0, 19*16-1)
 	MCFG_SCREEN_UPDATE_DRIVER(mbee_state, screen_update_mbee)
 
-	MCFG_GFXDECODE(mbeeic)
-	MCFG_PALETTE_LENGTH(96)
-	MCFG_PALETTE_INIT_OVERRIDE(mbee_state,mbeeic)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", mbeeic)
+
+	MCFG_PALETTE_ADD("palette", 96)
+	MCFG_PALETTE_INIT_OWNER(mbee_state,mbeeic)
 
 	MCFG_VIDEO_START_OVERRIDE(mbee_state,mbeeic)
 
@@ -789,11 +748,22 @@ static MACHINE_CONFIG_START( mbeeic, mbee_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
 	/* devices */
-	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_13_5MHz / 8, mbeeic_crtc)
-	MCFG_QUICKLOAD_ADD("quickload", mbee_state, mbee, "mwb,com", 2)
+	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_13_5MHz / 8)
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(8)
+	MCFG_MC6845_UPDATE_ROW_CB(mbee_state, mbeeic_update_row)
+	MCFG_MC6845_ADDR_CHANGED_CB(mbee_state, mbee_update_addr)
+
+	MCFG_QUICKLOAD_ADD("quickload", mbee_state, mbee, "mwb,com,bee", 2)
 	MCFG_QUICKLOAD_ADD("quickload2", mbee_state, mbee_z80bin, "bin", 2)
-	MCFG_CENTRONICS_PRINTER_ADD("centronics", standard_centronics)
-	MCFG_CASSETTE_ADD( "cassette", default_cassette_interface )
+
+	MCFG_CENTRONICS_ADD("centronics", centronics_printers, "printer")
+
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", "centronics")
+
+	MCFG_CASSETTE_ADD( "cassette" )
+	MCFG_CASSETTE_FORMATS(mbee_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_MOTOR_ENABLED | CASSETTE_SPEAKER_ENABLED)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( mbeepc, mbeeic )
@@ -809,7 +779,8 @@ static MACHINE_CONFIG_DERIVED( mbeepc85, mbeeic )
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( mbeepc85b, mbeepc85 )
-	MCFG_PALETTE_INIT_OVERRIDE(mbee_state,mbeepc85b)
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_INIT_OWNER(mbee_state,mbeepc85b)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( mbeeppc, mbeeic )
@@ -817,11 +788,17 @@ static MACHINE_CONFIG_DERIVED( mbeeppc, mbeeic )
 	MCFG_CPU_PROGRAM_MAP(mbeeppc_mem)
 	MCFG_CPU_IO_MAP(mbeeppc_io)
 	MCFG_VIDEO_START_OVERRIDE(mbee_state,mbeeppc)
-	MCFG_GFXDECODE(mbeeppc)
-	MCFG_PALETTE_LENGTH(16)
-	MCFG_PALETTE_INIT_OVERRIDE(mbee_state,mbeeppc)
+	MCFG_GFXDECODE_MODIFY("gfxdecode", mbeeppc)
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_ENTRIES(16)
+	MCFG_PALETTE_INIT_OWNER(mbee_state,mbeeppc)
+
 	MCFG_DEVICE_REMOVE("crtc")
-	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_13_5MHz / 8, mbeeppc_crtc)
+	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_13_5MHz / 8)
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(8)
+	MCFG_MC6845_UPDATE_ROW_CB(mbee_state, mbeeppc_update_row)
+	MCFG_MC6845_ADDR_CHANGED_CB(mbee_state, mbee_update_addr)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( mbee56, mbeeic )
@@ -856,8 +833,13 @@ static MACHINE_CONFIG_DERIVED( mbee256, mbee128 )
 	MCFG_CPU_IO_MAP(mbee256_io)
 	MCFG_MACHINE_RESET_OVERRIDE(mbee_state, mbee256 )
 	MCFG_MC146818_ADD( "rtc", XTAL_32_768kHz )
+
 	MCFG_DEVICE_REMOVE("crtc")
-	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_13_5MHz / 8, mbee256_crtc)
+	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_13_5MHz / 8)
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(8)
+	MCFG_MC6845_UPDATE_ROW_CB(mbee_state, mbeeppc_update_row)
+	MCFG_MC6845_ADDR_CHANGED_CB(mbee_state, mbee256_update_addr)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( mbeett, mbeeppc )
@@ -866,8 +848,13 @@ static MACHINE_CONFIG_DERIVED( mbeett, mbeeppc )
 	MCFG_CPU_IO_MAP(mbeett_io)
 	MCFG_MACHINE_RESET_OVERRIDE(mbee_state, mbeett )
 	MCFG_MC146818_ADD( "rtc", XTAL_32_768kHz )
+
 	MCFG_DEVICE_REMOVE("crtc")
-	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_13_5MHz / 8, mbee256_crtc)
+	MCFG_MC6845_ADD("crtc", SY6545_1, "screen", XTAL_13_5MHz / 8)
+	MCFG_MC6845_SHOW_BORDER_AREA(false)
+	MCFG_MC6845_CHAR_WIDTH(8)
+	MCFG_MC6845_UPDATE_ROW_CB(mbee_state, mbeeppc_update_row)
+	MCFG_MC6845_ADDR_CHANGED_CB(mbee_state, mbee256_update_addr)
 MACHINE_CONFIG_END
 
 /* Unused roms:
