@@ -53,11 +53,9 @@
 #include "machine/nvram.h"
 #include "cpu/z80/z80.h"
 #include "sound/2610intf.h"
-#include "imagedev/cartslot.h"
 #include "imagedev/chd_cd.h"
 #include "sound/cdda.h"
 #include "machine/megacdcd.h"
-#include "mcfglgcy.h"
 
 
 extern const char layout_neogeo[];
@@ -141,6 +139,8 @@ public:
 	DECLARE_READ16_MEMBER(aes_in1_r);
 	DECLARE_READ16_MEMBER(aes_in2_r);
 
+	DECLARE_INPUT_CHANGED_MEMBER(aes_jp1);
+
 	DECLARE_MACHINE_START(neocd);
 	DECLARE_MACHINE_START(neogeo);
 	DECLARE_MACHINE_RESET(neogeo);
@@ -192,6 +192,7 @@ public:
 
 	IRQ_CALLBACK_MEMBER(neocd_int_callback);
 
+	UINT8 *m_meminternal_data;
 protected:
 	required_ioport m_io_in2;
 	required_ioport m_io_in0;
@@ -227,7 +228,7 @@ protected:
 /* The NeoCD has an 8kB internal memory card, instead of memcard slots like the MVS and AES */
 READ16_MEMBER(ng_aes_state::neocd_memcard_r)
 {
-	return m_memcard_data[offset] | 0xff00;
+	return m_meminternal_data[offset] | 0xff00;
 }
 
 
@@ -235,7 +236,7 @@ WRITE16_MEMBER(ng_aes_state::neocd_memcard_w)
 {
 	if (ACCESSING_BITS_0_7)
 	{
-		m_memcard_data[offset] = data;
+		m_meminternal_data[offset] = data;
 	}
 }
 
@@ -373,7 +374,7 @@ WRITE16_MEMBER(ng_aes_state::neocd_control_w)
 		case 0x0140:
 //          bprintf(PRINT_NORMAL, _T("  - NGCD OBJ BUSREQ -> 0 (PC: 0x%06X)\n"), SekGetPC(-1));
 			m_has_sprite_bus = true;
-			optimize_sprite_data();
+			m_sprgen->optimize_sprite_data();
 			break;
 		case 0x0142:
 //          bprintf(PRINT_NORMAL, _T("  - NGCD PCM BUSREQ -> 0 (PC: 0x%06X)\n"), SekGetPC(-1));
@@ -409,7 +410,8 @@ WRITE16_MEMBER(ng_aes_state::neocd_control_w)
 				// writes 00 / 01 / ff
 				printf("MapVectorTable? %04x %04x\n",data,mem_mask);
 
-				m_bank_vectors->set_entry(data == 0 ? 0 : 1);
+				//m_bank_vectors->set_entry(data == 0 ? 0 : 1);
+				m_use_cart_vectors = (data == 0 ? 0 : 1);
 			}
 
 //extern INT32 bRunPause;
@@ -992,7 +994,7 @@ void ng_aes_state::common_machine_start()
 	neogeo_main_cpu_banking_init();
 
 	/* set the initial audio CPU ROM banks */
-	neogeo_audio_cpu_banking_init();
+	neogeo_audio_cpu_banking_init(1);
 
 	create_interrupt_timers();
 
@@ -1010,19 +1012,29 @@ void ng_aes_state::common_machine_start()
 	save_item(NAME(m_display_position_interrupt_pending));
 	save_item(NAME(m_irq3_pending));
 	save_item(NAME(m_controller_select));
-	save_item(NAME(m_main_cpu_bank_address));
+	//save_item(NAME(m_main_cpu_bank_address));
 
 	machine().save().register_postload(save_prepost_delegate(FUNC(ng_aes_state::neogeo_postload), this));
+
+
+	m_cartslots[0] = m_cartslot1;
+	m_cartslots[1] = m_cartslot2;
+	m_cartslots[2] = m_cartslot3;
+	m_cartslots[3] = m_cartslot4;
+	m_cartslots[4] = m_cartslot5;
+	m_cartslots[5] = m_cartslot6;
+
+	m_sprgen->set_screen(m_screen);
+
+	m_sprgen->set_sprite_region(m_region_sprites->base(), m_region_sprites->bytes());
+	m_sprgen->set_fixed_regions(m_region_fixed->base(), m_region_fixed->bytes(), m_region_fixedbios);
+
 }
 
 MACHINE_START_MEMBER(ng_aes_state,neogeo)
 {
 	m_type = NEOGEO_AES;
 	common_machine_start();
-
-	/* initialize the memcard data structure */
-	m_memcard_data = auto_alloc_array_clear(machine(), UINT8, MEMCARD_SIZE);
-	save_pointer(NAME(m_memcard_data), 0x800);
 }
 
 MACHINE_START_MEMBER(ng_aes_state,neocd)
@@ -1034,17 +1046,14 @@ MACHINE_START_MEMBER(ng_aes_state,neocd)
 	m_vblank_level = 2;
 	m_raster_level = 1;
 
-
 	/* initialize the memcard data structure */
 	/* NeoCD doesn't have memcard slots, rather, it has a larger internal memory which works the same */
-	m_memcard_data = auto_alloc_array_clear(machine(), UINT8, 0x2000);
-	machine().device<nvram_device>("saveram")->set_base(m_memcard_data, 0x2000);
-	save_pointer(NAME(m_memcard_data), 0x2000);
+	m_meminternal_data = auto_alloc_array_clear(machine(), UINT8, 0x2000);
+	machine().device<nvram_device>("saveram")->set_base(m_meminternal_data, 0x2000);
+	save_pointer(NAME(m_meminternal_data), 0x2000);
 
-	// for custom vectors
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(ng_aes_state::neocd_int_callback),this));
-
-	m_bank_vectors->set_entry(0); // default to the BIOS vectors
+	//m_bank_vectors->set_entry(0); // default to the BIOS vectors
+	m_use_cart_vectors = 0;
 
 	m_tempcdc->reset_cd();
 }
@@ -1063,13 +1072,15 @@ MACHINE_RESET_MEMBER(ng_aes_state,neogeo)
 
 	/* reset system control registers */
 	for (offs = 0; offs < 8; offs++)
-		system_control_w(space, offs, 0, 0x00ff);
+		system_control_w(space, offs, 0);
+
+	// disable audiocpu nmi
+	m_audio_cpu_nmi_enabled = false;
+	m_audio_cpu_nmi_pending = false;
+	audio_cpu_check_nmi();
 
 	m_maincpu->reset();
 
-	// FIXME: this doesn't belong in the base system
-	reset_sma_rng();
-
 	start_interrupt_timers();
 
 	/* trigger the IRQ3 that was set by MACHINE_START */
@@ -1078,7 +1089,12 @@ MACHINE_RESET_MEMBER(ng_aes_state,neogeo)
 	m_recurse = false;
 
 	/* AES has no SFIX ROM and always uses the cartridge's */
-	neogeo_set_fixed_layer_source(1);
+	m_sprgen->neogeo_set_fixed_layer_source(1);
+
+	if (m_cartslots[0]) // if thie system has cart slots then do some extra initialization
+	{
+		set_slot_number(0);
+	}
 
 	NeoSpriteRAM = memregion("sprites")->base();
 	YM2610ADPCMAROM = memregion("ymsnd")->base();
@@ -1106,19 +1122,20 @@ MACHINE_RESET_MEMBER(ng_aes_state,neocd)
  *************************************/
 
 static ADDRESS_MAP_START( aes_main_map, AS_PROGRAM, 16, ng_aes_state )
-	AM_RANGE(0x000000, 0x00007f) AM_ROMBANK("vectors")
+//  AM_RANGE(0x000000, 0x00007f) AM_ROMBANK("vectors")
+	AM_RANGE(0x000000, 0x00007f) AM_READ(neogeo_slot_rom_low_bectors_r)
 	AM_RANGE(0x000080, 0x0fffff) AM_ROM
 	AM_RANGE(0x100000, 0x10ffff) AM_MIRROR(0x0f0000) AM_RAM
 	/* some games have protection devices in the 0x200000 region, it appears to map to cart space, not surprising, the ROM is read here too */
-	AM_RANGE(0x200000, 0x2fffff) AM_ROMBANK("cartridge")
-	AM_RANGE(0x2ffff0, 0x2fffff) AM_WRITE(main_cpu_bank_select_w)
+	//AM_RANGE(0x200000, 0x2fffff) AM_ROMBANK("cartridge")
+	//AM_RANGE(0x2ffff0, 0x2fffff) AM_WRITE(main_cpu_bank_select_w)
 	AM_RANGE(0x300000, 0x300001) AM_MIRROR(0x01fffe) AM_READ(aes_in0_r)
-	AM_RANGE(0x320000, 0x320001) AM_MIRROR(0x01fffe) AM_READ_PORT("AUDIO") AM_WRITE(audio_command_w)
+	AM_RANGE(0x320000, 0x320001) AM_MIRROR(0x01fffe) AM_READ_PORT("AUDIO") AM_WRITE8(audio_command_w, 0xff00)
 	AM_RANGE(0x340000, 0x340001) AM_MIRROR(0x01fffe) AM_READ(aes_in1_r)
 	AM_RANGE(0x360000, 0x37ffff) AM_READ(neogeo_unmapped_r)
 	AM_RANGE(0x380000, 0x380001) AM_MIRROR(0x01fffe) AM_READ(aes_in2_r)
-	AM_RANGE(0x380000, 0x38007f) AM_MIRROR(0x01ff80) AM_WRITE(io_control_w)
-	AM_RANGE(0x3a0000, 0x3a001f) AM_MIRROR(0x01ffe0) AM_READ(neogeo_unmapped_r) AM_WRITE(system_control_w)
+	AM_RANGE(0x380000, 0x38007f) AM_MIRROR(0x01ff80) AM_WRITE8(io_control_w, 0x00ff)
+	AM_RANGE(0x3a0000, 0x3a001f) AM_MIRROR(0x01ffe0) AM_READ(neogeo_unmapped_r) AM_WRITE8(system_control_w, 0x00ff)
 	AM_RANGE(0x3c0000, 0x3c0007) AM_MIRROR(0x01fff8) AM_READ(neogeo_video_register_r)
 	AM_RANGE(0x3c0000, 0x3c000f) AM_MIRROR(0x01fff0) AM_WRITE(neogeo_video_register_w)
 	AM_RANGE(0x3e0000, 0x3fffff) AM_READ(neogeo_unmapped_r)
@@ -1132,16 +1149,17 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( neocd_main_map, AS_PROGRAM, 16, ng_aes_state )
-	AM_RANGE(0x000000, 0x00007f) AM_READ_BANK("vectors") // writes will fall through to area below
+//  AM_RANGE(0x000000, 0x00007f) AM_READ_BANK("vectors") // writes will fall through to area below
+	AM_RANGE(0x000000, 0x00007f) AM_READ(banked_vectors_r)
 	AM_RANGE(0x000000, 0x1fffff) AM_RAM AM_REGION("maincpu", 0x00000)
 
 	AM_RANGE(0x300000, 0x300001) AM_MIRROR(0x01fffe) AM_READ(aes_in0_r)
-	AM_RANGE(0x320000, 0x320001) AM_MIRROR(0x01fffe) AM_READ_PORT("AUDIO") AM_WRITE(audio_command_w)
+	AM_RANGE(0x320000, 0x320001) AM_MIRROR(0x01fffe) AM_READ_PORT("AUDIO") AM_WRITE8(audio_command_w, 0xff00)
 	AM_RANGE(0x340000, 0x340001) AM_MIRROR(0x01fffe) AM_READ(aes_in1_r)
 	AM_RANGE(0x360000, 0x37ffff) AM_READ(neogeo_unmapped_r)
 	AM_RANGE(0x380000, 0x380001) AM_MIRROR(0x01fffe) AM_READ(aes_in2_r)
-	AM_RANGE(0x380000, 0x38007f) AM_MIRROR(0x01ff80) AM_WRITE(io_control_w)
-	AM_RANGE(0x3a0000, 0x3a001f) AM_MIRROR(0x01ffe0) AM_READ(neogeo_unmapped_r) AM_WRITE(system_control_w)
+	AM_RANGE(0x380000, 0x38007f) AM_MIRROR(0x01ff80) AM_WRITE8(io_control_w, 0x00ff)
+	AM_RANGE(0x3a0000, 0x3a001f) AM_MIRROR(0x01ffe0) AM_READ(neogeo_unmapped_r) AM_WRITE8(system_control_w, 0x00ff)
 	AM_RANGE(0x3c0000, 0x3c0007) AM_MIRROR(0x01fff8) AM_READ(neogeo_video_register_r)
 	AM_RANGE(0x3c0000, 0x3c000f) AM_MIRROR(0x01fff0) AM_WRITE(neogeo_video_register_w)
 	AM_RANGE(0x3e0000, 0x3fffff) AM_READ(neogeo_unmapped_r)
@@ -1174,11 +1192,10 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( neocd_audio_io_map, AS_IO, 8, ng_aes_state )
 	AM_RANGE(0x00, 0x00) AM_MIRROR(0xff00) AM_READWRITE(audio_command_r, soundlatch_clear_byte_w)
 	AM_RANGE(0x04, 0x07) AM_MIRROR(0xff00) AM_DEVREADWRITE("ymsnd", ym2610_device, read, write)
-	AM_RANGE(0x08, 0x08) AM_MIRROR(0xff00) /* write - NMI enable / acknowledge? (the data written doesn't matter) */
+	AM_RANGE(0x08, 0x08) AM_MIRROR(0xff10) AM_MASK(0x0010) AM_WRITE(audio_cpu_enable_nmi_w)
 	// banking reads are actually NOP on NeoCD? but some games still access them
 //  AM_RANGE(0x08, 0x0b) AM_MIRROR(0xfff0) AM_MASK(0xff03) AM_READ(audio_cpu_bank_select_r)
 	AM_RANGE(0x0c, 0x0c) AM_MIRROR(0xff00) AM_WRITE(soundlatch2_byte_w)
-	AM_RANGE(0x18, 0x18) AM_MIRROR(0xff00) /* write - NMI disable? (the data written doesn't matter) */
 
 	// ??
 	AM_RANGE(0x80, 0x80) AM_MIRROR(0xff00) AM_WRITENOP
@@ -1310,15 +1327,15 @@ static INPUT_PORTS_START( mjpanel )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( aes )
-	PORT_START("CTRLSEL")  /* Select Controller Type */
+	PORT_START("CTRLSEL") /* Select Controller Type */
 	PORT_CONFNAME( 0x0f, 0x01, "P1 Controller")
-	PORT_CONFSETTING(  0x00, "Unconnected" )
-	PORT_CONFSETTING(  0x01, "NeoGeo Controller" )
-	PORT_CONFSETTING(  0x02, "NeoGeo Mahjong Panel" )
+	PORT_CONFSETTING(    0x00, "Unconnected" )
+	PORT_CONFSETTING(    0x01, "NeoGeo Controller" )
+	PORT_CONFSETTING(    0x02, "NeoGeo Mahjong Panel" )
 	PORT_CONFNAME( 0xf0, 0x10, "P2 Controller")
-	PORT_CONFSETTING(  0x00, "Unconnected" )
-	PORT_CONFSETTING(  0x10, "NeoGeo Controller" )
-	PORT_CONFSETTING(  0x20, "NeoGeo Mahjong Panel" )
+	PORT_CONFSETTING(    0x00, "Unconnected" )
+	PORT_CONFSETTING(    0x10, "NeoGeo Controller" )
+	PORT_CONFSETTING(    0x20, "NeoGeo Mahjong Panel" )
 
 	PORT_INCLUDE( controller )
 
@@ -1331,16 +1348,26 @@ static INPUT_PORTS_START( aes )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_START ) PORT_PLAYER(2)
 	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_SELECT ) PORT_PLAYER(2)
 	PORT_BIT( 0x7000, IP_ACTIVE_HIGH, IPT_CUSTOM ) PORT_CUSTOM_MEMBER(DEVICE_SELF, neogeo_state, get_memcard_status, NULL)
-	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_SPECIAL ) /* Hardware type (AES=0, MVS=1) Some games check this and show */
-													/* a piracy warning screen if the hardware and BIOS don't match */
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_SPECIAL ) /* Hardware type (AES=0, MVS=1) Some games check this and show a piracy warning screen if the hardware and BIOS don't match */
 
 	PORT_START("AUDIO")
 	PORT_BIT( 0x0007, IP_ACTIVE_HIGH, IPT_UNUSED )  /* AES has no coin slots, it's a console */
 	PORT_BIT( 0x0018, IP_ACTIVE_HIGH, IPT_UNKNOWN ) /* what is this? Universe BIOS uses these bits to detect MVS or AES hardware */
 	PORT_BIT( 0x00e0, IP_ACTIVE_HIGH, IPT_UNUSED )  /* AES has no upd4990a */
-	PORT_BIT( 0xff00, IP_ACTIVE_HIGH, IPT_CUSTOM ) PORT_CUSTOM_MEMBER(DEVICE_SELF, neogeo_state,get_audio_result, NULL)
+	PORT_BIT( 0xff00, IP_ACTIVE_HIGH, IPT_CUSTOM ) PORT_CUSTOM_MEMBER(DEVICE_SELF, neogeo_state, get_audio_result, NULL)
+
+	PORT_START("JP") // JP1 and JP2 are jumpers or solderpads depending on AES board revision, intended for use on the Development BIOS
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("Short JP1 (Debug Monitor)") PORT_CODE(KEYCODE_F1) PORT_CHANGED_MEMBER(DEVICE_SELF, ng_aes_state, aes_jp1, 0)
+//  PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_OTHER ) // what is JP2 for? somehow related to system reset, disable watchdog?
 INPUT_PORTS_END
 
+INPUT_CHANGED_MEMBER(ng_aes_state::aes_jp1)
+{
+	// Shorting JP1 causes a 68000 /BERR (Bus Error). On Dev Bios, this pops up the debug monitor.
+	if (newval)
+		m_maincpu->set_input_line(M68K_LINE_BUSERROR, HOLD_LINE);
+}
+
 
 static INPUT_PORTS_START( neocd )
 	PORT_INCLUDE( aes )
@@ -1361,15 +1388,12 @@ static MACHINE_CONFIG_DERIVED_CLASS( aes, neogeo_base, ng_aes_state )
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_PROGRAM_MAP(aes_main_map)
 
-	MCFG_MEMCARD_HANDLER(neogeo)
+	MCFG_NEOGEO_MEMCARD_ADD("memcard")
 
 	MCFG_MACHINE_START_OVERRIDE(ng_aes_state, neogeo)
 	MCFG_MACHINE_RESET_OVERRIDE(ng_aes_state, neogeo)
 
-	MCFG_CARTSLOT_ADD("cart")
-	MCFG_CARTSLOT_LOAD(ng_aes_state,neo_cartridge)
-	MCFG_CARTSLOT_INTERFACE("neo_cart")
-	MCFG_CARTSLOT_MANDATORY
+	MCFG_NEOGEO_CARTRIDGE_ADD("cartslot1", neogeo_cart, NULL)
 
 	MCFG_SOFTWARE_LIST_ADD("cart_list","neogeo")
 	MCFG_SOFTWARE_LIST_FILTER("cart_list","AES")
@@ -1443,27 +1467,21 @@ void ng_aes_state::NeoCDIRQUpdate(UINT8 byteValue)
 UINT32 ng_aes_state::screen_update_neocd(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
 {
 	// fill with background color first
-	bitmap.fill(m_pens[0x0fff], cliprect);
+	bitmap.fill(*m_bg_pen, cliprect);
 
-	if (m_has_sprite_bus) draw_sprites(bitmap, cliprect.min_y);
+	if (m_has_sprite_bus) m_sprgen->draw_sprites(bitmap, cliprect.min_y);
 
-	if (m_has_text_bus) draw_fixed_layer(bitmap, cliprect.min_y);
+	if (m_has_text_bus) m_sprgen->draw_fixed_layer(bitmap, cliprect.min_y);
 
 	return 0;
 }
 
 
-struct cdrom_interface neocd_cdrom =
-{
-	"neocd_cdrom",
-	NULL
-};
-
-
 static MACHINE_CONFIG_DERIVED_CLASS( neocd, neogeo_base, ng_aes_state )
 
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_PROGRAM_MAP(neocd_main_map)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(ng_aes_state,neocd_int_callback)
 
 	MCFG_CPU_MODIFY("audiocpu")
 	MCFG_CPU_PROGRAM_MAP(neocd_audio_map)
@@ -1484,7 +1502,8 @@ static MACHINE_CONFIG_DERIVED_CLASS( neocd, neogeo_base, ng_aes_state )
 	MCFG_MACHINE_START_OVERRIDE(ng_aes_state,neocd)
 	MCFG_MACHINE_RESET_OVERRIDE(ng_aes_state,neocd)
 
-	MCFG_CDROM_ADD( "cdrom",neocd_cdrom )
+	MCFG_CDROM_ADD( "cdrom" )
+	MCFG_CDROM_INTERFACE("neocd_cdrom")
 	MCFG_SOFTWARE_LIST_ADD("cd_list","neocd")
 MACHINE_CONFIG_END
 
@@ -1499,25 +1518,28 @@ MACHINE_CONFIG_END
 
 ROM_START( aes )
 	ROM_REGION16_BE( 0x20000, "mainbios", 0 )
-	ROM_SYSTEM_BIOS( 0, "asia",   "Asia AES" )
-	ROM_LOAD16_WORD_SWAP_BIOS( 0, "neo-epo.bin", 0x00000, 0x020000, CRC(d27a71f1) SHA1(1b3b22092f30c4d1b2c15f04d1670eb1e9fbea07) )    /* AES Console (Asia?) Bios */
-	ROM_SYSTEM_BIOS( 1, "japan",   "Japan AES" )
-	ROM_LOAD16_WORD_SWAP_BIOS( 1, "neo-po.bin",  0x00000, 0x020000, CRC(16d0c132) SHA1(4e4a440cae46f3889d20234aebd7f8d5f522e22c) )    /* AES Console (Japan) Bios */
-	ROM_SYSTEM_BIOS( 2, "unibios30","Universe Bios (Hack, Ver. 3.0)" )
-	ROM_LOAD16_WORD_SWAP_BIOS( 2, "uni-bios_3_0.rom",  0x00000, 0x020000, CRC(a97c89a9) SHA1(97a5eff3b119062f10e31ad6f04fe4b90d366e7f) ) /* Universe Bios v3.0 (hack) */
-	ROM_SYSTEM_BIOS( 3, "unibios23","Universe Bios (Hack, Ver. 2.3)" )
-	ROM_LOAD16_WORD_SWAP_BIOS( 3, "uni-bios_2_3.rom",  0x00000, 0x020000, CRC(27664eb5) SHA1(5b02900a3ccf3df168bdcfc98458136fd2b92ac0) ) /* Universe Bios v2.3 (hack) */
-	ROM_SYSTEM_BIOS( 4, "unibios23o","Universe Bios (Hack, Ver. 2.3, older?)" )
-	ROM_LOAD16_WORD_SWAP_BIOS( 4, "uni-bios_2_3o.rom",  0x00000, 0x020000, CRC(601720ae) SHA1(1b8a72c720cdb5ee3f1d735bbcf447b09204b8d9) ) /* Universe Bios v2.3 (hack) alt version, withdrawn? */
-	ROM_SYSTEM_BIOS( 5, "unibios22","Universe Bios (Hack, Ver. 2.2)" )
-	ROM_LOAD16_WORD_SWAP_BIOS( 5, "uni-bios_2_2.rom",  0x00000, 0x020000, CRC(2d50996a) SHA1(5241a4fb0c63b1a23fd1da8efa9c9a9bd3b4279c) ) /* Universe Bios v2.2 (hack) */
-	ROM_SYSTEM_BIOS( 6, "unibios21","Universe Bios (Hack, Ver. 2.1)" )
-	ROM_LOAD16_WORD_SWAP_BIOS( 6, "uni-bios_2_1.rom",  0x00000, 0x020000, CRC(8dabf76b) SHA1(c23732c4491d966cf0373c65c83c7a4e88f0082c) ) /* Universe Bios v2.1 (hack) */
-	ROM_SYSTEM_BIOS( 7, "unibios20","Universe Bios (Hack, Ver. 2.0)" )
-	ROM_LOAD16_WORD_SWAP_BIOS( 7, "uni-bios_2_0.rom",  0x00000, 0x020000, CRC(0c12c2ad) SHA1(37bcd4d30f3892078b46841d895a6eff16dc921e) ) /* Universe Bios v2.0 (hack) */
-	ROM_SYSTEM_BIOS( 8, "unibios13","Universe Bios (Hack, Ver. 1.3)" )
-	ROM_LOAD16_WORD_SWAP_BIOS( 8, "uni-bios_1_3.rom",  0x00000, 0x020000, CRC(b24b44a0) SHA1(eca8851d30557b97c309a0d9f4a9d20e5b14af4e) ) /* Universe Bios v1.3 (hack) */
-	// Universe BIOS versions older than 1.3 don't support AES hardware
+	ROM_SYSTEM_BIOS( 0, "asia", "Asia AES" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 0, "neo-epo.bin",       0x00000, 0x020000, CRC(d27a71f1) SHA1(1b3b22092f30c4d1b2c15f04d1670eb1e9fbea07) ) /* AES Console (Asia?) Bios */
+	ROM_SYSTEM_BIOS( 1, "japan", "Japan AES" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 1, "neo-po.bin",        0x00000, 0x020000, CRC(16d0c132) SHA1(4e4a440cae46f3889d20234aebd7f8d5f522e22c) ) /* AES Console (Japan) Bios */
+	ROM_SYSTEM_BIOS( 2, "devel", "Development System ROM" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 2, "neodebug.rom",      0x00000, 0x020000, CRC(698ebb7d) SHA1(081c49aa8cc7dad5939833dc1b18338321ea0a07) ) /* Official debug (development) ROM, for home-use base board */
+	ROM_SYSTEM_BIOS( 3, "unibios31", "Universe Bios (Hack, Ver. 3.1)" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 3, "uni-bios_3_1.rom",  0x00000, 0x020000, CRC(0c58093f) SHA1(29329a3448c2505e1ff45ffa75e61e9693165153) ) /* Universe Bios v3.1 (hack) */
+	ROM_SYSTEM_BIOS( 4, "unibios30", "Universe Bios (Hack, Ver. 3.0)" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 4, "uni-bios_3_0.rom",  0x00000, 0x020000, CRC(a97c89a9) SHA1(97a5eff3b119062f10e31ad6f04fe4b90d366e7f) ) /* Universe Bios v3.0 (hack) */
+	ROM_SYSTEM_BIOS( 5, "unibios23", "Universe Bios (Hack, Ver. 2.3)" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 5, "uni-bios_2_3.rom",  0x00000, 0x020000, CRC(27664eb5) SHA1(5b02900a3ccf3df168bdcfc98458136fd2b92ac0) ) /* Universe Bios v2.3 (hack) */
+	ROM_SYSTEM_BIOS( 6, "unibios23o", "Universe Bios (Hack, Ver. 2.3, older?)" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 6, "uni-bios_2_3o.rom", 0x00000, 0x020000, CRC(601720ae) SHA1(1b8a72c720cdb5ee3f1d735bbcf447b09204b8d9) ) /* Universe Bios v2.3 (hack) alt version, withdrawn? */
+	ROM_SYSTEM_BIOS( 7, "unibios22", "Universe Bios (Hack, Ver. 2.2)" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 7, "uni-bios_2_2.rom",  0x00000, 0x020000, CRC(2d50996a) SHA1(5241a4fb0c63b1a23fd1da8efa9c9a9bd3b4279c) ) /* Universe Bios v2.2 (hack) */
+	ROM_SYSTEM_BIOS( 8, "unibios21", "Universe Bios (Hack, Ver. 2.1)" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 8, "uni-bios_2_1.rom",  0x00000, 0x020000, CRC(8dabf76b) SHA1(c23732c4491d966cf0373c65c83c7a4e88f0082c) ) /* Universe Bios v2.1 (hack) */
+	ROM_SYSTEM_BIOS( 9, "unibios20", "Universe Bios (Hack, Ver. 2.0)" )
+	ROM_LOAD16_WORD_SWAP_BIOS( 9, "uni-bios_2_0.rom",  0x00000, 0x020000, CRC(0c12c2ad) SHA1(37bcd4d30f3892078b46841d895a6eff16dc921e) ) /* Universe Bios v2.0 (hack) */
+	ROM_SYSTEM_BIOS(10, "unibios13", "Universe Bios (Hack, Ver. 1.3)" )
+	ROM_LOAD16_WORD_SWAP_BIOS(10, "uni-bios_1_3.rom",  0x00000, 0x020000, CRC(b24b44a0) SHA1(eca8851d30557b97c309a0d9f4a9d20e5b14af4e) ) /* Universe Bios v1.3 (hack) - note: versions older than 1.3 don't support AES hardware */
 
 	ROM_REGION( 0x200000, "maincpu", ROMREGION_ERASEFF )
 
@@ -1588,11 +1610,12 @@ ROM_END
 
 DRIVER_INIT_MEMBER(ng_aes_state,neogeo)
 {
+	if (!m_cartslots[0]) m_banked_cart->install_banks(machine(), m_maincpu, m_region_maincpu->base(), m_region_maincpu->bytes());
 }
 
 
 /*    YEAR  NAME  PARENT COMPAT MACHINE INPUT  INIT     COMPANY      FULLNAME            FLAGS */
-CONS( 1990, aes,    0,      0,   aes,      aes, ng_aes_state,   neogeo,  "SNK", "Neo-Geo AES", 0)
+CONS( 1990, aes,    0,      0,   aes,      aes, ng_aes_state,   neogeo,  "SNK", "Neo-Geo AES", GAME_SUPPORTS_SAVE )
 
 DRIVER_INIT_MEMBER(ng_aes_state,neocdz)
 {
