@@ -538,14 +538,13 @@ WRITE8_MEMBER( ngp_state::flash1_w )
 
 
 static ADDRESS_MAP_START( ngp_mem, AS_PROGRAM, 8, ngp_state )
-	AM_RANGE( 0x000080, 0x0000bf )  AM_READWRITE(ngp_io_r, ngp_io_w)                            /* ngp/c specific i/o */
-	AM_RANGE( 0x004000, 0x006fff )  AM_RAM AM_SHARE("mainram")                                  /* work ram */
-	AM_RANGE( 0x007000, 0x007fff )  AM_RAM AM_SHARE("share1")                                   /* shared with sound cpu */
-	AM_RANGE( 0x008000, 0x0087ff )  AM_DEVREADWRITE("k1ge", k1ge_device, reg_read, reg_write)   /* video registers */
-	AM_RANGE( 0x008800, 0x00bfff )  AM_DEVREADWRITE("k1ge", k1ge_device, vram_read, vram_write) /* Video RAM area */
-	AM_RANGE( 0x200000, 0x3fffff )  AM_ROM AM_WRITE(flash0_w) AM_REGION("cart", 0)              /* cart area #1 */
-	AM_RANGE( 0x800000, 0x9fffff )  AM_ROM AM_WRITE(flash1_w) AM_REGION("cart", 0x200000)       /* cart area #2 */
-	AM_RANGE( 0xff0000, 0xffffff )  AM_ROM AM_REGION("maincpu", 0)                              /* system rom */
+	AM_RANGE( 0x000080, 0x0000bf )  AM_READWRITE(ngp_io_r, ngp_io_w)                        /* ngp/c specific i/o */
+	AM_RANGE( 0x004000, 0x006fff )  AM_RAM AM_SHARE("mainram")                              /* work ram */
+	AM_RANGE( 0x007000, 0x007fff )  AM_RAM AM_SHARE("share1")                               /* shared with sound cpu */
+	AM_RANGE( 0x008000, 0x00bfff )  AM_DEVREADWRITE("k1ge", k1ge_device, read, write)       /* video chip */
+	AM_RANGE( 0x200000, 0x3fffff )  AM_ROM AM_WRITE(flash0_w) AM_REGION("cart", 0)          /* cart area #1 */
+	AM_RANGE( 0x800000, 0x9fffff )  AM_ROM AM_WRITE(flash1_w) AM_REGION("cart", 0x200000)   /* cart area #2 */
+	AM_RANGE( 0xff0000, 0xffffff )  AM_ROM AM_REGION("maincpu", 0)                          /* system rom */
 ADDRESS_MAP_END
 
 
@@ -568,8 +567,8 @@ WRITE8_MEMBER( ngp_state::ngp_z80_signal_main_w )
 
 
 static ADDRESS_MAP_START( z80_mem, AS_PROGRAM, 8, ngp_state )
-	AM_RANGE( 0x0000, 0x0FFF )  AM_RAM AM_SHARE("share1")                               /* shared with tlcs900 */
-	AM_RANGE( 0x4000, 0x4001 )  AM_DEVWRITE("t6w28", t6w28_device, write )                  /* sound chip (right, left) */
+	AM_RANGE( 0x0000, 0x0fff )  AM_RAM AM_SHARE("share1")                       /* shared with tlcs900 */
+	AM_RANGE( 0x4000, 0x4001 )  AM_DEVWRITE("t6w28", t6w28_device, write )      /* sound chip (right, left) */
 	AM_RANGE( 0x8000, 0x8000 )  AM_READWRITE( ngp_z80_comm_r, ngp_z80_comm_w )  /* main-sound communication */
 	AM_RANGE( 0xc000, 0xc000 )  AM_WRITE( ngp_z80_signal_main_w )               /* signal irq to main cpu */
 ADDRESS_MAP_END
@@ -837,10 +836,11 @@ MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( ngp, ngp_common )
 
-	MCFG_PALETTE_LENGTH( 8 )
-
 	MCFG_K1GE_ADD( "k1ge", XTAL_6_144MHz, "screen", WRITELINE( ngp_state, ngp_vblank_pin_w ), WRITELINE( ngp_state, ngp_hblank_pin_w ) )
 
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_PALETTE("k1ge:palette")
+
 	MCFG_CARTSLOT_ADD("cart")
 	MCFG_CARTSLOT_EXTENSION_LIST("bin,ngp,npc,ngc")
 	MCFG_CARTSLOT_NOT_MANDATORY
@@ -855,11 +855,11 @@ MACHINE_CONFIG_END
 
 
 static MACHINE_CONFIG_DERIVED( ngpc, ngp_common )
-
-	MCFG_PALETTE_LENGTH( 4096 )
-
 	MCFG_K2GE_ADD( "k1ge", XTAL_6_144MHz, "screen", WRITELINE( ngp_state, ngp_vblank_pin_w ), WRITELINE( ngp_state, ngp_hblank_pin_w ) )
 
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_PALETTE("k1ge:palette")
+
 	MCFG_CARTSLOT_ADD("cart")
 	MCFG_CARTSLOT_EXTENSION_LIST("bin,ngp,npc,ngc")
 	MCFG_CARTSLOT_NOT_MANDATORY
