@@ -32,14 +32,8 @@ public:
 		m_user1(*this, "user1"),
 		m_bank1(*this, "bank1"),
 		m_bank2(*this, "bank2"),
-		m_key0(*this, "KEY0"),
-		m_key1(*this, "KEY1"),
-		m_key2(*this, "KEY2"),
-		m_key3(*this, "KEY3"),
-		m_key4(*this, "KEY4"),
-		m_key5(*this, "KEY5"),
-		m_joy0(*this, "JOY0"),
-		m_joy1(*this, "JOY1") { }
+		m_keyboard(*this, "KEY"),
+		m_joysticks(*this, "JOY") { }
 
 	required_device<cpu_device> m_maincpu;
 	required_device<i8244_device> m_i8244;
@@ -64,7 +58,7 @@ public:
 	DECLARE_DRIVER_INIT(odyssey2);
 	virtual void machine_start();
 	virtual void machine_reset();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(odyssey2);
 	UINT32 screen_update_odyssey2(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	DECLARE_WRITE_LINE_MEMBER(the_voice_lrq_callback);
 	DECLARE_WRITE_LINE_MEMBER(irq_callback);
@@ -87,14 +81,8 @@ protected:
 	required_memory_bank m_bank1;
 	required_memory_bank m_bank2;
 
-	required_ioport m_key0;
-	required_ioport m_key1;
-	required_ioport m_key2;
-	required_ioport m_key3;
-	required_ioport m_key4;
-	required_ioport m_key5;
-	required_ioport m_joy0;
-	required_ioport m_joy1;
+	required_ioport_array<6> m_keyboard;
+	required_ioport_array<2> m_joysticks;
 
 	void switch_banks();
 };
@@ -111,7 +99,7 @@ public:
 	required_device<i8243_device> m_i8243;
 	required_device<ef9340_1_device> m_ef9340_1;
 
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(g7400);
 	virtual void machine_start();
 	virtual void machine_reset();
 	DECLARE_WRITE8_MEMBER(p2_write);
@@ -155,7 +143,7 @@ ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( odyssey2 )
-	PORT_START("KEY0")      /* IN0 */
+	PORT_START("KEY.0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_0) PORT_CHAR('0')
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_1) PORT_CHAR('1')
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_2) PORT_CHAR('2')
@@ -165,7 +153,7 @@ static INPUT_PORTS_START( odyssey2 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_6) PORT_CHAR('6')
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_7) PORT_CHAR('7')
 
-	PORT_START("KEY1")      /* IN1 */
+	PORT_START("KEY.1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_8) PORT_CHAR('8')
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_9) PORT_CHAR('9')
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_NAME("?? :") PORT_CODE(KEYCODE_F1) PORT_CHAR(UCHAR_MAMEKEY(F1))
@@ -175,7 +163,7 @@ static INPUT_PORTS_START( odyssey2 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_L) PORT_CHAR('L')
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_P) PORT_CHAR('P')
 
-	PORT_START("KEY2")      /* IN2 */
+	PORT_START("KEY.2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_PLUS_PAD) PORT_CHAR('+')
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_W) PORT_CHAR('W')
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_E) PORT_CHAR('E')
@@ -185,7 +173,7 @@ static INPUT_PORTS_START( odyssey2 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_I) PORT_CHAR('I')
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_O) PORT_CHAR('O')
 
-	PORT_START("KEY3")      /* IN3 */
+	PORT_START("KEY.3")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_Q) PORT_CHAR('Q')
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_S) PORT_CHAR('S')
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_D) PORT_CHAR('D')
@@ -195,7 +183,7 @@ static INPUT_PORTS_START( odyssey2 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_J) PORT_CHAR('J')
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_K) PORT_CHAR('K')
 
-	PORT_START("KEY4")      /* IN4 */
+	PORT_START("KEY.4")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_A) PORT_CHAR('A')
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_Z) PORT_CHAR('Z')
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_X) PORT_CHAR('X')
@@ -205,7 +193,7 @@ static INPUT_PORTS_START( odyssey2 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_M) PORT_CHAR('M')
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_STOP) PORT_CHAR('.')
 
-	PORT_START("KEY5")      /* IN5 */
+	PORT_START("KEY.5")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_MINUS) PORT_CHAR('-')
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_ASTERISK) PORT_CHAR('*')
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_CODE(KEYCODE_SLASH_PAD) PORT_CHAR('/')
@@ -215,7 +203,7 @@ static INPUT_PORTS_START( odyssey2 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_NAME("CLR") PORT_CODE(KEYCODE_BACKSPACE) PORT_CHAR(8)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_KEYBOARD ) PORT_NAME("ENT") PORT_CODE(KEYCODE_ENTER) PORT_CHAR('\r')
 
-	PORT_START("JOY0")      /* IN6 */
+	PORT_START("JOY.0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP)     PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT)  PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN)   PORT_PLAYER(1)
@@ -223,7 +211,7 @@ static INPUT_PORTS_START( odyssey2 )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1)         PORT_PLAYER(1)
 	PORT_BIT( 0xe0, 0xe0,    IPT_UNUSED )
 
-	PORT_START("JOY1")      /* IN7 */
+	PORT_START("JOY.1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP)     PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT)  PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN)   PORT_PLAYER(2)
@@ -264,16 +252,16 @@ const UINT8 odyssey2_colors[] =
 };
 
 
-void odyssey2_state::palette_init()
+PALETTE_INIT_MEMBER(odyssey2_state, odyssey2)
 {
 	for ( int i = 0; i < 16; i++ )
 	{
-		palette_set_color_rgb( machine(), i, odyssey2_colors[i*3], odyssey2_colors[i*3+1], odyssey2_colors[i*3+2] );
+		palette.set_pen_color( i, odyssey2_colors[i*3], odyssey2_colors[i*3+1], odyssey2_colors[i*3+2] );
 	}
 }
 
 
-void g7400_state::palette_init()
+PALETTE_INIT_MEMBER(g7400_state, g7400)
 {
 	const UINT8 g7400_colors[] =
 	{
@@ -299,7 +287,7 @@ void g7400_state::palette_init()
 
 	for ( int i = 0; i < 16; i++ )
 	{
-		palette_set_color_rgb( machine(), i, g7400_colors[i*3], g7400_colors[i*3+1], g7400_colors[i*3+2] );
+		palette.set_pen_color( i, g7400_colors[i*3], g7400_colors[i*3+1], g7400_colors[i*3+2] );
 	}
 }
 
@@ -588,13 +576,12 @@ READ8_MEMBER(odyssey2_state::p2_read)
 {
 	UINT8 h = 0xFF;
 	int i, j;
-	ioport_port* ioports[] = { m_key0, m_key1, m_key2, m_key3, m_key4, m_key5 };
 
 	if (!(m_p1 & P1_KEYBOARD_SCAN_ENABLE))
 	{
 		if ((m_p2 & P2_KEYBOARD_SELECT_MASK) <= 5)  /* read keyboard */
 		{
-			h &= ioports[m_p2 & P2_KEYBOARD_SELECT_MASK]->read();
+			h &= m_keyboard[m_p2 & P2_KEYBOARD_SELECT_MASK]->read();
 		}
 
 		for (i= 0x80, j = 0; i > 0; i >>= 1, j++)
@@ -641,12 +628,12 @@ READ8_MEMBER(odyssey2_state::bus_read)
 
 	if ((m_p2 & P2_KEYBOARD_SELECT_MASK) == 1)
 	{
-		data &= m_joy0->read();       /* read joystick 1 */
+		data &= m_joysticks[0]->read();
 	}
 
 	if ((m_p2 & P2_KEYBOARD_SELECT_MASK) == 0)
 	{
-		data &= m_joy1->read();       /* read joystick 2 */
+		data &= m_joysticks[1]->read();
 	}
 
 	return data;
@@ -748,13 +735,6 @@ static GFXDECODE_START( odyssey2 )
 GFXDECODE_END
 
 
-static const sp0256_interface the_voice_sp0256 =
-{
-	DEVCB_DRIVER_LINE_MEMBER(odyssey2_state,the_voice_lrq_callback),
-	DEVCB_NULL
-};
-
-
 static MACHINE_CONFIG_FRAGMENT( odyssey2_cartslot )
 	MCFG_CARTSLOT_ADD("cart")
 	MCFG_CARTSLOT_EXTENSION_LIST("bin,rom")
@@ -775,9 +755,11 @@ static MACHINE_CONFIG_START( odyssey2, odyssey2_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS( XTAL_7_15909MHz/2 * 2, i8244_device::LINE_CLOCKS, i8244_device::START_ACTIVE_SCAN, i8244_device::END_ACTIVE_SCAN, i8244_device::LINES, i8244_device::START_Y, i8244_device::START_Y + i8244_device::SCREEN_HEIGHT )
 	MCFG_SCREEN_UPDATE_DRIVER(odyssey2_state, screen_update_odyssey2)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE( odyssey2 )
-	MCFG_PALETTE_LENGTH(32)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", odyssey2 )
+	MCFG_PALETTE_ADD("palette", 32)
+	MCFG_PALETTE_INIT_OWNER(odyssey2_state, odyssey2)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -785,7 +767,7 @@ static MACHINE_CONFIG_START( odyssey2, odyssey2_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
 	MCFG_SOUND_ADD("sp0256_speech", SP0256, 3120000)
-	MCFG_SOUND_CONFIG(the_voice_sp0256)
+	MCFG_SP0256_DATA_REQUEST_CB(WRITELINE(odyssey2_state, the_voice_lrq_callback))
 	/* The Voice uses a speaker with its own volume control so the relative volumes to use are subjective, these sound good */
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 
@@ -804,9 +786,11 @@ static MACHINE_CONFIG_START( videopac, odyssey2_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS( XTAL_17_73447MHz/5 * 2, i8244_device::LINE_CLOCKS, i8244_device::START_ACTIVE_SCAN, i8244_device::END_ACTIVE_SCAN, i8245_device::LINES, i8244_device::START_Y, i8244_device::START_Y + i8244_device::SCREEN_HEIGHT )
 	MCFG_SCREEN_UPDATE_DRIVER(odyssey2_state, screen_update_odyssey2)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE( odyssey2 )
-	MCFG_PALETTE_LENGTH(16)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", odyssey2 )
+	MCFG_PALETTE_ADD("palette", 16)
+	MCFG_PALETTE_INIT_OWNER(odyssey2_state, odyssey2)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -814,7 +798,7 @@ static MACHINE_CONFIG_START( videopac, odyssey2_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
 	MCFG_SOUND_ADD("sp0256_speech", SP0256, 3120000)
-	MCFG_SOUND_CONFIG(the_voice_sp0256)
+	MCFG_SP0256_DATA_REQUEST_CB(WRITELINE(odyssey2_state, the_voice_lrq_callback))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 
 	MCFG_FRAGMENT_ADD(odyssey2_cartslot)
@@ -832,9 +816,11 @@ static MACHINE_CONFIG_START( g7400, g7400_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS( 3540000 * 2, i8244_device::LINE_CLOCKS, i8244_device::START_ACTIVE_SCAN, i8244_device::END_ACTIVE_SCAN, i8245_device::LINES, i8244_device::START_Y, i8244_device::START_Y + i8244_device::SCREEN_HEIGHT )
 	MCFG_SCREEN_UPDATE_DRIVER(odyssey2_state, screen_update_odyssey2)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE( odyssey2 )
-	MCFG_PALETTE_LENGTH(16)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", odyssey2 )
+	MCFG_PALETTE_ADD("palette", 16)
+	MCFG_PALETTE_INIT_OWNER(g7400_state, g7400)
 
 	MCFG_I8243_ADD( "i8243", NOOP, WRITE8(g7400_state,i8243_port_w))
 
@@ -845,7 +831,7 @@ static MACHINE_CONFIG_START( g7400, g7400_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
 	MCFG_SOUND_ADD("sp0256_speech", SP0256, 3120000)
-	MCFG_SOUND_CONFIG(the_voice_sp0256)
+	MCFG_SP0256_DATA_REQUEST_CB(WRITELINE(odyssey2_state, the_voice_lrq_callback))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 
 	MCFG_FRAGMENT_ADD(odyssey2_cartslot)
@@ -866,9 +852,11 @@ static MACHINE_CONFIG_START( odyssey3, g7400_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS( 3540000 * 2, i8244_device::LINE_CLOCKS, i8244_device::START_ACTIVE_SCAN, i8244_device::END_ACTIVE_SCAN, i8244_device::LINES, i8244_device::START_Y, i8244_device::START_Y + i8244_device::SCREEN_HEIGHT )
 	MCFG_SCREEN_UPDATE_DRIVER(odyssey2_state, screen_update_odyssey2)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE( odyssey2 )
-	MCFG_PALETTE_LENGTH(16)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", odyssey2 )
+	MCFG_PALETTE_ADD("palette", 16)
+	MCFG_PALETTE_INIT_OWNER(g7400_state, g7400)
 
 	MCFG_I8243_ADD( "i8243", NOOP, WRITE8(g7400_state,i8243_port_w))
 
@@ -879,7 +867,7 @@ static MACHINE_CONFIG_START( odyssey3, g7400_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
 	MCFG_SOUND_ADD("sp0256_speech", SP0256, 3120000)
-	MCFG_SOUND_CONFIG(the_voice_sp0256)
+	MCFG_SP0256_DATA_REQUEST_CB(WRITELINE(odyssey2_state, the_voice_lrq_callback))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 
 	MCFG_FRAGMENT_ADD(odyssey2_cartslot)
