@@ -10,7 +10,6 @@
         - fix MisterX LCD
         - MisterX bankswitch
         - dump the chargen
-        - verify pc2000 cartridge interface (I don't have dump for test it)
 
 ****************************************************************************/
 
@@ -18,9 +17,11 @@
 #include "emu.h"
 #include "cpu/z80/z80.h"
 #include "video/hd44780.h"
+#include "video/sed1520.h"
 #include "sound/beep.h"
 #include "imagedev/cartslot.h"
 #include "rendlay.h"
+#include "gl3000s.lh"
 
 
 class pc2000_state : public driver_device
@@ -31,13 +32,15 @@ public:
 			m_maincpu(*this, "maincpu"),
 			m_lcdc(*this, "hd44780"),
 			m_beep(*this, "beeper"),
+			m_bank0(*this, "bank0"),
 			m_bank1(*this, "bank1"),
 			m_bank2(*this, "bank2")
 		{ }
 
 	required_device<cpu_device> m_maincpu;
-	required_device<hd44780_device> m_lcdc;
+	optional_device<hd44780_device> m_lcdc;
 	required_device<beep_device> m_beep;
+	optional_memory_bank m_bank0;
 	required_memory_bank m_bank1;
 	optional_memory_bank m_bank2;
 
@@ -46,15 +49,40 @@ public:
 
 	virtual void machine_start();
 	virtual void machine_reset();
-	UINT32 screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 
 	DECLARE_READ8_MEMBER( key_matrix_r );
 	DECLARE_WRITE8_MEMBER( key_matrix_w );
+	DECLARE_WRITE8_MEMBER( rombank0_w );
 	DECLARE_WRITE8_MEMBER( rombank1_w );
 	DECLARE_WRITE8_MEMBER( rombank2_w );
 	DECLARE_READ8_MEMBER( beep_r );
 	DECLARE_WRITE8_MEMBER( beep_w );
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(pc2000);
+};
+
+class gl3000s_state : public pc2000_state
+{
+public:
+	gl3000s_state(const machine_config &mconfig, device_type type, const char *tag)
+		: pc2000_state(mconfig, type, tag),
+			m_lcdc_r(*this, "sed1520_r"),
+			m_lcdc_l(*this, "sed1520_l")
+		{ }
+
+	required_device<sed1520_device> m_lcdc_r;
+	required_device<sed1520_device> m_lcdc_l;
+
+	UINT32 screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
+};
+
+class gl4004_state : public pc2000_state
+{
+public:
+	gl4004_state(const machine_config &mconfig, device_type type, const char *tag)
+		: pc2000_state(mconfig, type, tag)
+		{ }
+
+	virtual void machine_start();
 };
 
 class pc1000_state : public pc2000_state
@@ -68,7 +96,6 @@ public:
 	virtual void machine_start();
 	virtual void machine_reset();
 
-	DECLARE_DEVICE_IMAGE_LOAD_MEMBER( cart_load );
 	DECLARE_READ8_MEMBER( kb_r );
 	DECLARE_READ8_MEMBER( lcdc_data_r );
 	DECLARE_WRITE8_MEMBER( lcdc_data_w );
@@ -100,21 +127,22 @@ WRITE8_MEMBER( pc2000_state::key_matrix_w )
 	m_mux_data = data;
 }
 
+WRITE8_MEMBER( pc2000_state::rombank0_w )
+{
+	m_bank0->set_entry(data & 0x1f);
+}
+
 WRITE8_MEMBER( pc2000_state::rombank1_w )
 {
-	m_bank1->set_entry(data & 0x0f);
+	m_bank1->set_entry(data & 0x1f);
 }
 
 WRITE8_MEMBER( pc2000_state::rombank2_w )
 {
-	if (data == 0x80)
-	{
-		m_bank2->set_entry(data & 0x10);   //cartridge
-	}
+	if (data & 0x80)
+		m_bank2->set_entry(data & 0x8f);   //cartridge
 	else
-	{
-		m_bank2->set_entry(data & 0x0f);
-	}
+		m_bank2->set_entry(data & 0x1f);
 }
 
 READ8_MEMBER( pc2000_state::beep_r )
@@ -130,7 +158,7 @@ WRITE8_MEMBER( pc2000_state::beep_w )
 
 static ADDRESS_MAP_START(pc2000_mem, AS_PROGRAM, 8, pc2000_state)
 	ADDRESS_MAP_UNMAP_HIGH
-	AM_RANGE(0x0000, 0x3fff) AM_ROM AM_REGION("bios", 0x00000)
+	AM_RANGE(0x0000, 0x3fff) AM_ROMBANK("bank0")
 	AM_RANGE(0x4000, 0x7fff) AM_ROMBANK("bank1")
 	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK("bank2")    //0x8000 - 0xbfff tests a cartridge, header is 0x55 0xaa 0x59 0x45, if it succeeds a jump at 0x8004 occurs
 	AM_RANGE(0xc000, 0xdfff) AM_RAM
@@ -139,6 +167,7 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( pc2000_io , AS_IO, 8, pc2000_state)
 	ADDRESS_MAP_UNMAP_HIGH
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_WRITE(rombank0_w)
 	AM_RANGE(0x01, 0x01) AM_WRITE(rombank1_w)
 	AM_RANGE(0x03, 0x03) AM_WRITE(rombank2_w)
 	AM_RANGE(0x0a, 0x0b) AM_DEVREADWRITE("hd44780", hd44780_device, read, write)
@@ -146,6 +175,110 @@ static ADDRESS_MAP_START( pc2000_io , AS_IO, 8, pc2000_state)
 	AM_RANGE(0x12, 0x12) AM_READWRITE(beep_r, beep_w)
 ADDRESS_MAP_END
 
+
+UINT32 gl3000s_state::screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
+{
+	bitmap.fill(0);
+	m_lcdc_l->screen_update(screen, bitmap, cliprect);
+	m_lcdc_r->screen_update(screen, bitmap, cliprect);
+	return 0;
+}
+
+int gl3000s_sed1520_screen_update(device_t &device, bitmap_ind16 &bitmap, const rectangle &cliprect, UINT8 *vram, int start_line, int adc, int start_x)
+{
+	for (int y=0; y<2; y++)
+	{
+		int row_pos = 0;
+		for (int x=0; x<61; x++)
+		{
+			int addr = (y + (start_line >> 3)) * 80 + row_pos;
+			for (int yi=0; yi<8; yi++)
+			{
+				int px = start_x - (adc ? (80 - x) : x);
+				int py = 8 + y*8 + yi;
+
+				if (cliprect.contains(px, py))
+					bitmap.pix16(py, px) = (vram[addr % 0x140] >> yi) & 1;
+			}
+
+			row_pos++;
+		}
+	}
+	return 0;
+}
+
+SED1520_UPDATE_CB(gl3000s_screen_update_right)
+{
+	return gl3000s_sed1520_screen_update(device, bitmap, cliprect, vram, start_line, adc, 119);
+}
+
+SED1520_UPDATE_CB(gl3000s_screen_update_left)
+{
+	UINT8 sec[3];
+	UINT8 points[2][3];
+	memset(sec, 0, sizeof(sec));
+	memset(points, 0, sizeof(points));
+
+	for (int y=0; y<2; y++)
+		for (int x=59; x<85; x++)
+		{
+			UINT8 data = vram[(y*0x50 + x) % 0x140];
+			int dpos = (x - 74) / 2;
+
+			for (int yi=0; yi<8; yi++)
+			{
+				int state = (data >> yi) & 1;
+
+				if (y == 0 && (x == 74 || x == 76 || x == 78) && yi == 7)         sec[dpos] |= (state << 0);
+				else if (y == 0 && (x == 74 || x == 76 || x == 78) && yi == 0)    sec[dpos] |= (state << 2);
+				else if (y == 0 && (x == 75 || x == 77 || x == 79) && yi == 7)    sec[dpos] |= (state << 5);
+				else if (y == 0 && (x == 75 || x == 77 || x == 79) && yi == 0)    sec[dpos] |= (state << 4);
+				else if (y == 0 && (x == 75 || x == 77 || x == 79) && yi == 1)    sec[dpos] |= (state << 3);
+				else if (y == 1 && (x == 74 || x == 76 || x == 78) && yi == 7)    sec[dpos] |= (state << 1);
+				else if (y == 1 && (x == 75 || x == 77 || x == 79) && yi == 7)    sec[dpos] |= (state << 6);
+
+				else if ((x == 74 || x == 76 || x == 78) && yi == 3)    points[y][dpos] |= (state << 0);
+				else if ((x == 74 || x == 76 || x == 78) && yi == 4)    points[y][dpos] |= (state << 1);
+				else if ((x == 74 || x == 76 || x == 78) && yi == 5)    points[y][dpos] |= (state << 2);
+				else if ((x == 75 || x == 77 || x == 79) && yi == 3)    points[y][dpos] |= (state << 5);
+				else if ((x == 75 || x == 77 || x == 79) && yi == 4)    points[y][dpos] |= (state << 6);
+				else if ((x == 75 || x == 77 || x == 79) && yi == 5)    points[y][dpos] |= (state << 4);
+				else if ((x == 75 || x == 77 || x == 79) && yi == 6)    points[y][dpos] |= (state << 3);
+
+				else if (y == 1 && x >= 65 && x <= 68 && yi == 7)       output_set_indexed_value("LEV", x - 64, state);
+				else if (x >= 59  && x <= 60 && yi == 7)                output_set_indexed_value("TRY", x - 58 + (y ? 0 : 1), state);
+				else if (y == 1 && x >= 61 && x <= 64 && yi == 7)       output_set_indexed_value("TICK", x - 59, state);
+				else if (y == 0 && x >= 61 && x <= 64 && yi == 7)       output_set_indexed_value("TICK", 62 - x + (x >= 63 ? 8 : 0), state);
+
+				else if (x < 74 && yi < 7)
+				{
+					int cx = x - 59;
+					bitmap.pix16(yi, (y ? 0 : 89) + (16 - (cx + cx / 5))) = state;
+				}
+			}
+		}
+
+	for(int i=0; i<3; i++)
+	{
+		output_set_indexed_value("TIME", i, sec[i]);
+		output_set_indexed_value("P1", i, points[1][i]);
+		output_set_indexed_value("P2", i, points[0][i]);
+	}
+
+	return gl3000s_sed1520_screen_update(device, bitmap, cliprect, vram, start_line, adc, 58);
+}
+
+
+static ADDRESS_MAP_START( gl3000s_io , AS_IO, 8, gl3000s_state)
+	ADDRESS_MAP_UNMAP_HIGH
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x01, 0x01) AM_WRITE(rombank1_w)
+	AM_RANGE(0x03, 0x03) AM_WRITE(rombank2_w)
+	AM_RANGE(0x08, 0x09) AM_DEVREADWRITE("sed1520_r", sed1520_device, read, write)
+	AM_RANGE(0x0a, 0x0b) AM_DEVREADWRITE("sed1520_l", sed1520_device, read, write)
+	AM_RANGE(0x10, 0x11) AM_READWRITE(key_matrix_r, key_matrix_w)
+ADDRESS_MAP_END
+
 READ8_MEMBER( pc1000_state::kb_r )
 {
 	static const char *const bitnames[9] =
@@ -460,48 +593,172 @@ static INPUT_PORTS_START( pc1000 )
 	PORT_BIT(0xfc, IP_ACTIVE_LOW, IPT_UNUSED)
 INPUT_PORTS_END
 
+static INPUT_PORTS_START( gl3000s )
+	PORT_START("IN0")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_1) PORT_CHAR('1')
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_ESC)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_E) PORT_CHAR('E')
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_CAPSLOCK)
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD)
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Einstellen Antwort")
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_RIGHT)
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_LSHIFT) PORT_CODE(KEYCODE_RSHIFT)
 
-DEVICE_IMAGE_LOAD_MEMBER(pc1000_state, cart_load)
-{
-	UINT8 *cart = memregion("cart")->base();
+	PORT_START("IN1")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_2) PORT_CHAR('2')
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_Q) PORT_CHAR('Q')
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_R) PORT_CHAR('R')
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_A) PORT_CHAR('A')
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_X) PORT_CHAR('X')
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Hilfe")
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_SPACE)  PORT_CHAR(' ')
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_M) PORT_CHAR('M')
 
-	if (image.software_entry() == NULL)
-	{
-		UINT32 size = MIN(image.length(), memregion("cart")->bytes());
+	PORT_START("IN2")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_3) PORT_CHAR('3')
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_W) PORT_CHAR('W')
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_T) PORT_CHAR('T')
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_S) PORT_CHAR('S')
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_Y) PORT_CHAR('Y')
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Druck Symbol")
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_LEFT)
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_MINUS) PORT_CHAR('-')
 
-		if (image.fread(cart, size) != size)
-			return IMAGE_INIT_FAIL;
-	}
-	else
-	{
-		UINT32 size = MIN(image.get_software_region_length("rom"), memregion("cart")->bytes());
-		const char *pcb_type = image.get_feature("pcb_type");
+	PORT_START("IN3")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_4) PORT_CHAR('4')
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_Z) PORT_CHAR('Z')
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_D) PORT_CHAR('D')
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_K) PORT_CHAR('K')
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_SLASH) PORT_NAME("\xc3\x84")
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_DOWN)
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_UP)
 
-		if (pcb_type && !strcmp(pcb_type, "allgeme2"))
-			memcpy(cart, image.get_software_region("rom"), size >> 1);
-		else if (pcb_type && !strcmp(pcb_type, "ftrivia"))
-			memcpy(cart, image.get_software_region("rom") + (1<<16), size >> 1);
-		else
-			memcpy(cart, image.get_software_region("rom"), size);
-	}
+	PORT_START("IN4")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_5) PORT_CHAR('5')
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_U) PORT_CHAR('U')
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_F) PORT_CHAR('F')
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_J) PORT_CHAR('J')
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_C) PORT_CHAR('C')
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_INSERT)
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_N) PORT_CHAR('N')
 
-	return IMAGE_INIT_PASS;
-}
+	PORT_START("IN5")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_6) PORT_CHAR('6')
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_EQUALS)  PORT_NAME("\xc3\x9f")
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_P) PORT_CHAR('P')
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_QUOTE) PORT_CHAR('\'')
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_CLOSEBRACE)  PORT_NAME("\xc3\x96")
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_BACKSPACE)
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_KEYBOARD)
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_STOP) PORT_CHAR('.')
 
+	PORT_START("IN6")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_7) PORT_CHAR('7')
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_0) PORT_CHAR('0')
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_O) PORT_CHAR('O')
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_OPENBRACE)  PORT_NAME("\xc3\x9c")
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_L) PORT_CHAR('L')
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_PLUS_PAD) PORT_CHAR('+')
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_LALT) PORT_CODE(KEYCODE_RALT)
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_COMMA) PORT_CHAR(',')
+
+	PORT_START("IN7")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_8) PORT_CHAR('8')
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_9) PORT_CHAR('9')
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_I) PORT_CHAR('I')
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_G) PORT_CHAR('G')
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_H) PORT_CHAR('H')
+	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_V) PORT_CHAR('V')
+	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_ENTER) PORT_CHAR(13)
+	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_CODE(KEYCODE_B) PORT_CHAR('B')
+
+	PORT_START("IN8")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Off")
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("BASIC")              PORT_CODE(KEYCODE_DEL_PAD)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Logische Folgen")
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Bruch / Dezimalrechnen")
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Addition")
+	PORT_BIT(0xe0, IP_ACTIVE_LOW, IPT_UNUSED)
+
+	PORT_START("IN9")
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Textverarbeitung")   PORT_CODE(KEYCODE_ENTER_PAD)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Buchstabenschl" "\xc3\xbc" "ssel")
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Bruch / Prozentrechnen") PORT_CODE(KEYCODE_DEL)
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Subtraktion")        PORT_CODE(KEYCODE_HOME)
+	PORT_BIT(0xe1, IP_ACTIVE_LOW, IPT_UNUSED)
+
+	PORT_START("INA")
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Taschenrechner") PORT_CODE(KEYCODE_ASTERISK)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Gleitpfeile")    PORT_CODE(KEYCODE_MINUS_PAD)
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Algebra")        PORT_CODE(KEYCODE_SLASH_PAD)
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Multiplikation") PORT_CODE(KEYCODE_9_PAD)
+	PORT_BIT(0xe1, IP_ACTIVE_LOW, IPT_UNUSED)
+
+	PORT_START("INB")
+	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("ZusatzKassette") PORT_CODE(KEYCODE_8_PAD)
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Stufe")          PORT_CODE(KEYCODE_7_PAD)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Spieler")        PORT_CODE(KEYCODE_6_PAD)
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Zeichensuche")   PORT_CODE(KEYCODE_5_PAD)
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Division")       PORT_CODE(KEYCODE_4_PAD)
+	PORT_BIT(0xe0, IP_ACTIVE_LOW, IPT_UNUSED)
+
+	PORT_START("INC")
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Pr" "\xc3\xa4" "teritum")   PORT_CODE(KEYCODE_3_PAD)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Synonyme")       PORT_CODE(KEYCODE_2_PAD)
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Tipp Dich Fit")  PORT_CODE(KEYCODE_1_PAD)
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Super Schlau-Quiz")  PORT_CODE(KEYCODE_0_PAD)
+	PORT_BIT(0xe1, IP_ACTIVE_LOW, IPT_UNUSED)
+
+	PORT_START("IND")
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Silbentrennung")     PORT_CODE(KEYCODE_F12)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Knifflige Grammatik")  PORT_CODE(KEYCODE_F11)
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Textaufgaben")       PORT_CODE(KEYCODE_F10)
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Geographie-Quiz")    PORT_CODE(KEYCODE_F9)
+	PORT_BIT(0xe1, IP_ACTIVE_LOW, IPT_UNUSED)
+
+	PORT_START("INE")
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Wortr" "\xc3\xa4" "tsel")       PORT_CODE(KEYCODE_F8)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Verdrehte S" "\xc3\xa4" "tze")  PORT_CODE(KEYCODE_F7)
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Blitz-S" "\xc3\xa4" "tze")      PORT_CODE(KEYCODE_F6)
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Geschichte-Quiz")    PORT_CODE(KEYCODE_F5)
+	PORT_BIT(0xe1, IP_ACTIVE_LOW, IPT_UNUSED)
+
+	PORT_START("INF")
+	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Verr" "\xc3\xbc" "ckte R" "\xc3\xa4" "tsel")  PORT_CODE(KEYCODE_F4)
+	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Wortarten")                  PORT_CODE(KEYCODE_F3)
+	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Wortschlange")               PORT_CODE(KEYCODE_F2)
+	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Naturwissenschaften-Quiz")   PORT_CODE(KEYCODE_F1)
+	PORT_BIT(0xe1, IP_ACTIVE_LOW, IPT_UNUSED)
+INPUT_PORTS_END
 
 void pc2000_state::machine_start()
 {
 	UINT8 *bios = memregion("bios")->base();
 	UINT8 *cart = memregion("cart")->base();
 
+	m_bank0->configure_entries(0, 0x10, bios, 0x4000);
 	m_bank1->configure_entries(0, 0x10, bios, 0x4000);
 	m_bank2->configure_entries(0, 0x10, bios, 0x4000);
-	m_bank2->configure_entry(0x10, cart);
+	m_bank2->configure_entries(0x80, 0x10, cart, 0x4000);
+}
+
+void gl4004_state::machine_start()
+{
+	UINT8 *bios = memregion("bios")->base();
+	UINT8 *cart = memregion("cart")->base();
+
+	m_bank0->configure_entries(0, 0x20, bios, 0x4000);
+	m_bank1->configure_entries(0, 0x20, bios, 0x4000);
+	m_bank2->configure_entries(0, 0x20, bios, 0x4000);
+	m_bank2->configure_entries(0x80, 0x10, cart, 0x4000);
 }
 
 void pc2000_state::machine_reset()
 {
 	//set the initial bank
+	m_bank0->set_entry(0);
 	m_bank1->set_entry(0);
 	m_bank2->set_entry(0);
 }
@@ -517,10 +774,10 @@ void pc1000_state::machine_reset()
 	m_bank1->set_entry(0);
 }
 
-void pc2000_state::palette_init()
+PALETTE_INIT_MEMBER(pc2000_state, pc2000)
 {
-	palette_set_color(machine(), 0, MAKE_RGB(138, 146, 148));
-	palette_set_color(machine(), 1, MAKE_RGB(92, 83, 88));
+	palette.set_pen_color(0, rgb_t(138, 146, 148));
+	palette.set_pen_color(1, rgb_t(92, 83, 88));
 }
 
 static const gfx_layout hd44780_charlayout =
@@ -538,6 +795,7 @@ static GFXDECODE_START( pc2000 )
 	GFXDECODE_ENTRY( "hd44780:cgrom", 0x0000, hd44780_charlayout, 0, 1 )
 GFXDECODE_END
 
+
 static MACHINE_CONFIG_START( pc2000, pc2000_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu",Z80, XTAL_4MHz) /* probably not accurate */
@@ -552,9 +810,11 @@ static MACHINE_CONFIG_START( pc2000, pc2000_state )
 	MCFG_SCREEN_UPDATE_DEVICE("hd44780", hd44780_device, screen_update)
 	MCFG_SCREEN_SIZE(120, 18) //2x20 chars
 	MCFG_SCREEN_VISIBLE_AREA(0, 120-1, 0, 18-1)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_PALETTE_LENGTH(2)
-	MCFG_GFXDECODE(pc2000)
+	MCFG_PALETTE_ADD("palette", 2)
+	MCFG_PALETTE_INIT_OWNER(pc2000_state, pc2000)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", pc2000)
 	MCFG_DEFAULT_LAYOUT(layout_lcd)
 
 	MCFG_HD44780_ADD("hd44780")
@@ -567,10 +827,66 @@ static MACHINE_CONFIG_START( pc2000, pc2000_state )
 
 	MCFG_CARTSLOT_ADD("cart")
 	MCFG_CARTSLOT_EXTENSION_LIST("bin")
-	MCFG_CARTSLOT_INTERFACE("pc2000_cart")
+	MCFG_CARTSLOT_INTERFACE("genius_cart")
 	MCFG_CARTSLOT_NOT_MANDATORY
 MACHINE_CONFIG_END
 
+static MACHINE_CONFIG_DERIVED( gl2000, pc2000 )
+	MCFG_SOFTWARE_LIST_ADD("cart_list", "gl2000")
+	MCFG_SOFTWARE_LIST_COMPATIBLE_ADD("misterx_cart", "misterx")
+MACHINE_CONFIG_END
+
+static HD44780_PIXEL_UPDATE(gl4000_pixel_update)
+{
+	if (pos < 40)
+	{
+		static const UINT8 gl4000_display_layout[] =
+		{
+			0x00, 0x01, 0x02, 0x03, 0x28, 0x29, 0x2a, 0x2b, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x2c, 0x2d, 0x2e, 0x2f,
+			0x30, 0x31, 0x32, 0x33, 0x0c, 0x0d, 0x0e, 0x0f, 0x10, 0x11, 0x12, 0x13, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x3b,
+			0x14, 0x15, 0x16, 0x17, 0x3c, 0x3d, 0x3e, 0x3f, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f, 0x40, 0x41, 0x42, 0x43,
+			0x44, 0x45, 0x46, 0x47, 0x20, 0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27, 0x48, 0x49, 0x4a, 0x4b, 0x4c, 0x4d, 0x4e, 0x4f
+		};
+
+		UINT8 char_pos = gl4000_display_layout[line*40 + pos];
+		bitmap.pix16((char_pos / 20) * 9 + y, (char_pos % 20) * 6 + x) = state;
+	}
+}
+
+static MACHINE_CONFIG_DERIVED_CLASS( gl3000s, pc2000, gl3000s_state )
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_IO_MAP(gl3000s_io)
+
+	MCFG_DEVICE_REMOVE("hd44780")
+	MCFG_SED1520_ADD("sed1520_l", gl3000s_screen_update_left)   // left panel is 59 pixels (0-58)
+	MCFG_SED1520_ADD("sed1520_r", gl3000s_screen_update_right)  // right panel is 61 pixels (59-119)
+
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_SIZE(120, 24)
+	MCFG_SCREEN_VISIBLE_AREA(0, 120-1, 0, 24-1)
+	MCFG_SCREEN_UPDATE_DRIVER( gl3000s_state, screen_update )
+
+	MCFG_DEFAULT_LAYOUT(layout_gl3000s)
+
+	MCFG_DEVICE_REMOVE("gfxdecode")
+
+	MCFG_SOFTWARE_LIST_COMPATIBLE_ADD("gl2000_cart", "gl2000")
+	MCFG_SOFTWARE_LIST_COMPATIBLE_ADD("misterx_cart", "misterx")
+MACHINE_CONFIG_END
+
+static MACHINE_CONFIG_DERIVED_CLASS( gl4000, pc2000, gl4004_state )
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_SIZE(120, 36) // 4x20 chars
+	MCFG_SCREEN_VISIBLE_AREA(0, 120-1, 0, 36-1)
+
+	MCFG_DEVICE_MODIFY("hd44780")
+	MCFG_HD44780_LCD_SIZE(4, 20)
+	MCFG_HD44780_PIXEL_UPDATE_CB(gl4000_pixel_update)
+
+	MCFG_SOFTWARE_LIST_COMPATIBLE_ADD("gl2000_cart", "gl2000")
+	MCFG_SOFTWARE_LIST_COMPATIBLE_ADD("misterx_cart", "misterx")
+MACHINE_CONFIG_END
+
 static MACHINE_CONFIG_DERIVED_CLASS( misterx, pc2000, pc1000_state )
 	/* basic machine hardware */
 	MCFG_CPU_MODIFY("maincpu")
@@ -588,8 +904,7 @@ static MACHINE_CONFIG_DERIVED_CLASS( misterx, pc2000, pc1000_state )
 	MCFG_HD44780_PIXEL_UPDATE_CB(pc1000_pixel_update)
 
 	MCFG_CARTSLOT_MODIFY("cart")
-	MCFG_CARTSLOT_INTERFACE("pc1000_cart")
-	MCFG_CARTSLOT_LOAD(pc1000_state, cart_load)
+	MCFG_CARTSLOT_INTERFACE("genius_cart")
 
 	/* Software lists */
 	MCFG_SOFTWARE_LIST_ADD("cart_list", "misterx")
@@ -612,6 +927,14 @@ ROM_START( gl2000 )
 	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
 ROM_END
 
+ROM_START( gl2000c )
+	ROM_REGION( 0x40000, "bios", 0 )
+	ROM_LOAD( "27-5491-00", 0x000000, 0x020000, CRC(cbb9fe90) SHA1(a2a7a8afb027fe764a5998e3b35e87f291c24df1))
+
+	ROM_REGION( 0x40000, "cart", ROMREGION_ERASEFF )
+	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
+ROM_END
+
 ROM_START( gl2000p )
 	ROM_REGION( 0x40000, "bios", 0 )
 	ROM_LOAD( "27-5615-00_9534_d.bin", 0x000000, 0x040000, CRC(481c1000) SHA1(da6f60e5bb25145ec5239310296bedaabeeaee28))
@@ -620,7 +943,63 @@ ROM_START( gl2000p )
 	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
 ROM_END
 
-ROM_START( gln )
+ROM_START( gl3000s )
+	ROM_REGION(0x40000, "bios", 0)
+	ROM_LOAD( "27-5713-00", 0x000000, 0x040000, CRC(18b113e0) SHA1(27a12893c38068efa35a99fa97a260dbfbd497e3) )
+
+	ROM_REGION( 0x40000, "cart", ROMREGION_ERASEFF )
+	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
+ROM_END
+
+ROM_START( gl4000 )
+	ROM_REGION(0x80000, "bios", 0)
+	ROM_LOAD( "27-5480-00",   0x000000, 0x040000, CRC(8de047d3) SHA1(bb1d869954773bb7b8b51caa54531015d6b751ec) )
+
+	ROM_REGION( 0x40000, "cart", ROMREGION_ERASEFF )
+	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
+ROM_END
+
+ROM_START( gl4004 )
+	ROM_REGION(0x80000, "bios", 0)
+	ROM_LOAD( "27-5762-00.u2", 0x000000, 0x080000, CRC(fb242f0f) SHA1(aae1beeb94873e29920726ad35475641d9f1e94e) )
+
+	ROM_REGION( 0x40000, "cart", ROMREGION_ERASEFF )
+	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
+ROM_END
+
+ROM_START( gl5000 )
+	ROM_REGION(0x80000, "bios", 0)
+	ROM_LOAD( "27-5912-00.u1", 0x000000, 0x080000, CRC(9fe4c04a) SHA1(823d1d46e49e21f921260296874bc3ee5f718a5f) )
+
+	ROM_REGION( 0x40000, "cart", ROMREGION_ERASEFF )
+	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
+ROM_END
+
+ROM_START( gl5005x )
+	ROM_REGION(0x200000, "bios", 0)
+	ROM_LOAD( "27-6426-00.u1", 0x000000, 0x200000, CRC(adde3581) SHA1(80f2bde7c5c339534614f24a9ca6ea362ee2f816) )
+
+	ROM_REGION( 0x40000, "cart", ROMREGION_ERASEFF )
+	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
+ROM_END
+
+ROM_START( gmtt )
+	ROM_REGION(0x100000, "bios", 0)
+	ROM_LOAD( "27-6154-00.u4", 0x000000, 0x100000, CRC(e908262d) SHA1(a7964c9f9d304b6b2cce61822e8c6151b50388be) )
+
+	ROM_REGION( 0x40000, "cart", ROMREGION_ERASEFF )
+	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
+ROM_END
+
+ROM_START( gbs5505x )
+	ROM_REGION(0x200000, "bios", 0)
+	ROM_LOAD( "27-7006-00.u5", 0x000000, 0x200000, CRC(28af3ca7) SHA1(5df7063c7327263c23d5ac2aac3aa66f7e0821c5) )
+
+	ROM_REGION( 0x40000, "cart", ROMREGION_ERASEFF )
+	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
+ROM_END
+
+ROM_START( gln ) // not Z80 code
 	ROM_REGION( 0x80000, "bios", 0 )
 	ROM_LOAD( "27-5308-00_9524_d.bin", 0x000000, 0x080000, CRC(d1b994ee) SHA1(b5cf0810df0676712e4f30e279cc46c19b4277dd))
 
@@ -633,13 +1012,23 @@ ROM_START( misterx )
 	ROM_LOAD( "27-00882-001.bin", 0x000000, 0x020000, CRC(30e0dc94) SHA1(2f4675746a41399b3d9e3e8001a9b4a0dcc5b620))
 
 	ROM_REGION( 0x40000, "cart", ROMREGION_ERASEFF )
+	ROM_CART_LOAD( "cart", 0, 0x40000, 0 )
 ROM_END
 
+
 /* Driver */
 
-/*    YEAR  NAME    PARENT  COMPAT   MACHINE    INPUT    INIT    COMPANY   FULLNAME       FLAGS */
-COMP( 1988, misterx, 0,       0,    misterx,    pc1000, driver_device,   0,  "Video Technology / Yeno",     "MisterX",      GAME_NOT_WORKING)
-COMP( 1993, pc2000,  0,       0,    pc2000,     pc2000, driver_device,   0,  "Video Technology",   "PreComputer 2000",      GAME_NOT_WORKING)
-COMP( 1993, gl2000,  0,       0,    pc2000,     pc2000, driver_device,   0,  "Video Technology",   "Genius Leader 2000",      GAME_NOT_WORKING)
-COMP( 1993, gl2000p,  gl2000,       0,    pc2000,     pc2000, driver_device,   0,  "Video Technology",   "Genius Leader 2000 Plus",      GAME_NOT_WORKING)
-COMP( 199?, gln,  0,       0,    pc2000,     pc2000, driver_device,   0,  "Video Technology",   "Genius Leader Notebook",      GAME_NOT_WORKING)
+/*    YEAR  NAME     PARENT  COMPAT   MACHINE    INPUT   CLASS          INIT    COMPANY   FULLNAME       FLAGS */
+COMP( 1988, misterx,  0,       0,     misterx,   pc1000, driver_device,   0,  "Video Technology / Yeno", "MisterX", GAME_NOT_WORKING)
+COMP( 1993, pc2000,   0,       0,     pc2000,    pc2000, driver_device,   0,  "Video Technology", "PreComputer 2000", GAME_NOT_WORKING)
+COMP( 1993, gl2000,   0,       0,     gl2000,    pc2000, driver_device,   0,  "Video Technology", "Genius Leader 2000", GAME_NOT_WORKING)
+COMP( 1994, gl2000c,  gl2000,  0,     gl2000,    pc2000, driver_device,   0,  "Video Technology", "Genius Leader 2000 Compact", GAME_NOT_WORKING)
+COMP( 1995, gl2000p,  gl2000,  0,     gl2000,    pc2000, driver_device,   0,  "Video Technology", "Genius Leader 2000 Plus", GAME_NOT_WORKING)
+COMP( 1996, gl3000s,  0,       0,     gl3000s,   gl3000s,driver_device,   0,  "Video Technology", "Genius Leader 3000S (Germany)", GAME_NOT_WORKING)
+COMP( 1994, gl4000,   0,       0,     gl4000,    pc2000, driver_device,   0,  "Video Technology", "Genius Leader 4000 Quadro (Germany)", GAME_NOT_WORKING)
+COMP( 1996, gl4004,   0,       0,     gl4000,    pc2000, driver_device,   0,  "Video Technology", "Genius Leader 4004 Quadro L (Germany)", GAME_NOT_WORKING)
+COMP( 1997, gl5000,   0,       0,     pc2000,    pc2000, driver_device,   0,  "Video Technology", "Genius Leader 5000 (Germany)", GAME_IS_SKELETON)
+COMP( 1997, gl5005x,  0,       0,     pc2000,    pc2000, driver_device,   0,  "Video Technology", "Genius Leader 5005X (Germany)", GAME_IS_SKELETON)
+COMP( 1998, gmtt ,    0,       0,     gl4000,    pc2000, driver_device,   0,  "Video Technology", "Genius Master Table Top (Germany)", GAME_IS_SKELETON)
+COMP( 2001, gbs5505x, 0,       0,     pc2000,    pc2000, driver_device,   0,  "Video Technology", "Genius BrainStation 5505X (Germany)", GAME_IS_SKELETON)
+COMP( 1993, gln,      0,       0,     pc2000,    pc2000, driver_device,   0,  "Video Technology", "Genius Leader Notebook", GAME_IS_SKELETON)
