@@ -165,7 +165,8 @@ public:
 		m_bank5(*this, "bank5"),
 		m_bank6(*this, "bank6"),
 		m_bank7(*this, "bank7"),
-		m_bank8(*this, "bank8") { }
+		m_bank8(*this, "bank8"),
+		m_palette(*this, "palette")  { }
 
 	required_device<i8255_device> m_ppi;
 
@@ -247,7 +248,7 @@ public:
 	virtual void machine_start();
 	virtual void machine_reset();
 	virtual void video_start();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(pc6001);
 	DECLARE_MACHINE_RESET(pc6001m2);
 	DECLARE_PALETTE_INIT(pc6001m2);
 	DECLARE_MACHINE_RESET(pc6001sr);
@@ -289,6 +290,7 @@ protected:
 	optional_memory_bank m_bank6;
 	optional_memory_bank m_bank7;
 	optional_memory_bank m_bank8;
+	required_device<palette_device> m_palette;
 
 	void draw_gfx_mode4(bitmap_ind16 &bitmap,const rectangle &cliprect,int attr);
 	void draw_bitmap_2bpp(bitmap_ind16 &bitmap,const rectangle &cliprect, int attr);
@@ -362,7 +364,7 @@ void pc6001_state::draw_gfx_mode4(bitmap_ind16 &bitmap,const rectangle &cliprect
 
 					color = ((tile)>>(7-xi) & 1) ? fgcol : 0;
 
-					bitmap.pix16((y+24), (x*8+xi)+32) = machine().pens[color];
+					bitmap.pix16((y+24), (x*8+xi)+32) = m_palette->pen(color);
 				}
 			}
 			else
@@ -373,8 +375,8 @@ void pc6001_state::draw_gfx_mode4(bitmap_ind16 &bitmap,const rectangle &cliprect
 
 					color = (attr & 2) ? (pen_wattr[col_setting-1][fgcol]) : (pen_gattr[col_setting-1][fgcol]);
 
-					bitmap.pix16((y+24), ((x*8+xi*2)+0)+32) = machine().pens[color];
-					bitmap.pix16((y+24), ((x*8+xi*2)+1)+32) = machine().pens[color];
+					bitmap.pix16((y+24), ((x*8+xi*2)+0)+32) = m_palette->pen(color);
+					bitmap.pix16((y+24), ((x*8+xi*2)+1)+32) = m_palette->pen(color);
 				}
 			}
 		}
@@ -407,7 +409,7 @@ void pc6001_state::draw_bitmap_2bpp(bitmap_ind16 &bitmap,const rectangle &clipre
 						color = ((tile >> i) & 3)+8;
 						color+= col_bank;
 
-						bitmap.pix16(((y*shrink_y+yi)+24), (x*shrink_x+((shrink_x-1)-xi))+32) = machine().pens[color];
+						bitmap.pix16(((y*shrink_y+yi)+24), (x*shrink_x+((shrink_x-1)-xi))+32) = m_palette->pen(color);
 					}
 				}
 			}
@@ -430,9 +432,9 @@ void pc6001_state::draw_bitmap_2bpp(bitmap_ind16 &bitmap,const rectangle &clipre
 						color = ((tile >> i) & 3)+8;
 						color+= col_bank;
 
-						bitmap.pix16((((y+0)*shrink_y+yi)+24), (x*shrink_x+((shrink_x-1)-xi))+32) = machine().pens[color];
-						bitmap.pix16((((y+1)*shrink_y+yi)+24), (x*shrink_x+((shrink_x-1)-xi))+32) = machine().pens[color];
-						bitmap.pix16((((y+2)*shrink_y+yi)+24), (x*shrink_x+((shrink_x-1)-xi))+32) = machine().pens[color];
+						bitmap.pix16((((y+0)*shrink_y+yi)+24), (x*shrink_x+((shrink_x-1)-xi))+32) = m_palette->pen(color);
+						bitmap.pix16((((y+1)*shrink_y+yi)+24), (x*shrink_x+((shrink_x-1)-xi))+32) = m_palette->pen(color);
+						bitmap.pix16((((y+2)*shrink_y+yi)+24), (x*shrink_x+((shrink_x-1)-xi))+32) = m_palette->pen(color);
 					}
 				}
 			}
@@ -467,7 +469,7 @@ void pc6001_state::draw_tile_3bpp(bitmap_ind16 &bitmap,const rectangle &cliprect
 
 			color = ((tile >> i) & 1) ? pen+8 : 0;
 
-			bitmap.pix16(((y*12+(11-yi))+24), (x*8+(7-xi))+32) = machine().pens[color];
+			bitmap.pix16(((y*12+(11-yi))+24), (x*8+(7-xi))+32) = m_palette->pen(color);
 		}
 	}
 }
@@ -503,7 +505,7 @@ void pc6001_state::draw_tile_text(bitmap_ind16 &bitmap,const rectangle &cliprect
 					color = pen ? fgcol : 0;
 			}
 
-			bitmap.pix16(((y*12+yi)+24), (x*8+xi)+32) = machine().pens[color];
+			bitmap.pix16(((y*12+yi)+24), (x*8+xi)+32) = m_palette->pen(color);
 		}
 	}
 }
@@ -525,7 +527,7 @@ void pc6001_state::draw_border(bitmap_ind16 &bitmap,const rectangle &cliprect,in
 			else
 				color = 0; //FIXME: other modes not yet checked
 
-			bitmap.pix16(y, x) = machine().pens[color];
+			bitmap.pix16(y, x) = m_palette->pen(color);
 		}
 	}
 }
@@ -617,9 +619,9 @@ UINT32 pc6001_state::screen_update_pc6001m2(screen_device &screen, bitmap_ind16
 					color |= ((pen[1] & 2) << 2);
 
 					if (cliprect.contains((x+i)*2+0, y))
-						bitmap.pix16(y, (x+i)*2+0) = machine().pens[color];
+						bitmap.pix16(y, (x+i)*2+0) = m_palette->pen(color);
 					if (cliprect.contains((x+i)*2+1, y))
-						bitmap.pix16(y, (x+i)*2+1) = machine().pens[color];
+						bitmap.pix16(y, (x+i)*2+1) = m_palette->pen(color);
 				}
 
 				count++;
@@ -665,7 +667,7 @@ UINT32 pc6001_state::screen_update_pc6001m2(screen_device &screen, bitmap_ind16
 					}
 
 					if (cliprect.contains(x+i, y))
-						bitmap.pix16(y, (x+i)) = machine().pens[color];
+						bitmap.pix16(y, (x+i)) = m_palette->pen(color);
 				}
 
 				count++;
@@ -705,7 +707,7 @@ UINT32 pc6001_state::screen_update_pc6001m2(screen_device &screen, bitmap_ind16
 						color = pen ? fgcol : bgcol;
 
 						if (cliprect.contains(x*8+xi, y*12+yi))
-							bitmap.pix16(((y*12+yi)), (x*8+xi)) = machine().pens[color];
+							bitmap.pix16(((y*12+yi)), (x*8+xi)) = m_palette->pen(color);
 					}
 				}
 			}
@@ -749,7 +751,7 @@ UINT32 pc6001_state::screen_update_pc6001sr(screen_device &screen, bitmap_ind16
 						color = pen ? fgcol : bgcol;
 
 						if (cliprect.contains(x*8+xi, y*12+yi))
-							bitmap.pix16(((y*12+yi)), (x*8+xi)) = machine().pens[color];
+							bitmap.pix16(((y*12+yi)), (x*8+xi)) = m_palette->pen(color);
 					}
 				}
 			}
@@ -768,42 +770,42 @@ UINT32 pc6001_state::screen_update_pc6001sr(screen_device &screen, bitmap_ind16
 				color = m_video_ram[count] & 0x0f;
 
 				if (cliprect.contains(x+0, y+0))
-					bitmap.pix16((y+0), (x+0)) = machine().pens[color+0x10];
+					bitmap.pix16((y+0), (x+0)) = m_palette->pen(color+0x10);
 
 				color = (m_video_ram[count] & 0xf0) >> 4;
 
 				if (cliprect.contains(x+1, y+0))
-					bitmap.pix16((y+0), (x+1)) = machine().pens[color+0x10];
+					bitmap.pix16((y+0), (x+1)) = m_palette->pen(color+0x10);
 
 				color = m_video_ram[count+1] & 0x0f;
 
 				if (cliprect.contains(x+2, y+0))
-					bitmap.pix16((y+0), (x+2)) = machine().pens[color+0x10];
+					bitmap.pix16((y+0), (x+2)) = m_palette->pen(color+0x10);
 
 				color = (m_video_ram[count+1] & 0xf0) >> 4;
 
 				if (cliprect.contains(x+3, y+0))
-					bitmap.pix16((y+0), (x+3)) = machine().pens[color+0x10];
+					bitmap.pix16((y+0), (x+3)) = m_palette->pen(color+0x10);
 
 				color = m_video_ram[count+2] & 0x0f;
 
 				if (cliprect.contains(x+0, y+1))
-					bitmap.pix16((y+1), (x+0)) = machine().pens[color+0x10];
+					bitmap.pix16((y+1), (x+0)) = m_palette->pen(color+0x10);
 
 				color = (m_video_ram[count+2] & 0xf0) >> 4;
 
 				if (cliprect.contains(x+1, y+1))
-					bitmap.pix16((y+1), (x+1)) = machine().pens[color+0x10];
+					bitmap.pix16((y+1), (x+1)) = m_palette->pen(color+0x10);
 
 				color = m_video_ram[count+3] & 0x0f;
 
 				if (cliprect.contains(x+2, y+1))
-					bitmap.pix16((y+1), (x+2)) = machine().pens[color+0x10];
+					bitmap.pix16((y+1), (x+2)) = m_palette->pen(color+0x10);
 
 				color = (m_video_ram[count+3] & 0xf0) >> 4;
 
 				if (cliprect.contains(x+3, y+1))
-					bitmap.pix16((y+1), (x+3)) = machine().pens[color+0x10];
+					bitmap.pix16((y+1), (x+3)) = m_palette->pen(color+0x10);
 
 
 				count+=4;
@@ -1335,14 +1337,14 @@ WRITE8_MEMBER(pc6001_state::pc6001m2_vram_bank_w)
 	{
 		/* Apparently bitmap modes changes the screen res to 320 x 200 */
 		{
-			rectangle visarea = machine().primary_screen->visible_area();
+			rectangle visarea = machine().first_screen()->visible_area();
 			int y_height;
 
 			y_height = (m_exgfx_bitmap_mode || m_exgfx_2bpp_mode) ? 200 : 240;
 
 			visarea.set(0, (320) - 1, 0, (y_height) - 1);
 
-			machine().primary_screen->configure(320, 240, visarea, machine().primary_screen->frame_period().attoseconds);
+			machine().first_screen()->configure(320, 240, visarea, machine().first_screen()->frame_period().attoseconds);
 		}
 	}
 
@@ -1906,40 +1908,6 @@ READ8_MEMBER(pc6001_state::pc6001_8255_portc_r)
 	return 0x88;
 }
 
-
-
-static I8255_INTERFACE( pc6001_ppi8255_interface )
-{
-	DEVCB_DRIVER_MEMBER(pc6001_state,pc6001_8255_porta_r),
-	DEVCB_DRIVER_MEMBER(pc6001_state,pc6001_8255_porta_w),
-	DEVCB_DRIVER_MEMBER(pc6001_state,pc6001_8255_portb_r),
-	DEVCB_DRIVER_MEMBER(pc6001_state,pc6001_8255_portb_w),
-	DEVCB_DRIVER_MEMBER(pc6001_state,pc6001_8255_portc_r),
-	DEVCB_DRIVER_MEMBER(pc6001_state,pc6001_8255_portc_w)
-};
-
-static const i8251_interface pc6001_usart_interface=
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
-static const ay8910_interface pc6001_ay_interface =
-{
-	AY8910_LEGACY_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_INPUT_PORT("P1"),
-	DEVCB_INPUT_PORT("P2"),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
 UINT8 pc6001_state::check_keyboard_press()
 {
 	ioport_port *ports[3] = { m_io_key1, m_io_key2, m_io_key3 };
@@ -2116,7 +2084,6 @@ void pc6001_state::machine_reset()
 
 	m_port_c_8255=0;
 
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(pc6001_state::pc6001_irq_callback),this));
 	m_cas_switch = 0;
 	m_cas_offset = 0;
 	m_timer_irq_mask = 1;
@@ -2133,7 +2100,6 @@ MACHINE_RESET_MEMBER(pc6001_state,pc6001m2)
 
 	m_port_c_8255=0;
 
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(pc6001_state::pc6001_irq_callback),this));
 	m_cas_switch = 0;
 	m_cas_offset = 0;
 
@@ -2168,7 +2134,6 @@ MACHINE_RESET_MEMBER(pc6001_state,pc6001sr)
 
 	m_port_c_8255=0;
 
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(pc6001_state::pc6001_irq_callback),this));
 	m_cas_switch = 0;
 	m_cas_offset = 0;
 
@@ -2205,48 +2170,48 @@ MACHINE_RESET_MEMBER(pc6001_state,pc6001sr)
 
 static const rgb_t defcolors[] =
 {
-	MAKE_RGB(0x07, 0xff, 0x00), /* GREEN */
-	MAKE_RGB(0xff, 0xff, 0x00), /* YELLOW */
-	MAKE_RGB(0x3b, 0x08, 0xff), /* BLUE */
-	MAKE_RGB(0xcc, 0x00, 0x3b), /* RED */
-	MAKE_RGB(0xff, 0xff, 0xff), /* BUFF */
-	MAKE_RGB(0x07, 0xe3, 0x99), /* CYAN */
-	MAKE_RGB(0xff, 0x1c, 0xff), /* MAGENTA */
-	MAKE_RGB(0xff, 0x81, 0x00), /* ORANGE */
+	rgb_t(0x07, 0xff, 0x00), /* GREEN */
+	rgb_t(0xff, 0xff, 0x00), /* YELLOW */
+	rgb_t(0x3b, 0x08, 0xff), /* BLUE */
+	rgb_t(0xcc, 0x00, 0x3b), /* RED */
+	rgb_t(0xff, 0xff, 0xff), /* BUFF */
+	rgb_t(0x07, 0xe3, 0x99), /* CYAN */
+	rgb_t(0xff, 0x1c, 0xff), /* MAGENTA */
+	rgb_t(0xff, 0x81, 0x00), /* ORANGE */
 
 	/* MC6847 specific */
-	MAKE_RGB(0x00, 0x7c, 0x00), /* ALPHANUMERIC DARK GREEN */
-	MAKE_RGB(0x07, 0xff, 0x00), /* ALPHANUMERIC BRIGHT GREEN */
-	MAKE_RGB(0x91, 0x00, 0x00), /* ALPHANUMERIC DARK ORANGE */
-	MAKE_RGB(0xff, 0x81, 0x00)  /* ALPHANUMERIC BRIGHT ORANGE */
+	rgb_t(0x00, 0x7c, 0x00), /* ALPHANUMERIC DARK GREEN */
+	rgb_t(0x07, 0xff, 0x00), /* ALPHANUMERIC BRIGHT GREEN */
+	rgb_t(0x91, 0x00, 0x00), /* ALPHANUMERIC DARK ORANGE */
+	rgb_t(0xff, 0x81, 0x00)  /* ALPHANUMERIC BRIGHT ORANGE */
 };
 
 static const rgb_t mk2_defcolors[] =
 {
-	MAKE_RGB(0x00, 0x00, 0x00), /* BLACK */
-	MAKE_RGB(0xff, 0xaf, 0x00), /* ORANGE */
-	MAKE_RGB(0x00, 0xff, 0xaf), /* tone of GREEN */
-	MAKE_RGB(0xaf, 0xff, 0x00), /* tone of GREEN */
-	MAKE_RGB(0xaf, 0x00, 0xff), /* VIOLET */
-	MAKE_RGB(0xff, 0x00, 0xaf), /* SCARLET */
-	MAKE_RGB(0x00, 0xaf, 0xff), /* LIGHT BLUE */
-	MAKE_RGB(0xaf, 0xaf, 0xaf), /* GRAY */
-	MAKE_RGB(0x00, 0x00, 0x00), /* BLACK */
-	MAKE_RGB(0xff, 0x00, 0x00), /* RED */
-	MAKE_RGB(0x00, 0xff, 0x00), /* GREEN */
-	MAKE_RGB(0xff, 0xff, 0x00), /* YELLOW */
-	MAKE_RGB(0x00, 0x00, 0xff), /* BLUE */
-	MAKE_RGB(0xff, 0x00, 0xff), /* PINK */
-	MAKE_RGB(0x00, 0xff, 0xff), /* CYAN */
-	MAKE_RGB(0xff, 0xff, 0xff)  /* WHITE */
+	rgb_t(0x00, 0x00, 0x00), /* BLACK */
+	rgb_t(0xff, 0xaf, 0x00), /* ORANGE */
+	rgb_t(0x00, 0xff, 0xaf), /* tone of GREEN */
+	rgb_t(0xaf, 0xff, 0x00), /* tone of GREEN */
+	rgb_t(0xaf, 0x00, 0xff), /* VIOLET */
+	rgb_t(0xff, 0x00, 0xaf), /* SCARLET */
+	rgb_t(0x00, 0xaf, 0xff), /* LIGHT BLUE */
+	rgb_t(0xaf, 0xaf, 0xaf), /* GRAY */
+	rgb_t(0x00, 0x00, 0x00), /* BLACK */
+	rgb_t(0xff, 0x00, 0x00), /* RED */
+	rgb_t(0x00, 0xff, 0x00), /* GREEN */
+	rgb_t(0xff, 0xff, 0x00), /* YELLOW */
+	rgb_t(0x00, 0x00, 0xff), /* BLUE */
+	rgb_t(0xff, 0x00, 0xff), /* PINK */
+	rgb_t(0x00, 0xff, 0xff), /* CYAN */
+	rgb_t(0xff, 0xff, 0xff)  /* WHITE */
 };
 
-void pc6001_state::palette_init()
+PALETTE_INIT_MEMBER(pc6001_state, pc6001)
 {
 	int i;
 
 	for(i=0;i<8+4;i++)
-		palette_set_color(machine(), i+8,defcolors[i]);
+		palette.set_pen_color(i+8,defcolors[i]);
 }
 
 PALETTE_INIT_MEMBER(pc6001_state,pc6001m2)
@@ -2254,20 +2219,21 @@ PALETTE_INIT_MEMBER(pc6001_state,pc6001m2)
 	int i;
 
 	for(i=0;i<8;i++)
-		palette_set_color(machine(), i+8,defcolors[i]);
+		palette.set_pen_color(i+8,defcolors[i]);
 
 	for(i=0x10;i<0x20;i++)
-		palette_set_color(machine(), i,mk2_defcolors[i-0x10]);
+		palette.set_pen_color(i,mk2_defcolors[i-0x10]);
 }
 
+#if 0
 static const cassette_interface pc6001_cassette_interface =
 {
 	pc6001_cassette_formats,
 	NULL,
 	(cassette_state)(CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_ENABLED),
-	NULL,
 	NULL
 };
+#endif
 
 DEVICE_IMAGE_LOAD_MEMBER( pc6001_state,pc6001_cass )
 {
@@ -2323,27 +2289,34 @@ static MACHINE_CONFIG_START( pc6001, pc6001_state )
 	MCFG_CPU_PROGRAM_MAP(pc6001_map)
 	MCFG_CPU_IO_MAP(pc6001_io)
 	MCFG_CPU_VBLANK_INT_DRIVER("screen", pc6001_state,  pc6001_interrupt)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(pc6001_state,pc6001_irq_callback)
 
 //  MCFG_CPU_ADD("subcpu", I8049, 7987200)
 
 
-	MCFG_GFXDECODE(pc6001m2)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", pc6001m2)
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_UPDATE_DRIVER(pc6001_state, screen_update_pc6001)
-//  MCFG_SCREEN_REFRESH_RATE(M6847_NTSC_FRAMES_PER_SECOND)
-//  MCFG_SCREEN_UPDATE_STATIC(m6847)
 	MCFG_SCREEN_SIZE(320, 25+192+26)
 	MCFG_SCREEN_VISIBLE_AREA(0, 319, 0, 239)
+	MCFG_SCREEN_PALETTE("palette")
 
+	MCFG_PALETTE_ADD("palette", 16+4)
+	MCFG_PALETTE_INIT_OWNER(pc6001_state, pc6001)
 
-	MCFG_PALETTE_LENGTH(16+4)
+	MCFG_DEVICE_ADD("ppi8255", I8255, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(pc6001_state, pc6001_8255_porta_r))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(pc6001_state, pc6001_8255_porta_w))
+	MCFG_I8255_IN_PORTB_CB(READ8(pc6001_state, pc6001_8255_portb_r))
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(pc6001_state, pc6001_8255_portb_w))
+	MCFG_I8255_IN_PORTC_CB(READ8(pc6001_state, pc6001_8255_portc_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(pc6001_state, pc6001_8255_portc_w))
 
-	MCFG_I8255_ADD( "ppi8255", pc6001_ppi8255_interface )
 	/* uart */
-	MCFG_I8251_ADD("uart", pc6001_usart_interface)
+	MCFG_DEVICE_ADD("uart", I8251, 0)
 
 	MCFG_CARTSLOT_ADD("cart")
 	MCFG_CARTSLOT_EXTENSION_LIST("bin")
@@ -2358,7 +2331,8 @@ static MACHINE_CONFIG_START( pc6001, pc6001_state )
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD("ay8910", AY8910, PC6001_MAIN_CLOCK/4)
-	MCFG_SOUND_CONFIG(pc6001_ay_interface)
+	MCFG_AY8910_PORT_A_READ_CB(IOPORT("P1"))
+	MCFG_AY8910_PORT_B_READ_CB(IOPORT("P2"))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 //  MCFG_SOUND_WAVE_ADD(WAVE_TAG, "cassette")
 //  MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
@@ -2376,15 +2350,17 @@ static MACHINE_CONFIG_DERIVED( pc6001m2, pc6001 )
 
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_UPDATE_DRIVER(pc6001_state, screen_update_pc6001m2)
-	MCFG_PALETTE_LENGTH(16+16)
-	MCFG_PALETTE_INIT_OVERRIDE(pc6001_state,pc6001m2)
+
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_ENTRIES(16+16)
+	MCFG_PALETTE_INIT_OWNER(pc6001_state,pc6001m2)
 
 	/* basic machine hardware */
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_PROGRAM_MAP(pc6001m2_map)
 	MCFG_CPU_IO_MAP(pc6001m2_io)
 
-	MCFG_GFXDECODE(pc6001m2)
+	MCFG_GFXDECODE_MODIFY("gfxdecode", pc6001m2)
 
 	MCFG_SOUND_ADD("upd7752", UPD7752, PC6001_MAIN_CLOCK/4)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
@@ -2398,6 +2374,7 @@ static MACHINE_CONFIG_DERIVED( pc6601, pc6001m2 )
 	MCFG_CPU_PROGRAM_MAP(pc6001m2_map)
 	MCFG_CPU_IO_MAP(pc6601_io)
 	MCFG_CPU_VBLANK_INT_DRIVER("screen", pc6001_state,  pc6001_interrupt)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(pc6001_state,pc6001_irq_callback)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( pc6001sr, pc6001m2 )
@@ -2412,6 +2389,7 @@ static MACHINE_CONFIG_DERIVED( pc6001sr, pc6001m2 )
 	MCFG_CPU_PROGRAM_MAP(pc6001sr_map)
 	MCFG_CPU_IO_MAP(pc6001sr_io)
 	MCFG_CPU_VBLANK_INT_DRIVER("screen", pc6001_state,  pc6001sr_interrupt)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DRIVER(pc6001_state,pc6001_irq_callback)
 MACHINE_CONFIG_END
 
 /* ROM definition */
