@@ -10,17 +10,16 @@
 
 ***************************************************************************/
 
-#include "emu.h"
+#include "bus/rs232/rs232.h"
 #include "cpu/z80/z80.h"
 #include "machine/ram.h"
-#include "machine/epson_sio.h"
+#include "bus/epson_sio/epson_sio.h"
 #include "bus/centronics/ctronics.h"
 #include "imagedev/cartslot.h"
 #include "imagedev/cassette.h"
 #include "machine/ram.h"
 #include "machine/nvram.h"
 #include "sound/speaker.h"
-#include "machine/serial.h"
 #include "px4.lh"
 
 
@@ -52,10 +51,6 @@
 #define ART_OE      0x10    // overrun error
 #define ART_FE      0x20    // framing error
 
-// art baud rates
-static const int transmit_rate[] = { 2112, 1536, 768, 384, 192, 96, 48, 24, 192, 3072, 12, 6, 1152 };
-static const int receive_rate[] = { 2112, 1536, 768, 384, 192, 96, 48, 24, 3072, 192, 12, 6, 1152 };
-
 
 //**************************************************************************
 //  MACROS
@@ -63,37 +58,42 @@ static const int receive_rate[] = { 2112, 1536, 768, 384, 192, 96, 48, 24, 3072,
 
 #define ART_TX_ENABLED  (BIT(m_artcr, 0))
 #define ART_RX_ENABLED  (BIT(m_artcr, 2))
-
-#define ART_DATA        (BIT(m_artmr, 2))   // number of data bits, 7 or 8
-#define ART_PEN         (BIT(m_artmr, 4))   // parity enabled
-#define ART_EVEN        (BIT(m_artmr, 5))   // even or odd parity
-#define ART_STOP        (BIT(m_artmr, 7))   // number of stop bits, 1 or 2
+#define ART_BREAK       (BIT(m_artcr, 3))
 
 
 //**************************************************************************
 //  TYPE DEFINITIONS
 //**************************************************************************
 
-class px4_state : public driver_device
+class px4_state : public driver_device,
+					public device_serial_interface
 {
 public:
-	px4_state(const machine_config &mconfig, device_type type, const char *tag)
-		: driver_device(mconfig, type, tag),
-			m_z80(*this, "maincpu"),
-			m_ram(*this, RAM_TAG),
-			m_centronics(*this, "centronics"),
-			m_ext_cas(*this, "extcas"),
-			m_speaker(*this, "speaker"),
-			m_sio(*this, "sio"),
-			m_rs232(*this, "rs232")
-			,
-		m_maincpu(*this, "maincpu") { }
+	px4_state(const machine_config &mconfig, device_type type, const char *tag) :
+	driver_device(mconfig, type, tag),
+	device_serial_interface(mconfig, *this),
+	m_z80(*this, "maincpu"),
+	m_ram(*this, RAM_TAG),
+	m_centronics(*this, "centronics"),
+	m_ext_cas(*this, "extcas"),
+	m_ext_cas_timer(*this, "extcas_timer"),
+	m_speaker(*this, "speaker"),
+	m_sio(*this, "sio"),
+	m_rs232(*this, "rs232"),
+	m_isr(0), m_ier(0), m_str(0), m_sior(0xbf),
+	m_artdir(0xff), m_artdor(0xff), m_artsr(0), m_artcr(0),
+	m_swr(0),
+	m_one_sec_int_enabled(true), m_alarm_int_enabled(true), m_key_int_enabled(true),
+	m_ramdisk_address(0),
+	m_ear_last_state(0)
+	{ }
 
 	// internal devices
 	required_device<cpu_device> m_z80;
 	required_device<ram_device> m_ram;
 	required_device<centronics_device> m_centronics;
 	required_device<cassette_image_device> m_ext_cas;
+	required_device<timer_device> m_ext_cas_timer;
 	required_device<speaker_sound_device> m_speaker;
 	required_device<epson_sio_device> m_sio;
 	required_device<rs232_port_device> m_rs232;
@@ -123,11 +123,9 @@ public:
 	UINT8 m_artdir;
 	UINT8 m_artdor;
 	UINT8 m_artsr;
-	UINT8 m_artmr;
 	UINT8 m_artcr;
 	UINT8 m_swr;
 
-	int rxd_r();
 	void txd_w(int data);
 
 	// 7508 internal
@@ -143,11 +141,32 @@ public:
 	UINT8 *m_ramdisk;
 
 	// external cassette/barcode reader
-	emu_timer *m_ext_cas_timer;
 	int m_ear_last_state;
 
 	void install_rom_capsule(address_space &space, int size, const char *region);
 
+	// device_serial_interface overrides
+	virtual void tra_callback();
+	virtual void tra_complete();
+	virtual void rcv_callback();
+	virtual void rcv_complete();
+
+	virtual void device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr);
+
+	DECLARE_WRITE_LINE_MEMBER( sio_rx_w );
+	DECLARE_WRITE_LINE_MEMBER( sio_pin_w );
+
+	DECLARE_WRITE_LINE_MEMBER( rs232_rx_w );
+	DECLARE_WRITE_LINE_MEMBER( rs232_dcd_w );
+	DECLARE_WRITE_LINE_MEMBER( rs232_dsr_w );
+	DECLARE_WRITE_LINE_MEMBER( rs232_cts_w );
+
+	int m_sio_pin;
+
+	int m_serial_rx;
+	int m_rs232_dcd;
+	int m_rs232_cts;
+
 	DECLARE_READ8_MEMBER(px4_icrlc_r);
 	DECLARE_WRITE8_MEMBER(px4_ctrl1_w);
 	DECLARE_READ8_MEMBER(px4_icrhc_r);
@@ -182,17 +201,24 @@ public:
 	DECLARE_DRIVER_INIT(px4);
 	DECLARE_DRIVER_INIT(px4p);
 	virtual void machine_reset();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(px4);
 	DECLARE_MACHINE_START(px4_ramdisk);
 	DECLARE_PALETTE_INIT(px4p);
 	UINT32 screen_update_px4(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	DECLARE_INPUT_CHANGED_MEMBER(key_callback);
-	TIMER_CALLBACK_MEMBER(ext_cassette_read);
+	TIMER_DEVICE_CALLBACK_MEMBER( ext_cassette_read );
 	TIMER_CALLBACK_MEMBER(transmit_data);
 	TIMER_CALLBACK_MEMBER(receive_data);
 	TIMER_DEVICE_CALLBACK_MEMBER(frc_tick);
 	TIMER_DEVICE_CALLBACK_MEMBER(upd7508_1sec_callback);
-	required_device<cpu_device> m_maincpu;
+
+	int m_centronics_busy;
+	int m_centronics_perror;
+	DECLARE_WRITE_LINE_MEMBER(write_centronics_busy);
+	DECLARE_WRITE_LINE_MEMBER(write_centronics_perror);
+
+private:
+	DECLARE_WRITE_LINE_MEMBER( serial_rx_w );
 };
 
 
@@ -222,7 +248,7 @@ void px4_state::gapnit_interrupt()
 }
 
 // external cassette or barcode reader input
-TIMER_CALLBACK_MEMBER(px4_state::ext_cassette_read)
+TIMER_DEVICE_CALLBACK_MEMBER( px4_state::ext_cassette_read )
 {
 	UINT8 result;
 	int trigger = 0;
@@ -260,7 +286,7 @@ TIMER_CALLBACK_MEMBER(px4_state::ext_cassette_read)
 }
 
 // free running counter
-TIMER_DEVICE_CALLBACK_MEMBER(px4_state::frc_tick)
+TIMER_DEVICE_CALLBACK_MEMBER( px4_state::frc_tick )
 {
 	m_frc_value++;
 
@@ -272,7 +298,7 @@ TIMER_DEVICE_CALLBACK_MEMBER(px4_state::frc_tick)
 }
 
 // input capture register low command trigger
-READ8_MEMBER(px4_state::px4_icrlc_r)
+READ8_MEMBER( px4_state::px4_icrlc_r )
 {
 	if (VERBOSE)
 		logerror("%s: px4_icrlc_r\n", machine().describe_context());
@@ -284,27 +310,31 @@ READ8_MEMBER(px4_state::px4_icrlc_r)
 }
 
 // control register 1
-WRITE8_MEMBER(px4_state::px4_ctrl1_w)
+WRITE8_MEMBER( px4_state::px4_ctrl1_w )
 {
-	int baud;
+	const int rcv_rates[] = { 110, 150, 300, 600, 1200, 2400, 4800, 9600, 75, 1200, 19200, 38400, 200 };
+	const int tra_rates[] = { 110, 150, 300, 600, 1200, 2400, 4800, 9600, 1200, 75, 19200, 38400, 200 };
 
 	if (VERBOSE)
 		logerror("%s: px4_ctrl1_w (0x%02x)\n", machine().describe_context(), data);
 
 	// baudrate generator
-	baud = data >> 4;
+	int baud = data >> 4;
 
 	if (baud <= 12)
 	{
-		m_transmit_timer->adjust(attotime::zero, 0, attotime::from_hz(XTAL_7_3728MHz/2/transmit_rate[baud]));
-		m_receive_timer->adjust(attotime::zero, 0, attotime::from_hz(XTAL_7_3728MHz/2/receive_rate[baud]));
+		if (VERBOSE)
+			logerror("rcv baud = %d, tra baud = %d\n", rcv_rates[baud], tra_rates[baud]);
+
+		set_rcv_rate(rcv_rates[baud]);
+		set_tra_rate(tra_rates[baud]);
 	}
 
 	m_ctrl1 = data;
 }
 
 // input capture register high command trigger
-READ8_MEMBER(px4_state::px4_icrhc_r)
+READ8_MEMBER( px4_state::px4_icrhc_r )
 {
 	if (VERBOSE)
 		logerror("%s: px4_icrhc_r\n", machine().describe_context());
@@ -313,9 +343,9 @@ READ8_MEMBER(px4_state::px4_icrhc_r)
 }
 
 // command register
-WRITE8_MEMBER(px4_state::px4_cmdr_w)
+WRITE8_MEMBER( px4_state::px4_cmdr_w )
 {
-	if (VERBOSE)
+	if (0)
 		logerror("%s: px4_cmdr_w (0x%02x)\n", machine().describe_context(), data);
 
 	// clear overflow interrupt?
@@ -327,7 +357,7 @@ WRITE8_MEMBER(px4_state::px4_cmdr_w)
 }
 
 // input capture register low barcode trigger
-READ8_MEMBER(px4_state::px4_icrlb_r)
+READ8_MEMBER( px4_state::px4_icrlb_r )
 {
 	if (VERBOSE)
 		logerror("%s: px4_icrlb_r\n", machine().describe_context());
@@ -336,7 +366,7 @@ READ8_MEMBER(px4_state::px4_icrlb_r)
 }
 
 // control register 2
-WRITE8_MEMBER(px4_state::px4_ctrl2_w)
+WRITE8_MEMBER( px4_state::px4_ctrl2_w )
 {
 	if (VERBOSE)
 		logerror("%s: px4_ctrl2_w (0x%02x)\n", machine().describe_context(), data);
@@ -358,7 +388,7 @@ WRITE8_MEMBER(px4_state::px4_ctrl2_w)
 }
 
 // input capture register high barcode trigger
-READ8_MEMBER(px4_state::px4_icrhb_r)
+READ8_MEMBER( px4_state::px4_icrhb_r )
 {
 	if (VERBOSE)
 		logerror("%s: px4_icrhb_r\n", machine().describe_context());
@@ -371,7 +401,7 @@ READ8_MEMBER(px4_state::px4_icrhb_r)
 }
 
 // interrupt status register
-READ8_MEMBER(px4_state::px4_isr_r)
+READ8_MEMBER( px4_state::px4_isr_r )
 {
 	if (VERBOSE)
 		logerror("%s: px4_isr_r\n", machine().describe_context());
@@ -380,9 +410,9 @@ READ8_MEMBER(px4_state::px4_isr_r)
 }
 
 // interrupt enable register
-WRITE8_MEMBER(px4_state::px4_ier_w)
+WRITE8_MEMBER( px4_state::px4_ier_w )
 {
-	if (VERBOSE)
+	if (0)
 		logerror("%s: px4_ier_w (0x%02x)\n", machine().describe_context(), data);
 
 	m_ier = data;
@@ -390,20 +420,20 @@ WRITE8_MEMBER(px4_state::px4_ier_w)
 }
 
 // status register
-READ8_MEMBER(px4_state::px4_str_r)
+READ8_MEMBER( px4_state::px4_str_r )
 {
-	UINT8 result = 0;
+	UINT8 data = 0;
 
-	if (VERBOSE)
+	if (0)
 		logerror("%s: px4_str_r\n", machine().describe_context());
 
-	result |= (m_ext_cas)->input() > 0 ? 1 : 0;
-	result |= 1 << 1;   // BCRD, barcode reader input
-	result |= 1 << 2;   // RDY signal from 7805
-	result |= 1 << 3;   // RDYSIO, enable access to the 7805
-	result |= m_bankr & 0xf0;   // bit 4-7, BANK - memory bank
+	data |= (m_ext_cas)->input() > 0 ? 1 : 0;
+	data |= 1 << 1;   // BCRD, barcode reader input
+	data |= 1 << 2;   // RDY signal from 7805
+	data |= 1 << 3;   // RDYSIO, enable access to the 7805
+	data |= m_bankr & 0xf0;   // bit 4-7, BANK - memory bank
 
-	return result;
+	return data;
 }
 
 // helper function to map rom capsules
@@ -426,11 +456,11 @@ void px4_state::install_rom_capsule(address_space &space, int size, const char *
 }
 
 // bank register
-WRITE8_MEMBER(px4_state::px4_bankr_w)
+WRITE8_MEMBER( px4_state::px4_bankr_w )
 {
 	address_space &space_program = m_z80->space(AS_PROGRAM);
 
-	if (VERBOSE)
+	if (0)
 		logerror("%s: px4_bankr_w (0x%02x)\n", machine().describe_context(), data);
 
 	m_bankr = data;
@@ -464,18 +494,18 @@ WRITE8_MEMBER(px4_state::px4_bankr_w)
 }
 
 // serial io register
-READ8_MEMBER(px4_state::px4_sior_r)
+READ8_MEMBER( px4_state::px4_sior_r )
 {
-	if (VERBOSE)
+	if (0)
 		logerror("%s: px4_sior_r 0x%02x\n", machine().describe_context(), m_sior);
 
 	return m_sior;
 }
 
 // serial io register
-WRITE8_MEMBER(px4_state::px4_sior_w)
+WRITE8_MEMBER( px4_state::px4_sior_w )
 {
-	if (VERBOSE)
+	if (0)
 		logerror("%s: px4_sior_w (0x%02x)\n", machine().describe_context(), data);
 
 	m_sior = data;
@@ -603,7 +633,7 @@ WRITE8_MEMBER(px4_state::px4_sior_w)
 //**************************************************************************
 
 // vram start address register
-WRITE8_MEMBER(px4_state::px4_vadr_w)
+WRITE8_MEMBER( px4_state::px4_vadr_w )
 {
 	if (VERBOSE)
 		logerror("%s: px4_vadr_w (0x%02x)\n", machine().describe_context(), data);
@@ -612,7 +642,7 @@ WRITE8_MEMBER(px4_state::px4_vadr_w)
 }
 
 // y offset register
-WRITE8_MEMBER(px4_state::px4_yoff_w)
+WRITE8_MEMBER( px4_state::px4_yoff_w )
 {
 	if (VERBOSE)
 		logerror("%s: px4_yoff_w (0x%02x)\n", machine().describe_context(), data);
@@ -621,14 +651,14 @@ WRITE8_MEMBER(px4_state::px4_yoff_w)
 }
 
 // frame register
-WRITE8_MEMBER(px4_state::px4_fr_w)
+WRITE8_MEMBER( px4_state::px4_fr_w )
 {
 	if (VERBOSE)
 		logerror("%s: px4_fr_w (0x%02x)\n", machine().describe_context(), data);
 }
 
 // speed-up register
-WRITE8_MEMBER(px4_state::px4_spur_w)
+WRITE8_MEMBER( px4_state::px4_spur_w )
 {
 	if (VERBOSE)
 		logerror("%s: px4_spur_w (0x%02x)\n", machine().describe_context(), data);
@@ -639,182 +669,279 @@ WRITE8_MEMBER(px4_state::px4_spur_w)
 //  GAPNIO
 //**************************************************************************
 
-// helper function to read from selected serial port
-int px4_state::rxd_r()
+WRITE_LINE_MEMBER( px4_state::serial_rx_w )
+{
+	m_serial_rx = state;
+	device_serial_interface::rx_w(state);
+}
+
+WRITE_LINE_MEMBER( px4_state::sio_rx_w )
+{
+	if (!BIT(m_swr, 3) && BIT(m_swr, 2))
+		serial_rx_w(state);
+}
+
+WRITE_LINE_MEMBER( px4_state::sio_pin_w )
+{
+	m_sio_pin = state;
+}
+
+WRITE_LINE_MEMBER( px4_state::rs232_rx_w )
 {
 	if (BIT(m_swr, 3))
-		// from rs232
-		return m_rs232->rx();
-	else
-		if (BIT(m_swr, 2))
-			// from sio
-			return m_sio->rx_r();
+		serial_rx_w(state);
+}
+
+WRITE_LINE_MEMBER( px4_state::rs232_dcd_w )
+{
+	m_rs232_dcd = state;
+}
+
+WRITE_LINE_MEMBER( px4_state::rs232_dsr_w )
+{
+	m_artsr |= !state << 7;
+}
+
+WRITE_LINE_MEMBER( px4_state::rs232_cts_w )
+{
+	m_rs232_cts = state;
+}
+
+void px4_state::device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr)
+{
+	device_serial_interface::device_timer(timer, id, param, ptr);
+}
+
+void px4_state::tra_callback()
+{
+	if (ART_TX_ENABLED)
+	{
+		if (ART_BREAK)
+		{
+			// transmit break
+			txd_w(0);
+		}
 		else
-			// from cartridge
-			return 0;
+		{
+			// transmit data
+			txd_w(transmit_register_get_data_bit());
+		}
+	}
+	else
+	{
+		// transmit mark
+		txd_w(1);
+	}
+}
+
+void px4_state::tra_complete()
+{
+	if (m_artsr & ART_TXRDY)
+	{
+		// no more bytes, buffer now empty
+		m_artsr |= ART_TXEMPTY;
+	}
+	else
+	{
+		// transfer next byte
+		transmit_register_setup(m_artdor);
+		m_artsr |= ART_TXRDY;
+	}
+}
+
+void px4_state::rcv_callback()
+{
+	if (ART_RX_ENABLED)
+	{
+		// receive data
+		receive_register_update_bit(m_serial_rx);
+	}
+}
+
+void px4_state::rcv_complete()
+{
+	receive_register_extract();
+	m_artdir = get_received_char();
+
+	// TODO: verify parity and framing
+
+	// overrun?
+	if (m_artsr & ART_RXRDY)
+		m_artsr |= ART_OE;
+
+	// set ready and signal interrupt
+	m_artsr |= ART_RXRDY;
+	m_isr |= INT1_ART;
+	gapnit_interrupt();
 }
 
 // helper function to write to selected serial port
 void px4_state::txd_w(int data)
 {
 	if (BIT(m_swr, 2))
-		// from sio
+		// to sio
 		m_sio->tx_w(data);
 	else
 		if (BIT(m_swr, 3))
-			// from rs232
-			m_rs232->tx(data);
-		// else from cartridge
-}
-
-TIMER_CALLBACK_MEMBER(px4_state::transmit_data)
-{
-	if (ART_TX_ENABLED)
-	{
-	}
-}
-
-TIMER_CALLBACK_MEMBER(px4_state::receive_data)
-{
-	if (ART_RX_ENABLED)
-	{
-	}
+			// to rs232
+			m_rs232->write_txd(data);
+		// else to cartridge
 }
 
 // cartridge interface
-READ8_MEMBER(px4_state::px4_ctgif_r)
+READ8_MEMBER( px4_state::px4_ctgif_r )
 {
 	if (VERBOSE)
 		logerror("%s: px4_ctgif_r @ 0x%02x\n", machine().describe_context(), offset);
 
-	return 0xff;
+	return 0x00;
 }
 
 // cartridge interface
-WRITE8_MEMBER(px4_state::px4_ctgif_w)
+WRITE8_MEMBER( px4_state::px4_ctgif_w )
 {
 	if (VERBOSE)
 		logerror("%s: px4_ctgif_w (0x%02x @ 0x%02x)\n", machine().describe_context(), data, offset);
 }
 
 // art data input register
-READ8_MEMBER(px4_state::px4_artdir_r)
+READ8_MEMBER( px4_state::px4_artdir_r )
 {
 	if (VERBOSE)
-		logerror("%s: px4_artdir_r\n", machine().describe_context());
+		logerror("%s: px4_artdir_r (%02x)\n", machine().describe_context(), m_artdir);
 
 	// clear ready
 	m_artsr &= ~ART_RXRDY;
 
+	// clear interrupt
+	m_isr &= ~INT1_ART;
+	gapnit_interrupt();
+
 	return m_artdir;
 }
 
 // art data output register
-WRITE8_MEMBER(px4_state::px4_artdor_w)
+WRITE8_MEMBER( px4_state::px4_artdor_w )
 {
 	if (VERBOSE)
 		logerror("%s: px4_artdor_w (0x%02x)\n", machine().describe_context(), data);
 
-	// clear ready
-	m_artsr &= ~ART_TXRDY;
-
 	m_artdor = data;
+
+	// new data to transmit?
+	if (ART_TX_ENABLED && is_transmit_register_empty())
+	{
+		transmit_register_setup(m_artdor);
+		m_artsr &= ~ART_TXEMPTY;
+	}
+	else
+	{
+		// clear ready
+		m_artsr &= ~ART_TXRDY;
+	}
 }
 
 // art status register
-READ8_MEMBER(px4_state::px4_artsr_r)
+READ8_MEMBER( px4_state::px4_artsr_r )
 {
-	UINT8 result = 0;
+	if (0)
+		logerror("%s: px4_artsr_r (%02x)\n", machine().describe_context(), m_artsr);
 
-	if (VERBOSE)
-		logerror("%s: px4_artsr_r\n", machine().describe_context());
-
-	result |= m_rs232->dsr_r() << 7;
-
-	return result | m_artsr;
+	return m_artsr;
 }
 
 // art mode register
-WRITE8_MEMBER(px4_state::px4_artmr_w)
+WRITE8_MEMBER( px4_state::px4_artmr_w )
 {
-	if (VERBOSE)
-		logerror("%s: px4_artmr_w (0x%02x)\n", machine().describe_context(), data);
+	int data_bit_count = BIT(data, 2) ? 8 : 7;
+	parity_t parity = BIT(data, 4) ? (BIT(data, 5) ? PARITY_EVEN : PARITY_ODD) : PARITY_NONE;
+	stop_bits_t stop_bits = BIT(data, 7) ? STOP_BITS_2 : STOP_BITS_1;
 
-	m_artmr = data;
+	if (VERBOSE)
+		logerror("%s: serial frame setup: %d-%s-%d\n", tag(), data_bit_count, device_serial_interface::parity_tostring(parity), stop_bits);
+
+	set_data_frame(1, data_bit_count, parity, stop_bits);
+}
+
+WRITE_LINE_MEMBER( px4_state::write_centronics_busy )
+{
+	m_centronics_busy = state;
+}
+
+WRITE_LINE_MEMBER( px4_state::write_centronics_perror )
+{
+	m_centronics_perror = state;
 }
 
 // io status register
-READ8_MEMBER(px4_state::px4_iostr_r)
+READ8_MEMBER( px4_state::px4_iostr_r )
 {
-	UINT8 result = 0;
-
-	if (VERBOSE)
-		logerror("%s: px4_iostr_r\n", machine().describe_context());
+	UINT8 data = 0;
 
 	// centronics status
-	result |= m_centronics->busy_r() << 0;
-	result |= !m_centronics->pe_r() << 1;
+	data |= m_centronics_busy << 0;
+	data |= m_centronics_perror << 1;
 
 	// sio status
-	result |= !m_sio->pin_r() << 2;
+	data |= !m_sio_pin << 2;
 
 	// serial data
-	result |= rxd_r() << 3;
+	data |= m_serial_rx << 3;
 
 	// rs232 status
-	result |= m_rs232->dcd_r() << 4;
-	result |= m_rs232->cts_r() << 5;
+	data |= !m_rs232_dcd << 4;
+	data |= !m_rs232_cts << 5;
 
-	result |= 1 << 6;   // bit 6, csel, cartridge option select signal, set to 'other mode'
-	result |= 0 << 7;   // bit 7, caud - audio input from cartridge
+	data |= 1 << 6;   // bit 6, csel, cartridge option select signal
+	data |= 0 << 7;   // bit 7, caud - audio input from cartridge
 
-	return result;
+	if (0)
+		logerror("%s: px4_iostr_r: rx = %d, dcd = %d, cts = %d\n", machine().describe_context(), BIT(data, 3), BIT(data, 4), BIT(data, 5));
+
+	return data;
 }
 
 // art command register
-WRITE8_MEMBER(px4_state::px4_artcr_w)
+WRITE8_MEMBER( px4_state::px4_artcr_w )
 {
 	if (VERBOSE)
 		logerror("%s: px4_artcr_w (0x%02x)\n", machine().describe_context(), data);
 
 	m_artcr = data;
 
-	// bit 0, txe - transmit enable
-	if (!ART_TX_ENABLED)
-		txd_w(1); // force high when disabled
-
-	// bit 3, sbrk - break output
-	if (ART_TX_ENABLED && BIT(data, 3))
-		txd_w(0); // force low when enabled and transmit enabled
-
 	// error reset
 	if (BIT(data, 4))
 		m_artsr &= ~(ART_PE | ART_OE | ART_FE);
 
 	// rs232
-	m_rs232->dtr_w(BIT(data, 1));
-	m_rs232->rts_w(BIT(data, 5));
+	m_rs232->write_dtr(!BIT(data, 1));
+	m_rs232->write_rts(!BIT(data, 5));
 }
 
 // switch register
-WRITE8_MEMBER(px4_state::px4_swr_w)
+WRITE8_MEMBER( px4_state::px4_swr_w )
 {
 	if (VERBOSE)
-		logerror("%s: px4_swr_w (0x%02x)\n", machine().describe_context(), data);
+	{
+		const char *cart_mode[] = { "hs", "io", "db", "ot" };
+		const char *ser_mode[] = { "cart sio / cart sio", "sio / sio", "rs232 / rs232", "rs232 / sio" };
+		logerror("%s: px4_swr_w: cartridge mode: %s, serial mode: %s, audio: %s\n", machine().describe_context(),
+			cart_mode[data & 0x03], ser_mode[(data >> 2) & 0x03], BIT(data, 4) ? "on" : "off");
+	}
 
 	m_swr = data;
 }
 
 // io control register
-WRITE8_MEMBER(px4_state::px4_ioctlr_w)
+WRITE8_MEMBER( px4_state::px4_ioctlr_w )
 {
 	if (VERBOSE)
 		logerror("%s: px4_ioctlr_w (0x%02x)\n", machine().describe_context(), data);
 
-	m_centronics->strobe_w(!BIT(data, 0));
-	m_centronics->init_prime_w(BIT(data, 1));
+	m_centronics->write_strobe(!BIT(data, 0));
+	m_centronics->write_init(BIT(data, 1));
 
-	m_sio->pout_w(!BIT(data, 2));
+	m_sio->pout_w(BIT(data, 2));
 
 	// bit 3, cartridge reset
 
@@ -830,7 +957,7 @@ WRITE8_MEMBER(px4_state::px4_ioctlr_w)
 //  7508 RELATED
 //**************************************************************************
 
-TIMER_DEVICE_CALLBACK_MEMBER(px4_state::upd7508_1sec_callback)
+TIMER_DEVICE_CALLBACK_MEMBER( px4_state::upd7508_1sec_callback )
 {
 	// adjust interrupt status
 	m_interrupt_status |= UPD7508_INT_ONE_SECOND;
@@ -843,7 +970,7 @@ TIMER_DEVICE_CALLBACK_MEMBER(px4_state::upd7508_1sec_callback)
 	}
 }
 
-INPUT_CHANGED_MEMBER(px4_state::key_callback)
+INPUT_CHANGED_MEMBER( px4_state::key_callback )
 {
 	UINT32 oldvalue = oldval * field.mask(), newvalue = newval * field.mask();
 	UINT32 delta = oldvalue ^ newvalue;
@@ -887,7 +1014,7 @@ INPUT_CHANGED_MEMBER(px4_state::key_callback)
 //  EXTERNAL RAM-DISK
 //**************************************************************************
 
-WRITE8_MEMBER(px4_state::px4_ramdisk_address_w)
+WRITE8_MEMBER( px4_state::px4_ramdisk_address_w )
 {
 	switch (offset)
 	{
@@ -897,7 +1024,7 @@ WRITE8_MEMBER(px4_state::px4_ramdisk_address_w)
 	}
 }
 
-READ8_MEMBER(px4_state::px4_ramdisk_data_r)
+READ8_MEMBER( px4_state::px4_ramdisk_data_r )
 {
 	UINT8 ret = 0xff;
 
@@ -917,7 +1044,7 @@ READ8_MEMBER(px4_state::px4_ramdisk_data_r)
 	return ret;
 }
 
-WRITE8_MEMBER(px4_state::px4_ramdisk_data_w)
+WRITE8_MEMBER( px4_state::px4_ramdisk_data_w )
 {
 	if (m_ramdisk_address < 0x20000)
 		m_ramdisk[m_ramdisk_address] = data;
@@ -925,7 +1052,7 @@ WRITE8_MEMBER(px4_state::px4_ramdisk_data_w)
 	m_ramdisk_address = (m_ramdisk_address & 0xffff00) | ((m_ramdisk_address & 0xff) + 1);
 }
 
-READ8_MEMBER(px4_state::px4_ramdisk_control_r)
+READ8_MEMBER( px4_state::px4_ramdisk_control_r )
 {
 	// bit 7 determines the presence of a ram-disk
 	return 0x7f;
@@ -982,27 +1109,14 @@ UINT32 px4_state::screen_update_px4(screen_device &screen, bitmap_ind16 &bitmap,
 //  DRIVER INIT
 //**************************************************************************
 
-DRIVER_INIT_MEMBER(px4_state,px4)
+DRIVER_INIT_MEMBER( px4_state, px4 )
 {
-	// init 7508
-	m_one_sec_int_enabled = true;
-	m_key_int_enabled = true;
-	m_alarm_int_enabled = true;
-
-	// art
-	m_receive_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(px4_state::receive_data), this));
-	m_transmit_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(px4_state::transmit_data), this));
-
-	// external cassette or barcode reader
-	m_ext_cas_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(px4_state::ext_cassette_read), this));
-	m_ear_last_state = 0;
-
 	// map os rom and last half of memory
 	membank("bank1")->set_base(memregion("os")->base());
 	membank("bank2")->set_base(m_ram->pointer() + 0x8000);
 }
 
-DRIVER_INIT_MEMBER(px4_state, px4p)
+DRIVER_INIT_MEMBER( px4_state, px4p )
 {
 	DRIVER_INIT_CALL(px4);
 
@@ -1013,13 +1127,16 @@ DRIVER_INIT_MEMBER(px4_state, px4p)
 void px4_state::machine_reset()
 {
 	m_artsr = ART_TXRDY | ART_TXEMPTY;
+	receive_register_reset();
+	transmit_register_reset();
 }
 
-MACHINE_START_MEMBER(px4_state, px4_ramdisk)
+MACHINE_START_MEMBER( px4_state, px4_ramdisk )
 {
 	machine().device<nvram_device>("nvram")->set_base(m_ramdisk, 0x20000);
 }
 
+
 //**************************************************************************
 //  ADDRESS MAPS
 //**************************************************************************
@@ -1052,7 +1169,7 @@ static ADDRESS_MAP_START( px4_io, AS_IO, 8, px4_state )
 	AM_RANGE(0x14, 0x14) AM_READWRITE(px4_artdir_r, px4_artdor_w)
 	AM_RANGE(0x15, 0x15) AM_READWRITE(px4_artsr_r, px4_artmr_w)
 	AM_RANGE(0x16, 0x16) AM_READWRITE(px4_iostr_r, px4_artcr_w)
-	AM_RANGE(0x17, 0x17) AM_DEVWRITE("centronics", centronics_device, write)
+	AM_RANGE(0x17, 0x17) AM_DEVWRITE("cent_data_out", output_latch_device, write)
 	AM_RANGE(0x18, 0x18) AM_WRITE(px4_swr_w)
 	AM_RANGE(0x19, 0x19) AM_WRITE(px4_ioctlr_w)
 	AM_RANGE(0x1a, 0x1f) AM_NOP
@@ -1080,7 +1197,7 @@ static INPUT_PORTS_START( px4_dips )
 	PORT_START("dips")
 
 	PORT_DIPNAME(0x0f, 0x0f, "Character set")
-	PORT_DIPLOCATION("PX-4 DIP:8,7,6,5")
+	PORT_DIPLOCATION("PX-4:8,7,6,5")
 	PORT_DIPSETTING(0x0f, "ASCII")
 	PORT_DIPSETTING(0x0e, "France")
 	PORT_DIPSETTING(0x0d, "Germany")
@@ -1093,7 +1210,7 @@ static INPUT_PORTS_START( px4_dips )
 	PORT_DIPSETTING(0x06, "Norway")
 
 	PORT_DIPNAME(0x30, 0x30, "LST device")
-	PORT_DIPLOCATION("DIP:4,3")
+	PORT_DIPLOCATION("PX-4:4,3")
 	PORT_DIPSETTING(0x00, "SIO")
 	PORT_DIPSETTING(0x10, "Cartridge printer")
 	PORT_DIPSETTING(0x20, "RS-232C")
@@ -1101,13 +1218,13 @@ static INPUT_PORTS_START( px4_dips )
 
 	// available for user applications
 	PORT_DIPNAME(0x40, 0x40, "Not used")
-	PORT_DIPLOCATION("DIP:2")
+	PORT_DIPLOCATION("PX-4:2")
 	PORT_DIPSETTING(0x40, "Enable")
 	PORT_DIPSETTING(0x00, "Disable")
 
 	// this is automatically selected by the os, the switch has no effect
 	PORT_DIPNAME(0x80, 0x00, "Keyboard type")
-	PORT_DIPLOCATION("DIP:1")
+	PORT_DIPLOCATION("PX-4:1")
 	PORT_DIPSETTING(0x80, "Item keyboard")
 	PORT_DIPSETTING(0x00, "Standard keyboard")
 INPUT_PORTS_END
@@ -1225,16 +1342,16 @@ INPUT_PORTS_END
 //  PALETTE
 //**************************************************************************
 
-void px4_state::palette_init()
+PALETTE_INIT_MEMBER(px4_state, px4)
 {
-	palette_set_color(machine(), 0, MAKE_RGB(138, 146, 148));
-	palette_set_color(machine(), 1, MAKE_RGB(92, 83, 88));
+	palette.set_pen_color(0, rgb_t(138, 146, 148));
+	palette.set_pen_color(1, rgb_t(92, 83, 88));
 }
 
 PALETTE_INIT_MEMBER(px4_state, px4p)
 {
-	palette_set_color(machine(), 0, MAKE_RGB(149, 157, 130));
-	palette_set_color(machine(), 1, MAKE_RGB(92, 83, 88));
+	palette.set_pen_color(0, rgb_t(149, 157, 130));
+	palette.set_pen_color(1, rgb_t(92, 83, 88));
 }
 
 
@@ -1242,15 +1359,6 @@ PALETTE_INIT_MEMBER(px4_state, px4p)
 //  MACHINE DRIVERS
 //**************************************************************************
 
-static const cassette_interface px4_cassette_interface =
-{
-	cassette_default_formats,
-	NULL,
-	(cassette_state)(CASSETTE_PLAY | CASSETTE_SPEAKER_ENABLED | CASSETTE_MOTOR_DISABLED),
-	NULL,
-	NULL
-};
-
 static MACHINE_CONFIG_START( px4, px4_state )
 	// basic machine hardware
 	MCFG_CPU_ADD("maincpu", Z80, XTAL_7_3728MHz / 2)    // uPD70008
@@ -1263,10 +1371,12 @@ static MACHINE_CONFIG_START( px4, px4_state )
 	MCFG_SCREEN_SIZE(240, 64)
 	MCFG_SCREEN_VISIBLE_AREA(0, 239, 0, 63)
 	MCFG_SCREEN_UPDATE_DRIVER(px4_state, screen_update_px4)
+	MCFG_SCREEN_PALETTE("palette")
 
 	MCFG_DEFAULT_LAYOUT(layout_px4)
 
-	MCFG_PALETTE_LENGTH(2)
+	MCFG_PALETTE_ADD("palette", 2)
+	MCFG_PALETTE_INIT_OWNER(px4_state, px4)
 
 	// sound hardware
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1281,16 +1391,29 @@ static MACHINE_CONFIG_START( px4, px4_state )
 	MCFG_RAM_DEFAULT_SIZE("64k")
 
 	// centronics printer
-	MCFG_CENTRONICS_PRINTER_ADD("centronics", standard_centronics)
+	MCFG_CENTRONICS_ADD("centronics", centronics_printers, "printer")
+	MCFG_CENTRONICS_BUSY_HANDLER(WRITELINE(px4_state, write_centronics_busy))
+	MCFG_CENTRONICS_PERROR_HANDLER(WRITELINE(px4_state, write_centronics_perror))
+
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", "centronics")
 
 	// external cassette
-	MCFG_CASSETTE_ADD("extcas", px4_cassette_interface)
+	MCFG_CASSETTE_ADD("extcas")
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_PLAY | CASSETTE_SPEAKER_ENABLED | CASSETTE_MOTOR_DISABLED)
+
+	MCFG_TIMER_DRIVER_ADD("extcas_timer", px4_state, ext_cassette_read)
 
 	// sio port
 	MCFG_EPSON_SIO_ADD("sio", NULL)
+	MCFG_EPSON_SIO_RX(WRITELINE(px4_state, sio_rx_w))
+	MCFG_EPSON_SIO_PIN(WRITELINE(px4_state, sio_pin_w))
 
 	// rs232 port
 	MCFG_RS232_PORT_ADD("rs232", default_rs232_devices, NULL)
+	MCFG_RS232_RXD_HANDLER(WRITELINE(px4_state, rs232_rx_w))
+	MCFG_RS232_DCD_HANDLER(WRITELINE(px4_state, rs232_dcd_w))
+	MCFG_RS232_DSR_HANDLER(WRITELINE(px4_state, rs232_dsr_w))
+	MCFG_RS232_CTS_HANDLER(WRITELINE(px4_state, rs232_cts_w))
 
 	// rom capsules
 	MCFG_CARTSLOT_ADD("capsule1")
@@ -1314,7 +1437,8 @@ static MACHINE_CONFIG_DERIVED( px4p, px4 )
 	MCFG_MACHINE_START_OVERRIDE(px4_state, px4_ramdisk)
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MCFG_PALETTE_INIT_OVERRIDE(px4_state, px4p)
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_INIT_OWNER(px4_state, px4p)
 
 	MCFG_CARTSLOT_ADD("ramdisk")
 	MCFG_CARTSLOT_NOT_MANDATORY
