@@ -24,6 +24,7 @@
 */
 
 #include "includes/sage2.h"
+#include "bus/rs232/rs232.h"
 
 
 //**************************************************************************
@@ -182,7 +183,7 @@ INPUT_PORTS_END
 //**************************************************************************
 
 //-------------------------------------------------
-//  I8255A_INTERFACE( ppi0_intf )
+//  I8255A INTERFACE( ppi0_intf )
 //-------------------------------------------------
 
 /*
@@ -200,7 +201,7 @@ INPUT_PORTS_END
 
 
 //-------------------------------------------------
-//  I8255A_INTERFACE( ppi0_intf )
+//  I8255A INTERFACE( ppi0_intf )
 //-------------------------------------------------
 
 WRITE8_MEMBER( sage2_state::ppi0_pc_w )
@@ -245,20 +246,38 @@ WRITE8_MEMBER( sage2_state::ppi0_pc_w )
 	if(BIT(data, 7)) m_fdc->reset();
 }
 
-static I8255A_INTERFACE( ppi0_intf )
+
+//-------------------------------------------------
+//  I8255A INTERFACE( ppi1_intf )
+//-------------------------------------------------
+
+WRITE_LINE_MEMBER(sage2_state::write_centronics_ack)
 {
-	DEVCB_INPUT_PORT("J7"),
-	DEVCB_NULL,
-	DEVCB_INPUT_PORT("J6"),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(sage2_state, ppi0_pc_w)
-};
+	if (!state)
+	{
+		m_pic->ir5_w(ASSERT_LINE);
+	}
+}
 
+WRITE_LINE_MEMBER(sage2_state::write_centronics_busy)
+{
+	m_centronics_busy = state;
+}
 
-//-------------------------------------------------
-//  I8255A_INTERFACE( ppi1_intf )
-//-------------------------------------------------
+WRITE_LINE_MEMBER(sage2_state::write_centronics_perror)
+{
+	m_centronics_perror = state;
+}
+
+WRITE_LINE_MEMBER(sage2_state::write_centronics_select)
+{
+	m_centronics_select = state;
+}
+
+WRITE_LINE_MEMBER(sage2_state::write_centronics_fault)
+{
+	m_centronics_fault = state;
+}
 
 READ8_MEMBER( sage2_state::ppi1_pb_r )
 {
@@ -290,10 +309,10 @@ READ8_MEMBER( sage2_state::ppi1_pb_r )
 	// RS-232 carrier detect
 
 	// centronics
-	data |= m_centronics->busy_r() << 4;
-	data |= m_centronics->pe_r() << 5;
-	data |= m_centronics->vcc_r() << 6;
-	data |= m_centronics->fault_r() << 7;
+	data |= m_centronics_busy << 4;
+	data |= m_centronics_perror << 5;
+	data |= m_centronics_select << 6;
+	data |= m_centronics_fault << 7;
 
 	return data;
 }
@@ -328,8 +347,8 @@ WRITE8_MEMBER( sage2_state::ppi1_pc_w )
 	output_set_led_value(0, BIT(data, 3));
 
 	// centronics
-	m_centronics->strobe_w(BIT(data, 4));
-	m_centronics->init_prime_w(BIT(data, 5));
+	m_centronics->write_strobe(BIT(data, 4));
+	m_centronics->write_init(BIT(data, 5));
 
 	if (!BIT(data, 6))
 	{
@@ -344,115 +363,18 @@ WRITE8_MEMBER( sage2_state::ppi1_pc_w )
 	}
 }
 
-static I8255A_INTERFACE( ppi1_intf )
-{
-	DEVCB_NULL,
-	DEVCB_DEVICE_MEMBER(CENTRONICS_TAG, centronics_device, write),
-	DEVCB_DRIVER_MEMBER(sage2_state, ppi1_pb_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(sage2_state, ppi1_pc_w)
-};
-
-
-//-------------------------------------------------
-//  pit8253_config pit0_intf
-//-------------------------------------------------
-
-static const struct pit8253_interface pit0_intf =
-{
-	{
-		{
-			0, // from U75 OUT0
-			DEVCB_LINE_VCC,
-			DEVCB_DEVICE_LINE_MEMBER(I8259_TAG, pic8259_device, ir6_w)
-		}, {
-			XTAL_16MHz/2/125,
-			DEVCB_LINE_VCC,
-			DEVCB_DEVICE_LINE_MEMBER(I8253_0_TAG, pit8253_device, clk2_w)
-		}, {
-			0, // from OUT2
-			DEVCB_LINE_VCC,
-			DEVCB_DEVICE_LINE_MEMBER(I8259_TAG, pic8259_device, ir0_w)
-		}
-	}
-};
-
-
-//-------------------------------------------------
-//  pit8253_config pit1_intf
-//-------------------------------------------------
-
 WRITE_LINE_MEMBER( sage2_state::br1_w )
 {
-	if (state)
-	{
-		m_usart0->transmit_clock();
-		m_usart0->receive_clock();
-	}
+	m_usart0->write_txc(state);
+	m_usart0->write_rxc(state);
 }
 
 WRITE_LINE_MEMBER( sage2_state::br2_w )
 {
-	if (state)
-	{
-		m_usart1->transmit_clock();
-		m_usart1->receive_clock();
-	}
+	m_usart1->write_txc(state);
+	m_usart1->write_rxc(state);
 }
 
-static const struct pit8253_interface pit1_intf =
-{
-	{
-		{
-			XTAL_16MHz/2/125,
-			DEVCB_LINE_VCC,
-			DEVCB_DEVICE_LINE_MEMBER(I8253_0_TAG, pit8253_device, clk0_w)
-		}, {
-			XTAL_16MHz/2/13,
-			DEVCB_LINE_VCC,
-			DEVCB_DRIVER_LINE_MEMBER(sage2_state, br1_w)
-		}, {
-			XTAL_16MHz/2/13,
-			DEVCB_LINE_VCC,
-			DEVCB_DRIVER_LINE_MEMBER(sage2_state, br2_w)
-		}
-	}
-};
-
-
-//-------------------------------------------------
-//  i8251_interface usart0_intf
-//-------------------------------------------------
-
-static const i8251_interface usart0_intf =
-{
-	DEVCB_DEVICE_LINE_MEMBER(RS232_A_TAG, serial_port_device, tx),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_A_TAG, rs232_port_device, dtr_w),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_A_TAG, rs232_port_device, rts_w),
-	DEVCB_CPU_INPUT_LINE(M68000_TAG, M68K_IRQ_5),
-	DEVCB_DEVICE_LINE_MEMBER(I8259_TAG, pic8259_device, ir2_w),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
-//-------------------------------------------------
-//  i8251_interface usart1_intf
-//-------------------------------------------------
-
-static const i8251_interface usart1_intf =
-{
-	DEVCB_DEVICE_LINE_MEMBER(RS232_B_TAG, serial_port_device, tx),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_B_TAG, rs232_port_device, dtr_w),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_B_TAG, rs232_port_device, rts_w),
-	DEVCB_DEVICE_LINE_MEMBER(I8259_TAG, pic8259_device, ir1_w),
-	DEVCB_DEVICE_LINE_MEMBER(I8259_TAG, pic8259_device, ir3_w),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
 //-------------------------------------------------
 //  upd765_interface fdc_intf
 //-------------------------------------------------
@@ -466,36 +388,20 @@ void sage2_state::update_fdc_int()
 	m_maincpu->set_input_line(M68K_IRQ_6, m_fdie && m_fdc_int);
 }
 
-void sage2_state::fdc_irq(bool state)
+WRITE_LINE_MEMBER( sage2_state::fdc_irq )
 {
 	m_fdc_int = state;
 	update_fdc_int();
 }
 
 
-//-------------------------------------------------
-//  centronics_interface centronics_intf
-//-------------------------------------------------
-
-WRITE_LINE_MEMBER( sage2_state::ack_w )
-{
-	if (!state)
-	{
-		m_pic->ir5_w(ASSERT_LINE);
-	}
-}
-
-static const centronics_interface centronics_intf =
-{
-	DEVCB_DRIVER_LINE_MEMBER(sage2_state, ack_w),
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
 static DEVICE_INPUT_DEFAULTS_START( terminal )
-	DEVICE_INPUT_DEFAULTS( "TERM_FRAME", 0x0f, 0x08 ) // 19200
-	DEVICE_INPUT_DEFAULTS( "TERM_FRAME", 0x30, 0x10 ) // 7E1
+	DEVICE_INPUT_DEFAULTS( "RS232_TXBAUD", 0xff, RS232_BAUD_19200 )
+	DEVICE_INPUT_DEFAULTS( "RS232_RXBAUD", 0xff, RS232_BAUD_19200 )
+	DEVICE_INPUT_DEFAULTS( "RS232_STARTBITS", 0xff, RS232_STARTBITS_1 )
+	DEVICE_INPUT_DEFAULTS( "RS232_DATABITS", 0xff, RS232_DATABITS_7 )
+	DEVICE_INPUT_DEFAULTS( "RS232_PARITY", 0xff, RS232_PARITY_EVEN )
+	DEVICE_INPUT_DEFAULTS( "RS232_STOPBITS", 0xff, RS232_STOPBITS_1 )
 DEVICE_INPUT_DEFAULTS_END
 
 
@@ -512,9 +418,6 @@ void sage2_state::machine_start()
 {
 	// find memory regions
 	m_rom = memregion(M68000_TAG)->base();
-
-	// setup floppy callbacks
-	m_fdc->setup_intrq_cb(upd765a_device::line_cb(FUNC(sage2_state::fdc_irq), this));
 }
 
 
@@ -540,27 +443,72 @@ static MACHINE_CONFIG_START( sage2, sage2_state )
 
 	// devices
 	MCFG_PIC8259_ADD(I8259_TAG, INPUTLINE(M68000_TAG, M68K_IRQ_1), VCC, NULL)
-	MCFG_I8255A_ADD(I8255A_0_TAG, ppi0_intf)
-	MCFG_I8255A_ADD(I8255A_1_TAG, ppi1_intf)
-	MCFG_PIT8253_ADD(I8253_0_TAG, pit0_intf)
-	MCFG_PIT8253_ADD(I8253_1_TAG, pit1_intf)
-	MCFG_I8251_ADD(I8251_0_TAG, usart0_intf)
-	MCFG_I8251_ADD(I8251_1_TAG, usart1_intf)
+
+	MCFG_DEVICE_ADD(I8255A_0_TAG, I8255A, 0)
+	MCFG_I8255_IN_PORTA_CB(IOPORT("J7"))
+	MCFG_I8255_IN_PORTB_CB(IOPORT("J6"))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(sage2_state, ppi0_pc_w))
+
+	MCFG_DEVICE_ADD(I8255A_1_TAG, I8255A, 0)
+	MCFG_I8255_OUT_PORTA_CB(DEVWRITE8("cent_data_out", output_latch_device, write))
+	MCFG_I8255_IN_PORTB_CB(READ8(sage2_state, ppi1_pb_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(sage2_state, ppi1_pc_w))
+
+	MCFG_DEVICE_ADD(I8253_0_TAG, PIT8253, 0)
+	MCFG_PIT8253_CLK0(0) // from U75 OUT0
+	MCFG_PIT8253_OUT0_HANDLER(DEVWRITELINE(I8259_TAG, pic8259_device, ir6_w))
+	MCFG_PIT8253_CLK1(XTAL_16MHz/2/125)
+	MCFG_PIT8253_OUT1_HANDLER(DEVWRITELINE(I8253_0_TAG, pit8253_device, write_clk2))
+	MCFG_PIT8253_CLK2(0) // from OUT2
+	MCFG_PIT8253_OUT2_HANDLER(DEVWRITELINE(I8259_TAG, pic8259_device, ir0_w))
+
+	MCFG_DEVICE_ADD(I8253_1_TAG, PIT8253, 0)
+	MCFG_PIT8253_CLK0(XTAL_16MHz/2/125)
+	MCFG_PIT8253_OUT0_HANDLER(DEVWRITELINE(I8253_0_TAG, pit8253_device, write_clk0))
+	MCFG_PIT8253_CLK1(XTAL_16MHz/2/13)
+	MCFG_PIT8253_OUT1_HANDLER(WRITELINE(sage2_state, br1_w))
+	MCFG_PIT8253_CLK2(XTAL_16MHz/2/13)
+	MCFG_PIT8253_OUT2_HANDLER(WRITELINE(sage2_state, br2_w))
+
+	MCFG_DEVICE_ADD(I8251_0_TAG, I8251, 0)
+	MCFG_I8251_TXD_HANDLER(DEVWRITELINE(RS232_A_TAG, rs232_port_device, write_txd))
+	MCFG_I8251_DTR_HANDLER(DEVWRITELINE(RS232_A_TAG, rs232_port_device, write_dtr))
+	MCFG_I8251_RTS_HANDLER(DEVWRITELINE(RS232_A_TAG, rs232_port_device, write_rts))
+	MCFG_I8251_RXRDY_HANDLER(DEVWRITELINE(M68000_TAG, m68000_base_device, write_irq5))
+	MCFG_I8251_TXRDY_HANDLER(DEVWRITELINE(I8259_TAG, pic8259_device, ir2_w))
+
+	MCFG_RS232_PORT_ADD(RS232_A_TAG, default_rs232_devices, "terminal")
+	MCFG_RS232_RXD_HANDLER(DEVWRITELINE(I8251_0_TAG, i8251_device, write_rxd))
+	MCFG_RS232_DSR_HANDLER(DEVWRITELINE(I8251_0_TAG, i8251_device, write_dsr))
+	MCFG_DEVICE_CARD_DEVICE_INPUT_DEFAULTS("terminal", terminal)
+
+	MCFG_DEVICE_ADD(I8251_1_TAG, I8251, 0)
+	MCFG_I8251_TXD_HANDLER(DEVWRITELINE(RS232_B_TAG, rs232_port_device, write_txd))
+	MCFG_I8251_DTR_HANDLER(DEVWRITELINE(RS232_B_TAG, rs232_port_device, write_dtr))
+	MCFG_I8251_RTS_HANDLER(DEVWRITELINE(RS232_B_TAG, rs232_port_device, write_rts))
+	MCFG_I8251_RXRDY_HANDLER(DEVWRITELINE(I8259_TAG, pic8259_device, ir1_w))
+	MCFG_I8251_TXRDY_HANDLER(DEVWRITELINE(I8259_TAG, pic8259_device, ir3_w))
+
+	MCFG_RS232_PORT_ADD(RS232_B_TAG, default_rs232_devices, NULL)
+	MCFG_RS232_RXD_HANDLER(DEVWRITELINE(I8251_1_TAG, i8251_device, write_rxd))
+	MCFG_RS232_DSR_HANDLER(DEVWRITELINE(I8251_1_TAG, i8251_device, write_dsr))
+
 	MCFG_UPD765A_ADD(UPD765_TAG, false, false)
-	MCFG_CENTRONICS_PRINTER_ADD(CENTRONICS_TAG, centronics_intf)
+	MCFG_UPD765_INTRQ_CALLBACK(WRITELINE(sage2_state, fdc_irq))
+
+	MCFG_CENTRONICS_ADD("centronics", centronics_printers, "printer")
+	MCFG_CENTRONICS_ACK_HANDLER(WRITELINE(sage2_state, write_centronics_ack))
+	MCFG_CENTRONICS_BUSY_HANDLER(WRITELINE(sage2_state, write_centronics_busy))
+	MCFG_CENTRONICS_PERROR_HANDLER(WRITELINE(sage2_state, write_centronics_perror))
+	MCFG_CENTRONICS_SELECT_HANDLER(WRITELINE(sage2_state, write_centronics_select))
+	MCFG_CENTRONICS_FAULT_HANDLER(WRITELINE(sage2_state, write_centronics_fault))
+
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", "centronics")
+
 	MCFG_FLOPPY_DRIVE_ADD(UPD765_TAG ":0", sage2_floppies, "525qd", floppy_image_device::default_floppy_formats)
 	MCFG_FLOPPY_DRIVE_ADD(UPD765_TAG ":1", sage2_floppies, "525qd", floppy_image_device::default_floppy_formats)
 	MCFG_IEEE488_BUS_ADD()
 
-	MCFG_RS232_PORT_ADD(RS232_A_TAG, default_rs232_devices, "serial_terminal")
-	MCFG_SERIAL_OUT_RX_HANDLER(DEVWRITELINE(I8251_0_TAG, i8251_device, write_rx))
-	MCFG_RS232_OUT_DSR_HANDLER(DEVWRITELINE(I8251_0_TAG, i8251_device, write_dsr))
-	MCFG_DEVICE_CARD_DEVICE_INPUT_DEFAULTS("serial_terminal", terminal)
-
-	MCFG_RS232_PORT_ADD(RS232_B_TAG, default_rs232_devices, NULL)
-	MCFG_SERIAL_OUT_RX_HANDLER(DEVWRITELINE(I8251_1_TAG, i8251_device, write_rx))
-	MCFG_RS232_OUT_DSR_HANDLER(DEVWRITELINE(I8251_1_TAG, i8251_device, write_dsr))
-
 	// internal ram
 	MCFG_RAM_ADD(RAM_TAG)
 	MCFG_RAM_DEFAULT_SIZE("512K")
