@@ -29,12 +29,11 @@
 /* core includes */
 #include "emu.h"
 #include "includes/samcoupe.h"
-
+#
 /* components */
 #include "cpu/z80/z80.h"
 #include "machine/wd_fdc.h"
 #include "machine/msm6242.h"
-#include "bus/centronics/ctronics.h"
 #include "sound/saa1099.h"
 #include "sound/speaker.h"
 
@@ -126,7 +125,7 @@ WRITE8_MEMBER(samcoupe_state::samcoupe_disk_w)
 
 READ8_MEMBER(samcoupe_state::samcoupe_pen_r)
 {
-	screen_device *scr = machine().primary_screen;
+	screen_device *scr = machine().first_screen();
 	UINT8 data;
 
 	if (offset & 0x100)
@@ -279,31 +278,36 @@ READ8_MEMBER(samcoupe_state::samcoupe_attributes_r)
 	return m_attribute;
 }
 
+WRITE_LINE_MEMBER(samcoupe_state::write_lpt1_busy)
+{
+	m_lpt1_busy = state;
+}
+
 READ8_MEMBER(samcoupe_state::samcoupe_lpt1_busy_r)
 {
-	centronics_device *centronics = machine().device<centronics_device>("lpt1");
-	return centronics->busy_r();
+	return m_lpt1_busy;
 }
 
 WRITE8_MEMBER(samcoupe_state::samcoupe_lpt1_strobe_w)
 {
-	centronics_device *centronics = machine().device<centronics_device>("lpt1");
-	centronics->strobe_w(data);
+	m_lpt1->write_strobe(data & 1);
+}
+
+DECLARE_WRITE_LINE_MEMBER(samcoupe_state::write_lpt2_busy)
+{
+	m_lpt2_busy = state;
 }
 
 READ8_MEMBER(samcoupe_state::samcoupe_lpt2_busy_r)
 {
-	centronics_device *centronics = machine().device<centronics_device>("lpt2");
-	return centronics->busy_r();
+	return m_lpt2_busy;
 }
 
 WRITE8_MEMBER(samcoupe_state::samcoupe_lpt2_strobe_w)
 {
-	centronics_device *centronics = machine().device<centronics_device>("lpt2");
-	centronics->strobe_w(data);
+	m_lpt2->write_strobe(data & 1);
 }
 
-
 /***************************************************************************
     ADDRESS MAPS
 ***************************************************************************/
@@ -318,9 +322,9 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( samcoupe_io, AS_IO, 8, samcoupe_state )
 	AM_RANGE(0x0080, 0x0081) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_WRITE(samcoupe_ext_mem_w)
 	AM_RANGE(0x00e0, 0x00e7) AM_MIRROR(0xff10) AM_MASK(0xffff) AM_READWRITE(samcoupe_disk_r, samcoupe_disk_w)
-	AM_RANGE(0x00e8, 0x00e8) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_DEVWRITE("lpt1", centronics_device, write)
+	AM_RANGE(0x00e8, 0x00e8) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_DEVWRITE("lpt1_data_out", output_latch_device, write)
 	AM_RANGE(0x00e9, 0x00e9) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_READWRITE(samcoupe_lpt1_busy_r, samcoupe_lpt1_strobe_w)
-	AM_RANGE(0x00ea, 0x00ea) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_DEVWRITE("lpt2", centronics_device, write)
+	AM_RANGE(0x00ea, 0x00ea) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_DEVWRITE("lpt2_data_out", output_latch_device, write)
 	AM_RANGE(0x00eb, 0x00eb) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_READWRITE(samcoupe_lpt2_busy_r, samcoupe_lpt2_strobe_w)
 	AM_RANGE(0x00f8, 0x00f8) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_READWRITE(samcoupe_pen_r, samcoupe_clut_w)
 	AM_RANGE(0x00f9, 0x00f9) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_READWRITE(samcoupe_status_r, samcoupe_line_int_w)
@@ -489,7 +493,7 @@ INPUT_PORTS_END
          nothing   G+4     R+4     B+4    ALL+1    G+2     R+2     B+2
 
 */
-void samcoupe_state::palette_init()
+PALETTE_INIT_MEMBER(samcoupe_state, samcoupe)
 {
 	for (int i = 0; i < 128; i++)
 	{
@@ -501,10 +505,10 @@ void samcoupe_state::palette_init()
 		g <<= 5;
 		b <<= 5;
 
-		palette_set_color(machine(), i, MAKE_RGB(r, g, b));
+		palette.set_pen_color(i, rgb_t(r, g, b));
 	}
 
-	palette_normalize_range(machine().palette, 0, 127, 0, 255);
+	palette.palette()->normalize_range(0, 127);
 }
 
 
@@ -512,15 +516,6 @@ void samcoupe_state::palette_init()
     MACHINE DRIVERS
 ***************************************************************************/
 
-static const cassette_interface samcoupe_cassette_interface =
-{
-	tzx_cassette_formats,
-	NULL,
-	(cassette_state)(CASSETTE_STOPPED | CASSETTE_SPEAKER_ENABLED | CASSETTE_MOTOR_ENABLED),
-	"samcoupe_cass",
-	NULL
-};
-
 FLOPPY_FORMATS_MEMBER( samcoupe_state::floppy_formats )
 	FLOPPY_MGT_FORMAT
 FLOPPY_FORMATS_END
@@ -529,10 +524,6 @@ static SLOT_INTERFACE_START( samcoupe_floppies )
 	SLOT_INTERFACE( "35dd", FLOPPY_35_DD )
 SLOT_INTERFACE_END
 
-static MSM6242_INTERFACE( samcoupe_rtc_intf )
-{
-	DEVCB_NULL
-};
 
 static MACHINE_CONFIG_START( samcoupe, samcoupe_state )
 	/* basic machine hardware */
@@ -546,14 +537,28 @@ static MACHINE_CONFIG_START( samcoupe, samcoupe_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_RAW_PARAMS(SAMCOUPE_XTAL_X1/2, SAM_TOTAL_WIDTH, 0, SAM_BORDER_LEFT + SAM_SCREEN_WIDTH + SAM_BORDER_RIGHT, SAM_TOTAL_HEIGHT, 0, SAM_BORDER_TOP + SAM_SCREEN_HEIGHT + SAM_BORDER_BOTTOM)
 	MCFG_SCREEN_UPDATE_DRIVER(samcoupe_state, screen_update)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_PALETTE_LENGTH(128)
+	MCFG_PALETTE_ADD("palette", 128)
+	MCFG_PALETTE_INIT_OWNER(samcoupe_state, samcoupe)
 
 	/* devices */
-	MCFG_CENTRONICS_PRINTER_ADD("lpt1", standard_centronics)
-	MCFG_CENTRONICS_PRINTER_ADD("lpt2", standard_centronics)
-	MCFG_MSM6242_ADD("sambus_clock", samcoupe_rtc_intf)
-	MCFG_CASSETTE_ADD("cassette", samcoupe_cassette_interface)
+	MCFG_CENTRONICS_ADD("lpt1", centronics_printers, "printer")
+	MCFG_CENTRONICS_BUSY_HANDLER(WRITELINE(samcoupe_state, write_lpt1_busy))
+
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("lpt1_data_out", "lpt1")
+
+	MCFG_CENTRONICS_ADD("lpt2", centronics_printers, "printer")
+	MCFG_CENTRONICS_BUSY_HANDLER(WRITELINE(samcoupe_state, write_lpt2_busy))
+
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("lpt2_data_out", "lpt2")
+
+	MCFG_DEVICE_ADD("sambus_clock", MSM6242, XTAL_32_768kHz)
+	MCFG_CASSETTE_ADD("cassette")
+	MCFG_CASSETTE_FORMATS(tzx_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_SPEAKER_ENABLED | CASSETTE_MOTOR_ENABLED)
+	MCFG_CASSETTE_INTERFACE("samcoupe_cass")
+
 	MCFG_SOFTWARE_LIST_ADD("cass_list","samcoupe_cass")
 
 	MCFG_WD1772x_ADD("wd1772", SAMCOUPE_XTAL_X1/3)
