@@ -48,7 +48,7 @@ public:
 	bool m_cart_ram_enabled;
 	virtual void machine_start();
 	virtual void machine_reset();
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(scv);
 	void scv_postload();
 	UINT32 screen_update_scv(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	DECLARE_DEVICE_IMAGE_LOAD_MEMBER( scv_cart );
@@ -362,7 +362,7 @@ DEVICE_IMAGE_LOAD_MEMBER( scv_state, scv_cart )
 }
 
 
-void scv_state::palette_init()
+PALETTE_INIT_MEMBER(scv_state, scv)
 {
 	/*
 	  SCV Epoch-1A chip RGB voltage readouts from paused Bios color test:
@@ -395,22 +395,22 @@ void scv_state::palette_init()
 	  Quamtizing/scaling/rounding between 0 and 255 we thus get:
 
 	*/
-	palette_set_color_rgb( machine(),   0,   0,   0, 155);
-	palette_set_color_rgb( machine(),   1,   0,   0,   0);
-	palette_set_color_rgb( machine(),   2,   0,   0, 255);
-	palette_set_color_rgb( machine(),   3, 161,   0, 255);
-	palette_set_color_rgb( machine(),   4,   0, 255,   0);
-	palette_set_color_rgb( machine(),   5, 160, 255, 157);
-	palette_set_color_rgb( machine(),   6,   0, 255, 255);
-	palette_set_color_rgb( machine(),   7,   0, 161,   0);
-	palette_set_color_rgb( machine(),   8, 255,   0,   0);
-	palette_set_color_rgb( machine(),   9, 255, 161,   0);
-	palette_set_color_rgb( machine(),  10, 255,   0, 255);
-	palette_set_color_rgb( machine(),  11, 255, 160, 159);
-	palette_set_color_rgb( machine(),  12, 255, 255,   0);
-	palette_set_color_rgb( machine(),  13, 163, 160,   0);
-	palette_set_color_rgb( machine(),  14, 161, 160, 157);
-	palette_set_color_rgb( machine(),  15, 255, 255, 255);
+	palette.set_pen_color( 0,   0,   0, 155);
+	palette.set_pen_color( 1,   0,   0,   0);
+	palette.set_pen_color( 2,   0,   0, 255);
+	palette.set_pen_color( 3, 161,   0, 255);
+	palette.set_pen_color( 4,   0, 255,   0);
+	palette.set_pen_color( 5, 160, 255, 157);
+	palette.set_pen_color( 6,   0, 255, 255);
+	palette.set_pen_color( 7,   0, 161,   0);
+	palette.set_pen_color( 8, 255,   0,   0);
+	palette.set_pen_color( 9, 255, 161,   0);
+	palette.set_pen_color( 10, 255,   0, 255);
+	palette.set_pen_color( 11, 255, 160, 159);
+	palette.set_pen_color( 12, 255, 255,   0);
+	palette.set_pen_color( 13, 163, 160,   0);
+	palette.set_pen_color( 14, 161, 160, 157);
+	palette.set_pen_color( 15, 255, 255, 255);
 }
 
 
@@ -420,7 +420,7 @@ void scv_state::device_timer(emu_timer &timer, device_timer_id id, int param, vo
 	{
 		case TIMER_VB:
 			{
-				int vpos = machine().primary_screen->vpos();
+				int vpos = machine().first_screen()->vpos();
 
 				switch( vpos )
 				{
@@ -432,7 +432,7 @@ void scv_state::device_timer(emu_timer &timer, device_timer_id id, int param, vo
 					break;
 				}
 
-				m_vb_timer->adjust(machine().primary_screen->time_until_pos((vpos + 1) % 262, 0));
+				m_vb_timer->adjust(machine().first_screen()->time_until_pos((vpos + 1) % 262, 0));
 			}
 			break;
 
@@ -791,7 +791,7 @@ void scv_state::machine_start()
 
 void scv_state::machine_reset()
 {
-	m_vb_timer->adjust(machine().primary_screen->time_until_pos(0, 0));
+	m_vb_timer->adjust(machine().first_screen()->time_until_pos(0, 0));
 	scv_set_banks();
 }
 
@@ -815,30 +815,27 @@ static GFXDECODE_START( scv )
 GFXDECODE_END
 
 
-static const UPD7810_CONFIG scv_cpu_config = { TYPE_7801, NULL };
-static const upd1771_interface scv_upd1771c_config = { DEVCB_DRIVER_LINE_MEMBER( scv_state, scv_upd1771_ack_w ) };
-
-
 static MACHINE_CONFIG_START( scv, scv_state )
 
 	MCFG_CPU_ADD( "maincpu", UPD7801, XTAL_4MHz )
 	MCFG_CPU_PROGRAM_MAP( scv_mem )
 	MCFG_CPU_IO_MAP( scv_io )
-	MCFG_CPU_CONFIG( scv_cpu_config )
 
 
 	/* Video chip is EPOCH TV-1 */
 	MCFG_SCREEN_ADD( "screen", RASTER )
 	MCFG_SCREEN_RAW_PARAMS( XTAL_14_31818MHz/2, 456, 24, 24+192, 262, 23, 23+222 )  /* TODO: Verify */
 	MCFG_SCREEN_UPDATE_DRIVER(scv_state, screen_update_scv)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_GFXDECODE(scv)
-	MCFG_PALETTE_LENGTH( 16 )
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", scv)
+	MCFG_PALETTE_ADD( "palette", 16 )
+	MCFG_PALETTE_INIT_OWNER(scv_state, scv)
 
 	/* Sound is generated by UPD1771C clocked at XTAL_6MHz */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD( "upd1771c", UPD1771C, XTAL_6MHz )
-	MCFG_SOUND_CONFIG( scv_upd1771c_config )
+	MCFG_UPD1771_ACK_HANDLER(WRITELINE(scv_state, scv_upd1771_ack_w))
 	MCFG_SOUND_ROUTE( ALL_OUTPUTS, "mono", 1.00 )
 
 	MCFG_CARTSLOT_ADD( "cart" )
