@@ -94,7 +94,7 @@
 */
 
 #include "includes/softbox.h"
-
+#include "bus/rs232/rs232.h"
 
 
 //**************************************************************************
@@ -138,7 +138,7 @@ static ADDRESS_MAP_START( softbox_io, AS_IO, 8, softbox_state )
 	AM_RANGE(0x0c, 0x0c) AM_WRITE(dbrg_w)
 	AM_RANGE(0x10, 0x13) AM_DEVREADWRITE(I8255_0_TAG, i8255_device, read, write)
 	AM_RANGE(0x14, 0x17) AM_DEVREADWRITE(I8255_1_TAG, i8255_device, read, write)
-	AM_RANGE(0x18, 0x18) AM_READWRITE_LEGACY(corvus_hdc_data_r, corvus_hdc_data_w)
+	AM_RANGE(0x18, 0x18) AM_DEVREADWRITE(CORVUS_HDC_TAG, corvus_hdc_t, read, write)
 ADDRESS_MAP_END
 
 
@@ -173,23 +173,7 @@ INPUT_PORTS_END
 //**************************************************************************
 
 //-------------------------------------------------
-//  i8251_interface usart_intf
-//-------------------------------------------------
-
-static const i8251_interface usart_intf =
-{
-	DEVCB_DEVICE_LINE_MEMBER(RS232_TAG, serial_port_device, tx),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_TAG, rs232_port_device, dtr_w),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_TAG, rs232_port_device, rts_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
-
-//-------------------------------------------------
-//  I8255A_INTERFACE( ppi0_intf )
+//  I8255A 0 Interface
 //-------------------------------------------------
 
 READ8_MEMBER( softbox_state::ppi0_pa_r )
@@ -202,19 +186,8 @@ WRITE8_MEMBER( softbox_state::ppi0_pb_w )
 	m_ieee->dio_w(data ^ 0xff);
 }
 
-static I8255A_INTERFACE( ppi0_intf )
-{
-	DEVCB_DRIVER_MEMBER(softbox_state, ppi0_pa_r),
-	DEVCB_NULL, // Port A write
-	DEVCB_NULL, // Port B read
-	DEVCB_DRIVER_MEMBER(softbox_state, ppi0_pb_w),
-	DEVCB_INPUT_PORT("SW1"), // Port C read
-	DEVCB_NULL  // Port C write
-};
-
-
 //-------------------------------------------------
-//  I8255A_INTERFACE( ppi1_intf )
+//  I8255A 1 Interface
 //-------------------------------------------------
 
 READ8_MEMBER( softbox_state::ppi1_pa_r )
@@ -292,7 +265,7 @@ READ8_MEMBER( softbox_state::ppi1_pc_r )
 
 	*/
 
-	UINT8 status = corvus_hdc_status_r(space, 0);
+	UINT8 status = m_hdc->status_r(space, 0);
 	UINT8 data = 0;
 
 	data |= (status & CONTROLLER_BUSY) ? 0 : 0x10;
@@ -323,20 +296,13 @@ WRITE8_MEMBER( softbox_state::ppi1_pc_w )
 	output_set_led_value(LED_READY, !BIT(data, 2));
 }
 
-static I8255A_INTERFACE( ppi1_intf )
-{
-	DEVCB_DRIVER_MEMBER(softbox_state, ppi1_pa_r),
-	DEVCB_NULL, // Port A write
-	DEVCB_NULL, // Port B read
-	DEVCB_DRIVER_MEMBER(softbox_state, ppi1_pb_w),
-	DEVCB_DRIVER_MEMBER(softbox_state, ppi1_pc_r),
-	DEVCB_DRIVER_MEMBER(softbox_state, ppi1_pc_w)
-};
-
-
 static DEVICE_INPUT_DEFAULTS_START( terminal )
-	DEVICE_INPUT_DEFAULTS( "TERM_FRAME", 0x0f, 0x06 ) // 9600
-	DEVICE_INPUT_DEFAULTS( "TERM_FRAME", 0x30, 0x10 ) // 7E1
+	DEVICE_INPUT_DEFAULTS( "RS232_TXBAUD", 0xff, RS232_BAUD_9600 )
+	DEVICE_INPUT_DEFAULTS( "RS232_RXBAUD", 0xff, RS232_BAUD_9600 )
+	DEVICE_INPUT_DEFAULTS( "RS232_STARTBITS", 0xff, RS232_STARTBITS_1 )
+	DEVICE_INPUT_DEFAULTS( "RS232_DATABITS", 0xff, RS232_DATABITS_7 )
+	DEVICE_INPUT_DEFAULTS( "RS232_PARITY", 0xff, RS232_PARITY_EVEN )
+	DEVICE_INPUT_DEFAULTS( "RS232_STOPBITS", 0xff, RS232_STOPBITS_1 )
 DEVICE_INPUT_DEFAULTS_END
 
 
@@ -351,7 +317,6 @@ DEVICE_INPUT_DEFAULTS_END
 
 void softbox_state::machine_start()
 {
-	corvus_hdc_init(machine());
 }
 
 
@@ -392,6 +357,7 @@ void softbox_state::ieee488_ifc(int state)
 }
 
 
+
 //**************************************************************************
 //  MACHINE CONFIGURATION
 //**************************************************************************
@@ -407,22 +373,44 @@ static MACHINE_CONFIG_START( softbox, softbox_state )
 	MCFG_CPU_IO_MAP(softbox_io)
 
 	// devices
-	MCFG_I8251_ADD(I8251_TAG, usart_intf)
-	MCFG_I8255A_ADD(I8255_0_TAG, ppi0_intf)
-	MCFG_I8255A_ADD(I8255_1_TAG, ppi1_intf)
-	MCFG_COM8116_ADD(COM8116_TAG, XTAL_5_0688MHz, NULL, DEVWRITELINE(I8251_TAG, i8251_device, rxc_w), DEVWRITELINE(I8251_TAG, i8251_device, txc_w))
+	MCFG_DEVICE_ADD(I8251_TAG, I8251, 0)
+	MCFG_I8251_TXD_HANDLER(DEVWRITELINE(RS232_TAG, rs232_port_device, write_txd))
+	MCFG_I8251_DTR_HANDLER(DEVWRITELINE(RS232_TAG, rs232_port_device, write_dtr))
+	MCFG_I8251_RTS_HANDLER(DEVWRITELINE(RS232_TAG, rs232_port_device, write_rts))
+
+	MCFG_RS232_PORT_ADD(RS232_TAG, default_rs232_devices, "terminal")
+	MCFG_RS232_RXD_HANDLER(DEVWRITELINE(I8251_TAG, i8251_device, write_rxd))
+	MCFG_RS232_DSR_HANDLER(DEVWRITELINE(I8251_TAG, i8251_device, write_dsr))
+	MCFG_DEVICE_CARD_DEVICE_INPUT_DEFAULTS("terminal", terminal)
+
+	MCFG_DEVICE_ADD(I8255_0_TAG, I8255A, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(softbox_state, ppi0_pa_r))
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(softbox_state, ppi0_pb_w))
+	MCFG_I8255_IN_PORTC_CB(IOPORT("SW1"))
+
+	MCFG_DEVICE_ADD(I8255_1_TAG, I8255A, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(softbox_state, ppi1_pa_r))
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(softbox_state, ppi1_pb_w))
+	MCFG_I8255_IN_PORTC_CB(READ8(softbox_state, ppi1_pc_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(softbox_state, ppi1_pc_w))
+
+	MCFG_DEVICE_ADD(COM8116_TAG, COM8116, XTAL_5_0688MHz)
+	MCFG_COM8116_FR_HANDLER(DEVWRITELINE(I8251_TAG, i8251_device, write_rxc))
+	MCFG_COM8116_FT_HANDLER(DEVWRITELINE(I8251_TAG, i8251_device, write_txc))
+
 	MCFG_CBM_IEEE488_ADD("c8050")
+
+	MCFG_DEVICE_ADD(CORVUS_HDC_TAG, CORVUS_HDC, 0)
 	MCFG_HARDDISK_ADD("harddisk1")
+	MCFG_HARDDISK_INTERFACE("corvus_hdd")
 	MCFG_HARDDISK_ADD("harddisk2")
+	MCFG_HARDDISK_INTERFACE("corvus_hdd")
 	MCFG_HARDDISK_ADD("harddisk3")
+	MCFG_HARDDISK_INTERFACE("corvus_hdd")
 	MCFG_HARDDISK_ADD("harddisk4")
+	MCFG_HARDDISK_INTERFACE("corvus_hdd")
 
-	MCFG_RS232_PORT_ADD(RS232_TAG, default_rs232_devices, "serial_terminal")
-	MCFG_SERIAL_OUT_RX_HANDLER(DEVWRITELINE(I8251_TAG, i8251_device, write_rx))
-	MCFG_RS232_OUT_DSR_HANDLER(DEVWRITELINE(I8251_TAG, i8251_device, write_dsr))
-
-	MCFG_DEVICE_CARD_DEVICE_INPUT_DEFAULTS("serial_terminal", terminal)
-	MCFG_IMI5000H_ADD("corvus1")
+	MCFG_IMI7000_BUS_ADD("imi5000h", NULL, NULL, NULL)
 
 	// software lists
 	MCFG_SOFTWARE_LIST_ADD("flop_list", "softbox")
