@@ -342,15 +342,6 @@ static INPUT_PORTS_START( specimx )
 	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_KEYBOARD) PORT_NAME("Shift") PORT_CODE(KEYCODE_LSHIFT) PORT_CODE(KEYCODE_RSHIFT) PORT_CHAR(UCHAR_SHIFT_1)
 INPUT_PORTS_END
 
-static const cassette_interface special_cassette_interface =
-{
-	rks_cassette_formats,
-	NULL,
-	(cassette_state)(CASSETTE_STOPPED | CASSETTE_SPEAKER_ENABLED | CASSETTE_MOTOR_ENABLED),
-	"special_cass",
-	NULL
-};
-
 FLOPPY_FORMATS_MEMBER( special_state::specimx_floppy_formats )
 	FLOPPY_SMX_FORMAT
 FLOPPY_FORMATS_END
@@ -374,7 +365,9 @@ static MACHINE_CONFIG_START( special, special_state )
 	MCFG_SCREEN_VISIBLE_AREA(0, 384-1, 0, 256-1)
 	MCFG_VIDEO_START_OVERRIDE(special_state,special)
 	MCFG_SCREEN_UPDATE_DRIVER(special_state, screen_update_special)
-	MCFG_PALETTE_LENGTH(2)
+	MCFG_SCREEN_PALETTE("palette")
+
+	MCFG_PALETTE_ADD("palette", 2)
 
 	/* audio hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -384,9 +377,19 @@ static MACHINE_CONFIG_START( special, special_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	/* Devices */
-	MCFG_PIT8253_ADD( "pit8253", specimx_pit8253_intf )
-	MCFG_I8255_ADD( "ppi8255", specialist_ppi8255_interface )
-	MCFG_CASSETTE_ADD( "cassette", special_cassette_interface )
+	MCFG_DEVICE_ADD("ppi8255", I8255, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(special_state, specialist_8255_porta_r))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(special_state, specialist_8255_porta_w))
+	MCFG_I8255_IN_PORTB_CB(READ8(special_state, specialist_8255_portb_r))
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(special_state, specialist_8255_portb_w))
+	MCFG_I8255_IN_PORTC_CB(READ8(special_state, specialist_8255_portc_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(special_state, specialist_8255_portc_w))
+
+	MCFG_CASSETTE_ADD( "cassette" )
+	MCFG_CASSETTE_FORMATS(rks_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_SPEAKER_ENABLED | CASSETTE_MOTOR_ENABLED)
+	MCFG_CASSETTE_INTERFACE("special_cass")
+
 	MCFG_SOFTWARE_LIST_ADD("cass_list","special_cass")
 MACHINE_CONFIG_END
 
@@ -404,7 +407,13 @@ MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( specialm, special )
 	MCFG_DEVICE_REMOVE("ppi8255")
-	MCFG_I8255_ADD( "ppi8255", specimx_ppi8255_interface )
+	MCFG_DEVICE_ADD("ppi8255", I8255, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(special_state, specialist_8255_porta_r))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(special_state, specialist_8255_porta_w))
+	MCFG_I8255_IN_PORTB_CB(READ8(special_state, specimx_8255_portb_r))
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(special_state, specialist_8255_portb_w))
+	MCFG_I8255_IN_PORTC_CB(READ8(special_state, specialist_8255_portc_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(special_state, specialist_8255_portc_w))
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( specimx, special )
@@ -418,17 +427,35 @@ static MACHINE_CONFIG_DERIVED( specimx, special )
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_UPDATE_DRIVER(special_state, screen_update_specimx)
 	MCFG_VIDEO_START_OVERRIDE(special_state,specimx)
-	MCFG_PALETTE_LENGTH(16)
-	MCFG_PALETTE_INIT_OVERRIDE(special_state, specimx )
+
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_ENTRIES(16)
+	MCFG_PALETTE_INIT_OWNER(special_state, specimx )
 
 	/* audio hardware */
 	MCFG_SOUND_ADD("custom", SPECIMX, 0)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 
 	/* Devices */
+	MCFG_DEVICE_ADD( "pit8253", PIT8253, 0)
+	MCFG_PIT8253_CLK0(2000000)
+	MCFG_PIT8253_OUT0_HANDLER(DEVWRITELINE("custom", specimx_sound_device, set_input_ch0))
+	MCFG_PIT8253_CLK1(2000000)
+	MCFG_PIT8253_OUT1_HANDLER(DEVWRITELINE("custom", specimx_sound_device, set_input_ch1))
+	MCFG_PIT8253_CLK2(2000000)
+	MCFG_PIT8253_OUT2_HANDLER(DEVWRITELINE("custom", specimx_sound_device, set_input_ch2))
+
 	MCFG_DEVICE_REMOVE("ppi8255")
-	MCFG_I8255_ADD( "ppi8255", specimx_ppi8255_interface )
+	MCFG_DEVICE_ADD("ppi8255", I8255, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(special_state, specialist_8255_porta_r))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(special_state, specialist_8255_porta_w))
+	MCFG_I8255_IN_PORTB_CB(READ8(special_state, specimx_8255_portb_r))
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(special_state, specialist_8255_portb_w))
+	MCFG_I8255_IN_PORTC_CB(READ8(special_state, specialist_8255_portc_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(special_state, specialist_8255_portc_w))
+
 	MCFG_FD1793x_ADD("fd1793", XTAL_8MHz / 8)
+	MCFG_WD_FDC_DRQ_CALLBACK(WRITELINE(special_state, fdc_drq))
 	MCFG_FLOPPY_DRIVE_ADD("fd0", specimx_floppies, "525qd", special_state::specimx_floppy_formats)
 	MCFG_FLOPPY_DRIVE_ADD("fd1", specimx_floppies, "525qd", special_state::specimx_floppy_formats)
 	MCFG_SOFTWARE_LIST_ADD("flop_list","special_flop")
@@ -454,8 +481,10 @@ static MACHINE_CONFIG_START( erik, special_state )
 	MCFG_SCREEN_VISIBLE_AREA(0, 384-1, 0, 256-1)
 	MCFG_VIDEO_START_OVERRIDE(special_state,erik)
 	MCFG_SCREEN_UPDATE_DRIVER(special_state, screen_update_erik)
-	MCFG_PALETTE_LENGTH(8)
-	MCFG_PALETTE_INIT_OVERRIDE(special_state,erik)
+	MCFG_SCREEN_PALETTE("palette")
+
+	MCFG_PALETTE_ADD("palette", 8)
+	MCFG_PALETTE_INIT_OWNER(special_state,erik)
 
 	/* audio hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -465,10 +494,21 @@ static MACHINE_CONFIG_START( erik, special_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	/* Devices */
-	MCFG_CASSETTE_ADD( "cassette", special_cassette_interface )
-	MCFG_I8255_ADD( "ppi8255", specialist_ppi8255_interface )
-	MCFG_FD1793x_ADD("fd1793", XTAL_8MHz / 8)
+	MCFG_CASSETTE_ADD( "cassette" )
+	MCFG_CASSETTE_FORMATS(rks_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_SPEAKER_ENABLED | CASSETTE_MOTOR_ENABLED)
+	MCFG_CASSETTE_INTERFACE("special_cass")
 
+	MCFG_DEVICE_ADD("ppi8255", I8255, 0)
+	MCFG_I8255_IN_PORTA_CB(READ8(special_state, specialist_8255_porta_r))
+	MCFG_I8255_OUT_PORTA_CB(WRITE8(special_state, specialist_8255_porta_w))
+	MCFG_I8255_IN_PORTB_CB(READ8(special_state, specialist_8255_portb_r))
+	MCFG_I8255_OUT_PORTB_CB(WRITE8(special_state, specialist_8255_portb_w))
+	MCFG_I8255_IN_PORTC_CB(READ8(special_state, specialist_8255_portc_r))
+	MCFG_I8255_OUT_PORTC_CB(WRITE8(special_state, specialist_8255_portc_w))
+
+	MCFG_FD1793x_ADD("fd1793", XTAL_8MHz / 8)
+	MCFG_WD_FDC_DRQ_CALLBACK(WRITELINE(special_state, fdc_drq))
 	MCFG_FLOPPY_DRIVE_ADD("fd0", specimx_floppies, "525qd", special_state::specimx_floppy_formats)
 	MCFG_FLOPPY_DRIVE_ADD("fd1", specimx_floppies, "525qd", special_state::specimx_floppy_formats)
 
