@@ -4,7 +4,6 @@
  PeT mess@utanet.at in december 2000
 ******************************************************************************/
 
-#include <assert.h>
 #include "emu.h"
 #include "cpu/m6502/m65c02.h"
 
@@ -351,12 +350,12 @@ static const unsigned char svisionn_palette[] =
 	245, 249, 248
 };
 
-void svision_state::palette_init()
+PALETTE_INIT_MEMBER(svision_state, svision)
 {
 	int i;
 
 	for( i = 0; i < sizeof(svision_palette) / 3; i++ ) {
-		palette_set_color_rgb(machine(), i, svision_palette[i*3], svision_palette[i*3+1], svision_palette[i*3+2] );
+		palette.set_pen_color(i, svision_palette[i*3], svision_palette[i*3+1], svision_palette[i*3+2] );
 	}
 }
 PALETTE_INIT_MEMBER(svision_state,svisionn)
@@ -364,7 +363,7 @@ PALETTE_INIT_MEMBER(svision_state,svisionn)
 	int i;
 
 	for ( i = 0; i < sizeof(svisionn_palette) / 3; i++ ) {
-		palette_set_color_rgb(machine(), i, svisionn_palette[i*3], svisionn_palette[i*3+1], svisionn_palette[i*3+2] );
+		palette.set_pen_color(i, svisionn_palette[i*3], svisionn_palette[i*3+1], svisionn_palette[i*3+2] );
 	}
 }
 PALETTE_INIT_MEMBER(svision_state,svisionp)
@@ -372,7 +371,7 @@ PALETTE_INIT_MEMBER(svision_state,svisionp)
 	int i;
 
 	for ( i = 0; i < sizeof(svisionn_palette) / 3; i++ ) {
-		palette_set_color_rgb(machine(), i, svisionp_palette[i*3], svisionp_palette[i*3+1], svisionp_palette[i*3+2] );
+		palette.set_pen_color(i, svisionp_palette[i*3], svisionp_palette[i*3+1], svisionp_palette[i*3+2] );
 	}
 }
 
@@ -433,7 +432,7 @@ UINT32 svision_state::screen_update_tvlink(screen_device &screen, bitmap_rgb32 &
 	}
 	else
 	{
-		bitmap.plot_box(3, 0, 162, 159, machine().pens[PALETTE_START]);
+		bitmap.plot_box(3, 0, 162, 159, m_palette->pen(PALETTE_START));
 	}
 	return 0;
 }
@@ -474,32 +473,30 @@ DRIVER_INIT_MEMBER(svision_state,svisions)
 DEVICE_IMAGE_LOAD_MEMBER( svision_state, svision_cart )
 {
 	UINT32 size;
-	UINT8 *temp_copy;
+	dynamic_buffer temp_copy;
 	int mirror, i;
 
 	if (image.software_entry() == NULL)
 	{
 		size = image.length();
-		temp_copy = auto_alloc_array(machine(), UINT8, size);
 
 		if (size > memregion("user1")->bytes())
 		{
 			image.seterror(IMAGE_ERROR_UNSPECIFIED, "Unsupported cartridge size");
-			auto_free(machine(), temp_copy);
 			return IMAGE_INIT_FAIL;
 		}
 
+		temp_copy.resize(size);
 		if (image.fread( temp_copy, size) != size)
 		{
 			image.seterror(IMAGE_ERROR_UNSPECIFIED, "Unable to fully read from file");
-			auto_free(machine(), temp_copy);
 			return IMAGE_INIT_FAIL;
 		}
 	}
 	else
 	{
 		size = image.get_software_region_length("rom");
-		temp_copy = auto_alloc_array(machine(), UINT8, size);
+		temp_copy.resize(size);
 		memcpy(temp_copy, image.get_software_region("rom"), size);
 	}
 
@@ -511,8 +508,6 @@ DEVICE_IMAGE_LOAD_MEMBER( svision_state, svision_cart )
 		memcpy(memregion("user1")->base() + i * size, temp_copy, size);
 	}
 
-	auto_free(machine(), temp_copy);
-
 	return IMAGE_INIT_PASS;
 }
 
@@ -553,8 +548,10 @@ static MACHINE_CONFIG_START( svision, svision_state )
 	MCFG_SCREEN_SIZE(3+160+3, 160)
 	MCFG_SCREEN_VISIBLE_AREA(3+0, 3+160-1, 0, 160-1)
 	MCFG_SCREEN_UPDATE_DRIVER(svision_state, screen_update_svision)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_PALETTE_LENGTH(ARRAY_LENGTH(svision_palette) * 3)
+	MCFG_PALETTE_ADD("palette", ARRAY_LENGTH(svision_palette) * 3)
+	MCFG_PALETTE_INIT_OWNER(svision_state, svision )
 
 	MCFG_DEFAULT_LAYOUT(layout_svision)
 
@@ -584,7 +581,8 @@ static MACHINE_CONFIG_DERIVED( svisionp, svision )
 	MCFG_CPU_CLOCK(4430000)
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_REFRESH_RATE(50)
-	MCFG_PALETTE_INIT_OVERRIDE(svision_state, svisionp )
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_INIT_OWNER(svision_state, svisionp )
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( svisionn, svision )
@@ -592,7 +590,8 @@ static MACHINE_CONFIG_DERIVED( svisionn, svision )
 	MCFG_CPU_CLOCK(3560000/*?*/)
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_PALETTE_INIT_OVERRIDE(svision_state, svisionn )
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_INIT_OWNER(svision_state, svisionn )
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( tvlinkp, svisionp )
@@ -602,6 +601,7 @@ static MACHINE_CONFIG_DERIVED( tvlinkp, svisionp )
 	MCFG_MACHINE_RESET_OVERRIDE(svision_state, tvlink )
 
 	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_NO_PALETTE
 	MCFG_SCREEN_UPDATE_DRIVER(svision_state, screen_update_tvlink)
 
 MACHINE_CONFIG_END
