@@ -36,7 +36,7 @@ public:
 	required_device<intelfsh8_device> m_flash;
 	required_device<speaker_sound_device> m_speaker;
 
-	virtual void palette_init();
+	DECLARE_PALETTE_INIT(svmu);
 	virtual void machine_reset();
 
 	DECLARE_WRITE8_MEMBER(page_w);
@@ -149,10 +149,10 @@ void svmu_state::machine_reset()
 	m_page = 0;
 }
 
-void svmu_state::palette_init()
+PALETTE_INIT_MEMBER(svmu_state, svmu)
 {
-	palette_set_color(machine(), 0, MAKE_RGB(138, 146, 148));
-	palette_set_color(machine(), 1, MAKE_RGB(92, 83, 88));
+	palette.set_pen_color(0, rgb_t(138, 146, 148));
+	palette.set_pen_color(1, rgb_t(92, 83, 88));
 }
 
 static LC8670_LCD_UPDATE( svmu_lcd_update )
@@ -313,8 +313,11 @@ static MACHINE_CONFIG_START( svmu, svmu_state )
 	MCFG_SCREEN_SIZE(48 * (PIXEL_SIZE + PIXEL_DISTANCE), 32 * (PIXEL_SIZE + PIXEL_DISTANCE))
 	MCFG_SCREEN_VISIBLE_AREA(0, 48*(PIXEL_SIZE + PIXEL_DISTANCE) - 1, 0, 32*(PIXEL_SIZE + PIXEL_DISTANCE) - 1)
 	MCFG_SCREEN_UPDATE_DEVICE("maincpu", lc8670_cpu_device, screen_update)
+	MCFG_SCREEN_PALETTE("palette")
+
 	MCFG_DEFAULT_LAYOUT(layout_svmu)
-	MCFG_PALETTE_LENGTH(2)
+	MCFG_PALETTE_ADD("palette", 2)
+	MCFG_PALETTE_INIT_OWNER(svmu_state, svmu)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
