@@ -156,29 +156,6 @@ WRITE8_MEMBER( sym1_state::sym1_riot_b_w )
 	m_ttl74145->write(data & 0x0f);
 }
 
-const riot6532_interface sym1_r6532_interface =
-{
-	DEVCB_DRIVER_MEMBER(sym1_state, sym1_riot_a_r),
-	DEVCB_DRIVER_MEMBER(sym1_state, sym1_riot_b_r),
-	DEVCB_DRIVER_MEMBER(sym1_state, sym1_riot_a_w),
-	DEVCB_DRIVER_MEMBER(sym1_state, sym1_riot_b_w)
-};
-
-const ttl74145_interface sym1_ttl74145_intf =
-{
-	DEVCB_DRIVER_LINE_MEMBER(sym1_state, sym1_74145_output_0_w),
-	DEVCB_DRIVER_LINE_MEMBER(sym1_state, sym1_74145_output_1_w),
-	DEVCB_DRIVER_LINE_MEMBER(sym1_state, sym1_74145_output_2_w),
-	DEVCB_DRIVER_LINE_MEMBER(sym1_state, sym1_74145_output_3_w),
-	DEVCB_DRIVER_LINE_MEMBER(sym1_state, sym1_74145_output_4_w),
-	DEVCB_DRIVER_LINE_MEMBER(sym1_state, sym1_74145_output_5_w),
-	DEVCB_DEVICE_LINE_MEMBER("speaker", speaker_sound_device, level_w),
-	DEVCB_NULL, // not connected
-	DEVCB_NULL, // not connected
-	DEVCB_NULL  // not connected
-};
-
-
 //**************************************************************************
 //  INPUT PORTS
 //**************************************************************************
@@ -301,57 +278,6 @@ void sym1_state::machine_reset()
 	m_maincpu->reset();
 }
 
-const via6522_interface sym1_via0 =
-{
-	DEVCB_NULL,
-	DEVCB_UNMAPPED,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_UNMAPPED,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_CPU_INPUT_LINE("maincpu", M6502_IRQ_LINE)
-};
-
-const via6522_interface sym1_via1 =
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_CPU_INPUT_LINE("maincpu", M6502_IRQ_LINE)
-};
-
-const via6522_interface sym1_via2 =
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(sym1_state, sym1_via2_a_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_CPU_INPUT_LINE("maincpu", M6502_IRQ_LINE)
-};
-
 
 //**************************************************************************
 //  ADDRESS MAPS
@@ -389,11 +315,31 @@ static MACHINE_CONFIG_START( sym1, sym1_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
 	// devices
-	MCFG_RIOT6532_ADD("riot", SYM1_CLOCK, sym1_r6532_interface)
-	MCFG_TTL74145_ADD("ttl74145", sym1_ttl74145_intf)
-	MCFG_VIA6522_ADD("via6522_0", 0, sym1_via0)
-	MCFG_VIA6522_ADD("via6522_1", 0, sym1_via1)
-	MCFG_VIA6522_ADD("via6522_2", 0, sym1_via2)
+	MCFG_DEVICE_ADD("riot", RIOT6532, SYM1_CLOCK)
+	MCFG_RIOT6532_IN_PA_CB(READ8(sym1_state, sym1_riot_a_r))
+	MCFG_RIOT6532_OUT_PA_CB(WRITE8(sym1_state, sym1_riot_a_w))
+	MCFG_RIOT6532_IN_PB_CB(READ8(sym1_state, sym1_riot_b_r))
+	MCFG_RIOT6532_OUT_PB_CB(WRITE8(sym1_state, sym1_riot_b_w))
+
+	MCFG_DEVICE_ADD("ttl74145", TTL74145, 0)
+	MCFG_TTL74145_OUTPUT_LINE_0_CB(WRITELINE(sym1_state, sym1_74145_output_0_w))
+	MCFG_TTL74145_OUTPUT_LINE_1_CB(WRITELINE(sym1_state, sym1_74145_output_1_w))
+	MCFG_TTL74145_OUTPUT_LINE_2_CB(WRITELINE(sym1_state, sym1_74145_output_2_w))
+	MCFG_TTL74145_OUTPUT_LINE_3_CB(WRITELINE(sym1_state, sym1_74145_output_3_w))
+	MCFG_TTL74145_OUTPUT_LINE_4_CB(WRITELINE(sym1_state, sym1_74145_output_4_w))
+	MCFG_TTL74145_OUTPUT_LINE_5_CB(WRITELINE(sym1_state, sym1_74145_output_5_w))
+	MCFG_TTL74145_OUTPUT_LINE_6_CB(DEVWRITELINE("speaker", speaker_sound_device, level_w))
+	// lines 7-9 not connected
+
+	MCFG_DEVICE_ADD("via6522_0", VIA6522, 0)
+	MCFG_VIA6522_IRQ_HANDLER(DEVWRITELINE("maincpu", m6502_device, irq_line))
+
+	MCFG_DEVICE_ADD("via6522_1", VIA6522, 0)
+	MCFG_VIA6522_IRQ_HANDLER(DEVWRITELINE("maincpu", m6502_device, irq_line))
+
+	MCFG_DEVICE_ADD("via6522_2", VIA6522, 0)
+	MCFG_VIA6522_WRITEPA_HANDLER(WRITE8(sym1_state, sym1_via2_a_w))
+	MCFG_VIA6522_IRQ_HANDLER(DEVWRITELINE("maincpu", m6502_device, irq_line))
 
 	// internal ram
 	MCFG_RAM_ADD(RAM_TAG)
