@@ -176,8 +176,8 @@ static ADDRESS_MAP_START( tek4051_mem, AS_PROGRAM, 8, tek4051_state )
 	AM_RANGE(0x87b0, 0x87b3) AM_DEVREADWRITE(MC6820_GPIB_TAG, pia6821_device, read, write)
 	AM_RANGE(0x87c0, 0x87c0) AM_MIRROR(0x03) AM_WRITE(lbs_w)
 //  AM_RANGE(0x87c0, 0x87c3) AM_DEVREADWRITE(MC6820_COM_TAG, pia6821_device, read, write)
-//  AM_RANGE(0x87c4, 0x87c4) AM_MIRROR(0x02) AM_DEVREADWRITE(MC6850_TAG, acia6850_device, status_read, control_write)
-//  AM_RANGE(0x87c5, 0x87c5) AM_MIRROR(0x02) AM_DEVREADWRITE(MC6850_TAG, acia6850_device, data_read, data_write)
+//  AM_RANGE(0x87c4, 0x87c4) AM_MIRROR(0x02) AM_DEVREADWRITE(MC6850_TAG, acia6850_device, status_r, control_w)
+//  AM_RANGE(0x87c5, 0x87c5) AM_MIRROR(0x02) AM_DEVREADWRITE(MC6850_TAG, acia6850_device, data_r, data_w)
 //  AM_RANGE(0x87c8, 0x87cb) XPC2
 //  AM_RANGE(0x87cc, 0x87cf) XPC3
 //  AM_RANGE(0x87d0, 0x87d3) XPC4
@@ -392,10 +392,6 @@ void tek4052_state::video_start()
 //  DEVICE CONFIGURATION
 //**************************************************************************
 
-//-------------------------------------------------
-//  pia6821_interface x_pia_intf
-//-------------------------------------------------
-
 READ8_MEMBER( tek4051_state::x_pia_pa_r )
 {
 	/*
@@ -456,11 +452,6 @@ WRITE_LINE_MEMBER( tek4051_state::adot_w )
 {
 }
 
-READ_LINE_MEMBER( tek4051_state::viewcause_r )
-{
-	return 0;
-}
-
 WRITE_LINE_MEMBER( tek4051_state::bufclk_w )
 {
 }
@@ -477,27 +468,6 @@ WRITE_LINE_MEMBER( tek4051_state::x_pia_irqb_w )
 	update_irq();
 }
 
-static const pia6821_interface x_pia_intf =
-{
-	DEVCB_DRIVER_MEMBER(tek4051_state, x_pia_pa_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, viewcause_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(tek4051_state, x_pia_pa_w),
-	DEVCB_DRIVER_MEMBER(tek4051_state, x_pia_pb_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, adot_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, bufclk_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, x_pia_irqa_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, x_pia_irqb_w)
-};
-
-
-//-------------------------------------------------
-//  pia6821_interface y_pia_intf
-//-------------------------------------------------
-
 READ8_MEMBER( tek4051_state::sa_r )
 {
 	/*
@@ -554,21 +524,6 @@ WRITE8_MEMBER( tek4051_state::sb_w )
 	*/
 }
 
-READ_LINE_MEMBER( tek4051_state::rdbyte_r )
-{
-	return 0;
-}
-
-READ_LINE_MEMBER( tek4051_state::mdata_r )
-{
-	return 0;
-}
-
-READ_LINE_MEMBER( tek4051_state::fmark_r )
-{
-	return 0;
-}
-
 WRITE_LINE_MEMBER( tek4051_state::sot_w )
 {
 }
@@ -585,26 +540,6 @@ WRITE_LINE_MEMBER( tek4051_state::y_pia_irqb_w )
 	update_nmi();
 }
 
-static const pia6821_interface y_pia_intf =
-{
-	DEVCB_DRIVER_MEMBER(tek4051_state, sa_r),
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, rdbyte_r),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, mdata_r),
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, fmark_r),
-	DEVCB_DRIVER_MEMBER(tek4051_state, y_pia_pa_w),
-	DEVCB_DRIVER_MEMBER(tek4051_state, sb_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, sot_w),
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, y_pia_irqa_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, y_pia_irqb_w)
-};
-
-
-//-------------------------------------------------
-//  pia6821_interface kb_pia_intf
-//-------------------------------------------------
 
 READ8_MEMBER( tek4051_state::kb_pia_pa_r )
 {
@@ -696,11 +631,6 @@ WRITE8_MEMBER( tek4051_state::kb_pia_pb_w )
 	m_gpib->ren_w(!BIT(data, 7));
 }
 
-READ_LINE_MEMBER( tek4051_state::key_r )
-{
-	return m_key;
-}
-
 WRITE_LINE_MEMBER( tek4051_state::kb_halt_w )
 {
 }
@@ -717,26 +647,6 @@ WRITE_LINE_MEMBER( tek4051_state::kb_pia_irqb_w )
 	update_irq();
 }
 
-static const pia6821_interface kb_pia_intf =
-{
-	DEVCB_DRIVER_MEMBER(tek4051_state, kb_pia_pa_r),
-	DEVCB_DRIVER_MEMBER(tek4051_state, kb_pia_pb_r),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, key_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(tek4051_state, kb_pia_pb_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, kb_halt_w),
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, kb_pia_irqa_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, kb_pia_irqb_w)
-};
-
-
-//-------------------------------------------------
-//  pia6821_interface tape_pia_intf
-//-------------------------------------------------
 
 READ8_MEMBER( tek4051_state::tape_pia_pa_r )
 {
@@ -794,26 +704,6 @@ WRITE8_MEMBER( tek4051_state::tape_pia_pb_w )
 	*/
 }
 
-READ_LINE_MEMBER( tek4051_state::rmark_r )
-{
-	return 0;
-}
-
-READ_LINE_MEMBER( tek4051_state::lohole_r )
-{
-	return 0;
-}
-
-READ_LINE_MEMBER( tek4051_state::filfnd_r )
-{
-	return 0;
-}
-
-READ_LINE_MEMBER( tek4051_state::uphole_r )
-{
-	return 0;
-}
-
 WRITE_LINE_MEMBER( tek4051_state::tape_pia_irqa_w )
 {
 	m_tape_pia_irqa = state;
@@ -826,26 +716,6 @@ WRITE_LINE_MEMBER( tek4051_state::tape_pia_irqb_w )
 	update_nmi();
 }
 
-static const pia6821_interface tape_pia_intf =
-{
-	DEVCB_DRIVER_MEMBER(tek4051_state, tape_pia_pa_r),
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, rmark_r),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, lohole_r),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, filfnd_r),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, uphole_r),
-	DEVCB_DRIVER_MEMBER(tek4051_state, tape_pia_pa_w),
-	DEVCB_DRIVER_MEMBER(tek4051_state, tape_pia_pb_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, tape_pia_irqa_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, tape_pia_irqb_w)
-};
-
-
-//-------------------------------------------------
-//  pia6821_interface gpib_pia_intf
-//-------------------------------------------------
 
 WRITE8_MEMBER( tek4051_state::dio_w )
 {
@@ -967,26 +837,6 @@ WRITE_LINE_MEMBER( tek4051_state::gpib_pia_irqb_w )
 	update_irq();
 }
 
-static const pia6821_interface gpib_pia_intf =
-{
-	DEVCB_DEVICE_MEMBER(IEEE488_TAG, ieee488_device, dio_r),
-	DEVCB_DRIVER_MEMBER(tek4051_state, gpib_pia_pb_r),
-	DEVCB_DEVICE_LINE_MEMBER(IEEE488_TAG, ieee488_device, eoi_r),
-	DEVCB_DEVICE_LINE_MEMBER(IEEE488_TAG, ieee488_device, srq_r),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(tek4051_state, dio_w),
-	DEVCB_DRIVER_MEMBER(tek4051_state, gpib_pia_pb_w),
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, talk_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, gpib_pia_irqa_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, gpib_pia_irqb_w)
-};
-
-
-//-------------------------------------------------
-//  pia6821_interface com_pia_intf
-//-------------------------------------------------
 
 WRITE8_MEMBER( tek4051_state::com_pia_pa_w )
 {
@@ -1063,10 +913,8 @@ WRITE8_MEMBER( tek4051_state::com_pia_pb_w )
 	case 3: div = 2; break;
 	}
 
-	int clock = osc / div;
-
-	m_acia->set_tx_clock(clock);
-	m_acia->set_rx_clock(clock);
+	m_acia_clock->set_unscaled_clock(osc);
+	m_acia_clock->set_clock_scale((double) 1 / div);
 }
 
 WRITE_LINE_MEMBER( tek4051_state::com_pia_irqa_w )
@@ -1081,26 +929,6 @@ WRITE_LINE_MEMBER( tek4051_state::com_pia_irqb_w )
 	update_irq();
 }
 
-static const pia6821_interface com_pia_intf =
-{
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(tek4051_state, com_pia_pb_r),
-	DEVCB_NULL, // SRX (RS-232 pin 12)
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(tek4051_state, com_pia_pa_w),
-	DEVCB_DRIVER_MEMBER(tek4051_state, com_pia_pb_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, com_pia_irqa_w),
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, com_pia_irqb_w)
-};
-
-
-//-------------------------------------------------
-//  ACIA6850_INTERFACE( acia_intf )
-//-------------------------------------------------
 
 WRITE_LINE_MEMBER( tek4051_state::acia_irq_w )
 {
@@ -1108,15 +936,11 @@ WRITE_LINE_MEMBER( tek4051_state::acia_irq_w )
 	update_irq();
 }
 
-static ACIA6850_INTERFACE( acia_intf )
+WRITE_LINE_MEMBER( tek4051_state::write_acia_clock )
 {
-	0,
-	0,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(tek4051_state, acia_irq_w)
-};
-
+	m_acia->write_txc(state);
+	m_acia->write_rxc(state);
+}
 
 
 //**************************************************************************
@@ -1183,8 +1007,7 @@ static MACHINE_CONFIG_START( tek4051, tek4051_state )
 	MCFG_SCREEN_VISIBLE_AREA(0, 1024-1, 0, 780-1)
 	MCFG_SCREEN_UPDATE_DEVICE("vector", vector_device, screen_update)
 
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, monochrome_green)
-	MCFG_PALETTE_LENGTH(2)
+	MCFG_PALETTE_ADD_MONOCHROME_GREEN("palette")
 
 	// sound hardware
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1193,14 +1016,74 @@ static MACHINE_CONFIG_START( tek4051, tek4051_state )
 
 	// devices
 	MCFG_TIMER_DRIVER_ADD_PERIODIC("keyboard", tek4051_state, keyboard_tick, attotime::from_hz(XTAL_12_5MHz/15/4))
-	MCFG_PIA6821_ADD(MC6820_X_TAG, x_pia_intf)
-	MCFG_PIA6821_ADD(MC6820_Y_TAG, y_pia_intf)
-	MCFG_PIA6821_ADD(MC6820_KB_TAG, kb_pia_intf)
-	MCFG_PIA6821_ADD(MC6820_TAPE_TAG, tape_pia_intf)
-	MCFG_PIA6821_ADD(MC6820_GPIB_TAG, gpib_pia_intf)
-	MCFG_PIA6821_ADD(MC6820_COM_TAG, com_pia_intf)
-	MCFG_ACIA6850_ADD(MC6850_TAG, acia_intf)
+
+	MCFG_DEVICE_ADD(MC6820_X_TAG, PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(tek4051_state, x_pia_pa_r))
+	// CB1 viewcause
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(tek4051_state, x_pia_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(tek4051_state, x_pia_pb_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(tek4051_state, adot_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(tek4051_state, bufclk_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(tek4051_state, x_pia_irqa_w))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(tek4051_state, x_pia_irqb_w))
+
+	MCFG_DEVICE_ADD(MC6820_Y_TAG, PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(tek4051_state, sa_r))
+	// CA1 rdbyte
+	// CB1 mdata
+	// CB2 fmark
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(tek4051_state, y_pia_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(tek4051_state, sb_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(tek4051_state, sot_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(tek4051_state, y_pia_irqa_w))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(tek4051_state, y_pia_irqb_w))
+
+	MCFG_DEVICE_ADD(MC6820_KB_TAG, PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(tek4051_state, kb_pia_pa_r))
+	MCFG_PIA_READPB_HANDLER(READ8(tek4051_state, kb_pia_pb_r))
+	// CA1 key
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(tek4051_state, kb_pia_pb_w))
+	MCFG_PIA_CA2_HANDLER(WRITELINE(tek4051_state, kb_halt_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(tek4051_state, kb_pia_irqa_w))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(tek4051_state, kb_pia_irqb_w))
+
+	MCFG_DEVICE_ADD(MC6820_TAPE_TAG, PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(READ8(tek4051_state, tape_pia_pa_r))
+	// CA1 rmark
+	// CB1 lohole
+	// CA2 filfnd
+	// CB2 uphole
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(tek4051_state, tape_pia_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(tek4051_state, tape_pia_pb_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(tek4051_state, tape_pia_irqa_w))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(tek4051_state, tape_pia_irqb_w))
+
+	MCFG_DEVICE_ADD(MC6820_GPIB_TAG, PIA6821, 0)
+	MCFG_PIA_READPA_HANDLER(DEVREAD8(IEEE488_TAG, ieee488_device, dio_r))
+	MCFG_PIA_READPB_HANDLER(READ8(tek4051_state, gpib_pia_pb_r))
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(tek4051_state, dio_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(tek4051_state, gpib_pia_pb_w))
+	MCFG_PIA_CB2_HANDLER(WRITELINE(tek4051_state, talk_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(tek4051_state, gpib_pia_irqa_w))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(tek4051_state, gpib_pia_irqb_w))
+
+	MCFG_DEVICE_ADD(MC6820_COM_TAG, PIA6821, 0)
+	MCFG_PIA_READPB_HANDLER(READ8(tek4051_state, com_pia_pb_r))
+	//CA1 - SRX (RS-232 pin 12)
+	MCFG_PIA_WRITEPA_HANDLER(WRITE8(tek4051_state, com_pia_pa_w))
+	MCFG_PIA_WRITEPB_HANDLER(WRITE8(tek4051_state, com_pia_pb_w))
+	MCFG_PIA_IRQA_HANDLER(WRITELINE(tek4051_state, com_pia_irqa_w))
+	MCFG_PIA_IRQB_HANDLER(WRITELINE(tek4051_state, com_pia_irqb_w))
+
+	MCFG_DEVICE_ADD(MC6850_TAG, ACIA6850, 0)
+	MCFG_ACIA6850_IRQ_HANDLER(WRITELINE(tek4051_state, acia_irq_w))
+
+	MCFG_DEVICE_ADD("acia_clock", CLOCK, 38400)
+	MCFG_CLOCK_SIGNAL_HANDLER(WRITELINE(tek4051_state, write_acia_clock))
+
 	MCFG_IEEE488_BUS_ADD()
+	MCFG_IEEE488_EOI_CALLBACK(DEVWRITELINE(MC6820_GPIB_TAG, pia6821_device, ca1_w))
+	MCFG_IEEE488_SRQ_CALLBACK(DEVWRITELINE(MC6820_GPIB_TAG, pia6821_device, cb1_w))
 
 	// internal ram
 	MCFG_RAM_ADD(RAM_TAG)
@@ -1236,8 +1119,7 @@ static MACHINE_CONFIG_START( tek4052, tek4052_state )
 	MCFG_SCREEN_VISIBLE_AREA(0, 1024-1, 0, 780-1)
 	MCFG_SCREEN_UPDATE_DEVICE("vector", vector_device, screen_update)
 
-	MCFG_PALETTE_INIT_OVERRIDE(driver_device, monochrome_green)
-	MCFG_PALETTE_LENGTH(2)
+	MCFG_PALETTE_ADD_MONOCHROME_GREEN("palette")
 
 	// sound hardware
 	MCFG_SPEAKER_STANDARD_MONO("mono")
