@@ -188,9 +188,7 @@ TI-86 ports:
 #include "emu.h"
 #include "cpu/z80/z80.h"
 #include "imagedev/snapquik.h"
-#include "machine/nvram.h"
 #include "includes/ti85.h"
-#include "mcfglgcy.h"
 
 /* port i/o functions */
 
@@ -503,9 +501,11 @@ static MACHINE_CONFIG_START( ti81, ti85_state )
 	MCFG_SCREEN_SIZE(96, 64)
 	MCFG_SCREEN_VISIBLE_AREA(0, 96-1, 0, 64-1)
 	MCFG_SCREEN_UPDATE_DRIVER(ti85_state, screen_update_ti85)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_PALETTE_LENGTH(224)
-
+	MCFG_PALETTE_ADD("palette", 224)
+	MCFG_PALETTE_INDIRECT_ENTRIES(224)
+	MCFG_PALETTE_INIT_OWNER(ti85_state, ti85)
 
 	MCFG_NVRAM_ADD_0FILL("nvram")
 MACHINE_CONFIG_END
@@ -535,12 +535,6 @@ static MACHINE_CONFIG_DERIVED( ti85d, ti85 )
 MACHINE_CONFIG_END
 
 
-static const t6a04_interface ti82_display =
-{
-	64,                 // number of lines
-	96,                 // pixels for line
-};
-
 static MACHINE_CONFIG_DERIVED( ti82, ti81 )
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_CLOCK( 6000000)        /* 6 MHz */
@@ -550,10 +544,13 @@ static MACHINE_CONFIG_DERIVED( ti82, ti81 )
 
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_UPDATE_DEVICE("t6a04", t6a04_device, screen_update)
-	MCFG_PALETTE_LENGTH(2)
-	MCFG_PALETTE_INIT_OVERRIDE(ti85_state, ti82 )
 
-	MCFG_T6A04_ADD("t6a04", ti82_display)
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_ENTRIES(2)
+	MCFG_PALETTE_INIT_OWNER(ti85_state, ti82 )
+
+	MCFG_DEVICE_ADD("t6a04", T6A04, 0)
+	MCFG_T6A04_SIZE(96, 64)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD("speaker", SPEAKER_SOUND, 0)
@@ -578,10 +575,13 @@ static MACHINE_CONFIG_DERIVED( ti83, ti81 )
 
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_UPDATE_DEVICE("t6a04", t6a04_device, screen_update)
-	MCFG_PALETTE_LENGTH(2)
-	MCFG_PALETTE_INIT_OVERRIDE(ti85_state, ti82 )
 
-	MCFG_T6A04_ADD("t6a04", ti82_display)
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_ENTRIES(2)
+	MCFG_PALETTE_INIT_OWNER(ti85_state, ti82 )
+
+	MCFG_DEVICE_ADD("t6a04", T6A04, 0)
+	MCFG_T6A04_SIZE(96, 64)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( ti86, ti85 )
@@ -592,9 +592,6 @@ static MACHINE_CONFIG_DERIVED( ti86, ti85 )
 	MCFG_MACHINE_START_OVERRIDE(ti85_state, ti86 )
 	MCFG_MACHINE_RESET_OVERRIDE(ti85_state, ti85 )
 
-	MCFG_DEVICE_REMOVE("nvram")
-	MCFG_NVRAM_HANDLER( ti86 )
-
 	MCFG_SNAPSHOT_ADD("snapshot", ti85_state, ti8x, "sav", 0)
 	//MCFG_TI86SERIAL_ADD( "tiserial" )
 MACHINE_CONFIG_END
@@ -610,13 +607,13 @@ static MACHINE_CONFIG_DERIVED( ti83p, ti81 )
 
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_UPDATE_DEVICE("t6a04", t6a04_device, screen_update)
-	MCFG_PALETTE_LENGTH(2)
-	MCFG_PALETTE_INIT_OVERRIDE(ti85_state, ti82 )
 
-	MCFG_T6A04_ADD("t6a04", ti82_display)
+	MCFG_PALETTE_MODIFY("palette")
+	MCFG_PALETTE_ENTRIES(2)
+	MCFG_PALETTE_INIT_OWNER(ti85_state, ti82 )
 
-	MCFG_DEVICE_REMOVE("nvram")
-	MCFG_NVRAM_HANDLER(ti83p)
+	MCFG_DEVICE_ADD("t6a04", T6A04, 0)
+	MCFG_T6A04_SIZE(96, 64)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD("speaker", SPEAKER_SOUND, 0)
