@@ -26,6 +26,7 @@
 */
 
 #include "includes/tiki100.h"
+#include "bus/rs232/rs232.h"
 
 /* Memory Banking */
 
@@ -148,9 +149,9 @@ WRITE8_MEMBER( tiki100_state::video_mode_w )
 	if (BIT(data, 7))
 	{
 		int color = data & 0x0f;
-		UINT8 colordata = ~m_palette;
+		UINT8 colordata = ~m_palette_val;
 
-		palette_set_color_rgb(machine(), color, pal3bit(colordata >> 5), pal3bit(colordata >> 2), pal2bit(colordata >> 0));
+		m_palette->set_pen_color(color, pal3bit(colordata >> 5), pal3bit(colordata >> 2), pal2bit(colordata >> 0));
 	}
 }
 
@@ -171,7 +172,7 @@ WRITE8_MEMBER( tiki100_state::palette_w )
 
 	*/
 
-	m_palette = data;
+	m_palette_val = data;
 }
 
 WRITE8_MEMBER( tiki100_state::system_w )
@@ -393,7 +394,7 @@ INPUT_PORTS_END
 
 UINT32 tiki100_state::screen_update(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect)
 {
-	const rgb_t *palette = palette_entry_list_raw(bitmap.palette());
+	const rgb_t *palette = m_palette->palette()->entry_list_raw();
 	UINT16 addr = (m_scroll << 7);
 	int sx, y, pixel, mode = (m_mode >> 4) & 0x03;
 
@@ -462,32 +463,23 @@ UINT32 tiki100_state::screen_update(screen_device &screen, bitmap_rgb32 &bitmap,
 	return 0;
 }
 
-/* Z80-DART Interface */
-
-static Z80DART_INTERFACE( dart_intf )
-{
-	0, 0, 0, 0,
-
-	DEVCB_DEVICE_LINE_MEMBER(RS232_A_TAG, serial_port_device, tx),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_A_TAG, rs232_port_device, dtr_w),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_A_TAG, rs232_port_device, rts_w),
-	DEVCB_NULL,
-	DEVCB_NULL,
-
-	DEVCB_DEVICE_LINE_MEMBER(RS232_B_TAG, serial_port_device, tx),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_B_TAG, rs232_port_device, dtr_w),
-	DEVCB_DEVICE_LINE_MEMBER(RS232_B_TAG, rs232_port_device, rts_w),
-	DEVCB_NULL,
-
-	DEVCB_NULL,
-	DEVCB_CPU_INPUT_LINE(Z80_TAG, INPUT_LINE_IRQ0),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
 /* Z80-PIO Interface */
 
+DECLARE_WRITE_LINE_MEMBER( tiki100_state::write_centronics_ack )
+{
+	m_centronics_ack = state;
+}
+
+DECLARE_WRITE_LINE_MEMBER( tiki100_state::write_centronics_busy )
+{
+	m_centronics_busy = state;
+}
+
+DECLARE_WRITE_LINE_MEMBER( tiki100_state::write_centronics_perror )
+{
+	m_centronics_perror = state;
+}
+
 READ8_MEMBER( tiki100_state::pio_pb_r )
 {
 	/*
@@ -508,9 +500,9 @@ READ8_MEMBER( tiki100_state::pio_pb_r )
 	UINT8 data = 0;
 
 	// centronics
-	data |= m_centronics->ack_r() << 4;
-	data |= m_centronics->busy_r() << 5;
-	data |= m_centronics->pe_r() << 6;
+	data |= m_centronics_ack << 4;
+	data |= m_centronics_busy << 5;
+	data |= m_centronics_perror << 6;
 
 	// cassette
 	data |= (m_cassette->input() > 0.0) << 7;
@@ -536,23 +528,12 @@ WRITE8_MEMBER( tiki100_state::pio_pb_w )
 	*/
 
 	// centronics
-	m_centronics->strobe_w(BIT(data, 0));
+	m_centronics->write_strobe(BIT(data, 0));
 
 	// cassette
 	m_cassette->output(BIT(data, 6) ? -1 : 1);
 }
 
-static Z80PIO_INTERFACE( pio_intf )
-{
-	DEVCB_CPU_INPUT_LINE(Z80_TAG, INPUT_LINE_IRQ0),
-	DEVCB_DEVICE_MEMBER(CENTRONICS_TAG, centronics_device, read),
-	DEVCB_DEVICE_MEMBER(CENTRONICS_TAG, centronics_device, write),
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(tiki100_state, pio_pb_r),
-	DEVCB_DRIVER_MEMBER(tiki100_state, pio_pb_w),
-	DEVCB_NULL
-};
-
 /* Z80-CTC Interface */
 
 TIMER_DEVICE_CALLBACK_MEMBER(tiki100_state::ctc_tick)
@@ -577,14 +558,6 @@ WRITE_LINE_MEMBER( tiki100_state::ctc_z2_w )
 	m_ctc->trg3(state);
 }
 
-static Z80CTC_INTERFACE( ctc_intf )
-{
-	DEVCB_CPU_INPUT_LINE(Z80_TAG, INPUT_LINE_IRQ0),
-	DEVCB_DRIVER_LINE_MEMBER(tiki100_state, ctc_z0_w),
-	DEVCB_DEVICE_LINE_MEMBER(Z80DART_TAG, z80dart_device, rxtxcb_w),
-	DEVCB_DRIVER_LINE_MEMBER(tiki100_state, ctc_z2_w),
-};
-
 /* FD1797 Interface */
 
 FLOPPY_FORMATS_MEMBER( tiki100_state::floppy_formats )
@@ -604,16 +577,6 @@ WRITE8_MEMBER( tiki100_state::video_scroll_w )
 	m_scroll = data;
 }
 
-static const ay8910_interface ay8910_intf =
-{
-	AY8910_SINGLE_OUTPUT,
-	AY8910_DEFAULT_LOADS,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(tiki100_state, video_scroll_w),
-	DEVCB_NULL
-};
-
 /* Z80 Daisy Chain */
 
 static const z80_daisy_config tiki100_daisy_chain[] =
@@ -625,24 +588,12 @@ static const z80_daisy_config tiki100_daisy_chain[] =
 };
 
 
-//-------------------------------------------------
-//  cassette_interface cassette_intf
-//-------------------------------------------------
 
 TIMER_DEVICE_CALLBACK_MEMBER( tiki100_state::tape_tick )
 {
 	m_pio->port_b_write((m_cassette->input() > 0.0) << 7);
 }
 
-static const cassette_interface cassette_intf =
-{
-	cassette_default_formats,
-	NULL,
-	(cassette_state)(CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED),
-	NULL,
-	NULL
-};
-
 /* Machine Start */
 
 void tiki100_state::machine_start()
@@ -669,7 +620,7 @@ void tiki100_state::machine_start()
 	save_item(NAME(m_vire));
 	save_item(NAME(m_scroll));
 	save_item(NAME(m_mode));
-	save_item(NAME(m_palette));
+	save_item(NAME(m_palette_val));
 	save_item(NAME(m_keylatch));
 }
 
@@ -697,32 +648,63 @@ static MACHINE_CONFIG_START( tiki100, tiki100_state )
 	MCFG_SCREEN_SIZE(1024, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 1024-1, 0, 256-1)
 
-	MCFG_PALETTE_LENGTH(16)
+	MCFG_PALETTE_ADD("palette", 16)
 	// pixel clock 20.01782 MHz
 
 	/* devices */
-	MCFG_Z80DART_ADD(Z80DART_TAG, XTAL_8MHz/4, dart_intf)
-	MCFG_Z80PIO_ADD(Z80PIO_TAG, XTAL_8MHz/4, pio_intf)
-	MCFG_Z80CTC_ADD(Z80CTC_TAG, XTAL_8MHz/4, ctc_intf)
+	MCFG_Z80DART_ADD(Z80DART_TAG, XTAL_8MHz/4, 0, 0, 0, 0 )
+	MCFG_Z80DART_OUT_TXDA_CB(DEVWRITELINE(RS232_A_TAG, rs232_port_device, write_txd))
+	MCFG_Z80DART_OUT_DTRA_CB(DEVWRITELINE(RS232_A_TAG, rs232_port_device, write_dtr))
+	MCFG_Z80DART_OUT_RTSA_CB(DEVWRITELINE(RS232_A_TAG, rs232_port_device, write_rts))
+	MCFG_Z80DART_OUT_TXDB_CB(DEVWRITELINE(RS232_B_TAG, rs232_port_device, write_txd))
+	MCFG_Z80DART_OUT_DTRB_CB(DEVWRITELINE(RS232_B_TAG, rs232_port_device, write_dtr))
+	MCFG_Z80DART_OUT_RTSB_CB(DEVWRITELINE(RS232_B_TAG, rs232_port_device, write_rts))
+	MCFG_Z80DART_OUT_INT_CB(INPUTLINE(Z80_TAG, INPUT_LINE_IRQ0))
+
+	MCFG_DEVICE_ADD(Z80PIO_TAG, Z80PIO, XTAL_8MHz/4)
+	MCFG_Z80PIO_OUT_INT_CB(INPUTLINE(Z80_TAG, INPUT_LINE_IRQ0))
+	MCFG_Z80PIO_IN_PA_CB(DEVREAD8("cent_data_in", input_buffer_device, read))
+	MCFG_Z80PIO_OUT_PA_CB(DEVWRITE8("cent_data_out", output_latch_device, write))
+	MCFG_Z80PIO_IN_PB_CB(READ8(tiki100_state, pio_pb_r))
+	MCFG_Z80PIO_OUT_PB_CB(WRITE8(tiki100_state, pio_pb_w))
+
+	MCFG_DEVICE_ADD(Z80CTC_TAG, Z80CTC, XTAL_8MHz/4)
+	MCFG_Z80CTC_INTR_CB(INPUTLINE(Z80_TAG, INPUT_LINE_IRQ0))
+	MCFG_Z80CTC_ZC0_CB(WRITELINE(tiki100_state, ctc_z0_w))
+	MCFG_Z80CTC_ZC1_CB(DEVWRITELINE(Z80DART_TAG, z80dart_device, rxtxcb_w))
+	MCFG_Z80CTC_ZC2_CB(WRITELINE(tiki100_state, ctc_z2_w))
+
 	MCFG_TIMER_DRIVER_ADD_PERIODIC("ctc", tiki100_state, ctc_tick, attotime::from_hz(XTAL_8MHz/4))
+
 	MCFG_FD1797x_ADD(FD1797_TAG, XTAL_8MHz/8) // FD1767PL-02 or FD1797-PL
 	MCFG_FLOPPY_DRIVE_ADD(FD1797_TAG":0", tiki100_floppies, "525qd", tiki100_state::floppy_formats)
 	MCFG_FLOPPY_DRIVE_ADD(FD1797_TAG":1", tiki100_floppies, "525qd", tiki100_state::floppy_formats)
 
 	MCFG_RS232_PORT_ADD(RS232_A_TAG, default_rs232_devices, NULL)
-	MCFG_SERIAL_OUT_RX_HANDLER(DEVWRITELINE(Z80DART_TAG, z80dart_device, rxa_w))
+	MCFG_RS232_RXD_HANDLER(DEVWRITELINE(Z80DART_TAG, z80dart_device, rxa_w))
 
 	MCFG_RS232_PORT_ADD(RS232_B_TAG, default_rs232_devices, NULL)
-	MCFG_SERIAL_OUT_RX_HANDLER(DEVWRITELINE(Z80DART_TAG, z80dart_device, rxb_w))
+	MCFG_RS232_RXD_HANDLER(DEVWRITELINE(Z80DART_TAG, z80dart_device, rxb_w))
+
+	MCFG_CENTRONICS_ADD(CENTRONICS_TAG, centronics_printers, "printer")
+	MCFG_CENTRONICS_DATA_INPUT_BUFFER("cent_data_in")
+	MCFG_CENTRONICS_ACK_HANDLER(WRITELINE(tiki100_state, write_centronics_ack))
+	MCFG_CENTRONICS_BUSY_HANDLER(WRITELINE(tiki100_state, write_centronics_busy))
+	MCFG_CENTRONICS_PERROR_HANDLER(WRITELINE(tiki100_state, write_centronics_perror))
+
+	MCFG_DEVICE_ADD("cent_data_in", INPUT_BUFFER, 0)
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", CENTRONICS_TAG)
+
+	MCFG_CASSETTE_ADD(CASSETTE_TAG)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED)
 
-	MCFG_CENTRONICS_PRINTER_ADD(CENTRONICS_TAG, standard_centronics)
-	MCFG_CASSETTE_ADD(CASSETTE_TAG, cassette_intf)
 	MCFG_TIMER_DRIVER_ADD_PERIODIC("tape", tiki100_state, tape_tick, attotime::from_hz(44100))
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD(AY8912_TAG, AY8912, XTAL_8MHz/4)
-	MCFG_SOUND_CONFIG(ay8910_intf)
+	MCFG_AY8910_OUTPUT_TYPE(AY8910_SINGLE_OUTPUT)
+	MCFG_AY8910_PORT_A_WRITE_CB(WRITE8(tiki100_state, video_scroll_w))
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	/* internal ram */
