@@ -17,11 +17,14 @@ class tim100_state : public driver_device
 public:
 	tim100_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag),
-			m_maincpu(*this, "maincpu")
+			m_maincpu(*this, "maincpu"),
+			m_palette(*this, "palette")
 		{ }
 
 	required_device<cpu_device> m_maincpu;
+	required_device<palette_device> m_palette;
 	virtual void machine_reset();
+	I8275_DRAW_CHARACTER_MEMBER( crtc_display_pixels );
 };
 
 static ADDRESS_MAP_START(tim100_mem, AS_PROGRAM, 8, tim100_state)
@@ -49,14 +52,14 @@ static INPUT_PORTS_START( tim100 )
 INPUT_PORTS_END
 
 static const rgb_t tim100_palette[3] = {
-	MAKE_RGB(0x00, 0x00, 0x00), // black
-	MAKE_RGB(0xa0, 0xa0, 0xa0), // white
-	MAKE_RGB(0xff, 0xff, 0xff)  // highlight
+	rgb_t(0x00, 0x00, 0x00), // black
+	rgb_t(0xa0, 0xa0, 0xa0), // white
+	rgb_t(0xff, 0xff, 0xff)  // highlight
 };
 
 void tim100_state::machine_reset()
 {
-	palette_set_colors(machine(), 0, tim100_palette, ARRAY_LENGTH(tim100_palette));
+	m_palette->set_pen_colors(0, tim100_palette, ARRAY_LENGTH(tim100_palette));
 }
 
 const gfx_layout tim100_charlayout =
@@ -78,12 +81,11 @@ GFXDECODE_END
 
 // this gets called via a (i8275_dack_w), so does nothing currently
 // once fixed, pixel count needs adjusting
-static I8275_DISPLAY_PIXELS(tim100_display_pixels)
+I8275_DRAW_CHARACTER_MEMBER( tim100_state::crtc_display_pixels )
 {
-	tim100_state *state = device->machine().driver_data<tim100_state>();
 	int i;
-	const rgb_t *palette = palette_entry_list_raw(bitmap.palette());
-	UINT8 *charmap = state->memregion("chargen")->base();
+	const rgb_t *palette = m_palette->palette()->entry_list_raw();
+	UINT8 *charmap = memregion("chargen")->base();
 	UINT8 pixels = charmap[(linecount & 15) + (charcode << 4)];
 	if (vsp)
 	{
@@ -106,16 +108,6 @@ static I8275_DISPLAY_PIXELS(tim100_display_pixels)
 	}
 }
 
-static const i8275_interface tim100_i8276_interface = {
-	16, //12
-	0,
-	DEVCB_CPU_INPUT_LINE("maincpu", I8085_RST65_LINE),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	tim100_display_pixels
-};
-
 static MACHINE_CONFIG_START( tim100, tim100_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu",I8085A, XTAL_4_9152MHz) // divider unknown
@@ -130,14 +122,17 @@ static MACHINE_CONFIG_START( tim100, tim100_state )
 	MCFG_SCREEN_SIZE(40*16, 16*16)
 	MCFG_SCREEN_VISIBLE_AREA(0, 40*16-1, 0, 16*16-1)
 
-	MCFG_GFXDECODE( tim100 )
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", tim100 )
 
-	MCFG_I8275_ADD  ( "i8276", tim100_i8276_interface)
+	MCFG_DEVICE_ADD("i8276", I8275, XTAL_4_9152MHz)
+	MCFG_I8275_CHARACTER_WIDTH(16)
+	MCFG_I8275_DRAW_CHARACTER_CALLBACK_OWNER(tim100_state, crtc_display_pixels)
+	MCFG_I8275_IRQ_CALLBACK(INPUTLINE("maincpu", I8085_RST65_LINE))
 
-	MCFG_PALETTE_LENGTH(3)
+	MCFG_PALETTE_ADD("palette", 3)
 
-	MCFG_I8251_ADD("uart_u17", default_i8251_interface)
-	MCFG_I8251_ADD("uart_u18", default_i8251_interface)
+	MCFG_DEVICE_ADD("uart_u17", I8251, 0)
+	MCFG_DEVICE_ADD("uart_u18", I8251, 0)
 MACHINE_CONFIG_END
 
 /* ROM definition */
