@@ -137,14 +137,6 @@
 /*
    Devices and handlers
  */
-//upd7720 (TODO: hook up p0, p1, int)
-static NECDSP_INTERFACE( upd7720_config )
-{
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL
-};
-
 
 /*****************************************************************************
  USART 8251 and Terminal stuff
@@ -164,40 +156,11 @@ WRITE_LINE_MEMBER(tsispch_state::i8251_txrdy_int)
 	machine().device<pic8259_device>("pic8259")->ir3_w(state);
 }
 
-// (todo: proper hookup, currently using hack w/i8251_receive_character())
-const i8251_interface i8251_config =
-{
-	DEVCB_NULL, // out txd, serial
-	DEVCB_NULL, // out dtr
-	DEVCB_NULL, // out rts
-	DEVCB_DRIVER_LINE_MEMBER(tsispch_state,i8251_rxrdy_int), // out rxrdy
-	DEVCB_DRIVER_LINE_MEMBER(tsispch_state,i8251_txrdy_int), // out txrdy
-	DEVCB_DRIVER_LINE_MEMBER(tsispch_state,i8251_txempty_int), // out txempty
-	DEVCB_NULL  // out syndet
-};
-
 WRITE8_MEMBER( tsispch_state::i8251_rxd )
 {
 	i8251_device *uart = machine().device<i8251_device>("i8251a_u15");
 	uart->receive_character(data);
 }
-static GENERIC_TERMINAL_INTERFACE( tsispch_terminal_intf )
-{
-	DEVCB_DRIVER_MEMBER(tsispch_state, i8251_rxd)
-};
-
-/*****************************************************************************
- PIC 8259 stuff
-*****************************************************************************/
-WRITE_LINE_MEMBER(tsispch_state::pic8259_set_int_line)
-{
-	m_maincpu->set_input_line(0, state ? HOLD_LINE : CLEAR_LINE);
-}
-
-IRQ_CALLBACK_MEMBER(tsispch_state::irq_callback)
-{
-	return machine().device<pic8259_device>("pic8259")->acknowledge();
-}
 
 /*****************************************************************************
  LED/dipswitch stuff
@@ -284,7 +247,6 @@ void tsispch_state::machine_reset()
 	int i;
 	for (i=0; i<32; i++) m_infifo[i] = 0;
 	m_infifo_tail_ptr = m_infifo_head_ptr = 0;
-	m_maincpu->set_irq_acknowledge_callback(device_irq_acknowledge_delegate(FUNC(tsispch_state::irq_callback),this));
 	fprintf(stderr,"machine reset\n");
 }
 
@@ -422,26 +384,32 @@ static MACHINE_CONFIG_START( prose2k, tsispch_state )
 	MCFG_CPU_ADD("maincpu", I8086, 8000000) /* VERIFIED clock, unknown divider */
 	MCFG_CPU_PROGRAM_MAP(i8086_mem)
 	MCFG_CPU_IO_MAP(i8086_io)
+	MCFG_CPU_IRQ_ACKNOWLEDGE_DEVICE("pic8259", pic8259_device, inta_cb)
 
 	/* TODO: the UPD7720 has a 10KHz clock to its INT pin */
 	/* TODO: the UPD7720 has a 2MHz clock to its SCK pin */
+	/* TODO: hook up p0, p1, int */
 	MCFG_CPU_ADD("dsp", UPD7725, 8000000) /* VERIFIED clock, unknown divider; correct dsp type is UPD77P20 */
 	MCFG_CPU_PROGRAM_MAP(dsp_prg_map)
 	MCFG_CPU_DATA_MAP(dsp_data_map)
-	MCFG_CPU_CONFIG(upd7720_config)
 
 	/* PIC 8259 */
-	MCFG_PIC8259_ADD("pic8259", WRITELINE(tsispch_state,pic8259_set_int_line), VCC, NULL)
+	MCFG_PIC8259_ADD("pic8259", INPUTLINE("maincpu", 0), VCC, NULL)
 
 	/* uarts */
-	MCFG_I8251_ADD("i8251a_u15", i8251_config)
+	MCFG_DEVICE_ADD("i8251a_u15", I8251, 0)
+	// (todo: proper hookup, currently using hack w/i8251_receive_character())
+	MCFG_I8251_RXRDY_HANDLER(WRITELINE(tsispch_state, i8251_rxrdy_int))
+	MCFG_I8251_TXRDY_HANDLER(WRITELINE(tsispch_state, i8251_txrdy_int))
+	MCFG_I8251_TXEMPTY_HANDLER(WRITELINE(tsispch_state, i8251_txempty_int))
 
 	/* sound hardware */
 	//MCFG_SPEAKER_STANDARD_MONO("mono")
 	//MCFG_SOUND_ADD("dac", DAC, 0) /* TODO: correctly figure out how the DAC works; apparently it is connected to the serial output of the upd7720, which will be "fun" to connect up */
 	//MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MCFG_GENERIC_TERMINAL_ADD(TERMINAL_TAG,tsispch_terminal_intf)
+	MCFG_DEVICE_ADD(TERMINAL_TAG, GENERIC_TERMINAL, 0)
+	MCFG_GENERIC_TERMINAL_KEYBOARD_CB(WRITE8(tsispch_state, i8251_rxd))
 MACHINE_CONFIG_END
 
 /******************************************************************************
