@@ -181,14 +181,17 @@ class tutor_state : public driver_device
 public:
 	tutor_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag),
-	m_maincpu(*this, "maincpu"),
-	m_cass(*this, "cassette"),
-	m_centronics(*this, "centronics")
-	{ }
+		m_maincpu(*this, "maincpu"),
+		m_cass(*this, "cassette"),
+		m_centronics(*this, "centronics"),
+		m_cent_data_out(*this, "cent_data_out")
+	{
+	}
 
 	required_device<tms9995_device> m_maincpu;
 	optional_device<cassette_image_device> m_cass;
 	optional_device<centronics_device> m_centronics;
+	optional_device<output_latch_device> m_cent_data_out;
 	DECLARE_READ8_MEMBER(key_r);
 	DECLARE_READ8_MEMBER(tutor_mapper_r);
 	DECLARE_WRITE8_MEMBER(tutor_mapper_w);
@@ -210,6 +213,9 @@ public:
 	TIMER_CALLBACK_MEMBER(tape_interrupt_handler);
 	DECLARE_DEVICE_IMAGE_LOAD_MEMBER( tutor_cart );
 	DECLARE_DEVICE_IMAGE_UNLOAD_MEMBER( tutor_cart );
+
+	int m_centronics_busy;
+	DECLARE_WRITE_LINE_MEMBER( write_centronics_busy );
 };
 
 
@@ -244,13 +250,6 @@ DRIVER_INIT_MEMBER(tutor_state,pyuuta)
 	membank("bank1")->set_entry(1);
 }
 
-
-static TMS9928A_INTERFACE(tutor_tms9928a_interface)
-{
-	0x4000,
-	DEVCB_NULL
-};
-
 void tutor_state::machine_start()
 {
 }
@@ -471,6 +470,11 @@ WRITE8_MEMBER( tutor_state::tutor_cassette_w )
 	}
 }
 
+WRITE_LINE_MEMBER( tutor_state::write_centronics_busy )
+{
+	m_centronics_busy = state;
+}
+
 /* memory handlers */
 READ8_MEMBER( tutor_state::tutor_printer_r )
 {
@@ -480,7 +484,7 @@ READ8_MEMBER( tutor_state::tutor_printer_r )
 	{
 	case 0x20:
 		/* busy */
-		reply = m_centronics->busy_r() ? 0x00 : 0xff;
+		reply = m_centronics_busy ? 0x00 : 0xff;
 		break;
 
 	default:
@@ -499,12 +503,12 @@ WRITE8_MEMBER( tutor_state::tutor_printer_w )
 	{
 	case 0x10:
 		/* data */
-		m_centronics->write(space, 0, data);
+		m_cent_data_out->write(space, 0, data);
 		break;
 
 	case 0x40:
 		/* strobe */
-		m_centronics->strobe_w(BIT(data, 7));
+		m_centronics->write_strobe(BIT(data, 7));
 		break;
 
 	default:
@@ -743,47 +747,33 @@ static INPUT_PORTS_START(pyuutajr)
 		PORT_BIT(0xff, IP_ACTIVE_HIGH, IPT_UNUSED)
 INPUT_PORTS_END
 
-//-------------------------------------------------
-//  sn76496_config psg_intf
-//-------------------------------------------------
-
-static const sn76496_config psg_intf =
-{
-	DEVCB_NULL
-};
-
-static TMS9995_CONFIG( cpuconf95 )
-{
-	DEVCB_NULL,        // external op
-	DEVCB_NULL,        // Instruction acquisition
-	DEVCB_NULL,        // clock out
-	DEVCB_NULL,        // HOLDA
-	DEVCB_NULL,        // DBIN
-	INTERNAL_RAM,      // use internal RAM
-	NO_OVERFLOW_INT    // The generally available versions of TMS9995 have a deactivated overflow interrupt
-};
-
 static MACHINE_CONFIG_START( tutor, tutor_state )
-	/* basic machine hardware */
-	/* TMS9995 CPU @ 10.7 MHz */
-	MCFG_TMS99xx_ADD("maincpu", TMS9995, 10700000, tutor_memmap, tutor_io, cpuconf95)
+	// basic machine hardware
+	// TMS9995 CPU @ 10.7 MHz
+	// No lines connected yet
+	MCFG_TMS99xx_ADD("maincpu", TMS9995, XTAL_10_738635MHz, tutor_memmap, tutor_io)
 
 	/* video hardware */
-	MCFG_TMS9928A_ADD( "tms9928a", TMS9928A, tutor_tms9928a_interface )
+	MCFG_DEVICE_ADD( "tms9928a", TMS9928A, XTAL_10_738635MHz / 2 )
+	MCFG_TMS9928A_VRAM_SIZE(0x4000)
 	MCFG_TMS9928A_SCREEN_ADD_NTSC( "screen" )
 	MCFG_SCREEN_UPDATE_DEVICE( "tms9928a", tms9928a_device, screen_update )
 
 	/* sound */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
+
 	MCFG_SOUND_ADD("sn76489a", SN76489A, 3579545)   /* 3.579545 MHz */
-	MCFG_SOUND_CONFIG(psg_intf)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
+
 	MCFG_SOUND_WAVE_ADD(WAVE_TAG, "cassette")
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MCFG_CENTRONICS_PRINTER_ADD("centronics", standard_centronics)
+	MCFG_CENTRONICS_ADD("centronics", centronics_printers, "printer")
+	MCFG_CENTRONICS_BUSY_HANDLER(WRITELINE(tutor_state, write_centronics_busy))
 
-	MCFG_CASSETTE_ADD( "cassette", default_cassette_interface )
+	MCFG_CENTRONICS_OUTPUT_LATCH_ADD("cent_data_out", "centronics")
+
+	MCFG_CASSETTE_ADD( "cassette" )
 
 	/* cartridge */
 	MCFG_CARTSLOT_ADD("cart")
