@@ -342,22 +342,22 @@ INPUT_PORTS_END
 static const rgb_t vc4000_palette[] =
 {
 	// background colors
-	MAKE_RGB(0, 0, 0), // black
-	MAKE_RGB(0, 0, 175), // blue
-	MAKE_RGB(0, 175, 0), // green
-	MAKE_RGB(0, 255, 255), // cyan
-	MAKE_RGB(255, 0, 0), // red
-	MAKE_RGB(255, 0, 255), // magenta
-	MAKE_RGB(200, 200, 0), // yellow
-	MAKE_RGB(200, 200, 200), // white
+	rgb_t(0, 0, 0), // black
+	rgb_t(0, 0, 175), // blue
+	rgb_t(0, 175, 0), // green
+	rgb_t(0, 255, 255), // cyan
+	rgb_t(255, 0, 0), // red
+	rgb_t(255, 0, 255), // magenta
+	rgb_t(200, 200, 0), // yellow
+	rgb_t(200, 200, 200), // white
 	/* sprite colors
 	The control line simply inverts the RGB lines all at once.
 	We can do that in the code with ^7 */
 };
 
-void vc4000_state::palette_init()
+PALETTE_INIT_MEMBER(vc4000_state, vc4000)
 {
-	palette_set_colors(machine(), 0, vc4000_palette, ARRAY_LENGTH(vc4000_palette));
+	palette.set_pen_colors(0, vc4000_palette, ARRAY_LENGTH(vc4000_palette));
 }
 
 DEVICE_IMAGE_LOAD_MEMBER( vc4000_state, vc4000_cart )
@@ -423,9 +423,10 @@ static MACHINE_CONFIG_START( vc4000, vc4000_state )
 	MCFG_SCREEN_SIZE(226, 312)
 	MCFG_SCREEN_VISIBLE_AREA(8, 184, 0, 269)
 	MCFG_SCREEN_UPDATE_DRIVER(vc4000_state, screen_update_vc4000)
+	MCFG_SCREEN_PALETTE("palette")
 
-	MCFG_PALETTE_LENGTH(8)
-
+	MCFG_PALETTE_ADD("palette", 8)
+	MCFG_PALETTE_INIT_OWNER(vc4000_state, vc4000)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -449,7 +450,7 @@ MACHINE_CONFIG_END
 static MACHINE_CONFIG_DERIVED( elektor, vc4000 )
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_PROGRAM_MAP(elektor_mem)
-	MCFG_CASSETTE_ADD( "cassette", default_cassette_interface )
+	MCFG_CASSETTE_ADD( "cassette" )
 	MCFG_SOUND_WAVE_ADD(WAVE_TAG, "cassette")
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_CONFIG_END
@@ -557,134 +558,125 @@ QUICKLOAD_LOAD_MEMBER( vc4000_state,vc4000)
 	int i;
 	int exec_addr;
 	int quick_length;
-	UINT8 *quick_data;
+	dynamic_buffer quick_data;
 	int read_;
 	int result = IMAGE_INIT_FAIL;
 
 	quick_length = image.length();
-	quick_data = (UINT8*)malloc(quick_length);
-	if (!quick_data)
+	quick_data.resize(quick_length);
+	read_ = image.fread( quick_data, quick_length);
+	if (read_ != quick_length)
 	{
-		image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Cannot open file");
-		image.message(" Cannot open file");
+		image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Cannot read the file");
+		image.message(" Cannot read the file");
 	}
 	else
 	{
-		read_ = image.fread( quick_data, quick_length);
-		if (read_ != quick_length)
+		if (core_stricmp(image.filetype(), "tvc")==0)
 		{
-			image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Cannot read the file");
-			image.message(" Cannot read the file");
-		}
-		else
-		{
-			if (mame_stricmp(image.filetype(), "tvc")==0)
+			if (quick_data[0] != 2)
 			{
-				if (quick_data[0] != 2)
-				{
-					image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Invalid header");
-					image.message(" Invalid header");
-				}
-				else
-				{
-					int quick_addr = quick_data[1] * 256 + quick_data[2];
-					exec_addr = quick_data[3] * 256 + quick_data[4];
-
-					if (quick_length < 0x5)
-					{
-						image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File too short");
-						image.message(" File too short");
-					}
-					else
-					if ((quick_length + quick_addr - 5) > 0x1600)
-					{
-						image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File too long");
-						image.message(" File too long");
-					}
-					else
-					{
-						space.write_byte(0x08be, quick_data[3]);
-						space.write_byte(0x08bf, quick_data[4]);
-
-						for (i = 5; i < quick_length; i++)
-							space.write_byte(i - 5 + quick_addr, quick_data[i]);
-
-						/* display a message about the loaded quickload */
-						image.message(" Quickload: size=%04X : start=%04X : end=%04X : exec=%04X",quick_length-5,quick_addr,quick_addr+quick_length-5,exec_addr);
-
-						// Start the quickload
-						m_maincpu->set_state_int(S2650_PC, exec_addr);
-						result = IMAGE_INIT_PASS;
-					}
-				}
+				image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Invalid header");
+				image.message(" Invalid header");
 			}
 			else
-			if (mame_stricmp(image.filetype(), "pgm")==0)
 			{
-				if (quick_data[0] != 0)
+				int quick_addr = quick_data[1] * 256 + quick_data[2];
+				exec_addr = quick_data[3] * 256 + quick_data[4];
+
+				if (quick_length < 0x5)
 				{
-					image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Invalid header");
-					image.message(" Invalid header");
+					image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File too short");
+					image.message(" File too short");
+				}
+				else
+				if ((quick_length + quick_addr - 5) > 0x1600)
+				{
+					image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File too long");
+					image.message(" File too long");
 				}
 				else
 				{
-					exec_addr = quick_data[1] * 256 + quick_data[2];
+					space.write_byte(0x08be, quick_data[3]);
+					space.write_byte(0x08bf, quick_data[4]);
 
-					if (exec_addr >= quick_length)
-					{
-						image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Exec address beyond end of file");
-						image.message(" Exec address beyond end of file");
-					}
-					else
-					if (quick_length < 0x904)
-					{
-						image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File too short");
-						image.message(" File too short");
-					}
-					else
-					if (quick_length > 0x2000)
-					{
-						image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File too long");
-						image.message(" File too long");
-					}
-					else
-					{
-						space.write_byte(0x08be, quick_data[1]);
-						space.write_byte(0x08bf, quick_data[2]);
+					for (i = 5; i < quick_length; i++)
+						space.write_byte(i - 5 + quick_addr, quick_data[i]);
 
-						// load to 08C0-15FF (standard ram + extra)
-						int read_ = 0x1600;
-						if (quick_length < 0x1600)
-							read_ = quick_length;
-						for (i = 0x8c0; i < read_; i++)
-							space.write_byte(i, quick_data[i]);
+					/* display a message about the loaded quickload */
+					image.message(" Quickload: size=%04X : start=%04X : end=%04X : exec=%04X",quick_length-5,quick_addr,quick_addr+quick_length-5,exec_addr);
 
-						// load to 1F50-1FAF (PVI regs)
-						read_ = 0x1FB0;
-						if (quick_length < 0x1FB0)
-							read_ = quick_length;
-						if (quick_length > 0x1FC0)
-							for (i = 0x1F50; i < read_; i++)
-								vc4000_video_w(space, i-0x1f00, quick_data[i]);
-
-						/* display a message about the loaded quickload */
-						image.message(" Quickload: size=%04X : exec=%04X",quick_length,exec_addr);
-
-						// Start the quickload
-						m_maincpu->set_state_int(S2650_PC, exec_addr);
-						result = IMAGE_INIT_PASS;
-					}
+					// Start the quickload
+					m_maincpu->set_state_int(S2650_PC, exec_addr);
+					result = IMAGE_INIT_PASS;
+				}
+			}
+		}
+		else
+		if (core_stricmp(image.filetype(), "pgm")==0)
+		{
+			if (quick_data[0] != 0)
+			{
+				image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Invalid header");
+				image.message(" Invalid header");
+			}
+			else
+			{
+				exec_addr = quick_data[1] * 256 + quick_data[2];
+
+				if (exec_addr >= quick_length)
+				{
+					image.seterror(IMAGE_ERROR_INVALIDIMAGE, "Exec address beyond end of file");
+					image.message(" Exec address beyond end of file");
+				}
+				else
+				if (quick_length < 0x904)
+				{
+					image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File too short");
+					image.message(" File too short");
+				}
+				else
+				if (quick_length > 0x2000)
+				{
+					image.seterror(IMAGE_ERROR_INVALIDIMAGE, "File too long");
+					image.message(" File too long");
+				}
+				else
+				{
+					space.write_byte(0x08be, quick_data[1]);
+					space.write_byte(0x08bf, quick_data[2]);
+
+					// load to 08C0-15FF (standard ram + extra)
+					int read_ = 0x1600;
+					if (quick_length < 0x1600)
+						read_ = quick_length;
+					for (i = 0x8c0; i < read_; i++)
+						space.write_byte(i, quick_data[i]);
+
+					// load to 1F50-1FAF (PVI regs)
+					read_ = 0x1FB0;
+					if (quick_length < 0x1FB0)
+						read_ = quick_length;
+					if (quick_length > 0x1FC0)
+						for (i = 0x1F50; i < read_; i++)
+							vc4000_video_w(space, i-0x1f00, quick_data[i]);
+
+					/* display a message about the loaded quickload */
+					image.message(" Quickload: size=%04X : exec=%04X",quick_length,exec_addr);
+
+					// Start the quickload
+					m_maincpu->set_state_int(S2650_PC, exec_addr);
+					result = IMAGE_INIT_PASS;
 				}
 			}
 		}
-		free (quick_data);
 	}
 	return result;
 }
 
 
 /*   YEAR  NAME      PARENT     COMPAT    MACHINE    INPUT        INIT      COMPANY             FULLNAME */
-CONS(1978, vc4000,   0,         0,        vc4000,    vc4000, driver_device,      0,        "Interton",         "VC 4000",          GAME_IMPERFECT_GRAPHICS )          /* Germany, Austria, UK, Australia */
+CONS(1978, vc4000,   0,         0,        vc4000,    vc4000, driver_device,      0,        "Interton",         "Intertion Electronic VC 4000", GAME_IMPERFECT_GRAPHICS )          /* Germany, Austria, UK, Australia */
 CONS(1979, spc4000,  vc4000,    0,        vc4000,    vc4000, driver_device,      0,        "Grundig",          "Super Play Computer 4000", GAME_IMPERFECT_GRAPHICS )  /* Germany, Austria */
 CONS(1979, cx3000tc, vc4000,    0,        vc4000,    vc4000, driver_device,      0,        "Palson",           "CX 3000 Tele Computer", GAME_IMPERFECT_GRAPHICS )     /* Spain */
 CONS(1979, tvc4000,  vc4000,    0,        vc4000,    vc4000, driver_device,      0,        "Koerting",         "TVC-4000",         GAME_IMPERFECT_GRAPHICS )          /* Argentina */
@@ -707,7 +699,7 @@ CONS(1979, telngtcs, rwtrntcs,  0,        vc4000,    vc4000, driver_device,
 CONS(1979, krvnjvtv, 0,         vc4000,   vc4000,    vc4000, driver_device,      0,        "SOE",              "OC Jeu Video TV Karvan", GAME_IMPERFECT_GRAPHICS )    /* France */
 CONS(1979, oc2000,   krvnjvtv,  0,        vc4000,    vc4000, driver_device,      0,        "SOE",              "OC-2000",          GAME_IMPERFECT_GRAPHICS )          /* France */
 CONS(1980, mpt05,    0,         vc4000,   vc4000,    vc4000, driver_device,      0,        "ITMC",             "MPT-05",           GAME_IMPERFECT_GRAPHICS )          /* France */
-COMP(1979, elektor,  0,         0,        elektor,   elektor, driver_device,     0,        "Elektor",          "Elektor TV Games Computer", GAME_IMPERFECT_GRAPHICS )
+CONS(1979, elektor,  0,         0,        elektor,   elektor, driver_device,     0,        "Elektor",          "Elektor TV Games Computer", GAME_IMPERFECT_GRAPHICS )
 
 /*  Game List and Emulation Status
 
