@@ -28,9 +28,7 @@
 
 ****************************************************************************/
 
-
 #include "includes/x07.h"
-#include "mcfglgcy.h"
 
 /***************************************************************************
     T6834 IMPLEMENTATION
@@ -1070,10 +1068,10 @@ DEVICE_IMAGE_LOAD_MEMBER( x07_state, x07_card )
 	return IMAGE_INIT_PASS;
 }
 
-void x07_state::palette_init()
+PALETTE_INIT_MEMBER(x07_state, x07)
 {
-	palette_set_color(machine(), 0, MAKE_RGB(138, 146, 148));
-	palette_set_color(machine(), 1, MAKE_RGB(92, 83, 88));
+	palette.set_pen_color(0, rgb_t(138, 146, 148));
+	palette.set_pen_color(1, rgb_t(92, 83, 88));
 }
 
 
@@ -1324,37 +1322,10 @@ static INPUT_PORTS_START( x07 )
 INPUT_PORTS_END
 
 
-static NVRAM_HANDLER( x07 )
+void x07_state::nvram_init(nvram_device &nvram, void *data, size_t size)
 {
-	x07_state *state = machine.driver_data<x07_state>();
-
-	if (read_or_write)
-	{
-		file->write(state->m_t6834_ram, sizeof(state->m_t6834_ram));
-		file->write(state->m_ram->pointer(), state->m_ram->size());
-	}
-	else
-	{
-		if (file)
-		{
-			file->read(state->m_t6834_ram, sizeof(state->m_t6834_ram));
-			file->read(state->m_ram->pointer(), state->m_ram->size());
-			state->m_warm_start = 1;
-		}
-		else
-		{
-			memset(state->m_t6834_ram, 0, sizeof(state->m_t6834_ram));
-			memset(state->m_ram->pointer(), 0, state->m_ram->size());
-
-			for(int i = 0; i < 12; i++)
-				strcpy((char*)state->m_t6834_ram + udk_offset[i], udk_ini[i]);
-
-			//copy default chars in the UDC
-			memcpy(state->m_t6834_ram + 0x200, (UINT8*)machine.root_device().memregion("gfx1")->base() + 0x400, 0x100);
-			memcpy(state->m_t6834_ram + 0x300, (UINT8*)machine.root_device().memregion("gfx1")->base() + 0x700, 0x100);
-			state->m_warm_start = 0;
-		}
-	}
+	memcpy(data, memregion("default")->base(), size);
+	m_warm_start = 0;
 }
 
 TIMER_DEVICE_CALLBACK_MEMBER(x07_state::blink_timer)
@@ -1403,6 +1374,9 @@ void x07_state::machine_start()
 	m_cass_poll = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(x07_state::cassette_poll),this));
 	m_cass_tick = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(x07_state::cassette_tick),this));
 
+	m_nvram1->set_base(&m_t6834_ram, 0x800);
+	m_nvram2->set_base(m_ram->pointer(), m_ram->size());
+
 	/* Save State */
 	save_item(NAME(m_sleep));
 	save_item(NAME(m_warm_start));
@@ -1483,15 +1457,6 @@ void x07_state::machine_reset()
 	m_maincpu->set_state_int(Z80_PC, 0xc3c3);
 }
 
-static const cassette_interface x07_cassette_interface =
-{
-	x07_cassette_formats,
-	NULL,
-	(cassette_state)(CASSETTE_PLAY | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_ENABLED),
-	"x07_cass",
-	NULL
-};
-
 static MACHINE_CONFIG_START( x07, x07_state )
 
 	/* basic machine hardware */
@@ -1506,9 +1471,12 @@ static MACHINE_CONFIG_START( x07, x07_state )
 	MCFG_SCREEN_UPDATE_DRIVER(x07_state, screen_update)
 	MCFG_SCREEN_SIZE(120, 32)
 	MCFG_SCREEN_VISIBLE_AREA(0, 120-1, 0, 32-1)
-	MCFG_PALETTE_LENGTH(2)
+	MCFG_SCREEN_PALETTE("palette")
+
+	MCFG_PALETTE_ADD("palette", 2)
+	MCFG_PALETTE_INIT_OWNER(x07_state, x07)
 	MCFG_DEFAULT_LAYOUT(layout_lcd)
-	MCFG_GFXDECODE(x07)
+	MCFG_GFXDECODE_ADD("gfxdecode", "palette", x07)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO( "mono" )
@@ -1518,11 +1486,12 @@ static MACHINE_CONFIG_START( x07, x07_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
 	/* printer */
-	MCFG_PRINTER_ADD("printer")
+	MCFG_DEVICE_ADD("printer", PRINTER, 0)
 
 	MCFG_TIMER_DRIVER_ADD_PERIODIC("blink_timer", x07_state, blink_timer, attotime::from_msec(300))
 
-	MCFG_NVRAM_HANDLER( x07 )
+	MCFG_NVRAM_ADD_CUSTOM_DRIVER("nvram1", x07_state, nvram_init)   // t6834 RAM
+	MCFG_NVRAM_ADD_0FILL("nvram2") // RAM banks
 
 	/* internal ram */
 	MCFG_RAM_ADD(RAM_TAG)
@@ -1542,7 +1511,10 @@ static MACHINE_CONFIG_START( x07, x07_state )
 	MCFG_CARTSLOT_INTERFACE("x07_card")
 
 	/* cassette */
-	MCFG_CASSETTE_ADD( "cassette", x07_cassette_interface )
+	MCFG_CASSETTE_ADD( "cassette" )
+	MCFG_CASSETTE_FORMATS(x07_cassette_formats)
+	MCFG_CASSETTE_DEFAULT_STATE(CASSETTE_PLAY | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_ENABLED)
+	MCFG_CASSETTE_INTERFACE("x07_cass")
 
 	/* Software lists */
 	MCFG_SOFTWARE_LIST_ADD("card_list", "x07_card")
@@ -1558,9 +1530,25 @@ ROM_START( x07 )
 
 	ROM_REGION( 0x0800, "gfx1", 0 )
 	ROM_LOAD( "charset.rom", 0x0000, 0x0800, BAD_DUMP CRC(b1e59a6e) SHA1(b0c06315a2d5c940a8f288fb6a3428d738696e69) )
+
+	ROM_REGION( 0x0800, "default", ROMREGION_ERASE00 )
 ROM_END
 
+DRIVER_INIT_MEMBER(x07_state, x07)
+{
+	UINT8 *RAM = memregion("default")->base();
+	UINT8 *GFX = memregion("gfx1")->base();
+
+	for (int i = 0; i < 12; i++)
+		strcpy((char *)RAM + udk_offset[i], udk_ini[i]);
+
+	//copy default chars in the UDC
+	memcpy(RAM + 0x200, GFX + 0x400, 0x100);
+	memcpy(RAM + 0x300, GFX + 0x700, 0x100);
+}
+
+
 /* Driver */
 
-/*    YEAR  NAME    PARENT  COMPAT   MACHINE    INPUT    INIT    COMPANY   FULLNAME    FLAGS */
-COMP( 1983, x07,    0,      0,       x07,       x07, driver_device,     0,      "Canon",  "X-07",     GAME_SUPPORTS_SAVE)
+/*    YEAR  NAME    PARENT  COMPAT   MACHINE    INPUT    INIT                COMPANY   FULLNAME    FLAGS */
+COMP( 1983, x07,    0,      0,       x07,       x07,     x07_state,   x07,   "Canon",  "X-07",     GAME_SUPPORTS_SAVE)
