@@ -5,16 +5,15 @@
 #ifndef __ABC1600__
 #define __ABC1600__
 
-#include "emu.h"
 #include "bus/abcbus/abcbus.h"
+#include "bus/rs232/rs232.h"
 #include "cpu/m68000/m68000.h"
 #include "machine/8530scc.h"
-#include "machine/abckb.h"
+#include "bus/abckb/abckb.h"
 #include "machine/abc1600mac.h"
 #include "machine/e0516.h"
 #include "machine/nmc9306.h"
 #include "machine/ram.h"
-#include "machine/serial.h"
 #include "machine/wd_fdc.h"
 #include "machine/z80dart.h"
 #include "machine/z80dma.h"
@@ -126,8 +125,7 @@ public:
 
 	IRQ_CALLBACK_MEMBER( abc1600_int_ack );
 
-	void fdc_intrq_w(bool state);
-	void fdc_drq_w(bool state);
+	DECLARE_WRITE_LINE_MEMBER( fdc_drq_w );
 
 	UINT8 read_io(offs_t offset);
 	void write_io(offs_t offset, UINT8 data);
@@ -140,8 +138,6 @@ public:
 	void update_drdy1();
 	void update_drdy2();
 
-	void scc_irq(bool status);
-
 	// DMA
 	int m_dmadis;
 	int m_sysscc;
