@@ -8,15 +8,14 @@
 #include "emu.h"
 #include "bus/cbmiec/cbmiec.h"
 #include "bus/c64/exp.h"
-#include "bus/c64/user.h"
+#include "bus/vic20/user.h"
 #include "bus/pet/cass.h"
 #include "bus/vcs/ctrl.h"
 #include "cpu/m6502/m6510.h"
-#include "machine/cbm_snqk.h"
+#include "imagedev/snapquik.h"
 #include "machine/mos6526.h"
 #include "machine/pla.h"
 #include "machine/ram.h"
-#include "sound/dac.h"
 #include "sound/mos6581.h"
 #include "video/mos6566.h"
 
@@ -30,6 +29,7 @@
 #define SCREEN_TAG      "screen"
 #define CONTROL1_TAG    "joy1"
 #define CONTROL2_TAG    "joy2"
+#define PET_USER_PORT_TAG     "user"
 
 class c64_state : public driver_device
 {
@@ -46,12 +46,9 @@ public:
 			m_joy1(*this, CONTROL1_TAG),
 			m_joy2(*this, CONTROL2_TAG),
 			m_exp(*this, C64_EXPANSION_SLOT_TAG),
-			m_user(*this, C64_USER_PORT_TAG),
+			m_user(*this, PET_USER_PORT_TAG),
 			m_ram(*this, RAM_TAG),
 			m_cassette(*this, PET_DATASSETTE_PORT_TAG),
-			m_basic(*this, "basic"),
-			m_kernal(*this, "kernal"),
-			m_charom(*this, "charom"),
 			m_color_ram(*this, "color_ram"),
 			m_row0(*this, "ROW0"),
 			m_row1(*this, "ROW1"),
@@ -61,13 +58,13 @@ public:
 			m_row5(*this, "ROW5"),
 			m_row6(*this, "ROW6"),
 			m_row7(*this, "ROW7"),
-			m_restore(*this, "RESTORE"),
 			m_lock(*this, "LOCK"),
 			m_loram(1),
 			m_hiram(1),
 			m_charen(1),
 			m_va14(1),
 			m_va15(1),
+			m_restore(1),
 			m_cia1_irq(CLEAR_LINE),
 			m_cia2_irq(CLEAR_LINE),
 			m_vic_irq(CLEAR_LINE),
@@ -75,6 +72,11 @@ public:
 			m_exp_nmi(CLEAR_LINE)
 	{ }
 
+	// ROM
+	UINT8 *m_basic;
+	UINT8 *m_kernal;
+	UINT8 *m_charom;
+
 	required_device<m6510_device> m_maincpu;
 	required_device<pls100_device> m_pla;
 	required_device<mos6566_device> m_vic;
@@ -85,12 +87,9 @@ public:
 	required_device<vcs_control_port_device> m_joy1;
 	required_device<vcs_control_port_device> m_joy2;
 	required_device<c64_expansion_slot_device> m_exp;
-	required_device<c64_user_port_device> m_user;
+	required_device<pet_user_port_device> m_user;
 	required_device<ram_device> m_ram;
 	optional_device<pet_datassette_port_device> m_cassette;
-	optional_memory_region m_basic;
-	required_memory_region m_kernal;
-	required_memory_region m_charom;
 	optional_shared_ptr<UINT8> m_color_ram;
 	optional_ioport m_row0;
 	optional_ioport m_row1;
@@ -100,14 +99,13 @@ public:
 	optional_ioport m_row5;
 	optional_ioport m_row6;
 	optional_ioport m_row7;
-	optional_ioport m_restore;
 	optional_ioport m_lock;
 
 	virtual void machine_start();
 	virtual void machine_reset();
 
 	void check_interrupts();
-	void read_pla(offs_t offset, offs_t va, int rw, int aec, int ba, int *casram, int *basic, int *kernal, int *charom, int *grw, int *io, int *roml, int *romh);
+	int read_pla(offs_t offset, offs_t va, int rw, int aec, int ba);
 	UINT8 read_memory(address_space &space, offs_t offset, offs_t va, int aec, int ba);
 	void write_memory(address_space &space, offs_t offset, UINT8 data, int aec, int ba);
 
@@ -133,6 +131,7 @@ public:
 	DECLARE_READ8_MEMBER( cpu_r );
 	DECLARE_WRITE8_MEMBER( cpu_w );
 
+	DECLARE_WRITE_LINE_MEMBER( write_restore );
 	DECLARE_WRITE_LINE_MEMBER( exp_irq_w );
 	DECLARE_WRITE_LINE_MEMBER( exp_nmi_w );
 	DECLARE_WRITE_LINE_MEMBER( exp_dma_w );
@@ -140,6 +139,19 @@ public:
 
 	DECLARE_QUICKLOAD_LOAD_MEMBER( cbm_c64 );
 
+	DECLARE_READ8_MEMBER( cia2_pb_r );
+	DECLARE_WRITE8_MEMBER( cia2_pb_w );
+
+	DECLARE_WRITE_LINE_MEMBER( write_user_pa2 ) { m_user_pa2 = state; }
+	DECLARE_WRITE_LINE_MEMBER( write_user_pb0 ) { if (state) m_user_pb |= 1; else m_user_pb &= ~1; }
+	DECLARE_WRITE_LINE_MEMBER( write_user_pb1 ) { if (state) m_user_pb |= 2; else m_user_pb &= ~2; }
+	DECLARE_WRITE_LINE_MEMBER( write_user_pb2 ) { if (state) m_user_pb |= 4; else m_user_pb &= ~4; }
+	DECLARE_WRITE_LINE_MEMBER( write_user_pb3 ) { if (state) m_user_pb |= 8; else m_user_pb &= ~8; }
+	DECLARE_WRITE_LINE_MEMBER( write_user_pb4 ) { if (state) m_user_pb |= 16; else m_user_pb &= ~16; }
+	DECLARE_WRITE_LINE_MEMBER( write_user_pb5 ) { if (state) m_user_pb |= 32; else m_user_pb &= ~32; }
+	DECLARE_WRITE_LINE_MEMBER( write_user_pb6 ) { if (state) m_user_pb |= 64; else m_user_pb &= ~64; }
+	DECLARE_WRITE_LINE_MEMBER( write_user_pb7 ) { if (state) m_user_pb |= 128; else m_user_pb &= ~128; }
+
 	// memory state
 	int m_loram;
 	int m_hiram;
@@ -150,12 +162,16 @@ public:
 	int m_va15;
 
 	// interrupt state
+	int m_restore;
 	int m_cia1_irq;
 	int m_cia2_irq;
 	int m_vic_irq;
 	int m_exp_irq;
 	int m_exp_nmi;
 	int m_exp_dma;
+
+	int m_user_pa2;
+	int m_user_pb;
 };
 
 
