@@ -11,17 +11,17 @@
 #include "machine/coleco.h"
 #include "imagedev/cartslot.h"
 
-#define Z80_TAG     "z80"
-
 class coleco_state : public driver_device
 {
 public:
 	coleco_state(const machine_config &mconfig, device_type type, const char *tag)
 		: driver_device(mconfig, type, tag),
-			m_maincpu(*this, Z80_TAG)
+			m_maincpu(*this, "maincpu"),
+			m_ram(*this, "ram")
 	{ }
 
 	required_device<cpu_device> m_maincpu;
+	required_shared_ptr<UINT8> m_ram;
 
 	virtual void machine_start();
 	virtual void machine_reset();
