@@ -14,8 +14,7 @@
 #include "machine/i8255.h"
 #include "machine/i8251.h"
 #include "machine/ram.h"
-#include "machine/sega8_slot.h"
-#include "machine/serial.h"
+#include "bus/sega8/sega8_slot.h"
 #include "machine/upd765.h"
 #include "sound/sn76496.h"
 #include "video/tms9928a.h"
@@ -36,8 +35,6 @@
 
 
 INPUT_PORTS_EXTERN( sk1100 );
-extern const i8255_interface ( sc3000_ppi_intf );
-extern const cassette_interface sc3000_cassette_interface;
 
 class sg1000_state : public driver_device
 {
@@ -142,6 +139,8 @@ public:
 	virtual void machine_start();
 	virtual void machine_reset();
 
+	int m_centronics_busy;
+	DECLARE_WRITE_LINE_MEMBER( write_centronics_busy );
 	DECLARE_READ8_MEMBER( ppi_pa_r );
 	DECLARE_WRITE8_MEMBER( ppi_pc_w );
 
