@@ -8,8 +8,6 @@
 #include "emu.h"
 #include "includes/amiga.h"
 #include "amigakbd.h"
-#include "machine/6526cia.h"
-
 
 #define KEYBOARD_BUFFER_SIZE    256
 
@@ -20,7 +18,13 @@ const device_type AMIGAKBD = &device_creator<amigakbd_device>;
 //-------------------------------------------------
 
 amigakbd_device::amigakbd_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: device_t(mconfig, AMIGAKBD, "Amiga Keyboard", tag, owner, clock, "amigakbd", __FILE__)
+	: device_t(mconfig, AMIGAKBD, "Amiga Keyboard", tag, owner, clock, "amigakbd", __FILE__),
+	m_write_kclk(*this),
+	m_write_kdat(*this),
+	m_buf(NULL),
+	m_buf_pos(0),
+	m_cur_pos(0),
+	m_timer(NULL)
 {
 }
 
@@ -30,25 +34,23 @@ amigakbd_device::amigakbd_device(const machine_config &mconfig, const char *tag,
 
 void amigakbd_device::device_start()
 {
+	m_write_kclk.resolve_safe();
+	m_write_kdat.resolve_safe();
+
 	/* allocate a keyboard buffer */
 	m_buf = auto_alloc_array(machine(), UINT8, KEYBOARD_BUFFER_SIZE);
-	m_buf_pos = 0;
-	m_cur_pos = 0;
 	m_timer = timer_alloc(0);
 	m_timer->reset();
 }
 
 void amigakbd_device::kbd_sendscancode(UINT8 scancode )
 {
-	int j;
-	device_t *cia = machine().device(":cia_0");
-
-	/* send over to the cia A */
-	for( j = 0; j < 8; j++ )
+	// send over to the cia
+	for(int j = 0; j < 8; j++)
 	{
-		mos6526_cnt_w( cia, 0 );    /* lower cnt */
-		mos6526_sp_w( cia, BIT(scancode << j, 7) ); /* set the serial data */
-		mos6526_cnt_w( cia, 1 );    /* raise cnt */
+		m_write_kclk(0);    /* lower cnt */
+		m_write_kdat(BIT(scancode << j, 7)); /* set the serial data */
+		m_write_kclk(1);    /* raise cnt */
 	}
 }
 
@@ -75,49 +77,43 @@ void amigakbd_device::device_timer(emu_timer &timer, device_timer_id id, int par
 	/* if we still have more data, schedule another update */
 	if ( m_buf_pos != m_cur_pos )
 	{
-		m_timer->adjust(machine().primary_screen->frame_period() / 4);
+		m_timer->adjust(machine().first_screen()->frame_period() / 4);
 	}
 }
 
-INPUT_CHANGED_MEMBER(amigakbd_device::kbd_update)
+WRITE_LINE_MEMBER( amigakbd_device::kdat_w )
+{
+	// todo: do something with the handshake
+	// the real keyboard times out if it doesn't receive a handshake
+	// after a key and goes into resync mode
+}
+
+INPUT_CHANGED_MEMBER( amigakbd_device::kbd_update )
 {
 	int index = (int)(FPTR)param, i;
 	UINT32  oldvalue = oldval * field.mask(), newvalue = newval * field.mask();
 	UINT32  delta = oldvalue ^ newvalue;
 
-	/* Special case Page UP, which we will use as Action Replay button */
-	if ( (index == 3) && ( delta & 0x80000000 ) && ( newvalue & 0x80000000 ) )
-	{
-		const amiga_machine_interface *amiga_intf = amiga_get_interface(machine());
+	int key_buf_was_empty = ( m_buf_pos == m_cur_pos ) ? 1 : 0;
 
-		if ( amiga_intf != NULL && amiga_intf->nmi_callback )
+	for( i = 0; i < 32; i++ )
+	{
+		if ( delta & ( 1 << i ) )
 		{
-			(*amiga_intf->nmi_callback)(machine());
+			int down = ( newvalue & ( 1 << i ) ) ? 0 : 1;
+			int scancode = ( ( (index*32)+i ) << 1 ) | down;
+			int amigacode = ~scancode;
+
+			/* add the keycode to the buffer */
+			m_buf[m_buf_pos++] = amigacode & 0xff;
+			m_buf_pos %= KEYBOARD_BUFFER_SIZE;
 		}
 	}
-	else
+
+	/* if the buffer was empty and we have new data, start a timer to send the keystrokes */
+	if ( key_buf_was_empty && ( m_buf_pos != m_cur_pos ) )
 	{
-		int key_buf_was_empty = ( m_buf_pos == m_cur_pos ) ? 1 : 0;
-
-		for( i = 0; i < 32; i++ )
-		{
-			if ( delta & ( 1 << i ) )
-			{
-				int down = ( newvalue & ( 1 << i ) ) ? 0 : 1;
-				int scancode = ( ( (index*32)+i ) << 1 ) | down;
-				int amigacode = ~scancode;
-
-				/* add the keycode to the buffer */
-				m_buf[m_buf_pos++] = amigacode & 0xff;
-				m_buf_pos %= KEYBOARD_BUFFER_SIZE;
-			}
-		}
-
-		/* if the buffer was empty and we have new data, start a timer to send the keystrokes */
-		if ( key_buf_was_empty && ( m_buf_pos != m_cur_pos ) )
-		{
-			m_timer->adjust(machine().primary_screen->frame_period() / 4);
-		}
+		m_timer->adjust(machine().first_screen()->frame_period() / 4);
 	}
 }
 
@@ -271,3 +267,17 @@ ioport_constructor amigakbd_device::device_input_ports() const
 {
 	return INPUT_PORTS_NAME( amiga_us_keyboard );
 }
+
+//-------------------------------------------------
+//  rom_region - device-specific ROM region
+//-------------------------------------------------
+
+ROM_START( keyboard_mpu )
+	ROM_REGION(0x800, "keyboard", 0)
+	ROM_LOAD("328191-01.ic1", 0x000, 0x800, NO_DUMP)
+ROM_END
+
+const rom_entry *amigakbd_device::device_rom_region() const
+{
+	return ROM_NAME( keyboard_mpu );
+}
