@@ -18,8 +18,6 @@
 #include "machine/wd17xx.h"
 #include "imagedev/flopdrv.h"
 #include "includes/bbc.h"
-#include "machine/upd7002.h"
-#include "machine/i8271.h"
 #include "machine/mc146818.h"
 #include "bus/centronics/ctronics.h"
 #include "imagedev/cassette.h"
@@ -572,28 +570,25 @@ READ8_MEMBER(bbc_state::bbcm_r)
 
 	if ((offset>=0x200) && (offset<=0x2ff)) /* SHEILA */
 	{
-		via6522_device *via_0 = machine().device<via6522_device>("via6522_0");
-		via6522_device *via_1 = machine().device<via6522_device>("via6522_1");
-
 		myo = offset-0x200;
 		if ((myo>=0x00) && (myo<=0x07)) return bbc_6845_r(space, myo-0x00);     /* Video Controller */
 		if ((myo>=0x08) && (myo<=0x0f))
 		{
 			if ((myo - 0x08) & 1)
-				return m_acia->status_read(space,0);
+				return m_acia->status_r(space,0);
 			else
-				return m_acia->data_read(space,0);
+				return m_acia->data_r(space,0);
 		}
 		if ((myo>=0x10) && (myo<=0x17)) return 0xfe;                                /* Serial System Chip */
-		if ((myo>=0x18) && (myo<=0x1f)) return uPD7002_r(machine().device("upd7002"), space, myo-0x18);         /* A to D converter */
+		if ((myo>=0x18) && (myo<=0x1f)) return m_upd7002->read(space, myo-0x18);    /* A to D converter */
 		if ((myo>=0x20) && (myo<=0x23)) return 0xfe;                                /* VideoULA */
 		if ((myo>=0x24) && (myo<=0x27)) return bbcm_wd1770l_read(space, myo-0x24);  /* 1770 */
 		if ((myo>=0x28) && (myo<=0x2f)) return bbcm_wd1770_read(space, myo-0x28);   /* disc control latch */
 		if ((myo>=0x30) && (myo<=0x33)) return 0xfe;                                /* page select */
 		if ((myo>=0x34) && (myo<=0x37)) return bbcm_ACCCON_read(space, myo-0x34);   /* ACCCON */
 		if ((myo>=0x38) && (myo<=0x3f)) return 0xfe;                                /* NC ?? */
-		if ((myo>=0x40) && (myo<=0x5f)) return via_0->read(space, myo-0x40);
-		if ((myo>=0x60) && (myo<=0x7f)) return via_1->read(space, myo-0x60);
+		if ((myo>=0x40) && (myo<=0x5f)) return m_via6522_0->read(space, myo-0x40);
+		if ((myo>=0x60) && (myo<=0x7f)) return m_via6522_1->read(space, myo-0x60);
 		if ((myo>=0x80) && (myo<=0x9f)) return 0xfe;
 		if ((myo>=0xa0) && (myo<=0xbf)) return m_adlc->read(space, myo & 0x03);
 		if ((myo>=0xc0) && (myo<=0xdf)) return 0xfe;
@@ -609,28 +604,25 @@ WRITE8_MEMBER(bbc_state::bbcm_w)
 
 	if ((offset>=0x200) && (offset<=0x2ff)) /* SHEILA */
 	{
-		via6522_device *via_0 = machine().device<via6522_device>("via6522_0");
-		via6522_device *via_1 = machine().device<via6522_device>("via6522_1");
-
 		myo=offset-0x200;
 		if ((myo>=0x00) && (myo<=0x07)) bbc_6845_w(space, myo-0x00, data);           /* Video Controller */
 		if ((myo>=0x08) && (myo<=0x0f))
 		{
 			if ((myo - 0x08) & 1)
-				m_acia->control_write(space, 0, data);
+				m_acia->control_w(space, 0, data);
 			else
-				m_acia->data_write(space, 0, data);
+				m_acia->data_w(space, 0, data);
 		}
 		if ((myo>=0x10) && (myo<=0x17)) bbc_SerialULA_w(space, myo-0x10, data);     /* Serial System Chip */
-		if ((myo>=0x18) && (myo<=0x1f)) uPD7002_w(machine().device("upd7002"), space, myo-0x18, data);         /* A to D converter */
+		if ((myo>=0x18) && (myo<=0x1f)) m_upd7002->write(space, myo-0x18, data);    /* A to D converter */
 		if ((myo>=0x20) && (myo<=0x23)) bbc_videoULA_w(space, myo-0x20, data);      /* VideoULA */
 		if ((myo>=0x24) && (myo<=0x27)) bbcm_wd1770l_write(space, myo-0x24, data);  /* 1770 */
 		if ((myo>=0x28) && (myo<=0x2f)) bbcm_wd1770_write(space, myo-0x28, data);   /* disc control latch */
 		if ((myo>=0x30) && (myo<=0x33)) page_selectbm_w(space, myo-0x30, data);     /* page select */
 		if ((myo>=0x34) && (myo<=0x37)) bbcm_ACCCON_write(space, myo-0x34, data);   /* ACCCON */
 		//if ((myo>=0x38) && (myo<=0x3f))                                           /* NC ?? */
-		if ((myo>=0x40) && (myo<=0x5f)) via_0->write(space, myo-0x40, data);
-		if ((myo>=0x60) && (myo<=0x7f)) via_1->write(space, myo-0x60, data);
+		if ((myo>=0x40) && (myo<=0x5f)) m_via6522_0->write(space, myo-0x40, data);
+		if ((myo>=0x60) && (myo<=0x7f)) m_via6522_1->write(space, myo-0x60, data);
 		//if ((myo>=0x80) && (myo<=0x9f))
 		if ((myo>=0xa0) && (myo<=0xbf)) m_adlc->write(space, myo & 0x03, data);
 		//if ((myo>=0xc0) && (myo<=0xdf))
@@ -742,46 +734,9 @@ INTERRUPT_GEN_MEMBER(bbc_state::bbcb_keyscan)
 {
 	static const char *const colnames[] = {
 		"COL0", "COL1", "COL2", "COL3", "COL4",
-		"COL5", "COL6", "COL7", "COL8", "COL9"
+		"COL5", "COL6", "COL7", "COL8", "COL9",
+		"COL10", "COL11", "COL12"
 	};
-	via6522_device *via_0 = machine().device<via6522_device>("via6522_0");
-
-	/* only do auto scan if keyboard is not enabled */
-	if (m_b3_keyboard == 1)
-	{
-		/* KBD IC1 4 bit addressable counter */
-		/* KBD IC3 4 to 10 line decoder */
-		/* keyboard not enabled so increment counter */
-		m_column = (m_column + 1) % 16;
-		if (m_column < 10)
-		{
-			/* KBD IC4 8 input NAND gate */
-			/* set the value of via_system ca2, by checking for any keys
-			     being pressed on the selected m_column */
-			if ((ioport(colnames[m_column])->read() | 0x01) != 0xff)
-			{
-				via_0->write_ca2(1);
-			}
-			else
-			{
-				via_0->write_ca2(0);
-			}
-		}
-		else
-		{
-			via_0->write_ca2(0);
-		}
-	}
-}
-
-
-INTERRUPT_GEN_MEMBER(bbc_state::bbcm_keyscan)
-{
-	static const char *const colnames[] = {
-		"COL0", "COL1", "COL2", "COL3", "COL4",
-		"COL5", "COL6", "COL7", "COL8", "COL9"
-	};
-	via6522_device *via_0 = machine().device<via6522_device>("via6522_0");
 
 	/* only do auto scan if keyboard is not enabled */
 	if (m_b3_keyboard == 1)
@@ -791,30 +746,28 @@ INTERRUPT_GEN_MEMBER(bbc_state::bbcm_keyscan)
 		/* keyboard not enabled so increment counter */
 		m_column = (m_column + 1) % 16;
 
-		/* this IF should be removed as soon as the dip switches (keyboard keys) are set for the master */
-		if (m_column < 10)
+		if (m_column < 13)
 		{
 			/* KBD IC4 8 input NAND gate */
 			/* set the value of via_system ca2, by checking for any keys
 			     being pressed on the selected m_column */
 			if ((ioport(colnames[m_column])->read() | 0x01) != 0xff)
 			{
-				via_0->write_ca2(1);
+				m_via6522_0->write_ca2(1);
 			}
 			else
 			{
-				via_0->write_ca2(0);
+				m_via6522_0->write_ca2(0);
 			}
 		}
 		else
 		{
-			via_0->write_ca2(0);
+			m_via6522_0->write_ca2(0);
 		}
 	}
 }
 
 
-
 int bbc_state::bbc_keyboard(address_space &space, int data)
 {
 	int bit;
@@ -822,16 +775,16 @@ int bbc_state::bbc_keyboard(address_space &space, int data)
 	int res;
 	static const char *const colnames[] = {
 		"COL0", "COL1", "COL2", "COL3", "COL4",
-		"COL5", "COL6", "COL7", "COL8", "COL9"
+		"COL5", "COL6", "COL7", "COL8", "COL9",
+		"COL10", "COL11", "COL12"
 	};
-	via6522_device *via_0 = space.machine().device<via6522_device>("via6522_0");
 
 	m_column = data & 0x0f;
 	row = (data>>4) & 0x07;
 
 	bit = 0;
 
-	if (m_column < 10)
+	if (m_column < 13)
 	{
 		res = ioport(colnames[m_column])->read();
 	}
@@ -848,11 +801,11 @@ int bbc_state::bbc_keyboard(address_space &space, int data)
 
 	if ((res | 1) != 0xff)
 	{
-		via_0->write_ca2(1);
+		m_via6522_0->write_ca2(1);
 	}
 	else
 	{
-		via_0->write_ca2(0);
+		m_via6522_0->write_ca2(0);
 	}
 
 	return (data & 0x7f) | (bit<<7);
@@ -1004,6 +957,7 @@ WRITE8_MEMBER(bbc_state::bbcb_via_system_write_portb)
 			{
 				m_b6_caps_lock_led = 1;
 				/* call caps lock led update */
+				output_set_value("capslock_led", m_b6_caps_lock_led);
 			}
 			break;
 		case 7:
@@ -1011,6 +965,7 @@ WRITE8_MEMBER(bbc_state::bbcb_via_system_write_portb)
 			{
 				m_b7_shift_lock_led = 1;
 				/* call shift lock led update */
+				output_set_value("shiftlock_led", m_b7_shift_lock_led);
 			}
 			break;
 		}
@@ -1089,6 +1044,7 @@ WRITE8_MEMBER(bbc_state::bbcb_via_system_write_portb)
 			{
 				m_b6_caps_lock_led = 0;
 				/* call caps lock led update */
+				output_set_value("capslock_led", m_b6_caps_lock_led);
 			}
 			break;
 		case 7:
@@ -1096,6 +1052,7 @@ WRITE8_MEMBER(bbc_state::bbcb_via_system_write_portb)
 			{
 				m_b7_shift_lock_led = 0;
 				/* call shift lock led update */
+				output_set_value("shiftlock_led", m_b7_shift_lock_led);
 			}
 			break;
 		}
@@ -1157,34 +1114,6 @@ READ8_MEMBER(bbc_state::bbcb_via_system_read_portb)
 }
 
 
-/* vertical sync pulse from video circuit */
-READ8_MEMBER(bbc_state::bbcb_via_system_read_ca1)
-{
-	return 0x01;
-}
-
-
-/* joystick EOC */
-READ8_MEMBER(bbc_state::bbcb_via_system_read_cb1)
-{
-	return uPD7002_EOC_r(machine().device("upd7002"), space, 0);
-}
-
-
-/* keyboard pressed detect */
-READ8_MEMBER(bbc_state::bbcb_via_system_read_ca2)
-{
-	return 0x01;
-}
-
-
-/* light pen strobe detect (not emulated) */
-READ8_MEMBER(bbc_state::bbcb_via_system_read_cb2)
-{
-	return 0x01;
-}
-
-
 WRITE_LINE_MEMBER(bbc_state::bbcb_via_system_irq_w)
 {
 	m_via_system_irq = state;
@@ -1192,24 +1121,6 @@ WRITE_LINE_MEMBER(bbc_state::bbcb_via_system_irq_w)
 	check_interrupts();
 }
 
-const via6522_interface bbcb_system_via =
-{
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_system_read_porta),
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_system_read_portb),
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_system_read_ca1),
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_system_read_cb1),
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_system_read_ca2),
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_system_read_cb2),
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_system_write_porta),
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_system_write_portb),
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(bbc_state,bbcb_via_system_irq_w)
-};
-
-
 /**********************************************************************
 USER VIA
 Port A output is buffered before being connected to the printer connector.
@@ -1237,58 +1148,33 @@ WRITE_LINE_MEMBER(bbc_state::bbcb_via_user_irq_w)
 	check_interrupts();
 }
 
-const via6522_interface bbcb_user_via =
-{
-	DEVCB_NULL, //via_user_read_porta,
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_user_read_portb),
-	DEVCB_NULL, //via_user_read_ca1,
-	DEVCB_NULL, //via_user_read_cb1,
-	DEVCB_NULL, //via_user_read_ca2,
-	DEVCB_NULL, //via_user_read_cb2,
-	DEVCB_DEVICE_MEMBER("centronics", centronics_device, write),
-	DEVCB_DRIVER_MEMBER(bbc_state,bbcb_via_user_write_portb),
-	DEVCB_NULL, //via_user_write_ca1
-	DEVCB_NULL, //via_user_write_cb1
-	DEVCB_DEVICE_LINE_MEMBER("centronics", centronics_device, strobe_w),
-	DEVCB_NULL, //via_user_write_cb2,
-	DEVCB_DRIVER_LINE_MEMBER(bbc_state,bbcb_via_user_irq_w)
-};
-
 
 /**************************************
 BBC Joystick Support
 **************************************/
 
-static UPD7002_GET_ANALOGUE(BBC_get_analogue_input)
+UPD7002_GET_ANALOGUE(bbc_state::BBC_get_analogue_input)
 {
-	switch(channel_number)
+	switch (channel_number)
 	{
 		case 0:
-			return ((0xff-device->machine().root_device().ioport("JOY0")->read())<<8);
+			return ((0xff - m_joy0->read()) << 8);
 		case 1:
-			return ((0xff-device->machine().root_device().ioport("JOY1")->read())<<8);
+			return ((0xff - m_joy1->read()) << 8);
 		case 2:
-			return ((0xff-device->machine().root_device().ioport("JOY2")->read())<<8);
+			return ((0xff - m_joy2->read()) << 8);
 		case 3:
-			return ((0xff-device->machine().root_device().ioport("JOY3")->read())<<8);
+			return ((0xff - m_joy3->read()) << 8);
 	}
 
 	return 0;
 }
 
-static UPD7002_EOC(BBC_uPD7002_EOC)
+UPD7002_EOC(bbc_state::BBC_uPD7002_EOC)
 {
-	via6522_device *via_0 = device->machine().device<via6522_device>("via6522_0");
-	via_0->write_cb1(data);
+	m_via6522_0->write_cb1(data);
 }
 
-const uPD7002_interface bbc_uPD7002 =
-{
-	BBC_get_analogue_input,
-	BBC_uPD7002_EOC
-};
-
-
 /***************************************
   BBC 2C199 Serial Interface Cassette
 ****************************************/
@@ -1306,7 +1192,8 @@ void bbc_state::MC6850_Receive_Clock(int new_clock)
 	//
 	for (int i = 0; i < 16; i++ )
 	{
-		m_acia->rx_clock_in();
+		m_acia->write_rxc(1);
+		m_acia->write_rxc(0);
 	}
 }
 
@@ -1363,7 +1250,7 @@ TIMER_CALLBACK_MEMBER(bbc_state::bbc_tape_timer_cb)
 		{
 			if (m_wav_len>(9*3))
 			{
-				//this is to long to recive anything so reset the serial IC. This is a hack, this should be done as a timer in the MC6850 code.
+				//this is too long to receive anything so reset the serial IC. This is a hack, this should be done as a timer in the MC6850 code.
 				logerror ("Cassette length %d\n",m_wav_len);
 				m_nr_high_tones = 0;
 				m_dcd_cass = 0;
@@ -1428,7 +1315,7 @@ WRITE_LINE_MEMBER( bbc_state::write_rxd_serial )
 
 void bbc_state::update_acia_rxd()
 {
-	m_acia->write_rx(( m_serproc_data & 0x40 ) ? m_rxd_serial : m_rxd_cass);
+	m_acia->write_rxd(( m_serproc_data & 0x40 ) ? m_rxd_serial : m_rxd_cass);
 }
 
 
@@ -1460,7 +1347,7 @@ WRITE_LINE_MEMBER( bbc_state::bbc_rts_w )
 {
 	if ( m_serproc_data & 0x40 )
 	{
-		m_rs232->rts_w(state);
+		m_rs232->write_rts(state);
 		m_cass_out_enabled = 0;
 	}
 	else
@@ -1474,7 +1361,7 @@ WRITE_LINE_MEMBER( bbc_state::bbc_txd_w )
 {
 	if ( m_serproc_data & 0x40 )
 	{
-		m_rs232->tx(state);
+		m_rs232->write_txd(state);
 	}
 	else
 	{
@@ -1502,6 +1389,7 @@ void bbc_state::BBC_Cassette_motor(unsigned char status)
 		m_cass_out_phase = 0;
 		m_cass_out_samples_to_go = 4;
 	}
+	output_set_value("motor_led", !status);
 }
 
 
@@ -1526,14 +1414,14 @@ WRITE8_MEMBER(bbc_state::bbc_SerialULA_w)
 {
 	static const int serial_clocks[8] =
 	{
-		XTAL_16MHz / 13 / 1,    // 000
-		XTAL_16MHz / 13 / 16,   // 001
-		XTAL_16MHz / 13 / 4,    // 010
-		XTAL_16MHz / 13 / 128,  // 011
-		XTAL_16MHz / 13 / 2,    // 100
-		XTAL_16MHz / 13 / 64,   // 101
-		XTAL_16MHz / 13 / 8,    // 110
-		XTAL_16MHz / 13 / 256   // 111
+		1,    // 000
+		16,   // 001
+		4,    // 010
+		128,  // 011
+		2,    // 100
+		64,   // 101
+		8,    // 110
+		256   // 111
 	};
 
 	m_serproc_data = data;
@@ -1543,17 +1431,15 @@ WRITE8_MEMBER(bbc_state::bbc_SerialULA_w)
 	BBC_Cassette_motor(m_serproc_data & 0x80);
 
 	// Set transmit clock rate
-	m_acia->set_tx_clock( serial_clocks[ data & 0x07 ] );
+	m_acia_clock->set_clock_scale( (double) 1 / serial_clocks[ data & 0x07 ] );
+}
 
-	if ( data & 0x40 )
-	{
-		// Set receive clock rate
-		m_acia->set_rx_clock( serial_clocks[ ( data >> 3 ) & 0x07 ] );
-	}
-	else
-	{
-		m_acia->set_rx_clock( 0 );
-	}
+WRITE_LINE_MEMBER(bbc_state::write_acia_clock)
+{
+	m_acia->write_txc(state);
+
+	if (m_serproc_data & 0x40)
+		m_acia->write_rxc(state);
 }
 
 /**************************************
@@ -1561,41 +1447,31 @@ WRITE8_MEMBER(bbc_state::bbc_SerialULA_w)
 ***************************************/
 
 
-static void bbc_i8271_interrupt(device_t *device, int state)
+WRITE_LINE_MEMBER(bbc_state::bbc_i8271_interrupt)
 {
-	bbc_state *drvstate = device->machine().driver_data<bbc_state>();
 	/* I'm assuming that the nmi is edge triggered */
 	/* a interrupt from the fdc will cause a change in line state, and
 	the nmi will be triggered, but when the state changes because the int
 	is cleared this will not cause another nmi */
 	/* I'll emulate it like this to be sure */
 
-	if (state!=drvstate->m_previous_i8271_int_state)
+	if (state!=m_previous_i8271_int_state)
 	{
 		if (state)
 		{
 			/* I'll pulse it because if I used hold-line I'm not sure
 			it would clear - to be checked */
-			drvstate->m_maincpu->set_input_line(INPUT_LINE_NMI,PULSE_LINE);
+			m_maincpu->set_input_line(INPUT_LINE_NMI,PULSE_LINE);
 		}
 	}
 
-	drvstate->m_previous_i8271_int_state = state;
+	m_previous_i8271_int_state = state;
 }
 
 
-const i8271_interface bbc_i8271_interface=
-{
-	bbc_i8271_interrupt,
-	NULL,
-	{FLOPPY_0, FLOPPY_1}
-};
-
-
 READ8_MEMBER(bbc_state::bbc_i8271_read)
 {
 	int ret;
-	device_t *i8271 = machine().device("i8271");
 	logerror("i8271 read %d  ",offset);
 	switch (offset)
 	{
@@ -1604,11 +1480,11 @@ READ8_MEMBER(bbc_state::bbc_i8271_read)
 		case 2:
 		case 3:
 			/* 8271 registers */
-			ret=i8271_r(i8271, space, offset);
+			ret=m_i8271->read(space, offset);
 			logerror("  %d\n",ret);
 			break;
 		case 4:
-			ret=i8271_data_r(i8271, space, offset);
+			ret=m_i8271->data_r(space, offset);
 			logerror("  %d\n",ret);
 			break;
 		default:
@@ -1621,7 +1497,6 @@ READ8_MEMBER(bbc_state::bbc_i8271_read)
 
 WRITE8_MEMBER(bbc_state::bbc_i8271_write)
 {
-	device_t *i8271 = machine().device("i8271");
 	logerror("i8271 write  %d  %d\n",offset,data);
 
 	switch (offset)
@@ -1631,10 +1506,10 @@ WRITE8_MEMBER(bbc_state::bbc_i8271_write)
 		case 2:
 		case 3:
 			/* 8271 registers */
-			i8271_w(i8271, space, offset, data);
+			m_i8271->write(space, offset, data);
 			return;
 		case 4:
-			i8271_data_w(i8271, space, offset, data);
+			m_i8271->data_w(space, offset, data);
 			return;
 		default:
 			break;
@@ -1727,28 +1602,20 @@ WRITE_LINE_MEMBER(bbc_state::bbc_wd177x_drq_w)
 	bbc_update_fdq_int(state);
 }
 
-const wd17xx_interface bbc_wd17xx_interface =
-{
-	DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(bbc_state,bbc_wd177x_intrq_w),
-	DEVCB_DRIVER_LINE_MEMBER(bbc_state,bbc_wd177x_drq_w),
-	{FLOPPY_0, FLOPPY_1, NULL, NULL}
-};
-
 WRITE8_MEMBER(bbc_state::bbc_wd177x_status_w)
 {
-	device_t *fdc = machine().device("wd177x");
+	wd1770_device *fdc = machine().device<wd1770_device>("wd177x");
 	m_drive_control = data;
 
 	/* set drive */
-	if ((data>>0) & 0x01) wd17xx_set_drive(fdc,0);
-	if ((data>>1) & 0x01) wd17xx_set_drive(fdc,1);
+	if ((data>>0) & 0x01) fdc->set_drive(0);
+	if ((data>>1) & 0x01) fdc->set_drive(1);
 
 	/* set side */
-	wd17xx_set_side(fdc,(data>>2) & 0x01);
+	fdc->set_side((data>>2) & 0x01);
 
 	/* set density */
-	wd17xx_dden_w(fdc, BIT(data, 3));
+	fdc->dden_w(BIT(data, 3));
 
 	m_1770_IntEnabled=(((data>>4) & 0x01)==0);
 }
@@ -1758,20 +1625,20 @@ WRITE8_MEMBER(bbc_state::bbc_wd177x_status_w)
 READ8_MEMBER(bbc_state::bbc_wd1770_read)
 {
 	int retval=0xff;
-	device_t *fdc = machine().device("wd177x");
+	wd1770_device *fdc = machine().device<wd1770_device>("wd177x");
 	switch (offset)
 	{
 	case 4:
-		retval=wd17xx_status_r(fdc, space, 0);
+		retval=fdc->status_r(space, 0);
 		break;
 	case 5:
-		retval=wd17xx_track_r(fdc, space, 0);
+		retval=fdc->track_r(space, 0);
 		break;
 	case 6:
-		retval=wd17xx_sector_r(fdc, space, 0);
+		retval=fdc->sector_r(space, 0);
 		break;
 	case 7:
-		retval=wd17xx_data_r(fdc, space, 0);
+		retval=fdc->data_r(space, 0);
 		break;
 	default:
 		break;
@@ -1783,7 +1650,7 @@ READ8_MEMBER(bbc_state::bbc_wd1770_read)
 
 WRITE8_MEMBER(bbc_state::bbc_wd1770_write)
 {
-	device_t *fdc = machine().device("wd177x");
+	wd1770_device *fdc = machine().device<wd1770_device>("wd177x");
 	logerror("wd177x write: $%02X  $%02X\n", offset,data);
 	switch (offset)
 	{
@@ -1791,16 +1658,16 @@ WRITE8_MEMBER(bbc_state::bbc_wd1770_write)
 		bbc_wd177x_status_w(space, 0, data);
 		break;
 	case 4:
-		wd17xx_command_w(fdc, space, 0, data);
+		fdc->command_w(space, 0, data);
 		break;
 	case 5:
-		wd17xx_track_w(fdc, space, 0, data);
+		fdc->track_w(space, 0, data);
 		break;
 	case 6:
-		wd17xx_sector_w(fdc, space, 0, data);
+		fdc->sector_w(space, 0, data);
 		break;
 	case 7:
-		wd17xx_data_w(fdc, space, 0, data);
+		fdc->data_w(space, 0, data);
 		break;
 	default:
 		break;
@@ -1846,25 +1713,25 @@ AM_RANGE(0xfc00, 0xfdff) AM_READWRITE(bbc_opus_read     , bbc_opus_write    )
 
 WRITE8_MEMBER(bbc_state::bbc_opus_status_w)
 {
-	device_t *fdc = machine().device("wd177x");
+	wd1770_device *fdc = machine().device<wd1770_device>("wd177x");
 	m_drive_control = data;
 
 	/* set drive */
-	if ((data>>1) & 0x01) wd17xx_set_drive(fdc,0);
-	if ((data>>2) & 0x01) wd17xx_set_drive(fdc,1);
+	if ((data>>1) & 0x01) fdc->set_drive(0);
+	if ((data>>2) & 0x01) fdc->set_drive(1);
 
 	/* set side */
-	wd17xx_set_side(fdc,(data>>0) & 0x01);
+	fdc->set_side((data>>0) & 0x01);
 
 	/* set density */
-	wd17xx_dden_w(fdc, BIT(data, 5));
+	fdc->dden_w(BIT(data, 5));
 
 	m_1770_IntEnabled=(data>>4) & 0x01;
 }
 
 READ8_MEMBER(bbc_state::bbc_opus_read)
 {
-	device_t *fdc = machine().device("wd177x");
+	wd1770_device *fdc = machine().device<wd1770_device>("wd177x");
 	logerror("wd177x read: $%02X\n", offset);
 
 	if (m_DFSType==6)
@@ -1874,13 +1741,13 @@ READ8_MEMBER(bbc_state::bbc_opus_read)
 			switch (offset)
 			{
 				case 0xf8:
-					return wd17xx_status_r(fdc, space, 0);
+					return fdc->status_r(space, 0);
 				case 0xf9:
-					return wd17xx_track_r(fdc, space, 0);
+					return fdc->track_r(space, 0);
 				case 0xfa:
-					return wd17xx_sector_r(fdc, space, 0);
+					return fdc->sector_r(space, 0);
 				case 0xfb:
-					return wd17xx_data_r(fdc, space, 0);
+					return fdc->data_r(space, 0);
 			}
 		}
 		else
@@ -1893,7 +1760,7 @@ READ8_MEMBER(bbc_state::bbc_opus_read)
 
 WRITE8_MEMBER(bbc_state::bbc_opus_write)
 {
-	device_t *fdc = machine().device("wd177x");
+	wd1770_device *fdc = machine().device<wd1770_device>("wd177x");
 	logerror("wd177x write: $%02X  $%02X\n", offset,data);
 
 	if (m_DFSType==6)
@@ -1903,16 +1770,16 @@ WRITE8_MEMBER(bbc_state::bbc_opus_write)
 			switch (offset)
 			{
 				case 0xf8:
-					wd17xx_command_w(fdc, space, 0, data);
+					fdc->command_w(space, 0, data);
 					break;
 				case 0xf9:
-					wd17xx_track_w(fdc, space, 0, data);
+					fdc->track_w(space, 0, data);
 					break;
 				case 0xfa:
-					wd17xx_sector_w(fdc, space, 0, data);
+					fdc->sector_w(space, 0, data);
 					break;
 				case 0xfb:
-					wd17xx_data_w(fdc, space, 0, data);
+					fdc->data_w(space, 0, data);
 					break;
 				case 0xfc:
 					bbc_opus_status_w(space, 0,data);
@@ -1941,20 +1808,20 @@ BBC MASTER DISC SUPPORT
 READ8_MEMBER(bbc_state::bbcm_wd1770_read)
 {
 	int retval=0xff;
-	device_t *fdc = machine().device("wd177x");
+	wd1770_device *fdc = machine().device<wd1770_device>("wd177x");
 	switch (offset)
 	{
 	case 0:
-		retval=wd17xx_status_r(fdc, space, 0);
+		retval=fdc->status_r(space, 0);
 		break;
 	case 1:
-		retval=wd17xx_track_r(fdc, space, 0);
+		retval=fdc->track_r(space, 0);
 		break;
 	case 2:
-		retval=wd17xx_sector_r(fdc, space, 0);
+		retval=fdc->sector_r(space, 0);
 		break;
 	case 3:
-		retval=wd17xx_data_r(fdc, space, 0);
+		retval=fdc->data_r(space, 0);
 		break;
 	default:
 		break;
@@ -1965,21 +1832,21 @@ READ8_MEMBER(bbc_state::bbcm_wd1770_read)
 
 WRITE8_MEMBER(bbc_state::bbcm_wd1770_write)
 {
-	device_t *fdc = machine().device("wd177x");
+	wd1770_device *fdc = machine().device<wd1770_device>("wd177x");
 	//logerror("wd177x write: $%02X  $%02X\n", offset,data);
 	switch (offset)
 	{
 	case 0:
-		wd17xx_command_w(fdc, space, 0, data);
+		fdc->command_w(space, 0, data);
 		break;
 	case 1:
-		wd17xx_track_w(fdc, space, 0, data);
+		fdc->track_w(space, 0, data);
 		break;
 	case 2:
-		wd17xx_sector_w(fdc, space, 0, data);
+		fdc->sector_w(space, 0, data);
 		break;
 	case 3:
-		wd17xx_data_w(fdc, space, 0, data);
+		fdc->data_w(space, 0, data);
 		break;
 	default:
 		break;
@@ -1994,18 +1861,18 @@ READ8_MEMBER(bbc_state::bbcm_wd1770l_read)
 
 WRITE8_MEMBER(bbc_state::bbcm_wd1770l_write)
 {
-	device_t *fdc = machine().device("wd177x");
+	wd1770_device *fdc = machine().device<wd1770_device>("wd177x");
 	m_drive_control = data;
 
 	/* set drive */
-	if ((data>>0) & 0x01) wd17xx_set_drive(fdc,0);
-	if ((data>>1) & 0x01) wd17xx_set_drive(fdc,1);
+	if ((data>>0) & 0x01) fdc->set_drive(0);
+	if ((data>>1) & 0x01) fdc->set_drive(1);
 
 	/* set side */
-	wd17xx_set_side(fdc,(data>>4) & 0x01);
+	fdc->set_side((data>>4) & 0x01);
 
 	/* set density */
-	wd17xx_dden_w(fdc, BIT(data, 5));
+	fdc->dden_w(BIT(data, 5));
 
 //  m_1770_IntEnabled=(((data>>4) & 0x01)==0);
 	m_1770_IntEnabled=1;
@@ -2070,116 +1937,105 @@ WRITE8_MEMBER(bbc_state::bbc_disc_w)
 /**************************************
    BBC B Rom loading functions
 ***************************************/
-DEVICE_IMAGE_LOAD_MEMBER( bbc_state, bbcb_cart )
+
+int bbc_state::exp_rom_load(device_image_interface &image, int index)
 {
 	UINT8 *RAM = m_region_user1->base();
 	int size, read_;
-	int addr = 0;
-	int index = 0;
+	int addr = 0x8000 + (0x4000 * index);
 
-	size = image.length();
-
-	if (strcmp(image.device().tag(),":cart1") == 0)
+	if (image.software_entry() == NULL)
 	{
-		index = 0;
-	}
-	if (strcmp(image.device().tag(),":cart2") == 0)
-	{
-		index = 1;
-	}
-	if (strcmp(image.device().tag(),":cart3") == 0)
-	{
-		index = 2;
-	}
-	if (strcmp(image.device().tag(),":cart4") == 0)
-	{
-		index = 3;
-	}
-	addr = 0x8000 + (0x4000 * index);
+		size = image.length();
+		logerror("loading rom %s, at %.4x size:%.4x\n", image.filename(), addr, size);
 
+		switch (size)
+		{
+			case 0x2000:
+				read_ = image.fread(RAM + addr, size);
+				if (read_ != size)
+					return 1;
+				image.fseek(0, SEEK_SET);
+				read_ = image.fread(RAM + addr + 0x2000, size);
+				break;
+			case 0x4000:
+				read_ = image.fread(RAM + addr, size);
+				break;
+			default:
+				read_ = 0;
+				logerror("bad rom file size of %.4x\n", size);
+				break;
+		}
 
-	logerror("loading rom %s at %.4x size:%.4x\n", image.filename(), addr, size);
-
-
-	switch (size)
-	{
-	case 0x2000:
-		read_ = image.fread(RAM + addr, size);
 		if (read_ != size)
-			return 1;
-		image.fseek(0, SEEK_SET);
-		read_ = image.fread(RAM + addr + 0x2000, size);
-		break;
-	case 0x4000:
-		read_ = image.fread(RAM + addr, size);
-		break;
-	default:
-		read_ = 0;
-		logerror("bad rom file size of %.4x\n", size);
-		break;
+			return IMAGE_INIT_FAIL;
 	}
+	return IMAGE_INIT_PASS;
+}
 
-	if (read_ != size)
-		return 1;
-	return 0;
+DEVICE_IMAGE_LOAD_MEMBER( bbc_state, bbc_exp_rom )
+{
+	if (strcmp(image.device().tag(),":exp_rom1") == 0)
+		return exp_rom_load(image, 0);
+
+	if (strcmp(image.device().tag(),":exp_rom2") == 0)
+		return exp_rom_load(image, 1);
+
+	if (strcmp(image.device().tag(),":exp_rom3") == 0)
+		return exp_rom_load(image, 2);
+
+	if (strcmp(image.device().tag(),":exp_rom4") == 0)
+		return exp_rom_load(image, 3);
+
+	return IMAGE_INIT_FAIL;
 }
 
 
 /**************************************
    BBC Master Rom loading functions
 ***************************************/
+
 DEVICE_IMAGE_LOAD_MEMBER( bbc_state, bbcm_cart )
 {
 	UINT8 *RAM = m_region_user1->base();
-	int size, read_;
-	int addr = 0;
-	int index = 0;
-
-	size = image.length();
+	int addr = 0, index = 0;
 
 	if (strcmp(image.device().tag(),":cart1") == 0)
-	{
 		index = 0;
-	}
 	if (strcmp(image.device().tag(),":cart2") == 0)
-	{
 		index = 1;
-	}
-	if (strcmp(image.device().tag(),":cart3") == 0)
+	addr += index * 0x8000;
+
+	if (image.software_entry() == NULL)
 	{
-		index = 2;
+		UINT32 size = image.length();
+		logerror("loading rom %s, size:%.4x\n", image.filename(), size);
+
+		if (size != 0x8000)
+		{
+			image.seterror(IMAGE_ERROR_UNSUPPORTED, "Invalid rom file size");
+			return IMAGE_INIT_FAIL;
+		}
+
+		image.fread(RAM + addr, size);
 	}
-	if (strcmp(image.device().tag(),":cart4") == 0)
+	else
 	{
-		index = 3;
-	}
-	addr = 0x8000 + (0x4000 * index);
+		UINT32 size_lo = image.get_software_region_length("lorom");
+		UINT32 size_hi = image.get_software_region_length("uprom");
+		logerror("loading rom %s, size:%.4x\n", image.filename(), size_lo + size_hi);
 
+		if (size_lo + size_hi != 0x8000)
+		{
+			image.seterror(IMAGE_ERROR_UNSUPPORTED, "Invalid rom file size");
+			return IMAGE_INIT_FAIL;
+		}
 
-	logerror("loading rom %s at %.4x size:%.4x\n", image.filename(), addr, size);
-
-
-	switch (size)
-	{
-	case 0x2000:
-		read_ = image.fread(RAM + addr, size);
-		if (read_ != size)
-			return 1;
-		image.fseek(0, SEEK_SET);
-		read_ = image.fread(RAM + addr + 0x2000, size);
-		break;
-	case 0x4000:
-		read_ = image.fread(RAM + addr, size);
-		break;
-	default:
-		read_ = 0;
-		logerror("bad rom file size of %.4x\n", size);
-		break;
+		memcpy(RAM + addr + 0,       image.get_software_region("uprom"), size_hi);
+		memcpy(RAM + addr + size_hi, image.get_software_region("lorom"), size_lo);
 	}
 
-	if (read_ != size)
-		return 1;
-	return 0;
+	return IMAGE_INIT_PASS;
 }
 
 
@@ -2195,6 +2051,12 @@ DRIVER_INIT_MEMBER(bbc_state,bbc)
 	m_serproc_data = 0;
 	m_cass_out_enabled = 0;
 	m_tape_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(bbc_state::bbc_tape_timer_cb),this));
+
+	/* vertical sync pulse from video circuit */
+	m_via6522_0->write_ca1(1);
+
+	/* light pen strobe detect (not emulated) */
+	m_via6522_0->write_cb2(1);
 }
 
 DRIVER_INIT_MEMBER(bbc_state,bbcm)
@@ -2205,6 +2067,12 @@ DRIVER_INIT_MEMBER(bbc_state,bbcm)
 	m_serproc_data = 0;
 	m_cass_out_enabled = 0;
 	m_tape_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(bbc_state::bbc_tape_timer_cb),this));
+
+	/* vertical sync pulse from video circuit */
+	m_via6522_0->write_ca1(1);
+
+	/* light pen strobe detect (not emulated) */
+	m_via6522_0->write_cb2(1);
 }
 
 MACHINE_START_MEMBER(bbc_state,bbca)
