@@ -7,216 +7,198 @@
     04/05/2008 Created by Miodrag Milanovic
 
 *********************************************************************/
+/*
+BUGS:
+- random commands can be sent to FDC, so better keep .trd images write protected for now
+goto TR-DOS, CAT -> files will be shown, CAT again -> NO DISK mesage as result of trash commands
+
+*/
 #include "emu.h"
 #include "imagedev/flopdrv.h"
 #include "formats/trd_dsk.h"
-#include "machine/wd17xx.h"
 #include "machine/beta.h"
-#include "devlegcy.h"
+
 
 /***************************************************************************
     TYPE DEFINITIONS
 ***************************************************************************/
 
-struct beta_disk_state
+
+const device_type BETA_DISK = &device_creator<beta_disk_device>;
+
+beta_disk_device::beta_disk_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: device_t(mconfig, BETA_DISK, "Beta Disk Interface", tag, owner, clock, "betadisk", __FILE__),
+	m_betadisk_status(0),
+	m_betadisk_active(0)
 {
-	UINT8 betadisk_status;
-	UINT8 betadisk_active;
-
-	device_t *wd179x;
-};
-
-
-/*****************************************************************************
-    INLINE FUNCTIONS
-*****************************************************************************/
-INLINE beta_disk_state *get_safe_token(device_t *device)
-{
-	assert(device != NULL);
-	assert(device->type() == BETA_DISK);
-
-	return (beta_disk_state *)downcast<beta_disk_device *>(device)->token();
 }
 
+//-------------------------------------------------
+//  device_start - device-specific startup
+//-------------------------------------------------
 
-int betadisk_is_active(device_t *device)
+void beta_disk_device::device_start()
 {
-	beta_disk_state *beta = get_safe_token(device);
+	astring tempstring;
 
-	return beta->betadisk_active;
+	/* validate arguments */
+	assert(tag() != NULL);
+
+	/* find our WD179x */
+	tempstring.printf("%s:%s", tag(), "wd179x");
+	m_wd179x = machine().device<wd2793_device>(tempstring);
 }
 
-void betadisk_enable(device_t *device)
-{
-	beta_disk_state *beta = get_safe_token(device);
+//-------------------------------------------------
+//  device_reset - device-specific reset
+//-------------------------------------------------
 
-	beta->betadisk_active = 1;
+void beta_disk_device::device_reset()
+{
 }
 
-void betadisk_disable(device_t *device)
+int beta_disk_device::is_active()
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	beta->betadisk_active = 0;
+	return m_betadisk_active;
 }
 
-void betadisk_clear_status(device_t *device)
+void beta_disk_device::enable()
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	beta->betadisk_status = 0;
+	m_betadisk_active = 1;
 }
 
-static WRITE_LINE_DEVICE_HANDLER( betadisk_wd179x_intrq_w )
+void beta_disk_device::disable()
 {
-	beta_disk_state *beta = get_safe_token(device->owner());
+	m_betadisk_active = 0;
+}
 
+void beta_disk_device::clear_status()
+{
+	m_betadisk_status = 0;
+}
+
+WRITE_LINE_MEMBER(beta_disk_device::wd179x_intrq_w)
+{
 	if (state)
-		beta->betadisk_status |= (1<<7);
+		m_betadisk_status |= (1<<7);
 	else
-		beta->betadisk_status &=~(1<<7);
+		m_betadisk_status &=~(1<<7);
 }
 
-static WRITE_LINE_DEVICE_HANDLER( betadisk_wd179x_drq_w )
+WRITE_LINE_MEMBER(beta_disk_device::wd179x_drq_w)
 {
-	beta_disk_state *beta = get_safe_token(device->owner());
-
 	if (state)
-		beta->betadisk_status |= (1<<6);
+		m_betadisk_status |= (1<<6);
 	else
-		beta->betadisk_status &=~(1<<6);
+		m_betadisk_status &=~(1<<6);
 }
 
-static const wd17xx_interface beta_wd17xx_interface =
+READ8_MEMBER(beta_disk_device::status_r)
 {
-	DEVCB_NULL,
-	DEVCB_LINE(betadisk_wd179x_intrq_w),
-	DEVCB_LINE(betadisk_wd179x_drq_w),
-	{FLOPPY_0, FLOPPY_1, FLOPPY_2, FLOPPY_3}
-};
-
-READ8_DEVICE_HANDLER(betadisk_status_r)
-{
-	beta_disk_state *beta = get_safe_token(device);
-
-	if (beta->betadisk_active==1) {
-		return wd17xx_status_r(beta->wd179x, space, offset);
+	if (m_betadisk_active==1) {
+		return m_wd179x->status_r(space, offset);
 	} else {
 		return 0xff;
 	}
 }
 
-READ8_DEVICE_HANDLER(betadisk_track_r)
+READ8_MEMBER(beta_disk_device::track_r)
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	if (beta->betadisk_active==1) {
-		return wd17xx_track_r(beta->wd179x, space, offset);
+	if (m_betadisk_active==1) {
+		return m_wd179x->track_r(space, offset);
 	} else {
 		return 0xff;
 	}
 }
 
-READ8_DEVICE_HANDLER(betadisk_sector_r)
+READ8_MEMBER(beta_disk_device::sector_r)
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	if (beta->betadisk_active==1) {
-		return wd17xx_sector_r(beta->wd179x, space, offset);
+	if (m_betadisk_active==1) {
+		return m_wd179x->sector_r(space, offset);
 	} else {
 		return 0xff;
 	}
 }
 
-READ8_DEVICE_HANDLER(betadisk_data_r)
+READ8_MEMBER(beta_disk_device::data_r)
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	if (beta->betadisk_active==1) {
-		return wd17xx_data_r(beta->wd179x, space, offset);
+	if (m_betadisk_active==1) {
+		return m_wd179x->data_r(space, offset);
 	} else {
 		return 0xff;
 	}
 }
 
-READ8_DEVICE_HANDLER(betadisk_state_r)
+READ8_MEMBER(beta_disk_device::state_r)
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	if (beta->betadisk_active==1) {
-		return beta->betadisk_status;
+	if (m_betadisk_active==1) {
+		return m_betadisk_status;
 	} else {
 		return 0xff;
 	}
 }
 
-WRITE8_DEVICE_HANDLER(betadisk_param_w)
+WRITE8_MEMBER(beta_disk_device::param_w)
 {
-	beta_disk_state *beta = get_safe_token(device);
+	const char *floppy_tags[4] = { FLOPPY_0, FLOPPY_1, FLOPPY_2, FLOPPY_3 };
 
-	if (beta->betadisk_active==1) {
-		wd17xx_set_drive(beta->wd179x, data & 3);
-		wd17xx_set_side (beta->wd179x,(data & 0x10) ? 0 : 1 );
-		wd17xx_dden_w(beta->wd179x, !BIT(data, 5));
+	if (m_betadisk_active == 1)
+	{
+		m_wd179x->set_drive(data & 3);
+		m_wd179x->set_side ((data & 0x10) ? 0 : 1 );
+		m_wd179x->dden_w(!BIT(data, 6));
 		if ((data & 0x04) == 0) // reset
-		{
-			wd17xx_reset(beta->wd179x);
-		}
-		beta->betadisk_status = (data & 0x3f) | beta->betadisk_status;
+			m_wd179x->reset();
+
+		// bit 3 connected to pin 23 "HRDY" of FDC
+		// TEMP HACK, FDD motor and RDY FDC pin controlled by HLD pin of FDC
+		legacy_floppy_image_device *flop = subdevice<legacy_floppy_image_device>(floppy_tags[data & 3]);
+		flop->floppy_mon_w(CLEAR_LINE);
+		flop->floppy_drive_set_ready_state(1, 0);
 	}
 }
 
-WRITE8_DEVICE_HANDLER(betadisk_command_w)
+WRITE8_MEMBER(beta_disk_device::command_w)
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	if (beta->betadisk_active==1) {
-		wd17xx_command_w(beta->wd179x, space, offset, data);
+	if (m_betadisk_active==1) {
+		m_wd179x->command_w(space, offset, data);
 	}
 }
 
-WRITE8_DEVICE_HANDLER(betadisk_track_w)
+WRITE8_MEMBER(beta_disk_device::track_w)
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	if (beta->betadisk_active==1) {
-		wd17xx_track_w(beta->wd179x, space, offset, data);
+	if (m_betadisk_active==1) {
+		m_wd179x->track_w(space, offset, data);
 	}
 }
 
-WRITE8_DEVICE_HANDLER(betadisk_sector_w)
+WRITE8_MEMBER(beta_disk_device::sector_w)
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	if (beta->betadisk_active==1) {
-		wd17xx_sector_w(beta->wd179x, space, offset, data);
+	if (m_betadisk_active==1) {
+		m_wd179x->sector_w(space, offset, data);
 	}
 }
 
-WRITE8_DEVICE_HANDLER(betadisk_data_w)
+WRITE8_MEMBER(beta_disk_device::data_w)
 {
-	beta_disk_state *beta = get_safe_token(device);
-
-	if (beta->betadisk_active==1) {
-		wd17xx_data_w(beta->wd179x, space, offset, data);
+	if (m_betadisk_active==1) {
+		m_wd179x->data_w(space, offset, data);
 	}
 }
 
 static const floppy_interface beta_floppy_interface =
 {
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	DEVCB_NULL,
-	FLOPPY_STANDARD_5_25_DSHD,
+	FLOPPY_STANDARD_5_25_DSDD,
 	LEGACY_FLOPPY_OPTIONS_NAME(trd),
-	NULL,
 	NULL
 };
 
 static MACHINE_CONFIG_FRAGMENT( beta_disk )
-	MCFG_WD2793_ADD("wd179x", beta_wd17xx_interface ) // KR1818VG93
+	MCFG_DEVICE_ADD("wd179x", WD2793, 0) // KR1818VG93 clone of WD1793
+	MCFG_WD17XX_DEFAULT_DRIVE4_TAGS
+	MCFG_WD17XX_INTRQ_CALLBACK(WRITELINE(beta_disk_device, wd179x_intrq_w))
+	MCFG_WD17XX_DRQ_CALLBACK(WRITELINE(beta_disk_device, wd179x_drq_w))
+
 	MCFG_LEGACY_FLOPPY_4_DRIVES_ADD(beta_floppy_interface)
 MACHINE_CONFIG_END
 
@@ -302,48 +284,6 @@ ROM_START( beta_disk )
 ROM_END
 
 
-/*-------------------------------------------------
-    DEVICE_START( beta_disk )
--------------------------------------------------*/
-
-static DEVICE_START( beta_disk )
-{
-	beta_disk_state *beta = get_safe_token(device);
-	astring tempstring;
-
-	/* validate arguments */
-	assert(device->tag() != NULL);
-
-	/* find our WD179x */
-	tempstring.printf("%s:%s", device->tag(), "wd179x");
-	beta->wd179x = device->machine().device(tempstring);
-}
-
-const device_type BETA_DISK = &device_creator<beta_disk_device>;
-
-beta_disk_device::beta_disk_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: device_t(mconfig, BETA_DISK, "Beta Disk Interface", tag, owner, clock, "betadisk", __FILE__)
-{
-	m_token = global_alloc_clear(beta_disk_state);
-}
-
-//-------------------------------------------------
-//  device_start - device-specific startup
-//-------------------------------------------------
-
-void beta_disk_device::device_start()
-{
-	DEVICE_START_NAME( beta_disk )(this);
-}
-
-//-------------------------------------------------
-//  device_reset - device-specific reset
-//-------------------------------------------------
-
-void beta_disk_device::device_reset()
-{
-}
-
 //-------------------------------------------------
 //  device_mconfig_additions - return a pointer to
 //  the device's machine fragment
