@@ -10,7 +10,7 @@
 #include "includes/c65.h"
 #include "cpu/m6502/m4510.h"
 #include "sound/mos6581.h"
-#include "machine/6526cia.h"
+#include "machine/mos6526.h"
 #include "bus/cbmiec/cbmiec.h"
 #include "machine/ram.h"
 #include "video/vic4567.h"
@@ -375,14 +375,15 @@ UINT8 cbm_common_cia0_port_b_r( device_t *device, UINT8 output_a )
 
 ***********************************************/
 
+#if 0
 const cassette_interface cbm_cassette_interface =
 {
 	cbm_cassette_formats,
 	NULL,
 	(cassette_state) (CASSETTE_STOPPED | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_ENABLED),
-	NULL,
 	NULL
 };
+#endif
 
 
 /*UINT8 *c65_basic; */
@@ -421,17 +422,17 @@ void c65_state::c65_nmi(  )
 
 READ8_MEMBER(c65_state::c65_cia0_port_a_r)
 {
-	UINT8 cia0portb = machine().device<mos6526_device>("cia_0")->pb_r(space, 0);
+	UINT8 cia0portb = m_cia0->pb_r(space, 0);
 
-	return cbm_common_cia0_port_a_r(machine().device("cia_0"), cia0portb);
+	return cbm_common_cia0_port_a_r(m_cia0, cia0portb);
 }
 
 READ8_MEMBER(c65_state::c65_cia0_port_b_r)
 {
 	UINT8 value = 0xff;
-	UINT8 cia0porta = machine().device<mos6526_device>("cia_0")->pa_r(space, 0);
+	UINT8 cia0porta = m_cia0->pa_r(space, 0);
 
-	value &= cbm_common_cia0_port_b_r(machine().device("cia_0"), cia0porta);
+	value &= cbm_common_cia0_port_b_r(m_cia0, cia0porta);
 
 	if (!(m_6511_port & 0x02))
 		value &= m_keyline;
@@ -1001,16 +1002,13 @@ WRITE8_MEMBER( c65_state::c65_write_io )
 
 WRITE8_MEMBER( c65_state::c65_write_io_dc00 )
 {
-	device_t *cia_0 = machine().device("cia_0");
-	device_t *cia_1 = machine().device("cia_1");
-
 	switch (offset & 0xf00)
 	{
 	case 0x000:
-		mos6526_w(cia_0, space, offset, data);
+		m_cia0->write(space, offset, data);
 		break;
 	case 0x100:
-		mos6526_w(cia_1, space, offset, data);
+		m_cia1->write(space, offset, data);
 		break;
 	case 0x200:
 	case 0x300:
@@ -1064,15 +1062,12 @@ READ8_MEMBER( c65_state::c65_read_io )
 
 READ8_MEMBER( c65_state::c65_read_io_dc00 )
 {
-	device_t *cia_0 = machine().device("cia_0");
-	device_t *cia_1 = machine().device("cia_1");
-
 	switch (offset & 0x300)
 	{
 	case 0x000:
-		return mos6526_r(cia_0, space, offset);
+		return m_cia0->read(space, offset);
 	case 0x100:
-		return mos6526_r(cia_1, space, offset);
+		return m_cia1->read(space, offset);
 	case 0x200:
 	case 0x300:
 		DBG_LOG(machine(), 1, "io read", ("%.3x\n", offset+0xc00));
