@@ -57,7 +57,6 @@ DAC and bitbanger values written should be reflected in the read.
 
 #include "includes/coco.h"
 #include "cpu/m6809/m6809.h"
-#include "formats/coco_cas.h"
 #include "debug/debugcpu.h"
 
 
@@ -88,7 +87,7 @@ coco_state::coco_state(const machine_config &mconfig, device_type type, const ch
 	m_cococart(*this, CARTRIDGE_TAG),
 	m_ram(*this, RAM_TAG),
 	m_cassette(*this, "cassette"),
-	m_bitbanger(*this, BITBANGER_TAG),
+	m_rs232(*this, RS232_TAG),
 	m_vhd_0(*this, VHD0_TAG),
 	m_vhd_1(*this, VHD1_TAG)
 {
@@ -120,10 +119,10 @@ void coco_state::device_start()
 	driver_device::device_start();
 
 	/* look up keyboard ports */
-	for (int i = 0; i < sizeof(m_keyboard) / sizeof(m_keyboard[0]); i++)
+	for (int i = 0; i < ARRAY_LENGTH(m_keyboard); i++)
 	{
 		char name[32];
-		snprintf(name, sizeof(name) / sizeof(name[0]), "row%d", i);
+		snprintf(name, ARRAY_LENGTH(name), "row%d", i);
 		m_keyboard[i] =  ioport(name);
 	}
 
@@ -401,28 +400,6 @@ WRITE_LINE_MEMBER( coco_state::pia0_irq_b )
 
 
 
-//-------------------------------------------------
-//  pia0_config
-//-------------------------------------------------
-
-const pia6821_interface coco_state::pia0_config =
-{
-	DEVCB_NULL,                                                 /* port A input */
-	DEVCB_NULL,                                                 /* port B input */
-	DEVCB_NULL,                                                 /* CA1 input */
-	DEVCB_NULL,                                                 /* CB1 input */
-	DEVCB_NULL,                                                 /* CA2 input */
-	DEVCB_NULL,                                                 /* CB2 input */
-	DEVCB_DRIVER_MEMBER(coco_state, pia0_pa_w),                 /* port A output */
-	DEVCB_DRIVER_MEMBER(coco_state, pia0_pb_w),                 /* port B output */
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, pia0_ca2_w),           /* CA2 output */
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, pia0_cb2_w),           /* CB2 output */
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, pia0_irq_a),           /* IRQA output */
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, pia0_irq_b)            /* IRQB output */
-};
-
-
-
 /***************************************************************************
   PIA1 ($FF20-$FF3F) (Chip U4)
 
@@ -501,7 +478,7 @@ READ8_MEMBER( coco_state::pia1_pb_r )
 		|| (ram_size >= 0x8000 && (m_pia_0->b_output() & 0x80));
 
 	// serial in (PB0)
-	bool serial_in = (m_bitbanger != NULL) && (m_bitbanger->input() ? true : false);
+	bool serial_in = (m_rs232 != NULL) && (m_rs232->rxd_r() ? true : false);
 
 	// composite the results
 	return (memory_sense ? 0x04 : 0x00)
@@ -582,28 +559,6 @@ WRITE_LINE_MEMBER( coco_state::pia1_firq_b )
 
 
 
-//-------------------------------------------------
-//  pia1_config
-//-------------------------------------------------
-
-const pia6821_interface coco_state::pia1_config =
-{
-	DEVCB_DRIVER_MEMBER(coco_state, pia1_pa_r),                 /* port A input */
-	DEVCB_DRIVER_MEMBER(coco_state, pia1_pb_r),                 /* port B input */
-	DEVCB_NULL,                                                 /* CA1 input */
-	DEVCB_NULL,                                                 /* CB1 input */
-	DEVCB_NULL,                                                 /* CA2 input */
-	DEVCB_NULL,                                                 /* CB2 input */
-	DEVCB_DRIVER_MEMBER(coco_state, pia1_pa_w),                 /* port A output */
-	DEVCB_DRIVER_MEMBER(coco_state, pia1_pb_w),                 /* port B output */
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, pia1_ca2_w),           /* CA2 output */
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, pia1_cb2_w),           /* CB2 output */
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, pia1_firq_a),          /* IRQA output */
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, pia1_firq_b)           /* IRQB output */
-};
-
-
-
 /***************************************************************************
   CPU INTERRUPTS
 
@@ -852,7 +807,7 @@ void coco_state::poll_joystick(bool *joyin, UINT8 *buttons)
 			/* get the vertical position of the lightgun */
 			dclg_vpos = analog->input(joystick, 1);
 
-			if (machine().primary_screen->vpos() == dclg_vpos)
+			if (machine().first_screen()->vpos() == dclg_vpos)
 			{
 				/* if gun is pointing at the current scan line, set hit bit and cache horizontal timer value */
 				m_dclg_output_h |= 0x02;
@@ -864,7 +819,7 @@ void coco_state::poll_joystick(bool *joyin, UINT8 *buttons)
 			if (m_dclg_state == 7)
 			{
 				/* while in state 7, prepare to check next video frame for a hit */
-				attotime dclg_time = machine().primary_screen->time_until_pos(dclg_vpos, 0);
+				attotime dclg_time = machine().first_screen()->time_until_pos(dclg_vpos, 0);
 				m_diecom_lightgun_timer->adjust(dclg_time);
 			}
 			break;
@@ -894,7 +849,7 @@ void coco_state::poll_keyboard(void)
 	UINT8 pia0_pa_z = 0x7F;
 
 	/* poll the keyboard, and update PA6-PA0 accordingly*/
-	for (int i = 0; i < sizeof(m_keyboard) / sizeof(m_keyboard[0]); i++)
+	for (int i = 0; i < ARRAY_LENGTH(m_keyboard); i++)
 	{
 		int value = m_keyboard[i]->read();
 		if ((value | pia0_pb) != 0xFF)
@@ -1007,9 +962,9 @@ void coco_state::update_prinout(bool prinout)
 	else
 	{
 		/* output bitbanger if present (only on CoCos) */
-		if (m_bitbanger != NULL)
+		if (m_rs232 != NULL)
 		{
-			m_bitbanger->output(prinout ? 1 : 0);
+			m_rs232->write_txd(prinout ? 1 : 0);
 		}
 	}
 }
@@ -1063,42 +1018,6 @@ INPUT_CHANGED_MEMBER(coco_state::joystick_mode_changed)
 
 
 
-//-------------------------------------------------
-//  bitbanger_changed
-//-------------------------------------------------
-
-void coco_state::bitbanger_changed(bool newvalue)
-{
-	// do nothing
-}
-
-
-
-//-------------------------------------------------
-//  bitbanger_callback
-//-------------------------------------------------
-
-WRITE_LINE_MEMBER( coco_state::bitbanger_callback )
-{
-	bitbanger_changed(state ? true : false);
-}
-
-
-
-//-------------------------------------------------
-//  bitbanger_config
-//-------------------------------------------------
-
-const bitbanger_config coco_state::coco_bitbanger_config =
-{
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, bitbanger_callback),   /* callback */
-	BITBANGER_PRINTER,                                          /* default mode */
-	BITBANGER_600,                                              /* default output baud */
-	BITBANGER_0PERCENT                                          /* default fine tune adjustment */
-};
-
-
-
 //-------------------------------------------------
 //  poll_hires_joystick
 //-------------------------------------------------
@@ -1267,33 +1186,6 @@ void coco_state::cart_w(bool state)
 
 
 
-//-------------------------------------------------
-//  cartridge_config
-//-------------------------------------------------
-
-const cococart_interface coco_state::cartridge_config =
-{
-	DEVCB_DRIVER_LINE_MEMBER(coco_state, cart_w),       // coco_cart_w,
-	DEVCB_CPU_INPUT_LINE(MAINCPU_TAG, INPUT_LINE_NMI),  // coco_nmi_w,
-	DEVCB_CPU_INPUT_LINE(MAINCPU_TAG, INPUT_LINE_HALT)  // coco_halt_w
-};
-
-
-//-------------------------------------------------
-//  coco_cassette_interface
-//-------------------------------------------------
-
-const cassette_interface coco_state::coco_cassette_interface =
-{
-	coco_cassette_formats,
-	NULL,
-	(cassette_state)(CASSETTE_PLAY | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED),
-	NULL,
-	NULL
-};
-
-
-
 /***************************************************************************
   DISASSEMBLY OVERRIDE (OS9 syscalls)
  ***************************************************************************/
