@@ -37,7 +37,7 @@ const device_type FMSCSI = &device_creator<fmscsi_device>;
  */
 
 fmscsi_device::fmscsi_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: device_t(mconfig, FMSCSI, "FM-SCSI", tag, owner, clock, "fmscsi", __FILE__),
+	: legacy_scsi_host_adapter(mconfig, FMSCSI, "FM-SCSI", tag, owner, clock, "fmscsi", __FILE__),
 	m_irq_handler(*this),
 	m_drq_handler(*this)
 {
@@ -56,18 +56,6 @@ void fmscsi_device::device_start()
 	m_irq_handler.resolve_safe();
 	m_drq_handler.resolve_safe();
 
-	memset(m_SCSIdevices,0,sizeof(m_SCSIdevices));
-
-	// try to open the devices
-	for( device_t *device = owner()->first_subdevice(); device != NULL; device = device->next() )
-	{
-		scsihle_device *scsidev = dynamic_cast<scsihle_device *>(device);
-		if( scsidev != NULL )
-		{
-			m_SCSIdevices[scsidev->GetDeviceID()] = scsidev;
-		}
-	}
-
 	// allocate read timer
 	m_transfer_timer = timer_alloc(TIMER_TRANSFER);
 	m_phase_timer = timer_alloc(TIMER_PHASE);
@@ -83,6 +71,9 @@ void fmscsi_device::device_reset()
 	m_target = 0;
 	m_result_length = 0;
 	m_result_index = 0;
+	stop_transfer();
+	set_input_line(FMSCSI_LINE_INT,0);
+	m_irq_handler(0);
 
 	m_phase = SCSI_PHASE_BUS_FREE;
 }
@@ -121,6 +112,17 @@ void fmscsi_device::device_timer(emu_timer &timer, device_timer_id id, int param
 	}
 }
 
+void fmscsi_device::stop_transfer()
+{
+	m_transfer_timer->adjust(attotime::never);  // stop timer
+	m_phase_timer->adjust(attotime::from_usec(800),SCSI_PHASE_STATUS);
+	if(m_output_lines & FMSCSI_LINE_DMAE)
+	{
+		m_drq_handler(0);
+	}
+	logerror("FMSCSI: Stopping transfer : (%i/%i)\n",m_result_index,m_result_length);
+}
+
 UINT8 fmscsi_device::fmscsi_data_r(void)
 {
 	// read from data bus
@@ -133,18 +135,12 @@ UINT8 fmscsi_device::fmscsi_data_r(void)
 		//logerror("FMSCSI: DATAIN phase read data %02x\n",m_data);
 		m_result_index++;
 		if(m_result_index % 512 == 0)
-			m_SCSIdevices[m_target]->ReadData(m_buffer,512);  // read next sector
+			read_data(m_buffer,512);  // read next sector
 
 		if(m_result_index >= m_result_length)
 		{
 			// end of data transfer
-			m_transfer_timer->adjust(attotime::never);  // stop timer
-			m_phase_timer->adjust(attotime::from_usec(800),SCSI_PHASE_STATUS);
-			if(m_output_lines & FMSCSI_LINE_DMAE)
-			{
-				m_drq_handler(0);
-			}
-			logerror("FMSCSI: Stopping transfer : (%i/%i)\n",m_result_index,m_result_length);
+			stop_transfer();
 		}
 		return m_data;
 	}
@@ -159,7 +155,7 @@ UINT8 fmscsi_device::fmscsi_data_r(void)
 
 	if(m_phase == SCSI_PHASE_STATUS)
 	{
-		m_data = 0;  // GOOD status
+		m_data = get_status();
 		// no command complete message?
 		m_phase_timer->adjust(attotime::from_usec(800),SCSI_PHASE_MESSAGE_IN);
 		m_command_index = 0;
@@ -198,7 +194,7 @@ void fmscsi_device::fmscsi_data_w(UINT8 data)
 		m_buffer[m_result_index % 512] = m_data;
 		m_result_index++;
 		if(m_result_index % 512 == 0)
-			m_SCSIdevices[m_target]->WriteData(m_buffer,512);  // write buffer to disc
+			write_data(m_buffer,512);  // write buffer to disc
 		if(m_result_index >= m_result_length)
 		{
 			// end of data transfer
@@ -219,14 +215,10 @@ void fmscsi_device::fmscsi_data_w(UINT8 data)
 		if(m_command_index >= get_scsi_cmd_len(m_command[0]))
 		{
 			// command complete
-			m_SCSIdevices[m_target]->SetCommand(m_command,m_command_index);
-			m_SCSIdevices[m_target]->ExecCommand();
-			m_SCSIdevices[m_target]->GetLength(&m_result_length);
-			m_SCSIdevices[m_target]->GetPhase(&phase);
-			if(m_command[0] == 1)  // rezero unit command - not implemented in SCSI code
-				m_phase_timer->adjust(attotime::from_usec(800),SCSI_PHASE_STATUS);
-			else
-				m_phase_timer->adjust(attotime::from_usec(800),phase);
+			send_command(m_command,m_command_index);
+			m_result_length = get_length();
+			phase = legacy_scsi_host_adapter::get_phase();
+			m_phase_timer->adjust(attotime::from_usec(800),phase);
 
 			logerror("FMSCSI: Command %02x sent, result length = %i\n",m_command[0],m_result_length);
 		}
@@ -275,9 +267,9 @@ void fmscsi_device::set_phase(int phase)
 		set_input_line(FMSCSI_LINE_REQ,1);
 		// start transfer timer
 		m_transfer_timer->adjust(attotime::zero,0,attotime::from_hz(3000000));  // arbitrary value for now
-		m_SCSIdevices[m_target]->ReadData(m_buffer,512);
+		read_data(m_buffer,512);
 		m_result_index = 0;
-		logerror("FMSCSI: Starting transfer (%i)\n",m_result_length);
+		logerror("FMSCSI: Starting transfer in (%i)\n",m_result_length);
 		break;
 	case SCSI_PHASE_DATAOUT:
 		set_input_line(FMSCSI_LINE_CD,0);
@@ -287,7 +279,7 @@ void fmscsi_device::set_phase(int phase)
 		// start transfer timer
 		m_transfer_timer->adjust(attotime::zero,0,attotime::from_hz(3000000));  // arbitrary value for now
 		m_result_index = 0;
-		logerror("FMSCSI: Starting transfer (%i)\n",m_result_length);
+		logerror("FMSCSI: Starting transfer out (%i)\n",m_result_length);
 		break;
 	case SCSI_PHASE_MESSAGE_IN:
 		set_input_line(FMSCSI_LINE_CD,1);
@@ -356,9 +348,7 @@ void fmscsi_device::set_output_line(UINT8 line, UINT8 state)
 	{
 		if(state != 0 && !(m_output_lines & FMSCSI_LINE_SEL)) // low to high transition
 		{
-			void *image;
-			m_SCSIdevices[m_target]->GetDevice(&image);
-			if (image != NULL)  // if device is mounted
+			if (select(m_target))
 			{
 				m_phase_timer->adjust(attotime::from_usec(800),SCSI_PHASE_COMMAND);
 				m_data = 0x08;
