@@ -102,38 +102,38 @@ TIMER_CALLBACK_MEMBER(hec2hrp_state::Callback_CK)
 
 void hec2hrp_state::hector_minidisc_init()
 {
-	device_t *fdc = machine().device("wd179x");
+	fd1793_device *fdc = machine().device<fd1793_device>("wd179x");
 	//set density
-	wd17xx_dden_w(fdc, 1);// density select => always 1 (0 ?a plante !)
+	fdc->dden_w(1);// density select => always 1 (0 ?a plante !)
 
 	/* FDC Motor Control - Bit 0/1 defines the state of the FDD 0/1 motor */
-	floppy_mon_w(floppy_get_device(machine(), 0), 0); // Moteur floppy A:
-	//floppy_mon_w(floppy_get_device(space.machine(), 1), BIT(data, 7));   // Moteur floppy B:, not implanted on the real machine
+	floppy_get_device(machine(), 0)->floppy_mon_w( 0); // Moteur floppy A:
+	//floppy_get_device(machine(), 1)->floppy_mon_w(BIT(data, 7));   // Moteur floppy B:, not implanted on the real machine
 
 	//Set the drive ready !
-	floppy_drive_set_ready_state(floppy_get_device(machine(), 0), FLOPPY_DRIVE_READY, 0);// Disc 0 ready !
+	floppy_get_device(machine(), 0)->floppy_drive_set_ready_state(FLOPPY_DRIVE_READY, 0);// Disc 0 ready !
 
 }
 
 READ8_MEMBER(hec2hrp_state::hector_179x_register_r)
 {
 int data=0;
-device_t *fdc = machine().device("wd179x");
+fd1793_device *fdc = machine().device<fd1793_device>("wd179x");
 
 	switch (offset & 0x0ff)
 	{
 		/* minidisc floppy disc interface */
 		case 0x04:
-			data = wd17xx_status_r(fdc, space, 0);
+			data = fdc->status_r(space, 0);
 			break;
 		case 0x05:
-			data = wd17xx_track_r(fdc, space, 0);
+			data = fdc->track_r(space, 0);
 			break;
 		case 0x06:
-			data = wd17xx_sector_r(fdc, space, 0);
+			data = fdc->sector_r(space, 0);
 			break;
 		case 0x07:
-			data = wd17xx_data_r(fdc, space, 0);
+			data = fdc->data_r(space, 0);
 			break;
 		default:
 			break;
@@ -143,22 +143,22 @@ device_t *fdc = machine().device("wd179x");
 }
 WRITE8_MEMBER(hec2hrp_state::hector_179x_register_w)
 {
-device_t *fdc = machine().device("wd179x");
+fd1793_device *fdc = machine().device<fd1793_device>("wd179x");
 switch (offset)
 	{
 		/* minidisc floppy disc interface */
 		case 0x04:
-			wd17xx_command_w(fdc, space, 0, data);
+			fdc->command_w(space, 0, data);
 			break;
 		case 0x05:
-			wd17xx_track_w(fdc, space, 0, data);
+			fdc->track_w(space, 0, data);
 			break;
 		case 0x06:
-			wd17xx_sector_w(fdc, space, 0, data);
+			fdc->sector_w(space, 0, data);
 			break;
 		case 0x07:
 			/*write into command register*/
-			wd17xx_data_w(fdc, space, 0, data);
+			fdc->data_w(space, 0, data);
 			break;
 		case 0x08:
 			/*General purpose port (0x08) for the minidisk I/O */
@@ -167,11 +167,11 @@ switch (offset)
 			membank("bank2")->set_entry(BIT(data, 5) ? HECTOR_BANK_BASE : HECTOR_BANK_DISC );
 
 			// Set drive number
-			if (BIT(data, 6)) wd17xx_set_drive(fdc, 0);  // Set the correct drive number 0
-			//if (BIT(data, 7)) wd17xx_set_drive(fdc, 1);// Set the correct drive number 1,never here
+			if (BIT(data, 6)) fdc->set_drive(0);  // Set the correct drive number 0
+			//if (BIT(data, 7)) fdc->set_drive(1);// Set the correct drive number 1,never here
 
 			// Set side
-			wd17xx_set_side(fdc,BIT(data, 4) ? 1 : 0);// side select
+			fdc->set_side(BIT(data, 4) ? 1 : 0);// side select
 			}
 			break;
 
@@ -230,12 +230,11 @@ WRITE8_MEMBER(hec2hrp_state::hector_keyboard_w)
 READ8_MEMBER(hec2hrp_state::hector_keyboard_r)
 {
 	UINT8 data = 0xff;
-	static const char *const keynames[] = { "KEY0", "KEY1", "KEY2", "KEY3", "KEY4", "KEY5", "KEY6", "KEY7", "KEY8" };
 
 	if (offset ==7) /* Only when joy reading*/
 	{
 		/* Read special key for analog joystick emulation only (button and pot are analog signal!) and the reset */
-		data=ioport(keynames[8])->read();
+		data=m_keyboard[8]->read();
 
 		if (data & 0x01) /* Reset machine ! (on ESC key)*/
 		{
@@ -254,8 +253,7 @@ READ8_MEMBER(hec2hrp_state::hector_keyboard_r)
 
 				/* floppy md master reset */
 				if (isHectorWithMiniDisc())
-					wd17xx_mr_w(machine().device("wd179x"), 1);
-
+					machine().device<fd1793_device>("wd179x")->mr_w(1);
 			}
 
 			else /* aviable for BR machines */
@@ -294,7 +292,7 @@ READ8_MEMBER(hec2hrp_state::hector_keyboard_r)
 	}
 
 	/* in all case return the request value*/
-	return ioport(keynames[offset])->read();
+	return m_keyboard[offset]->read();
 }
 
 WRITE8_MEMBER(hec2hrp_state::hector_sn_2000_w)
@@ -413,7 +411,7 @@ WRITE8_MEMBER(hec2hrp_state::hector_color_a_w)
 
 WRITE8_MEMBER(hec2hrp_state::hector_color_b_w)
 {
-	device_t *discrete = machine().device("discrete");
+	discrete_device *discrete = machine().device<discrete_device>("discrete");
 	m_hector_color[1] =  data        & 0x07;
 	m_hector_color[3] = (data >> 3)  & 0x07;
 
@@ -421,7 +419,7 @@ WRITE8_MEMBER(hec2hrp_state::hector_color_b_w)
 	if (data & 0x40) m_hector_color[2] |= 8; else m_hector_color[2] &= 7;
 
 	/* Play bit*/
-	discrete_sound_w(discrete, space, NODE_01,  (data & 0x80) ? 0:1 );
+	discrete->write(space, NODE_01,  (data & 0x80) ? 0:1 );
 }
 
 
