@@ -121,44 +121,6 @@ extern TIMER_CALLBACK(mac_pmu_tick);    // macadb.c
 
 static offs_t mac_dasm_override(device_t &device, char *buffer, offs_t pc, const UINT8 *oprom, const UINT8 *opram, int options);
 
-const via6522_interface mac_via6522_intf =
-{
-	DEVCB_DRIVER_MEMBER(mac_state,mac_via_in_a), DEVCB_DRIVER_MEMBER(mac_state,mac_via_in_b),
-	DEVCB_NULL, DEVCB_NULL,
-
-#ifdef MAC_USE_EMULATED_KBD
-	DEVCB_NULL, DEVCB_DRIVER_MEMBER(mac_state,mac_via_in_cb2),
-#else
-	DEVCB_NULL, DEVCB_NULL,
-#endif
-	DEVCB_DRIVER_MEMBER(mac_state,mac_via_out_a), DEVCB_DRIVER_MEMBER(mac_state,mac_via_out_b),
-	DEVCB_NULL, DEVCB_NULL,
-	DEVCB_NULL, DEVCB_DRIVER_MEMBER(mac_state,mac_via_out_cb2),
-	DEVCB_DRIVER_LINE_MEMBER(mac_state,mac_via_irq)
-};
-
-const via6522_interface mac_via6522_adb_intf =
-{
-	DEVCB_DRIVER_MEMBER(mac_state,mac_via_in_a), DEVCB_DRIVER_MEMBER(mac_state,mac_via_in_b),
-	DEVCB_NULL, DEVCB_NULL,
-	DEVCB_NULL, DEVCB_DRIVER_MEMBER(mac_state,mac_adb_via_in_cb2),
-	DEVCB_DRIVER_MEMBER(mac_state,mac_via_out_a), DEVCB_DRIVER_MEMBER(mac_state,mac_via_out_b),
-	DEVCB_NULL, DEVCB_NULL,
-	DEVCB_NULL, DEVCB_DRIVER_MEMBER(mac_state,mac_adb_via_out_cb2),
-	DEVCB_DRIVER_LINE_MEMBER(mac_state,mac_via_irq)
-};
-
-const via6522_interface mac_via6522_2_intf =
-{
-	DEVCB_DRIVER_MEMBER(mac_state,mac_via2_in_a), DEVCB_DRIVER_MEMBER(mac_state,mac_via2_in_b),
-	DEVCB_NULL, DEVCB_NULL,
-	DEVCB_NULL, DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(mac_state,mac_via2_out_a), DEVCB_DRIVER_MEMBER(mac_state,mac_via2_out_b),
-	DEVCB_NULL, DEVCB_NULL,
-	DEVCB_NULL, DEVCB_NULL,
-	DEVCB_DRIVER_LINE_MEMBER(mac_state,mac_via2_irq)
-};
-
 // returns non-zero if this Mac has ADB
 int mac_state::has_adb()
 {
@@ -280,9 +242,9 @@ void mac_state::field_interrupts()
 	}
 }
 
-void mac_state::set_scc_interrupt(bool value)
+WRITE_LINE_MEMBER(mac_state::set_scc_interrupt)
 {
-	m_scc_interrupt = value;
+	m_scc_interrupt = state;
 	this->field_interrupts();
 }
 
@@ -671,20 +633,15 @@ void mac_state::keyboard_init()
 
 /******************* Keyboard <-> VIA communication ***********************/
 
+#ifdef MAC_USE_EMULATED_KBD
+
 WRITE_LINE_MEMBER(mac_state::mac_kbd_clk_in)
 {
 	printf("CLK: %d\n", state^1);
 	m_via1->write_cb1(state ? 0 : 1);
 }
 
-#ifdef MAC_USE_EMULATED_KBD
-READ8_MEMBER(mac_state::mac_via_in_cb2)
-{
-	printf("Read %d from keyboard (PC=%x)\n", (m_mackbd->data_r() == ASSERT_LINE) ? 1 : 0, m_maincpu->pc());
-	return (m_mackbd->data_r() == ASSERT_LINE) ? 1 : 0;
-}
-
-WRITE8_MEMBER(mac_state::mac_via_out_cb2)
+WRITE_LINE_MEMBER(mac_state::mac_via_out_cb2)
 {
 	printf("Sending %d to kbd (PC=%x)\n", data, m_maincpu->pc());
 	m_mackbd->data_w((data & 1) ? ASSERT_LINE : CLEAR_LINE);
@@ -730,9 +687,9 @@ void mac_state::kbd_shift_out(int data)
 	}
 }
 
-WRITE8_MEMBER(mac_state::mac_via_out_cb2)
+WRITE_LINE_MEMBER(mac_state::mac_via_out_cb2)
 {
-	if (m_kbd_comm == FALSE && data == 0)
+	if (m_kbd_comm == FALSE && state == 0)
 	{
 		/* Mac pulls CB2 down to initiate communication */
 		m_kbd_comm = TRUE;
@@ -742,7 +699,7 @@ WRITE8_MEMBER(mac_state::mac_via_out_cb2)
 	if (m_kbd_comm == TRUE && m_kbd_receive == TRUE)
 	{
 		/* Shift in what mac is sending */
-		m_kbd_shift_reg = (m_kbd_shift_reg & ~1) | data;
+		m_kbd_shift_reg = (m_kbd_shift_reg & ~1) | state;
 	}
 }
 
@@ -1166,49 +1123,23 @@ WRITE16_MEMBER ( mac_state::mac_iwm_w )
 		fdc->write((offset >> 8), data>>8);
 }
 
-READ8_MEMBER(mac_state::mac_adb_via_in_cb2)
+WRITE_LINE_MEMBER(mac_state::mac_adb_via_out_cb2)
 {
-	UINT8 ret;
+//        printf("VIA OUT CB2 = %x\n", state);
 	if (ADB_IS_EGRET)
 	{
-		ret = m_egret->get_via_data();
-		#if LOG_ADB
-		printf("68K: Read VIA_DATA %x\n", ret);
-		#endif
+		m_egret->set_via_data(state & 1);
 	}
 	else if (ADB_IS_CUDA)
 	{
-		ret = m_cuda->get_via_data();
-		#if LOG_ADB
-		printf("68K: Read VIA_DATA %x\n", ret);
-		#endif
+		m_cuda->set_via_data(state & 1);
 	}
 	else
 	{
-		ret = (m_adb_send & 0x80)>>7;
-		m_adb_send <<= 1;
-	}
-
-//  printf("VIA IN CB2 = %x\n", ret);
-
-	return ret;
-}
-
-WRITE8_MEMBER(mac_state::mac_adb_via_out_cb2)
-{
-//        printf("VIA OUT CB2 = %x\n", data);
-	if (ADB_IS_EGRET)
-	{
-		m_egret->set_via_data(data & 1);
-	}
-	else if (ADB_IS_CUDA)
-	{
-		m_cuda->set_via_data(data & 1);
-	}
-	else
-	{
-		m_adb_command <<= 1;
-		m_adb_command |= data & 1;
+		if (state)
+			m_adb_command |= 1;
+		else
+			m_adb_command &= ~1;
 	}
 }
 
@@ -1254,13 +1185,6 @@ READ8_MEMBER(mac_state::mac_via_in_a)
 
 	switch (m_model)
 	{
-		case MODEL_MAC_PORTABLE:
-		case MODEL_MAC_PB100:
-			#if LOG_ADB
-//          printf("Read PM data %x\n", m_pm_data_recv);
-			#endif
-			return m_pm_data_recv;
-
 		case MODEL_MAC_CLASSIC:
 		case MODEL_MAC_II:
 		case MODEL_MAC_II_FDHD:
@@ -1313,57 +1237,55 @@ READ8_MEMBER(mac_state::mac_via_in_a)
 	return 0x80;
 }
 
+READ8_MEMBER(mac_state::mac_via_in_a_pmu)
+{
+//  printf("VIA1 IN_A (PC %x)\n", m_maincpu->safe_pc());
+
+	#if LOG_ADB
+//  printf("Read PM data %x\n", m_pm_data_recv);
+	#endif
+	return m_pm_data_recv;
+}
+
 READ8_MEMBER(mac_state::mac_via_in_b)
 {
 	int val = 0;
-	// portable/PB100 is pretty different
-	if (m_model >= MODEL_MAC_PORTABLE && m_model <= MODEL_MAC_PB100)
+	/* video beam in display (! VBLANK && ! HBLANK basically) */
+	if (machine().first_screen())
 	{
-//      printf("Read VIA B: PM_ACK %x\n", m_pm_ack);
-		val = 0x80 | 0x04 | m_pm_ack;   // SCC wait/request (bit 2 must be set at 900c1a or startup tests always fail)
+		if (machine().first_screen()->vpos() >= MAC_V_VIS)
+			val |= 0x40;
+	}
+
+	if (ADB_IS_BITBANG_CLASS)
+	{
+		val |= m_adb_state<<4;
+
+		if (!m_adb_irq_pending)
+		{
+			val |= 0x08;
+		}
+
+		val |= m_rtc->data_r();
+	}
+	else if (ADB_IS_EGRET)
+	{
+		val |= m_egret->get_xcvr_session()<<3;
+	}
+	else if (ADB_IS_CUDA)
+	{
+		val |= m_cuda->get_treq()<<3;
 	}
 	else
 	{
-		/* video beam in display (! VBLANK && ! HBLANK basically) */
-		if (machine().primary_screen)
-		{
-			if (machine().primary_screen->vpos() >= MAC_V_VIS)
-				val |= 0x40;
-		}
+		if (m_mouse_bit_y)  /* Mouse Y2 */
+			val |= 0x20;
+		if (m_mouse_bit_x)  /* Mouse X2 */
+			val |= 0x10;
+		if ((m_mouse0->read() & 0x01) == 0)
+			val |= 0x08;
 
-		if (ADB_IS_BITBANG_CLASS)
-		{
-			val |= m_adb_state<<4;
-
-			if (!m_adb_irq_pending)
-			{
-				val |= 0x08;
-			}
-
-			val |= m_rtc->data_r();
-		}
-		else if (ADB_IS_EGRET)
-		{
-			val |= m_egret->get_xcvr_session()<<3;
-		}
-		else if (ADB_IS_CUDA)
-		{
-			val |= m_cuda->get_treq()<<3;
-		}
-		else
-		{
-			if (m_mouse_bit_y)  /* Mouse Y2 */
-				val |= 0x20;
-			if (m_mouse_bit_x)  /* Mouse X2 */
-				val |= 0x10;
-			if ((m_mouse0->read() & 0x01) == 0)
-				val |= 0x08;
-
-			if (!ADB_IS_PM_CLASS)
-			{
-				val |= m_rtc->data_r();
-			}
-		}
+		val |= m_rtc->data_r();
 	}
 
 //  printf("VIA1 IN_B = %02x (PC %x)\n", val, m_maincpu->safe_pc());
@@ -1371,21 +1293,39 @@ READ8_MEMBER(mac_state::mac_via_in_b)
 	return val;
 }
 
+READ8_MEMBER(mac_state::mac_via_in_b_via2pmu)
+{
+	int val = 0;
+	// TODO: is this valid for VIA2 PMU machines?
+	/* video beam in display (! VBLANK && ! HBLANK basically) */
+	if (machine().first_screen())
+	{
+		if (machine().first_screen()->vpos() >= MAC_V_VIS)
+			val |= 0x40;
+	}
+
+//  printf("VIA1 IN_B = %02x (PC %x)\n", val, m_maincpu->safe_pc());
+
+	return val;
+}
+
+READ8_MEMBER(mac_state::mac_via_in_b_pmu)
+{
+	int val = 0;
+//  printf("Read VIA B: PM_ACK %x\n", m_pm_ack);
+	val = 0x80 | 0x04 | m_pm_ack;   // SCC wait/request (bit 2 must be set at 900c1a or startup tests always fail)
+
+//  printf("VIA1 IN_B = %02x (PC %x)\n", val, m_maincpu->safe_pc());
+
+	return val;
+}
+
 WRITE8_MEMBER(mac_state::mac_via_out_a)
 {
 	mac_sound_device *sound = machine().device<mac_sound_device>("custom");
 	device_t *fdc = machine().device("fdc");
 //  printf("VIA1 OUT A: %02x (PC %x)\n", data, m_maincpu->safe_pc());
 
-	if (ADB_IS_PM_VIA1)
-	{
-		#if LOG_ADB
-//      printf("%02x to PM\n", data);
-		#endif
-		m_pm_data_send = data;
-		return;
-	}
-
 	set_scc_waitrequest((data & 0x80) >> 7);
 	m_screen_buffer = (data & 0x40) >> 6;
 	sony_set_sel_line(fdc,(data & 0x20) >> 5);
@@ -1413,80 +1353,36 @@ WRITE8_MEMBER(mac_state::mac_via_out_a)
 	}
 }
 
+WRITE8_MEMBER(mac_state::mac_via_out_a_pmu)
+{
+//  printf("VIA1 OUT A: %02x (PC %x)\n", data, m_maincpu->safe_pc());
+
+	#if LOG_ADB
+//  printf("%02x to PM\n", data);
+	#endif
+	m_pm_data_send = data;
+	return;
+}
+
 WRITE8_MEMBER(mac_state::mac_via_out_b)
 {
 	mac_sound_device *sound = machine().device<mac_sound_device>("custom");
 //  printf("VIA1 OUT B: %02x (PC %x)\n", data, m_maincpu->safe_pc());
 
-	if (ADB_IS_PM_VIA1)
-	{
-		device_t *fdc = machine().device("fdc");
-
-		sony_set_sel_line(fdc,(data & 0x20) >> 5);
-		m_drive_select = ((data & 0x10) >> 4);
-
-		if ((data & 1) && !(m_pm_req & 1))
-		{
-			#if LOG_ADB
-			printf("PM: 68k dropping /REQ\n");
-			#endif
-
-			if (m_pm_state == 0)     // do this in receive state only
-			{
-				m_pm_data_recv = 0xff;
-				m_pm_ack |= 2;
-
-				// check if length byte matches
-				if ((m_pm_dptr >= 2) && (m_pm_cmd[1] == (m_pm_dptr-2)))
-				{
-					pmu_exec();
-					#if LOG_ADB
-					printf("PMU exec: command %02x length %d\n", m_pm_cmd[0], m_pm_cmd[1]);
-					#endif
-				}
-			}
-		}
-		else if (!(data & 1) && (m_pm_req & 1))
-		{
-			if (m_pm_state == 0)
-			{
-				#if LOG_ADB
-				printf("PM: 68k asserting /REQ, clocking in byte [%d] = %02x\n", m_pm_dptr, m_pm_data_send);
-				#endif
-				m_pm_ack &= ~2; // clear, we're waiting for more bytes
-				m_pm_cmd[m_pm_dptr++] = m_pm_data_send;
-			}
-			else    // receiving, so this is different
-			{
-				m_pm_data_recv = m_pm_out[m_pm_sptr++];
-				m_pm_slen--;
-				m_pm_ack |= 2;  // raise ACK to indicate available byte
-				#if LOG_ADB
-				printf("PM: 68k asserted /REQ, sending byte %02x\n", m_pm_data_recv);
-				#endif
-
-				// another byte to send?
-				if (m_pm_slen)
-				{
-					m_pmu_send_timer->adjust(attotime(0, ATTOSECONDS_IN_USEC(100)));
-				}
-				else
-				{
-					m_pm_state = 0; // back to receive state
-					m_pmu_send_timer->adjust(attotime::never);
-				}
-			}
-		}
-
-		m_pm_req = data & 1;
-		return;
-	}
-
 	if (AUDIO_IS_CLASSIC)
 	{
 		sound->enable_sound((data & 0x80) == 0);
 	}
 
+	m_rtc->ce_w((data & 0x04)>>2);
+	m_rtc->data_w(data & 0x01);
+	m_rtc->clk_w((data >> 1) & 0x01);
+}
+
+WRITE8_MEMBER(mac_state::mac_via_out_b_bbadb)
+{
+//  printf("VIA1 OUT B: %02x (PC %x)\n", data, m_maincpu->safe_pc());
+
 	// SE and Classic have SCSI enable/disable here
 	if ((m_model == MODEL_MAC_SE) || (m_model == MODEL_MAC_CLASSIC))
 	{
@@ -1506,36 +1402,103 @@ WRITE8_MEMBER(mac_state::mac_via_out_b)
 		}
 	}
 
-	if (ADB_IS_BITBANG_CLASS)
-	{
-		mac_adb_newaction((data & 0x30) >> 4);
+	mac_adb_newaction((data & 0x30) >> 4);
 
-		m_rtc->ce_w((data & 0x04)>>2);
-		m_rtc->data_w(data & 0x01);
-		m_rtc->clk_w((data >> 1) & 0x01);
-	}
-	else if (ADB_IS_EGRET)
+	m_rtc->ce_w((data & 0x04)>>2);
+	m_rtc->data_w(data & 0x01);
+	m_rtc->clk_w((data >> 1) & 0x01);
+}
+
+WRITE8_MEMBER(mac_state::mac_via_out_b_egadb)
+{
+//  printf("VIA1 OUT B: %02x (PC %x)\n", data, m_maincpu->safe_pc());
+
+	#if LOG_ADB
+	printf("68K: New Egret state: SS %d VF %d (PC %x)\n", (data>>5)&1, (data>>4)&1, space.device().safe_pc());
+	#endif
+	m_egret->set_via_full((data&0x10) ? 1 : 0);
+	m_egret->set_sys_session((data&0x20) ? 1 : 0);
+}
+
+WRITE8_MEMBER(mac_state::mac_via_out_b_cdadb)
+{
+//  printf("VIA1 OUT B: %02x (PC %x)\n", data, m_maincpu->safe_pc());
+
+	#if LOG_ADB
+	printf("68K: New Cuda state: TIP %d BYTEACK %d (PC %x)\n", (data>>5)&1, (data>>4)&1, space.device().safe_pc());
+	#endif
+	m_cuda->set_byteack((data&0x10) ? 1 : 0);
+	m_cuda->set_tip((data&0x20) ? 1 : 0);
+}
+
+WRITE8_MEMBER(mac_state::mac_via_out_b_via2pmu)
+{
+//  printf("VIA1 OUT B: %02x (PC %x)\n", data, m_maincpu->safe_pc());
+}
+
+WRITE8_MEMBER(mac_state::mac_via_out_b_pmu)
+{
+//  printf("VIA1 OUT B: %02x (PC %x)\n", data, m_maincpu->safe_pc());
+
+	device_t *fdc = machine().device("fdc");
+
+	sony_set_sel_line(fdc,(data & 0x20) >> 5);
+	m_drive_select = ((data & 0x10) >> 4);
+
+	if ((data & 1) && !(m_pm_req & 1))
 	{
 		#if LOG_ADB
-		printf("68K: New Egret state: SS %d VF %d (PC %x)\n", (data>>5)&1, (data>>4)&1, space.device().safe_pc());
+		printf("PM: 68k dropping /REQ\n");
 		#endif
-		m_egret->set_via_full((data&0x10) ? 1 : 0);
-		m_egret->set_sys_session((data&0x20) ? 1 : 0);
+
+		if (m_pm_state == 0)     // do this in receive state only
+		{
+			m_pm_data_recv = 0xff;
+			m_pm_ack |= 2;
+
+			// check if length byte matches
+			if ((m_pm_dptr >= 2) && (m_pm_cmd[1] == (m_pm_dptr-2)))
+			{
+				pmu_exec();
+				#if LOG_ADB
+				printf("PMU exec: command %02x length %d\n", m_pm_cmd[0], m_pm_cmd[1]);
+				#endif
+			}
+		}
 	}
-	else if (ADB_IS_CUDA)
+	else if (!(data & 1) && (m_pm_req & 1))
 	{
-		#if LOG_ADB
-		printf("68K: New Cuda state: TIP %d BYTEACK %d (PC %x)\n", (data>>5)&1, (data>>4)&1, space.device().safe_pc());
-		#endif
-		m_cuda->set_byteack((data&0x10) ? 1 : 0);
-		m_cuda->set_tip((data&0x20) ? 1 : 0);
-	}
-	else if (!ADB_IS_PM_CLASS)
-	{
-		m_rtc->ce_w((data & 0x04)>>2);
-		m_rtc->data_w(data & 0x01);
-		m_rtc->clk_w((data >> 1) & 0x01);
+		if (m_pm_state == 0)
+		{
+			#if LOG_ADB
+			printf("PM: 68k asserting /REQ, clocking in byte [%d] = %02x\n", m_pm_dptr, m_pm_data_send);
+			#endif
+			m_pm_ack &= ~2; // clear, we're waiting for more bytes
+			m_pm_cmd[m_pm_dptr++] = m_pm_data_send;
+		}
+		else    // receiving, so this is different
+		{
+			m_pm_data_recv = m_pm_out[m_pm_sptr++];
+			m_pm_slen--;
+			m_pm_ack |= 2;  // raise ACK to indicate available byte
+			#if LOG_ADB
+			printf("PM: 68k asserted /REQ, sending byte %02x\n", m_pm_data_recv);
+			#endif
+
+			// another byte to send?
+			if (m_pm_slen)
+			{
+				m_pmu_send_timer->adjust(attotime(0, ATTOSECONDS_IN_USEC(100)));
+			}
+			else
+			{
+				m_pm_state = 0; // back to receive state
+				m_pmu_send_timer->adjust(attotime::never);
+			}
+		}
 	}
+
+	m_pm_req = data & 1;
 }
 
 WRITE_LINE_MEMBER(mac_state::mac_via_irq)
@@ -1577,7 +1540,7 @@ WRITE16_MEMBER ( mac_state::mac_via_w )
 }
 
 /* *************************************************************************
- * VIA 2 (on Mac IIs and PowerMacs)
+ * VIA 2 (on Mac IIs, PowerBooks > 100, and PowerMacs)
  * *************************************************************************/
 
 WRITE_LINE_MEMBER(mac_state::mac_via2_irq)
@@ -1618,11 +1581,8 @@ WRITE16_MEMBER ( mac_state::mac_via2_w )
 READ8_MEMBER(mac_state::mac_via2_in_a)
 {
 	UINT8 result;
-	if (ADB_IS_PM_VIA2)
-	{
-		result = m_pm_data_recv;
-	}
-	else if ((m_model == MODEL_MAC_QUADRA_700) || (m_model == MODEL_MAC_QUADRA_900) || (m_model == MODEL_MAC_QUADRA_950))
+
+	if ((m_model == MODEL_MAC_QUADRA_700) || (m_model == MODEL_MAC_QUADRA_900) || (m_model == MODEL_MAC_QUADRA_950))
 	{
 		result = 0x80 | m_nubus_irq_state;
 	}
@@ -1634,22 +1594,15 @@ READ8_MEMBER(mac_state::mac_via2_in_a)
 	return result;
 }
 
+READ8_MEMBER(mac_state::mac_via2_in_a_pmu)
+{
+	return m_pm_data_recv;
+}
+
 READ8_MEMBER(mac_state::mac_via2_in_b)
 {
 //  logerror("VIA2 IN B (PC %x)\n", m_maincpu->safe_pc());
 
-	if (ADB_IS_PM_VIA2)
-	{
-		if (m_pm_ack == 2)
-		{
-			return 0xcf;
-		}
-		else
-		{
-			return 0xcd;
-		}
-	}
-
 	if ((m_model == MODEL_MAC_LC) || (m_model == MODEL_MAC_LC_II) || (m_model == MODEL_MAC_CLASSIC_II))
 	{
 		return 0x4f;
@@ -1663,91 +1616,105 @@ READ8_MEMBER(mac_state::mac_via2_in_b)
 	return 0xcf;        // indicate no NuBus transaction error
 }
 
+READ8_MEMBER(mac_state::mac_via2_in_b_pmu)
+{
+//  logerror("VIA2 IN B (PC %x)\n", m_maincpu->safe_pc());
+
+	if (m_pm_ack == 2)
+	{
+		return 0xcf;
+	}
+	else
+	{
+		return 0xcd;
+	}
+}
+
 WRITE8_MEMBER(mac_state::mac_via2_out_a)
 {
 //  logerror("VIA2 OUT A: %02x (PC %x)\n", data, m_maincpu->safe_pc());
-	if (ADB_IS_PM_VIA2)
-	{
-		m_pm_data_send = data;
-		return;
-	}
+}
+
+WRITE8_MEMBER(mac_state::mac_via2_out_a_pmu)
+{
+//  logerror("VIA2 OUT A: %02x (PC %x)\n", data, m_maincpu->safe_pc());
+	m_pm_data_send = data;
 }
 
 WRITE8_MEMBER(mac_state::mac_via2_out_b)
 {
 //  logerror("VIA2 OUT B: %02x (PC %x)\n", data, m_maincpu->safe_pc());
 
-	if (ADB_IS_PM_VIA2)
-	{
-		if ((data & 4) && !(m_pm_req & 4))
-		{
-			#if LOG_ADB
-			printf("PM: 68k dropping /REQ\n");
-			#endif
-
-			if (m_pm_state == 0)     // do this in receive state only
-			{
-				m_pm_data_recv = 0xff;
-				m_pm_ack |= 2;
-
-				// check if length byte matches
-				if ((m_pm_dptr >= 2) && (m_pm_cmd[1] == (m_pm_dptr-2)))
-				{
-					pmu_exec();
-					#if LOG_ADB
-					printf("PMU exec: command %02x length %d\n", m_pm_cmd[0], m_pm_cmd[1]);
-					#endif
-				}
-			}
-		}
-		else if (!(data & 4) && (m_pm_req & 4))
-		{
-			if (m_pm_state == 0)
-			{
-				#if LOG_ADB
-				printf("PM: 68k asserting /REQ, clocking in byte [%d] = %02x\n", m_pm_dptr, m_pm_data_send);
-				#endif
-				m_pm_ack &= ~2; // clear, we're waiting for more bytes
-				m_pm_cmd[m_pm_dptr++] = m_pm_data_send;
-			}
-			else    // receiving, so this is different
-			{
-				m_pm_data_recv = m_pm_out[m_pm_sptr++];
-				m_pm_slen--;
-				m_pm_ack |= 2;  // raise ACK to indicate available byte
-				#if LOG_ADB
-				printf("PM: 68k asserted /REQ, sending byte %02x\n", m_pm_data_recv);
-				#endif
-
-				// another byte to send?
-				if (m_pm_slen)
-				{
-					m_pmu_send_timer->adjust(attotime(0, ATTOSECONDS_IN_USEC(100)));
-				}
-				else
-				{
-					m_pm_state = 0; // back to receive state
-					m_pmu_send_timer->adjust(attotime::never);
-				}
-			}
-		}
-
-		m_pm_req = data & 4;
-		return;
-	}
-	else
-	{
-		// chain 60.15 Hz to VIA1
-		m_via1->write_ca1(data>>7);
-	}
+	// chain 60.15 Hz to VIA1
+	m_via1->write_ca1(data>>7);
 
 	if (m_model == MODEL_MAC_II)
 	{
 		m68000_base_device *m68k = downcast<m68000_base_device *>(m_maincpu.target());
-		m68k_set_hmmu_enable(m68k, (data & 0x8) ? M68K_HMMU_DISABLE : M68K_HMMU_ENABLE_II);
+		m68k->set_hmmu_enable((data & 0x8) ? M68K_HMMU_DISABLE : M68K_HMMU_ENABLE_II);
 	}
 }
 
+WRITE8_MEMBER(mac_state::mac_via2_out_b_pmu)
+{
+//  logerror("VIA2 OUT B PMU: %02x (PC %x)\n", data, m_maincpu->pc());
+
+	if ((data & 4) && !(m_pm_req & 4))
+	{
+		#if LOG_ADB
+		printf("PM: 68k dropping /REQ\n");
+		#endif
+
+		if (m_pm_state == 0)     // do this in receive state only
+		{
+			m_pm_data_recv = 0xff;
+			m_pm_ack |= 2;
+
+			// check if length byte matches
+			if ((m_pm_dptr >= 2) && (m_pm_cmd[1] == (m_pm_dptr-2)))
+			{
+				pmu_exec();
+				#if LOG_ADB
+				printf("PMU exec: command %02x length %d\n", m_pm_cmd[0], m_pm_cmd[1]);
+				#endif
+			}
+		}
+	}
+	else if (!(data & 4) && (m_pm_req & 4))
+	{
+		if (m_pm_state == 0)
+		{
+			#if LOG_ADB
+			printf("PM: 68k asserting /REQ, clocking in byte [%d] = %02x\n", m_pm_dptr, m_pm_data_send);
+			#endif
+			m_pm_ack &= ~2; // clear, we're waiting for more bytes
+			m_pm_cmd[m_pm_dptr++] = m_pm_data_send;
+		}
+		else    // receiving, so this is different
+		{
+			m_pm_data_recv = m_pm_out[m_pm_sptr++];
+			m_pm_slen--;
+			m_pm_ack |= 2;  // raise ACK to indicate available byte
+			#if LOG_ADB
+			printf("PM: 68k asserted /REQ, sending byte %02x\n", m_pm_data_recv);
+			#endif
+
+			// another byte to send?
+			if (m_pm_slen)
+			{
+				m_pmu_send_timer->adjust(attotime(0, ATTOSECONDS_IN_USEC(100)));
+			}
+			else
+			{
+				m_pm_state = 0; // back to receive state
+				m_pmu_send_timer->adjust(attotime::never);
+			}
+		}
+	}
+
+	m_pm_req = data & 4;
+}
+
 // This signal is generated internally on RBV, V8, Sonora, VASP, Eagle, etc.
 TIMER_CALLBACK_MEMBER(mac_state::mac_6015_tick)
 {
@@ -1773,13 +1740,12 @@ void mac_state::machine_start()
 			this->m_adb_timer->adjust(attotime::never);
 			m_pmu_int_status = 0;
 		}
-
 	}
 
-	if (machine().primary_screen)
+	if (machine().first_screen())
 	{
 		this->m_scanline_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(mac_state::mac_scanline_tick),this));
-		this->m_scanline_timer->adjust(machine().primary_screen->time_until_pos(0, 0));
+		this->m_scanline_timer->adjust(machine().first_screen()->time_until_pos(0, 0));
 	}
 
 	m_6015_timer = machine().scheduler().timer_alloc(timer_expired_delegate(FUNC(mac_state::mac_6015_tick),this));
@@ -1860,7 +1826,7 @@ void mac_state::machine_reset()
 	if (m_model == MODEL_MAC_LC)
 	{
 		m68000_base_device *m68k = downcast<m68000_base_device *>(m_maincpu.target());
-		m68k_set_hmmu_enable(m68k, M68K_HMMU_DISABLE);
+		m68k->set_hmmu_enable(M68K_HMMU_DISABLE);
 	}
 
 	m_last_taken_interrupt = -1;
@@ -1882,6 +1848,7 @@ void mac_state::machine_reset()
 	}
 	else if (MAC_HAS_VIA2)  // prime CB1 for ASC and slot interrupts
 	{
+		m_via2_ca1_hack = 1;
 		m_via2->write_ca1(1);
 		m_via2->write_cb1(1);
 	}
@@ -2153,14 +2120,16 @@ void mac_state::nubus_slot_interrupt(UINT8 slot, UINT32 state)
 		if ((m_nubus_irq_state & mask) != mask)
 		{
 			// HACK: sometimes we miss an ack (possible misbehavior in the VIA?)
-			if (m_via2->read_ca1() == 0)
+			if (m_via2_ca1_hack == 0)
 			{
 				m_via2->write_ca1(1);
 			}
+			m_via2_ca1_hack = 0;
 			m_via2->write_ca1(0);
 		}
 		else
 		{
+			m_via2_ca1_hack = 1;
 			m_via2->write_ca1(1);
 		}
 	}
@@ -2249,7 +2218,7 @@ TIMER_CALLBACK_MEMBER(mac_state::mac_scanline_tick)
 		}
 	}
 
-	scanline = machine().primary_screen->vpos();
+	scanline = machine().first_screen()->vpos();
 	if (scanline == MAC_V_VIS)
 		vblank_irq();
 
@@ -2260,7 +2229,7 @@ TIMER_CALLBACK_MEMBER(mac_state::mac_scanline_tick)
 			mouse_callback();
 	}
 
-	m_scanline_timer->adjust(machine().primary_screen->time_until_pos((scanline+1) % MAC_V_TOTAL, 0));
+	m_scanline_timer->adjust(machine().first_screen()->time_until_pos((scanline+1) % MAC_V_TOTAL, 0));
 }
 
 WRITE_LINE_MEMBER(mac_state::nubus_irq_9_w)
