@@ -611,6 +611,17 @@ TIMER_CALLBACK(mac_adb_tick)
 		// do one clock transition on CB1 to advance the VIA shifter
 		mac->m_adb_extclock ^= 1;
 		mac->m_via1->write_cb1(mac->m_adb_extclock);
+
+		if (mac->m_adb_direction)
+		{
+			mac->m_adb_command <<= 1;
+		}
+		else
+		{
+			mac->m_via1->write_cb2((mac->m_adb_send & 0x80)>>7);
+			mac->m_adb_send <<= 1;
+		}
+
 		mac->m_adb_extclock ^= 1;
 		mac->m_via1->write_cb1(mac->m_adb_extclock);
 
