@@ -201,6 +201,14 @@ void pce_cd_device::device_reset()
 	m_regs[0x0c] &= ~PCE_CD_ADPCM_PLAY_FLAG;
 	//m_regs[0x03] = (m_regs[0x03] & ~0x0c) | (PCE_CD_SAMPLE_STOP_PLAY);
 	m_msm_idle = 1;
+
+	m_scsi_RST = 0;
+	m_scsi_last_RST = 0;
+	m_scsi_SEL = 0;
+	m_scsi_BSY = 0;
+	m_selected = 0;
+	m_scsi_ATN = 0;
+	m_end_mark = 0;
 }
 
 
@@ -221,29 +229,18 @@ void pce_cd_device::late_setup()
 	m_msm->change_clock_w((PCE_CD_CLOCK / 6) / m_adpcm_clock_divider);
 }
 
-struct cdrom_interface pce_cdrom =
-{
-	"pce_cdrom",
-	NULL
-};
-
-static const msm5205_interface pce_cd_msm5205_interface =
-{
-	DEVCB_DEVICE_LINE_MEMBER(DEVICE_SELF_OWNER, pce_cd_device, msm5205_int), /* interrupt function */
-	MSM5205_S48_4B      /* 1/48 prescaler, 4bit data */
-};
-
-
 // TODO: left and right speaker tags should be passed from the parent config, instead of using the hard-coded ones below!?!
 static MACHINE_CONFIG_FRAGMENT( pce_cd )
 	MCFG_NVRAM_ADD_0FILL("bram")
 
-	MCFG_CDROM_ADD("cdrom", pce_cdrom)
+	MCFG_CDROM_ADD("cdrom")
+	MCFG_CDROM_INTERFACE("pce_cdrom")
 
 	MCFG_SOUND_ADD( "msm5205", MSM5205, PCE_CD_CLOCK / 6 )
-	MCFG_SOUND_CONFIG( pce_cd_msm5205_interface )
-	MCFG_SOUND_ROUTE( ALL_OUTPUTS, "^:lspeaker", 0.00 )
-	MCFG_SOUND_ROUTE( ALL_OUTPUTS, "^:rspeaker", 0.00 )
+	MCFG_MSM5205_VCLK_CB(WRITELINE(pce_cd_device, msm5205_int)) /* interrupt function */
+	MCFG_MSM5205_PRESCALER_SELECTOR(MSM5205_S48_4B)      /* 1/48 prescaler, 4bit data */
+	MCFG_SOUND_ROUTE( ALL_OUTPUTS, "^:lspeaker", 0.50 )
+	MCFG_SOUND_ROUTE( ALL_OUTPUTS, "^:rspeaker", 0.50 )
 
 	MCFG_SOUND_ADD( "cdda", CDDA, 0 )
 	MCFG_SOUND_ROUTE( 0, "^:lspeaker", 1.00 )
