@@ -17,12 +17,8 @@
 */
 
 #include "emu.h"
-
 #include "smartmed.h"
 
-#include "harddisk.h"
-#include "imagedev/harddriv.h"
-#include "formats/imageutl.h"
 
 #define MAX_SMARTMEDIA  1
 
@@ -75,48 +71,37 @@ enum
 const device_type NAND = &device_creator<nand_device>;
 
 nand_device::nand_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
-	: device_t(mconfig, NAND, "NAND Flash Memory", tag, owner, clock, "nand", __FILE__)
+	: device_t(mconfig, NAND, "NAND Flash Memory", tag, owner, clock, "nand", __FILE__),
+		m_page_data_size(0),
+		m_page_total_size(0),
+		m_num_pages(0),
+		m_log2_pages_per_block(0),
+		m_pagereg(NULL),
+		m_id_len(0),
+		m_col_address_cycles(0),
+		m_row_address_cycles(0),
+		m_sequential_row_read(0),
+		m_write_rnb(*this)
 {
+	memset(m_id, 0, sizeof(m_id));
 }
+
 nand_device::nand_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, const char *shortname, const char *source)
-	: device_t(mconfig, type, name, tag, owner, clock, shortname, source)
+	: device_t(mconfig, type, name, tag, owner, clock, shortname, source),
+		m_page_data_size(0),
+		m_page_total_size(0),
+		m_num_pages(0),
+		m_log2_pages_per_block(0),
+		m_pagereg(NULL),
+		m_id_len(0),
+		m_col_address_cycles(0),
+		m_row_address_cycles(0),
+		m_sequential_row_read(0),
+		m_write_rnb(*this)
 {
+	memset(m_id, 0, sizeof(m_id));
 }
 
-void nand_device::device_config_complete()
-{
-	// inherit a copy of the static data
-	const nand_interface *intf = reinterpret_cast<const nand_interface *>(static_config());
-	if (intf != NULL)
-	{
-		*static_cast<nand_interface *>(this) = *intf;
-		m_id_len = m_chip.id_len;
-		memcpy( m_id, m_chip.id, m_chip.id_len);
-		m_page_data_size = m_chip.page_size;
-		m_page_total_size = m_chip.page_size + m_chip.oob_size;
-		m_log2_pages_per_block = compute_log2( m_chip.pages_per_block);
-		m_num_pages = m_chip.pages_per_block * m_chip.blocks_per_device;
-		m_col_address_cycles = m_chip.col_address_cycles;
-		m_row_address_cycles = m_chip.row_address_cycles;
-		m_sequential_row_read = m_chip.sequential_row_read;
-	}
-
-	// or initialize to defaults if none provided
-	else
-	{
-		memset(&m_chip, 0, sizeof(m_chip));
-		memset(&m_devcb_write_line_cb, 0, sizeof(m_devcb_write_line_cb));
-		m_id_len = 0;
-		m_page_data_size = 0;
-		m_page_total_size = 0;
-		m_log2_pages_per_block = 0;
-		m_num_pages = 0;
-		m_pagereg = NULL;
-		m_col_address_cycles = 0;
-		m_row_address_cycles = 0;
-		m_sequential_row_read = 0;
-	}
-}
 /*
     Init a SmartMedia image
 */
@@ -137,7 +122,7 @@ void nand_device::device_start()
 	#ifdef SMARTMEDIA_IMAGE_SAVE
 	m_image_format = 0;
 	#endif
-	m_devcb_write_line_rnb.resolve( m_devcb_write_line_cb, *this);
+	m_write_rnb.resolve_safe();
 }
 
 /*
@@ -408,10 +393,10 @@ void nand_device::command_w(UINT8 data)
 		m_status = (m_status & 0x80) | 0x40;
 		m_accumulated_status = 0;
 		m_mode_3065 = 0;
-		if (!m_devcb_write_line_rnb.isnull())
+		if (!m_write_rnb.isnull())
 		{
-			m_devcb_write_line_rnb( 0);
-			m_devcb_write_line_rnb( 1);
+			m_write_rnb( 0);
+			m_write_rnb( 1);
 		}
 		break;
 	case 0x00: // Read (1st cycle)
@@ -475,10 +460,10 @@ void nand_device::command_w(UINT8 data)
 			else
 				m_accumulated_status = 0;
 			m_mode = SM_M_INIT;
-			if (!m_devcb_write_line_rnb.isnull())
+			if (!m_write_rnb.isnull())
 			{
-				m_devcb_write_line_rnb( 0);
-				m_devcb_write_line_rnb( 1);
+				m_write_rnb( 0);
+				m_write_rnb( 1);
 			}
 		}
 		break;
@@ -504,10 +489,10 @@ void nand_device::command_w(UINT8 data)
 			m_mode = SM_M_INIT;
 			if (m_pointer_mode == SM_PM_B)
 				m_pointer_mode = SM_PM_A;
-			if (!m_devcb_write_line_rnb.isnull())
+			if (!m_write_rnb.isnull())
 			{
-				m_devcb_write_line_rnb( 0);
-				m_devcb_write_line_rnb( 1);
+				m_write_rnb( 0);
+				m_write_rnb( 1);
 			}
 		}
 		break;
@@ -541,10 +526,10 @@ void nand_device::command_w(UINT8 data)
 			}
 			else
 			{
-				if (!m_devcb_write_line_rnb.isnull())
+				if (!m_write_rnb.isnull())
 				{
-					m_devcb_write_line_rnb( 0);
-					m_devcb_write_line_rnb( 1);
+					m_write_rnb( 0);
+					m_write_rnb( 1);
 				}
 			}
 		}
@@ -794,13 +779,11 @@ const device_type SMARTMEDIA = &device_creator<smartmedia_image_device>;
 
 smartmedia_image_device::smartmedia_image_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
 	: nand_device(mconfig, SMARTMEDIA, "SmartMedia Flash ROM", tag, owner, clock, "smartmedia", __FILE__),
-		device_image_interface(mconfig, *this),
-		m_image_interface(NULL)
+		device_image_interface(mconfig, *this)
 {
 }
 
 void smartmedia_image_device::device_config_complete()
 {
-	nand_device::device_config_complete();
 	update_names();
 }
