@@ -7,11 +7,12 @@
 #define VERBOSE 0
 #define LOG(x) do { if (VERBOSE) logerror x; } while (0)
 
-#define ENABLE_NONE      0
-#define ENABLE_EXPANSION 1
-#define ENABLE_CARD      2
-#define ENABLE_CART      3
-#define ENABLE_BIOS      4
+#define ENABLE_NONE      0x00
+#define ENABLE_EXPANSION 0x01
+#define ENABLE_CARD      0x02
+#define ENABLE_CART      0x04
+#define ENABLE_BIOS      0x08
+#define ENABLE_EXT_RAM   0x10
 
 
 void sms_state::lphaser_hcount_latch()
@@ -25,7 +26,7 @@ void sms_state::lphaser_hcount_latch()
 WRITE_LINE_MEMBER(sms_state::sms_ctrl1_th_input)
 {
 	// Check if TH of controller port 1 is set to input (1)
-	if (m_is_korean || (m_io_ctrl_reg & 0x02))
+	if (m_io_ctrl_reg & 0x02)
 	{
 		if (state == 0)
 		{
@@ -33,7 +34,7 @@ WRITE_LINE_MEMBER(sms_state::sms_ctrl1_th_input)
 		}
 		else
 		{
-			// If previous state was 0 and now is 1, latch hcount.
+			// State is 1. If changed from 0, hcount is latched.
 			if (m_ctrl1_th_state == 0)
 				lphaser_hcount_latch();
 		}
@@ -45,7 +46,7 @@ WRITE_LINE_MEMBER(sms_state::sms_ctrl1_th_input)
 WRITE_LINE_MEMBER(sms_state::sms_ctrl2_th_input)
 {
 	// Check if TH of controller port 2 is set to input (1)
-	if (m_is_korean || (m_io_ctrl_reg & 0x08))
+	if (m_io_ctrl_reg & 0x08)
 	{
 		if (state == 0)
 		{
@@ -53,7 +54,7 @@ WRITE_LINE_MEMBER(sms_state::sms_ctrl2_th_input)
 		}
 		else
 		{
-			// If previous state was 0 and now is 1, latch hcount.
+			// State is 1. If changed from 0, hcount is latched.
 			if (m_ctrl2_th_state == 0)
 				lphaser_hcount_latch();
 		}
@@ -69,6 +70,10 @@ void sms_state::sms_get_inputs( address_space &space )
 	m_port_dc_reg = 0xff;
 	m_port_dd_reg = 0xff;
 
+	// The bit order of the emulated controller port tries to follow its
+	// physical pins numbering. For register bits whose order differs,
+	// it's necessary move the equivalent controller bits to match.
+
 	data1 = m_port_ctrl1->port_r();
 	m_port_dc_reg &= ~0x0f | data1; // Up, Down, Left, Right
 	m_port_dc_reg &= ~0x10 | (data1 >> 1); // TL (Button 1)
@@ -80,8 +85,9 @@ void sms_state::sms_get_inputs( address_space &space )
 	m_port_dd_reg &= ~0x04 | (data2 >> 3); // TL (Button 1)
 	m_port_dd_reg &= ~0x08 | (data2 >> 4); // TR (Button 2)
 
-	// Japanese consoles do not have TH line connected.
-	if (!m_is_region_japan || m_is_korean)
+	// Sega Mark III does not have TH line connected.
+	// Also, the japanese Master System does not set port $dd with TH input.
+	if (!m_is_mark_iii && !m_is_smsj)
 	{
 		m_port_dd_reg &= ~0x40 | data1; // TH ctrl1
 		m_port_dd_reg &= ~0x80 | (data2 << 1); // TH ctrl2
@@ -104,7 +110,7 @@ READ8_MEMBER(sms_state::sms_fm_detect_r)
 	}
 	else
 	{
-		if (m_bios_port & IO_CHIP)
+		if (!m_is_mark_iii && (m_mem_ctrl_reg & IO_CHIP))
 		{
 			return 0xff;
 		}
@@ -213,15 +219,24 @@ WRITE_LINE_MEMBER(sms_state::sms_pause_callback)
 	else
 		m_paused = 0;
 
-	// clear TH latch of the controller ports
-	m_ctrl1_th_latch = 0;
-	m_ctrl2_th_latch = 0;
+	if (!m_is_mark_iii)
+	{
+		// clear TH latch of the controller ports
+		m_ctrl1_th_latch = 0;
+		m_ctrl2_th_latch = 0;
+	}
 }
 
 
 READ8_MEMBER(sms_state::sms_input_port_dc_r)
 {
-	if (m_bios_port & IO_CHIP)
+	if (m_is_mark_iii)
+	{
+		sms_get_inputs(space);
+		return m_port_dc_reg;
+	}
+
+	if (m_mem_ctrl_reg & IO_CHIP)
 	{
 		return 0xff;
 	}
@@ -230,7 +245,7 @@ READ8_MEMBER(sms_state::sms_input_port_dc_r)
 		sms_get_inputs(space);
 
 		// Check if TR of controller port 1 is set to output (0)
-		if (!m_is_region_japan && !(m_io_ctrl_reg & 0x01))
+		if (!(m_io_ctrl_reg & 0x01))
 		{
 			// Read TR state set through IO control port
 			m_port_dc_reg &= ~0x20 | ((m_io_ctrl_reg & 0x10) << 1);
@@ -243,26 +258,45 @@ READ8_MEMBER(sms_state::sms_input_port_dc_r)
 
 READ8_MEMBER(sms_state::sms_input_port_dd_r)
 {
-	if (m_bios_port & IO_CHIP)
+	if (m_is_mark_iii)
+	{
+		sms_get_inputs(space);
+		return m_port_dd_reg;
+	}
+
+	if (m_mem_ctrl_reg & IO_CHIP)
 		return 0xff;
 
 	sms_get_inputs(space);
 
+	// Check if TR of controller port 2 is set to output (0)
+	if (!(m_io_ctrl_reg & 0x04))
+	{
+		// Read TR state set through IO control port
+		m_port_dd_reg &= ~0x08 | ((m_io_ctrl_reg & 0x40) >> 3);
+	}
+
+	if (m_is_smsj)
+	{
+		// For japanese Master System, set upper 4 bits with TH/TR
+		// direction bits of IO control register, according to Enri's
+		// docs (http://www43.tok2.com/home/cmpslv/Sms/EnrSms.htm).
+		// This makes the console incapable of using the Light Phaser.
+		m_port_dd_reg &= ~0x10 | ((m_io_ctrl_reg & 0x01) << 4);
+		m_port_dd_reg &= ~0x20 | ((m_io_ctrl_reg & 0x04) << 3);
+		m_port_dd_reg &= ~0x40 | ((m_io_ctrl_reg & 0x02) << 5);
+		m_port_dd_reg &= ~0x80 | ((m_io_ctrl_reg & 0x08) << 4);
+		return m_port_dd_reg;
+	}
+
 	// Reset Button
 	if ( m_port_reset )
 	{
 		m_port_dd_reg &= ~0x10 | (m_port_reset->read() & 0x01) << 4;
 	}
 
-	// Check if TR of controller port 2 is set to output (0)
-	if (!m_is_region_japan && !(m_io_ctrl_reg & 0x04))
-	{
-		// Read TR state set through IO control port
-		m_port_dd_reg &= ~0x08 | ((m_io_ctrl_reg & 0x40) >> 3);
-	}
-
 	// Check if TH of controller port 1 is set to output (0)
-	if (!m_is_region_japan && !(m_io_ctrl_reg & 0x02))
+	if (!(m_io_ctrl_reg & 0x02))
 	{
 		// Read TH state set through IO control port
 		m_port_dd_reg &= ~0x40 | ((m_io_ctrl_reg & 0x20) << 1);
@@ -277,7 +311,7 @@ READ8_MEMBER(sms_state::sms_input_port_dd_r)
 	}
 
 	// Check if TH of controller port 2 is set to output (0)
-	if (!m_is_region_japan && !(m_io_ctrl_reg & 0x08))
+	if (!(m_io_ctrl_reg & 0x08))
 	{
 		// Read TH state set through IO control port
 		m_port_dd_reg &= ~0x80 | (m_io_ctrl_reg & 0x80);
@@ -314,8 +348,8 @@ WRITE8_MEMBER(sms_state::sms_ym2413_data_port_w)
 
 READ8_MEMBER(sms_state::gg_input_port_2_r)
 {
-	//logerror("joy 2 read, val: %02x, pc: %04x\n", ((m_is_region_japan ? 0x00 : 0x40) | (m_port_start->read() & 0x80)), activecpu_get_pc());
-	return ((m_is_region_japan ? 0x00 : 0x40) | (m_port_start->read() & 0x80));
+	//logerror("joy 2 read, val: %02x, pc: %04x\n", (m_is_gg_region_japan ? 0x00 : 0x40) | (m_port_start->read() & 0x80), activecpu_get_pc());
+	return (m_is_gg_region_japan ? 0x00 : 0x40) | (m_port_start->read() & 0x80);
 }
 
 
@@ -329,13 +363,13 @@ READ8_MEMBER(sms_state::sms_sscope_r)
 		return m_sscope_state;
 	}
 
-	return m_mainram[0x1FF8 + offset];
+	return read_ram(space, 0x3ff8 + offset);
 }
 
 
 WRITE8_MEMBER(sms_state::sms_sscope_w)
 {
-	m_mainram[0x1FF8 + offset] = data;
+	write_ram(space, 0x3ff8 + offset, data);
 
 	int sscope = m_port_scope->read();
 
@@ -357,64 +391,77 @@ WRITE8_MEMBER(sms_state::sms_sscope_w)
 }
 
 
+READ8_MEMBER(sms_state::read_ram)
+{
+	if (m_mem_device_enabled & ENABLE_EXT_RAM)
+	{
+		UINT8 data = 0xff;
+
+		if (m_mem_device_enabled & ENABLE_CART)
+			data &= m_cartslot->read_ram(space, offset);
+		if (m_mem_device_enabled & ENABLE_CARD)
+			data &= m_cardslot->read_ram(space, offset);
+		if (m_mem_device_enabled & ENABLE_EXPANSION)
+			data &= m_expslot->read_ram(space, offset);
+
+		return data;
+	}
+	else
+	{
+		return m_mainram[offset & 0x1fff];
+	}
+}
+
+
+WRITE8_MEMBER(sms_state::write_ram)
+{
+	if (m_mem_device_enabled & ENABLE_EXT_RAM)
+	{
+		if (m_mem_device_enabled & ENABLE_CART)
+			m_cartslot->write_ram(space, offset, data);
+		if (m_mem_device_enabled & ENABLE_CARD)
+			m_cardslot->write_ram(space, offset, data);
+		if (m_mem_device_enabled & ENABLE_EXPANSION)
+			m_expslot->write_ram(space, offset, data);
+	}
+	else
+	{
+		m_mainram[offset & 0x1fff] = data;
+	}
+}
+
+
 READ8_MEMBER(sms_state::sms_mapper_r)
 {
-	return m_mainram[0x1ffc + offset];
+	return read_ram(space, 0x3ffc + offset);
 }
 
 
 WRITE8_MEMBER(sms_state::sms_mapper_w)
 {
-	bool bios_selected = false;
-	bool cartridge_selected = false;
-	bool card_selected = false;
-	bool expansion_selected = false;
-
 	m_mapper[offset] = data;
-	m_mainram[0x1ffc + offset] = data;
-
-	if (m_bios_port & IO_BIOS_ROM || (m_is_gamegear && m_BIOS == NULL))
-	{
-		if (!(m_bios_port & IO_CARTRIDGE) || (m_is_gamegear && m_BIOS == NULL))
-			cartridge_selected = true;
-		else if (!(m_bios_port & IO_CARD))
-			card_selected = true;
-		else if (!(m_bios_port & IO_EXPANSION))
-			expansion_selected = true;
-		else
-			return; // nothing to page in
-	}
-	else
-	{
-		if (!m_BIOS)
-			return; // nothing to page in
-		bios_selected = true;
-	}
+	write_ram(space, 0x3ffc + offset, data);
 
 	switch (offset)
 	{
 		case 0: // Control RAM/ROM
-			if (!(data & 0x08) && !(m_bios_port & IO_BIOS_ROM) && bios_selected)    // BIOS ROM
+			if (!(data & 0x08) && (m_mem_device_enabled & ENABLE_BIOS))    // BIOS ROM
 			{
 				if (!m_has_bios_0400 && !m_has_bios_2000)
 				{
-					m_bank_enabled[2] = ENABLE_BIOS;
 					m_bios_page[2] = m_mapper[3];
 				}
 			}
-			else if (cartridge_selected)    // CART ROM/RAM
+			if (m_mem_device_enabled & ENABLE_CART)    // CART ROM/RAM
 			{
-				m_bank_enabled[2] = ENABLE_CART;
 				m_cartslot->write_mapper(space, offset, data);
 			}
-			else if (card_selected)    // CARD ROM/RAM
+			if (m_mem_device_enabled & ENABLE_CARD)    // CARD ROM/RAM
 			{
-				m_bank_enabled[2] = ENABLE_CARD;
 				m_cardslot->write_mapper(space, offset, data);
 			}
-			else if (expansion_selected)    // expansion slot
+			if (m_mem_device_enabled & ENABLE_EXPANSION)    // expansion slot
 			{
-				m_bank_enabled[2] = ENABLE_EXPANSION;
 				m_expslot->write_mapper(space, offset, data);
 			}
 			break;
@@ -422,27 +469,23 @@ WRITE8_MEMBER(sms_state::sms_mapper_w)
 		case 1: // Select 16k ROM bank for 0400-3fff
 		case 2: // Select 16k ROM bank for 4000-7fff
 		case 3: // Select 16k ROM bank for 8000-bfff
-			if (bios_selected)
+			if (m_mem_device_enabled & ENABLE_BIOS)
 			{
 				if (!m_has_bios_0400 && !m_has_bios_2000)
 				{
-					m_bank_enabled[offset - 1] = ENABLE_BIOS;
 					m_bios_page[offset - 1] = data & (m_bios_page_count - 1);
 				}
 			}
-			else if (cartridge_selected || m_is_gamegear)
+			if (m_mem_device_enabled & ENABLE_CART)
 			{
-				m_bank_enabled[offset - 1] = ENABLE_CART;
 				m_cartslot->write_mapper(space, offset, data);
 			}
-			else if (card_selected)
+			if (m_mem_device_enabled & ENABLE_CARD)
 			{
-				m_bank_enabled[offset - 1] = ENABLE_CARD;
 				m_cardslot->write_mapper(space, offset, data);
 			}
-			else if (expansion_selected)
+			if (m_mem_device_enabled & ENABLE_EXPANSION)
 			{
-				m_bank_enabled[offset - 1] = ENABLE_EXPANSION;
 				m_expslot->write_mapper(space, offset, data);
 			}
 			break;
@@ -450,172 +493,91 @@ WRITE8_MEMBER(sms_state::sms_mapper_w)
 }
 
 
+UINT8 sms_state::read_bus(address_space &space, unsigned int page, UINT16 base_addr, UINT16 offset)
+{
+	if (m_mem_device_enabled != ENABLE_NONE)
+	{
+		UINT8 data = 0xff;
+
+		// SMS2 behavior described by Charles MacDonald's SMS notes:
+		// "If the BIOS is enabled at the same time the cartridge slot is,
+		// the data from both sources are logically ANDed together when read."
+
+		if (m_mem_device_enabled & ENABLE_BIOS)
+			data &= m_BIOS[(m_bios_page[page] * 0x4000) + (offset & 0x3fff)];
+		if (m_mem_device_enabled & ENABLE_CART)
+			data &= m_cartslot->read_cart(space, base_addr + offset);
+		if (m_mem_device_enabled & ENABLE_CARD)
+			data &= m_cardslot->read_cart(space, base_addr + offset);
+		if (m_mem_device_enabled & ENABLE_EXPANSION)
+			data &= m_expslot->read(space, base_addr + offset);
+
+		return data;
+	}
+	else
+	{
+		return m_region_maincpu->base()[offset];
+	}
+}
+
+
 READ8_MEMBER(sms_state::read_0000)
 {
 	if (offset < 0x400)
 	{
-		if (m_bank_enabled[3] == ENABLE_BIOS)
-		{
-			if (m_BIOS)
-				return m_BIOS[(m_bios_page[3] * 0x4000) + (offset & 0x3fff)];
-		}
-		if (m_bank_enabled[3] == ENABLE_CART)
-			return m_cartslot->read_cart(space, offset);
-		if (m_cardslot && m_bank_enabled[3] == ENABLE_CARD)
-			return m_cardslot->read_cart(space, offset);
-		if (m_expslot && m_bank_enabled[3] == ENABLE_EXPANSION)
-			return m_expslot->read(space, offset);
+		return read_bus(space, 3, 0x0000, offset);
 	}
 	else
 	{
-		if (m_bank_enabled[0] == ENABLE_BIOS)
-		{
-			if (m_BIOS)
-				return m_BIOS[(m_bios_page[0] * 0x4000) + (offset & 0x3fff)];
-		}
-		if (m_bank_enabled[0] == ENABLE_CART)
-			return m_cartslot->read_cart(space, offset);
-		if (m_cardslot && m_bank_enabled[0] == ENABLE_CARD)
-			return m_cardslot->read_cart(space, offset);
-		if (m_expslot && m_bank_enabled[0] == ENABLE_EXPANSION)
-			return m_expslot->read(space, offset);
+		return read_bus(space, 0, 0x0000, offset);
 	}
-	return m_region_maincpu->base()[offset];
 }
 
 READ8_MEMBER(sms_state::read_4000)
 {
-	if (m_bank_enabled[1] == ENABLE_BIOS)
-	{
-		if (m_BIOS)
-			return m_BIOS[(m_bios_page[1] * 0x4000) + (offset & 0x3fff)];
-	}
-
-	if (m_bank_enabled[1] == ENABLE_CART)
-		return m_cartslot->read_cart(space, offset + 0x4000);
-	if (m_cardslot && m_bank_enabled[1] == ENABLE_CARD)
-		return m_cardslot->read_cart(space, offset + 0x4000);
-	if (m_expslot && m_bank_enabled[1] == ENABLE_EXPANSION)
-		return m_expslot->read(space, offset + 0x4000);
-
-	return m_region_maincpu->base()[offset];
+	return read_bus(space, 1, 0x4000, offset);
 }
 
 READ8_MEMBER(sms_state::read_8000)
 {
-	if (m_bank_enabled[2] == ENABLE_BIOS)
-	{
-		if (m_BIOS)
-			return m_BIOS[(m_bios_page[2] * 0x4000) + (offset & 0x3fff)];
-	}
-
-	if (m_bank_enabled[2] == ENABLE_CART)
-		return m_cartslot->read_cart(space, offset + 0x8000);
-	if (m_cardslot && m_bank_enabled[2] == ENABLE_CARD)
-		return m_cardslot->read_cart(space, offset + 0x8000);
-	if (m_expslot && m_bank_enabled[2] == ENABLE_EXPANSION)
-		return m_expslot->read(space, offset + 0x8000);
-
-	return m_region_maincpu->base()[offset];
+	return read_bus(space, 2, 0x8000, offset);
 }
 
 WRITE8_MEMBER(sms_state::write_cart)
 {
-	if (m_bank_enabled[0] == ENABLE_CART)
+	if (m_mem_device_enabled & ENABLE_CART)
 		m_cartslot->write_cart(space, offset, data);
-	if (m_cardslot && m_bank_enabled[0] == ENABLE_CARD)
+	if (m_mem_device_enabled & ENABLE_CARD)
 		m_cardslot->write_cart(space, offset, data);
-	if (m_expslot && m_bank_enabled[0] == ENABLE_EXPANSION)
+	if (m_mem_device_enabled & ENABLE_EXPANSION)
 		m_expslot->write(space, offset, data);
 }
 
-READ8_MEMBER(smssdisp_state::store_read_0000)
-{
-	if (offset < 0x400)
-	{
-		if (m_bank_enabled[3] == ENABLE_BIOS)
-		{
-			if (m_BIOS)
-				return m_BIOS[(m_bios_page[3] * 0x4000) + (offset & 0x3fff)];
-		}
-		if (m_bank_enabled[3] == ENABLE_CART)
-			return m_slots[m_current_cartridge]->read_cart(space, offset);
-		if (m_bank_enabled[3] == ENABLE_CARD)
-			return m_cards[m_current_cartridge]->read_cart(space, offset);
-	}
-	else
-	{
-		if (m_bank_enabled[0] == ENABLE_BIOS)
-		{
-			if (m_BIOS)
-				return m_BIOS[(m_bios_page[0] * 0x4000) + (offset & 0x3fff)];
-		}
-		if (m_bank_enabled[0] == ENABLE_CART)
-			return m_slots[m_current_cartridge]->read_cart(space, offset);
-		if (m_bank_enabled[0] == ENABLE_CARD)
-			return m_cards[m_current_cartridge]->read_cart(space, offset);
-	}
-
-	return m_region_maincpu->base()[offset];
-}
-
-READ8_MEMBER(smssdisp_state::store_read_4000)
-{
-	if (m_bank_enabled[1] == ENABLE_BIOS)
-	{
-		if (m_BIOS)
-			return m_BIOS[(m_bios_page[1] * 0x4000) + (offset & 0x3fff)];
-	}
-	if (m_bank_enabled[1] == ENABLE_CART)
-		return m_slots[m_current_cartridge]->read_cart(space, offset + 0x4000);
-	if (m_bank_enabled[1] == ENABLE_CARD)
-		return m_cards[m_current_cartridge]->read_cart(space, offset + 0x4000);
-
-	return m_region_maincpu->base()[offset];
-}
-
-READ8_MEMBER(smssdisp_state::store_read_8000)
-{
-	if (m_bank_enabled[2] == ENABLE_BIOS)
-	{
-		if (m_BIOS)
-			return m_BIOS[(m_bios_page[2] * 0x4000) + (offset & 0x3fff)];
-	}
-	if (m_bank_enabled[2] == ENABLE_CART)
-		return m_slots[m_current_cartridge]->read_cart(space, offset + 0x8000);
-	if (m_bank_enabled[2] == ENABLE_CARD)
-		return m_cards[m_current_cartridge]->read_cart(space, offset + 0x8000);
-
-	return m_region_maincpu->base()[offset];
-}
-
-WRITE8_MEMBER(smssdisp_state::store_write_cart)
-{
-	// this might only work because we are not emulating properly the cart/card selection system
-	// it will have to be reviewed when proper emulation is worked on!
-	if (m_bank_enabled[0] == ENABLE_CART)
-		m_slots[m_current_cartridge]->write_cart(space, offset, data);
-	if (m_bank_enabled[0] == ENABLE_CARD)
-		m_cards[m_current_cartridge]->write_cart(space, offset, data);
-}
 
 READ8_MEMBER(smssdisp_state::store_cart_peek)
 {
-	if (m_bank_enabled[1] == ENABLE_CART)
-		return m_slots[m_current_cartridge]->read_cart(space, 0x4000 + (offset & 0x1fff));
-	if (m_bank_enabled[1] == ENABLE_CARD)
-		return m_cards[m_current_cartridge]->read_cart(space, 0x4000 + (offset & 0x1fff));
+	if (m_mem_device_enabled != ENABLE_NONE)
+	{
+		UINT8 data = 0xff;
 
-	return m_region_maincpu->base()[offset];
+		if (m_mem_device_enabled & ENABLE_CART)
+			data &= m_cartslot->read_cart(space, 0x6000 + (offset & 0x1fff));
+
+		return data;
+	}
+	else
+	{
+		return m_region_maincpu->base()[offset];
+	}
 }
 
-WRITE8_MEMBER(sms_state::sms_bios_w)
+WRITE8_MEMBER(sms_state::sms_mem_control_w)
 {
-	m_bios_port = data;
+	m_mem_ctrl_reg = data;
 
-	logerror("bios write %02x, pc: %04x\n", data, space.device().safe_pc());
+	logerror("memory control reg write %02x, pc: %04x\n", data, space.device().safe_pc());
 
-	setup_rom();
+	setup_media_slots();
 }
 
 
@@ -670,71 +632,92 @@ READ8_MEMBER(sms_state::gg_sio_r)
 }
 
 
-void sms_state::setup_rom()
+void sms_state::setup_enabled_slots()
 {
-	m_bank_enabled[3] = ENABLE_NONE;
-	m_bank_enabled[0] = ENABLE_NONE;
-	m_bank_enabled[1] = ENABLE_NONE;
-	m_bank_enabled[2] = ENABLE_NONE;
+	m_mem_device_enabled = ENABLE_NONE;
 
-	/* 2. check and set up expansion port */
-	if (!(m_bios_port & IO_EXPANSION) && (m_bios_port & IO_CARTRIDGE) && (m_bios_port & IO_CARD))
+	if (m_is_mark_iii)
 	{
-		m_bank_enabled[3] = ENABLE_EXPANSION;
-		m_bank_enabled[0] = ENABLE_EXPANSION;
-		m_bank_enabled[1] = ENABLE_EXPANSION;
-		m_bank_enabled[2] = ENABLE_EXPANSION;
-		logerror("Switching to expansion port.\n");
+		// Mark III uses the card slot by default, but has hardware method
+		// (/CART pin) that prioritizes the cartridge slot if it has media
+		// inserted. Japanese 3-D cartridges do not connect the /CART pin,
+		// to not disable the card adaptor used by the 3-D glasses.
+		if (m_cartslot && m_cartslot->m_cart)
+		{
+			m_mem_device_enabled |= ENABLE_CART;
+			logerror("Cartridge ROM/RAM enabled.\n");
+		}
+		else if (m_cardslot && m_cardslot->m_cart)
+		{
+			m_mem_device_enabled |= ENABLE_CARD;
+			logerror("Card ROM port enabled.\n");
+		}
+		return;
 	}
 
-	/* 3. check and set up card rom */
-	if (!(m_bios_port & IO_CARD) && (m_bios_port & IO_CARTRIDGE) && (m_bios_port & IO_EXPANSION))
+	if (!(m_mem_ctrl_reg & IO_EXPANSION) && m_expslot && m_expslot->m_device)
 	{
-		m_bank_enabled[3] = ENABLE_CARD;
-		m_bank_enabled[0] = ENABLE_CARD;
-		m_bank_enabled[1] = ENABLE_CARD;
-		m_bank_enabled[2] = ENABLE_CARD;
-		logerror("Switching to card rom port.\n");
+		m_mem_device_enabled |= ENABLE_EXPANSION;
+		logerror("Expansion port enabled.\n");
 	}
 
-	/* 4. check and set up cartridge rom */
-	/* if ((!(bios_port & IO_CARTRIDGE) && (bios_port & IO_EXPANSION) && (bios_port & IO_CARD)) || state->m_is_gamegear) { */
-	/* Out Run Europa initially writes a value to port 3E where IO_CARTRIDGE, IO_EXPANSION and IO_CARD are reset */
-	if ((!(m_bios_port & IO_CARTRIDGE)) || m_is_gamegear)
+	if (!(m_mem_ctrl_reg & IO_CARD) && m_cardslot && m_cardslot->m_cart)
 	{
-		m_bank_enabled[3] = ENABLE_CART;
-		m_bank_enabled[0] = ENABLE_CART;
-		m_bank_enabled[1] = ENABLE_CART;
-		m_bank_enabled[2] = ENABLE_CART;
-		logerror("Switched in cartridge rom.\n");
+		m_mem_device_enabled |= ENABLE_CARD;
+		logerror("Card ROM port enabled.\n");
 	}
 
-	/* 5. check and set up bios rom */
-	if (!(m_bios_port & IO_BIOS_ROM))
+	if (!(m_mem_ctrl_reg & IO_CARTRIDGE) && m_cartslot && m_cartslot->m_cart)
 	{
-		if (m_has_bios_0400)
+		m_mem_device_enabled |= ENABLE_CART;
+		logerror("Cartridge ROM/RAM enabled.\n");
+	}
+
+	if (!(m_mem_ctrl_reg & IO_BIOS_ROM) && m_BIOS)
+	{
+		m_mem_device_enabled |= ENABLE_BIOS;
+		logerror("BIOS enabled.\n");
+	}
+}
+
+
+void sms_state::setup_media_slots()
+{
+	setup_enabled_slots();
+
+	if (m_mem_device_enabled == ENABLE_NONE)
+		return;
+
+	// Setup cartridge RAM
+	if (!m_is_mark_iii && (m_mem_ctrl_reg & IO_WORK_RAM)) // Work RAM disabled (1).
+	{
+		m_mem_device_enabled |= ENABLE_EXT_RAM;
+	}
+	else if (m_has_jpn_sms_cart_slot && (m_mem_device_enabled & ENABLE_CART))
+	{
+		// a bunch of SG1000 carts (compatible with SG1000 Mark III) use their own RAM...
+		// TODO: are BASIC and Music actually compatible with Mark III??
+		if (m_cartslot->get_type() == SEGA8_BASIC_L3 ||
+			m_cartslot->get_type() == SEGA8_MUSIC_EDITOR ||
+			m_cartslot->get_type() == SEGA8_DAHJEE_TYPEA ||
+			m_cartslot->get_type() == SEGA8_DAHJEE_TYPEB)
 		{
-			// 1K bios
-			m_bank_enabled[3] = ENABLE_BIOS;
-			logerror("Switched in 0x0400 bios.\n");
-		}
-		if (m_has_bios_2000)
-		{
-			// 8K bios
-			m_bank_enabled[3] = ENABLE_BIOS;
-			m_bank_enabled[0] = ENABLE_BIOS;
-			logerror("Switched in 0x2000 bios.\n");
-		}
-		if (m_has_bios_full)
-		{
-			// larger bios
-			m_bank_enabled[3] = ENABLE_BIOS;
-			m_bank_enabled[0] = ENABLE_BIOS;
-			m_bank_enabled[1] = ENABLE_BIOS;
-			m_bank_enabled[2] = ENABLE_BIOS;
-			logerror("Switched in full bios.\n");
+			m_mem_device_enabled |= ENABLE_EXT_RAM;
 		}
 	}
+
+	// Set offset for Light Phaser
+	if (!m_is_mark_iii)
+	{
+		m_lphaser_x_offs = 44;
+
+		if (m_mem_device_enabled & ENABLE_CART)
+			m_lphaser_x_offs = m_cartslot->m_cart->get_lphaser_xoffs();
+		else if (m_mem_device_enabled & ENABLE_CARD)
+			m_lphaser_x_offs = m_cardslot->m_cart->get_lphaser_xoffs();
+		else if (m_mem_device_enabled & ENABLE_EXPANSION)
+			m_lphaser_x_offs = m_expslot->m_device->get_lphaser_xoffs();
+	}
 }
 
 
@@ -746,7 +729,6 @@ void sms_state::setup_bios()
 	if (m_BIOS == NULL || m_BIOS[0] == 0x00)
 	{
 		m_BIOS = NULL;
-		m_bios_port |= IO_BIOS_ROM;
 		m_has_bios_0400 = 0;
 		m_has_bios_2000 = 0;
 		m_has_bios_full = 0;
@@ -759,51 +741,81 @@ void sms_state::setup_bios()
 		m_bios_page[1] = (1 < m_bios_page_count) ? 1 : 0;
 		m_bios_page[2] = (2 < m_bios_page_count) ? 2 : 0;
 	}
+
+	if (!m_is_mark_iii)
+	{
+		m_mem_ctrl_reg = (IO_EXPANSION | IO_CARTRIDGE | IO_CARD);
+		if (!m_BIOS)
+		{
+			m_mem_ctrl_reg &= ~(IO_CARTRIDGE);
+			m_mem_ctrl_reg |= IO_BIOS_ROM;
+		}
+	}
 }
 
 MACHINE_START_MEMBER(sms_state,sms)
 {
 	char str[7];
 
-	m_left_lcd = machine().device("left_lcd");
-	m_right_lcd = machine().device("right_lcd");
+	m_cartslot = machine().device<sega8_cart_slot_device>("slot");
+	m_cardslot = machine().device<sega8_card_slot_device>("mycard");
+	m_expslot = machine().device<sms_expansion_slot_device>("exp");
 	m_space = &m_maincpu->space(AS_PROGRAM);
 
-	// alibaba and blockhol are ports of games for the MSX system. The
-	// MSX bios usually initializes callback "vectors" at the top of RAM.
-	// The code in alibaba does not do this so the IRQ vector only contains
-	// the "call $4010" without a following RET statement. That is basically
-	// a bug in the program code. The only way this cartridge could have run
-	// successfully on a real unit is if the RAM would be initialized with
-	// a F0 pattern on power up; F0 = RET P. Do that only for consoles in
-	// Japan region (including KR), until confirmed on other consoles.
-	if (m_is_region_japan)
+	if (m_mainram == NULL)
 	{
-		memset((UINT8*)m_space->get_write_ptr(0xc000), 0xf0, 0x1fff);
+		m_mainram = auto_alloc_array_clear(machine(), UINT8, 0x2000);
+		save_pointer(NAME(m_mainram), 0x2000);
+
+		// alibaba and blockhol are ports of games for the MSX system. The
+		// MSX bios usually initializes callback "vectors" at the top of RAM.
+		// The code in alibaba does not do this so the IRQ vector only contains
+		// the "call $4010" without a following RET statement. That is basically
+		// a bug in the program code. The only way this cartridge could have run
+		// successfully on a real unit is if the RAM would be initialized with
+		// a F0 pattern on power up; F0 = RET P.
+		// This initialization breaks the some Game Gear games though (e.g.
+		// tempojr), suggesting that not all systems had the same initialization.
+		// For the moment we apply this to systems that have the Japanese SMS
+		// cartridge slot.
+		if (m_has_jpn_sms_cart_slot)
+		{
+			memset(m_mainram, 0xf0, 0x2000);
+		}
 	}
 
-	save_item(NAME(m_fm_detect));
-	save_item(NAME(m_io_ctrl_reg));
 	save_item(NAME(m_paused));
-	save_item(NAME(m_bios_port));
 	save_item(NAME(m_mapper));
 	save_item(NAME(m_port_dc_reg));
 	save_item(NAME(m_port_dd_reg));
-	save_item(NAME(m_gg_sio));
-	save_item(NAME(m_bank_enabled));
-	save_item(NAME(m_bios_page));
+	save_item(NAME(m_mem_device_enabled));
 
-	save_item(NAME(m_ctrl1_th_state));
-	save_item(NAME(m_ctrl2_th_state));
-	save_item(NAME(m_ctrl1_th_latch));
-	save_item(NAME(m_ctrl2_th_latch));
-	save_item(NAME(m_sscope_state));
-	save_item(NAME(m_frame_sscope_state));
+	if (m_has_fm)
+	{
+		save_item(NAME(m_fm_detect));
+	}
+
+	if (!m_is_mark_iii)
+	{
+		save_item(NAME(m_mem_ctrl_reg));
+		save_item(NAME(m_bios_page));
+		save_item(NAME(m_io_ctrl_reg));
+		save_item(NAME(m_ctrl1_th_latch));
+		save_item(NAME(m_ctrl2_th_latch));
+		save_item(NAME(m_ctrl1_th_state));
+		save_item(NAME(m_ctrl2_th_state));
+		save_item(NAME(m_lphaser_x_offs));
+	}
+
+	if (m_is_gamegear)
+	{
+		save_item(NAME(m_gg_sio));
+	}
 
 	if (m_is_sdisp)
 	{
 		save_item(NAME(m_store_control));
-		save_item(NAME(m_current_cartridge));
+		save_item(NAME(m_store_cart_selection_data));
 
 		m_slots[0] = m_cartslot;
 		for (int i = 1; i < 16; i++)
@@ -816,97 +828,96 @@ MACHINE_START_MEMBER(sms_state,sms)
 			sprintf(str,"slot%i",i + 16 + 1);
 			m_cards[i] = machine().device<sega8_card_slot_device>(str);
 		}
-	}
-
-	// a bunch of SG1000 carts (compatible with SG1000 Mark III) can access directly system RAM... let's install here the necessary handlers
-	// TODO: are BASIC and Music actually compatible with Mark III??
-	if (m_cartslot->get_type() == SEGA8_BASIC_L3 || m_cartslot->get_type() == SEGA8_MUSIC_EDITOR
-			|| m_cartslot->get_type() == SEGA8_DAHJEE_TYPEA || m_cartslot->get_type() == SEGA8_DAHJEE_TYPEB)
-	{
-		m_maincpu->space(AS_PROGRAM).install_read_handler(0xc000, 0xffff, 0, 0, read8_delegate(FUNC(sega8_cart_slot_device::read_ram),(sega8_cart_slot_device*)m_cartslot));
-		m_maincpu->space(AS_PROGRAM).install_write_handler(0xc000, 0xffff, 0, 0, write8_delegate(FUNC(sega8_cart_slot_device::write_ram),(sega8_cart_slot_device*)m_cartslot));
+		store_select_cart(m_store_cart_selection_data);
 	}
 }
 
 MACHINE_RESET_MEMBER(sms_state,sms)
 {
-	m_io_ctrl_reg = 0xff;
 	if (m_has_fm)
 		m_fm_detect = 0x01;
 
+	if (!m_is_mark_iii)
+	{
+		m_io_ctrl_reg = 0xff;
+		m_ctrl1_th_latch = 0;
+		m_ctrl2_th_latch = 0;
+		m_ctrl1_th_state = 1;
+		m_ctrl2_th_state = 1;
+	}
+
+	if (m_is_gamegear)
+	{
+		if (m_cartslot->m_cart && m_cartslot->m_cart->get_sms_mode())
+			m_vdp->set_sega315_5124_compatibility_mode(true);
+
+		/* Initialize SIO stuff for GG */
+		m_gg_sio[0] = 0x7f;
+		m_gg_sio[1] = 0xff;
+		m_gg_sio[2] = 0x00;
+		m_gg_sio[3] = 0xff;
+		m_gg_sio[4] = 0x00;
+	}
+
 	if (m_is_sdisp)
 	{
 		m_store_control = 0;
-		m_current_cartridge = 0;
+		m_store_cart_selection_data = 0;
+		store_select_cart(m_store_cart_selection_data);
 	}
 
-	m_bios_port = 0;
-
 	setup_bios();
-	setup_sms_cart();
-	setup_rom();
-
-	if (m_cartslot->m_cart && m_cartslot->m_cart->get_sms_mode())
-		m_vdp->set_sega315_5124_compatibility_mode(true);
-
-	/* Initialize SIO stuff for GG */
-	m_gg_sio[0] = 0x7f;
-	m_gg_sio[1] = 0xff;
-	m_gg_sio[2] = 0x00;
-	m_gg_sio[3] = 0xff;
-	m_gg_sio[4] = 0x00;
-
-	m_ctrl1_th_state = 1;
-	m_ctrl2_th_state = 1;
-	m_ctrl1_th_latch = 0;
-	m_ctrl2_th_latch = 0;
-	m_lphaser_x_offs = (m_cartslot->m_cart) ? m_cartslot->m_cart->get_lphaser_xoffs() : 44;
-
-	m_sscope_state = 0;
-	m_frame_sscope_state = 0;
+	setup_media_slots();
 }
 
 READ8_MEMBER(smssdisp_state::sms_store_cart_select_r)
 {
-	return 0xff;
+	return m_store_cart_selection_data;
 }
 
 
 WRITE8_MEMBER(smssdisp_state::sms_store_cart_select_w)
+{
+	store_select_cart(data);
+	m_store_cart_selection_data = data;
+	setup_media_slots();
+}
+
+
+// There are two known models of the Store Display Unit:
+//
+// - the one with 16 cart slots and 3 card slots;
+// - the one with 16 cart slots and 16 card slots.
+//
+// On front panel of both models there are only 16 game switches,
+// that seems to change the active cart/card slot pair or, for the 4th
+// game switch onward of the 16-3 model, the active cart slot only.
+
+void sms_state::store_select_cart(UINT8 data)
 {
 	UINT8 slot = data >> 4;
 	UINT8 slottype = data & 0x08;
 
-	logerror("switching in part of %s slot #%d\n", slottype ? "card" : "cartridge", slot );
-	/* cartridge? slot #0 */
-	//if (slottype == 0)
-	//  m_current_cartridge = slot;
+	// The SMS Store Display Unit only uses the logical cartridge slot to
+	// map the active cartridge or card slot, of its multiple ones.
+	if (slottype == 0)
+		m_cartslot = m_slots[slot];
+	else
+		m_cartslot = m_cards[slot];
 
-	setup_rom();
+	logerror("switching in part of %s slot #%d\n", slottype ? "card" : "cartridge", slot);
 }
 
-
-READ8_MEMBER(smssdisp_state::sms_store_select1)
-{
-	return 0xff;
-}
-
-
-READ8_MEMBER(smssdisp_state::sms_store_select2)
-{
-	return 0xff;
-}
-
-
-READ8_MEMBER(smssdisp_state::sms_store_control_r)
-{
-	return m_store_control;
-}
-
-
 WRITE8_MEMBER(smssdisp_state::sms_store_control_w)
 {
+	int led_number = data >> 4;
+	int led_column = led_number / 4;
+	int led_line = led_number % 4;
+	int game_number = (4 * led_column) + (3 - led_line);
+
 	logerror("0x%04X: sms_store_control write 0x%02X\n", space.device().safe_pc(), data);
+	logerror("sms_store_control: LED #%d activated for game #%d\n", led_number, game_number);
+
 	if (data & 0x02)
 	{
 		m_maincpu->resume(SUSPEND_REASON_HALT);
@@ -932,26 +943,11 @@ WRITE_LINE_MEMBER(smssdisp_state::sms_store_int_callback)
 	}
 }
 
-void sms_state::setup_sms_cart()
-{
-	m_bios_port = (IO_EXPANSION | IO_CARTRIDGE | IO_CARD);
-	if (!m_is_gamegear && !m_BIOS)
-	{
-		m_bios_port |= IO_BIOS_ROM;
-
-		// Mark-III has hardware method that prioritizes cartridge slot.
-		if (m_cartslot && m_cartslot->m_cart)
-			m_bios_port &= ~(IO_CARTRIDGE);
-		else
-			m_bios_port &= ~(IO_CARD);
-	}
-}
-
-
 DRIVER_INIT_MEMBER(sms_state,sg1000m3)
 {
-	m_is_region_japan = 1;
+	m_is_mark_iii = 1;
 	m_has_fm = 1;
+	m_has_jpn_sms_cart_slot = 1;
 }
 
 
@@ -963,18 +959,33 @@ DRIVER_INIT_MEMBER(sms_state,sms1)
 
 DRIVER_INIT_MEMBER(sms_state,smsj)
 {
-	m_is_region_japan = 1;
+	m_is_smsj = 1;
 	m_has_bios_2000 = 1;
 	m_has_fm = 1;
+	m_has_jpn_sms_cart_slot = 1;
 }
 
 
-DRIVER_INIT_MEMBER(sms_state,sms2kr)
+DRIVER_INIT_MEMBER(sms_state,sms1krfm)
 {
-	m_is_region_japan = 1;
-	m_has_bios_full = 1;
+	m_has_bios_2000 = 1;
 	m_has_fm = 1;
-	m_is_korean = 1;
+	m_has_jpn_sms_cart_slot = 1;
+}
+
+
+DRIVER_INIT_MEMBER(sms_state,sms1kr)
+{
+	m_has_bios_2000 = 1;
+	m_has_jpn_sms_cart_slot = 1;
+}
+
+
+DRIVER_INIT_MEMBER(sms_state,smskr)
+{
+	m_has_bios_full = 1;
+	// Despite having a Japanese cartridge slot, this version is detected as Export region.
+	m_has_jpn_sms_cart_slot = 1;
 }
 
 
@@ -993,18 +1004,23 @@ DRIVER_INIT_MEMBER(sms_state,gamegear)
 
 DRIVER_INIT_MEMBER(sms_state,gamegeaj)
 {
-	m_is_region_japan = 1;
 	m_is_gamegear = 1;
 	m_has_bios_0400 = 1;
+	m_is_gg_region_japan = 1;
 }
 
 
 VIDEO_START_MEMBER(sms_state,sms1)
 {
+	m_left_lcd = machine().device("left_lcd");
+	m_right_lcd = machine().device("right_lcd");
+
 	m_main_scr->register_screen_bitmap(m_prevleft_bitmap);
 	m_main_scr->register_screen_bitmap(m_prevright_bitmap);
 	save_item(NAME(m_prevleft_bitmap));
 	save_item(NAME(m_prevright_bitmap));
+	save_item(NAME(m_sscope_state));
+	save_item(NAME(m_frame_sscope_state));
 
 	// Allow sscope screens to have crosshair, useful for the game missil3d
 	crosshair_set_screen(machine(), 0, CROSSHAIR_SCREEN_ALL);
@@ -1018,10 +1034,13 @@ VIDEO_RESET_MEMBER(sms_state,sms1)
 		UINT8 sscope_binocular_hack = m_port_scope_binocular->read();
 
 		if (sscope_binocular_hack & 0x01)
-			m_prevleft_bitmap.fill(RGB_BLACK);
+			m_prevleft_bitmap.fill(rgb_t::black);
 		if (sscope_binocular_hack & 0x02)
-			m_prevright_bitmap.fill(RGB_BLACK);
+			m_prevright_bitmap.fill(rgb_t::black);
 	}
+
+	m_sscope_state = 0;
+	m_frame_sscope_state = 0;
 }
 
 
@@ -1126,7 +1145,7 @@ UINT32 sms_state::screen_update_sms1(screen_device &screen, bitmap_rgb32 &bitmap
 				}
 			}
 		}
-		bitmap.fill(RGB_BLACK, cliprect);
+		bitmap.fill(rgb_t::black, cliprect);
 	}
 
 	return 0;
@@ -1155,7 +1174,7 @@ UINT32 sms_state::screen_update_gamegear(screen_device &screen, bitmap_rgb32 &bi
 		copybitmap(bitmap, vdp_bitmap, 0, 0, 0, 0, cliprect);
 		if (prev_bitmap_copied)
 		{
-			m_prev_bitmap.fill(RGB_BLACK);
+			m_prev_bitmap.fill(rgb_t::black);
 			prev_bitmap_copied = false;
 		}
 	}
