@@ -122,26 +122,6 @@ WRITE8_MEMBER( special_state::specialist_8255_portc_w )
 	m_dac->write_unsigned8(BIT(data, 5)); //beeper
 }
 
-I8255_INTERFACE( specialist_ppi8255_interface )
-{
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_porta_r),
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_porta_w),
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_portb_r),
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_portb_w),
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_portc_r),
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_portc_w)
-};
-
-I8255_INTERFACE( specimx_ppi8255_interface )
-{
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_porta_r),
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_porta_w),
-	DEVCB_DRIVER_MEMBER(special_state, specimx_8255_portb_r),
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_portb_w),
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_portc_r),
-	DEVCB_DRIVER_MEMBER(special_state, specialist_8255_portc_w)
-};
-
 void special_state::device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr)
 {
 	switch (id)
@@ -151,9 +131,9 @@ void special_state::device_timer(emu_timer &timer, device_timer_id id, int param
 		break;
 	case TIMER_PIT8253_GATES:
 	{
-		m_pit->gate0_w(0);
-		m_pit->gate1_w(0);
-		m_pit->gate2_w(0);
+		m_pit->write_gate0(0);
+		m_pit->write_gate1(0);
+		m_pit->write_gate2(0);
 		break;
 	}
 	default:
@@ -235,49 +215,9 @@ WRITE8_MEMBER( special_state::specimx_select_bank )
 	specimx_set_bank(offset, data);
 }
 
-WRITE_LINE_MEMBER( special_state::specimx_pit8253_out0_changed )
-{
-	m_specimx_audio->set_input( 0, state );
-}
-
-WRITE_LINE_MEMBER( special_state::specimx_pit8253_out1_changed )
-{
-	m_specimx_audio->set_input( 1, state );
-}
-
-WRITE_LINE_MEMBER( special_state::specimx_pit8253_out2_changed )
-{
-	m_specimx_audio->set_input( 2, state );
-}
-
-
-
-const struct pit8253_interface specimx_pit8253_intf =
-{
-	{
-		{
-			2000000,
-			DEVCB_NULL,
-			DEVCB_DRIVER_LINE_MEMBER(special_state, specimx_pit8253_out0_changed)
-		},
-		{
-			2000000,
-			DEVCB_NULL,
-			DEVCB_DRIVER_LINE_MEMBER(special_state, specimx_pit8253_out1_changed)
-		},
-		{
-			2000000,
-			DEVCB_NULL,
-			DEVCB_DRIVER_LINE_MEMBER(special_state, specimx_pit8253_out2_changed)
-		}
-	}
-};
-
 MACHINE_START_MEMBER(special_state,specimx)
 {
-	m_specimx_audio = machine().device<specimx_sound_device>("custom");
 	m_drive = 0;
-	m_fdc->setup_drq_cb(fd1793_t::line_cb(FUNC(special_state::fdc_drq), this));
 }
 
 MACHINE_RESET_MEMBER(special_state,specimx)
@@ -291,7 +231,7 @@ READ8_MEMBER( special_state::specimx_disk_ctrl_r )
 	return 0xff;
 }
 
-void special_state::fdc_drq(bool state)
+WRITE_LINE_MEMBER( special_state::fdc_drq )
 {
 	/* Clears HALT state of CPU when data is ready to read */
 	if(state) {
