@@ -20,21 +20,15 @@
 
 
 
-//**************************************************************************
-//  MACROS / CONSTANTS
-//**************************************************************************
-
-#define VICTOR9K_KEYBOARD_TAG   "victor9kb"
-
-
-
 //**************************************************************************
 //  INTERFACE CONFIGURATION MACROS
 //**************************************************************************
 
-#define MCFG_VICTOR9K_KEYBOARD_ADD(_kbrdy) \
-	MCFG_DEVICE_ADD(VICTOR9K_KEYBOARD_TAG, VICTOR9K_KEYBOARD, 0) \
-	downcast<victor9k_keyboard_device *>(device)->set_kbrdy_callback(DEVCB2_##_kbrdy);
+#define MCFG_VICTOR9K_KBRDY_HANDLER(_devcb) \
+	devcb = &victor9k_keyboard_device::set_kbrdy_handler(*device, DEVCB_##_devcb);
+
+#define MCFG_VICTOR9K_KBDATA_HANDLER(_devcb) \
+	devcb = &victor9k_keyboard_device::set_kbdata_handler(*device, DEVCB_##_devcb);
 
 
 //**************************************************************************
@@ -49,7 +43,8 @@ public:
 	// construction/destruction
 	victor9k_keyboard_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
 
-	template<class _kbrdy> void set_kbrdy_callback(_kbrdy kbrdy) { m_write_kbrdy.set_callback(kbrdy); }
+	template<class _Object> static devcb_base &set_kbrdy_handler(device_t &device, _Object object) { return downcast<victor9k_keyboard_device &>(device).m_kbrdy_handler.set_callback(object); }
+	template<class _Object> static devcb_base &set_kbdata_handler(device_t &device, _Object object) { return downcast<victor9k_keyboard_device &>(device).m_kbdata_handler.set_callback(object); }
 
 	// optional information overrides
 	virtual const rom_entry *device_rom_region() const;
@@ -87,7 +82,8 @@ private:
 	required_ioport m_yb;
 	required_ioport m_yc;
 
-	devcb2_write_line   m_write_kbrdy;
+	devcb_write_line   m_kbrdy_handler;
+	devcb_write_line   m_kbdata_handler;
 
 	UINT8 m_y;
 	int m_kbrdy;
