@@ -58,17 +58,17 @@ Apple color FPD      01           11           10   (FPD = Full Page Display)
 
 PALETTE_INIT_MEMBER(mac_state,mac)
 {
-	palette_set_color_rgb(machine(), 0, 0xff, 0xff, 0xff);
-	palette_set_color_rgb(machine(), 1, 0x00, 0x00, 0x00);
+	palette.set_pen_color(0, 0xff, 0xff, 0xff);
+	palette.set_pen_color(1, 0x00, 0x00, 0x00);
 }
 
 // 4-level grayscale
 PALETTE_INIT_MEMBER(mac_state,macgsc)
 {
-	palette_set_color_rgb(machine(), 0, 0xff, 0xff, 0xff);
-	palette_set_color_rgb(machine(), 1, 0x7f, 0x7f, 0x7f);
-	palette_set_color_rgb(machine(), 2, 0x3f, 0x3f, 0x3f);
-	palette_set_color_rgb(machine(), 3, 0x00, 0x00, 0x00);
+	palette.set_pen_color(0, 0xff, 0xff, 0xff);
+	palette.set_pen_color(1, 0x7f, 0x7f, 0x7f);
+	palette.set_pen_color(2, 0x3f, 0x3f, 0x3f);
+	palette.set_pen_color(3, 0x00, 0x00, 0x00);
 }
 
 VIDEO_START_MEMBER(mac_state,mac)
@@ -280,7 +280,7 @@ VIDEO_RESET_MEMBER(mac_state,macrbv)
 	}
 
 //    printf("RBV reset: monitor is %dx%d @ %f Hz\n", visarea.max_x+1, visarea.max_y+1, framerate);
-	machine().primary_screen->configure(htotal, vtotal, visarea, HZ_TO_ATTOSECONDS(framerate));
+	machine().first_screen()->configure(htotal, vtotal, visarea, HZ_TO_ATTOSECONDS(framerate));
 	render_target *target = machine().render().first_target();
 	target->set_view(view);
 }
@@ -337,7 +337,7 @@ VIDEO_RESET_MEMBER(mac_state,macsonora)
 	}
 
 //    printf("Sonora reset: monitor is %dx%d @ %f Hz\n", visarea.max_x+1, visarea.max_y+1, framerate);
-	machine().primary_screen->configure(htotal, vtotal, visarea, HZ_TO_ATTOSECONDS(framerate));
+	machine().first_screen()->configure(htotal, vtotal, visarea, HZ_TO_ATTOSECONDS(framerate));
 	render_target *target = machine().render().first_target();
 	target->set_view(view);
 }
@@ -848,7 +848,7 @@ UINT32 mac_state::screen_update_macsonora(screen_device &screen, bitmap_rgb32 &b
 				for (x = 0; x < hres; x++)
 				{
 					pixels = vram16[(y * stride) + (x^1)];
-					*scanline++ = MAKE_RGB(((pixels>>10) & 0x1f)<<3, ((pixels>>5) & 0x1f)<<3, (pixels & 0x1f)<<3);
+					*scanline++ = rgb_t(((pixels>>10) & 0x1f)<<3, ((pixels>>5) & 0x1f)<<3, (pixels & 0x1f)<<3);
 				}
 			}
 		}
@@ -1030,8 +1030,8 @@ WRITE32_MEMBER(mac_state::dafb_dac_w)
 
 			if (m_rbv_count == 3)
 			{
-				palette_set_color(space.machine(), m_rbv_clutoffs, MAKE_RGB(m_rbv_colors[0], m_rbv_colors[1], m_rbv_colors[2]));
-				m_rbv_palette[m_rbv_clutoffs] = MAKE_RGB(m_rbv_colors[0], m_rbv_colors[1], m_rbv_colors[2]);
+				m_palette->set_pen_color(m_rbv_clutoffs, rgb_t(m_rbv_colors[0], m_rbv_colors[1], m_rbv_colors[2]));
+				m_rbv_palette[m_rbv_clutoffs] = rgb_t(m_rbv_colors[0], m_rbv_colors[1], m_rbv_colors[2]);
 				m_rbv_clutoffs++;
 				m_rbv_count = 0;
 			}
@@ -1238,7 +1238,7 @@ WRITE32_MEMBER(mac_state::macwd_w)
 				if (m_rbv_count == 3)
 				{
 //                    printf("RAMDAC: color %d = %02x %02x %02x\n", m_rbv_clutoffs, m_rbv_colors[0], m_rbv_colors[1], m_rbv_colors[2]);
-					m_rbv_palette[m_rbv_clutoffs] = MAKE_RGB(m_rbv_colors[0], m_rbv_colors[1], m_rbv_colors[2]);
+					m_rbv_palette[m_rbv_clutoffs] = rgb_t(m_rbv_colors[0], m_rbv_colors[1], m_rbv_colors[2]);
 					m_rbv_clutoffs++;
 					m_rbv_count = 0;
 				}
