@@ -19,9 +19,9 @@ void nes_state::video_start()
 	m_last_frame_flip =  0;
 }
 
-void nes_state::palette_init()
+PALETTE_INIT_MEMBER(nes_state, nes)
 {
-	m_ppu->init_palette(machine(), 0);
+	m_ppu->init_palette(palette, 0);
 }
 
 
