@@ -20,11 +20,7 @@
 #define __OSDCORE_H__
 
 #include "osdcomm.h"
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
+#include "delegate.h"
 
 /***************************************************************************
     FILE I/O INTERFACES
@@ -166,6 +162,23 @@ file_error osd_read(osd_file *file, void *buffer, UINT64 offset, UINT32 length,
 file_error osd_write(osd_file *file, const void *buffer, UINT64 offset, UINT32 length, UINT32 *actual);
 
 
+/*-----------------------------------------------------------------------------
+    osd_truncate: change the size of an open file
+
+    Parameters:
+
+        file - handle to a file previously opened via osd_open
+
+        offset - future size of the file
+
+    Return value:
+
+        a file_error describing any error that occurred while writing to
+        the file, or FILERR_NONE if no error occurred
+-----------------------------------------------------------------------------*/
+file_error osd_truncate(osd_file *file, UINT64 offset);
+
+
 /*-----------------------------------------------------------------------------
     osd_rmfile: deletes a file
 
@@ -830,7 +843,8 @@ char *osd_get_clipboard_text(void);
     Return value:
 
         an allocated pointer to an osd_directory_entry representing
-        info on the path; even if the file does not exist
+        info on the path; even if the file does not exist.
+        free with osd_free()
 
 -----------------------------------------------------------------------------*/
 osd_directory_entry *osd_stat(const char *path);
@@ -860,10 +874,10 @@ file_error osd_get_full_path(char **dst, const char *path);
 ***************************************************************************/
 struct osd_midi_device;
 
-void osd_init_midi(void);
-void osd_shutdown_midi(void);
 void osd_list_midi_devices(void);
+// free result with osd_close_midi_channel()
 osd_midi_device *osd_open_midi_input(const char *devname);
+// free result with osd_close_midi_channel()
 osd_midi_device *osd_open_midi_output(const char *devname);
 void osd_close_midi_channel(osd_midi_device *dev);
 bool osd_poll_midi_channel(osd_midi_device *dev);
@@ -888,8 +902,38 @@ void osd_write_midi_channel(osd_midi_device *dev, UINT8 data);
 -----------------------------------------------------------------------------*/
 const char *osd_get_volume_name(int idx);
 
-#ifdef __cplusplus
-}
-#endif
+/* ----- output management ----- */
+
+// output channels
+enum output_channel
+{
+	OSD_OUTPUT_CHANNEL_ERROR,
+	OSD_OUTPUT_CHANNEL_WARNING,
+	OSD_OUTPUT_CHANNEL_INFO,
+	OSD_OUTPUT_CHANNEL_DEBUG,
+	OSD_OUTPUT_CHANNEL_VERBOSE,
+	OSD_OUTPUT_CHANNEL_LOG,
+	OSD_OUTPUT_CHANNEL_COUNT
+};
+
+// output channel callback
+typedef delegate<void (const char *, va_list)> output_delegate;
+
+/* set the output handler for a channel, returns the current one */
+output_delegate osd_set_output_channel(output_channel channel, output_delegate callback);
+
+/* calls to be used by the code */
+void CLIB_DECL osd_printf_error(const char *format, ...) ATTR_PRINTF(1,2);
+void CLIB_DECL osd_printf_warning(const char *format, ...) ATTR_PRINTF(1,2);
+void CLIB_DECL osd_printf_info(const char *format, ...) ATTR_PRINTF(1,2);
+void CLIB_DECL osd_printf_verbose(const char *format, ...) ATTR_PRINTF(1,2);
+void CLIB_DECL osd_printf_debug(const char *format, ...) ATTR_PRINTF(1,2);
+
+/* discourage the use of printf directly */
+/* sadly, can't do this because of the ATTR_PRINTF under GCC */
+/*
+#undef printf
+#define printf !MUST_USE_osd_printf_*_CALLS_WITHIN_THE_CORE!
+*/
 
 #endif  /* __OSDEPEND_H__ */
