@@ -40,7 +40,7 @@
 // MAME headers
 #include "emu.h"
 #include "rendutil.h"
-#include "ui.h"
+#include "ui/ui.h"
 #include "emuopts.h"
 #include "uiinput.h"
 
@@ -49,11 +49,6 @@
 #include "video.h"
 #include "window.h"
 #include "input.h"
-
-#if !defined(NO_DEBUGGER)
-#include "debugqt.h"
-#endif
-
 #include "osdsdl.h"
 #include "sdlos.h"
 
@@ -85,7 +80,6 @@ static sdl_monitor_info *sdl_monitor_list;
 //  PROTOTYPES
 //============================================================
 
-static void video_exit(running_machine &machine);
 static void init_monitors(void);
 static sdl_monitor_info *pick_monitor(sdl_options &options, int index);
 
@@ -98,44 +92,38 @@ static void get_resolution(const char *defdata, const char *data, sdl_window_con
 
 
 //============================================================
-//  sdlvideo_init
+//  video_init
 //============================================================
 
-int sdlvideo_init(running_machine &machine)
+bool sdl_osd_interface::video_init()
 {
-	int index, tc;
+	int index;
 
 	// extract data from the options
-	extract_video_config(machine);
-
-	// ensure we get called on the way out
-	machine.add_notifier(MACHINE_NOTIFY_EXIT, machine_notify_delegate(FUNC(video_exit), &machine));
+	extract_video_config(machine());
 
 	// set up monitors first
 	init_monitors();
 
 	// we need the beam width in a float, contrary to what the core does.
-	video_config.beamwidth = machine.options().beam();
+	video_config.beamwidth = machine().options().beam();
 
 	// initialize the window system so we can make windows
-	if (sdlwindow_init(machine))
-		return 1;
-
-	tc = machine.total_colors();
+	if (sdlwindow_init(machine()))
+		return false;
 
 	// create the windows
-	sdl_options &options = downcast<sdl_options &>(machine.options());
+	sdl_options &options = downcast<sdl_options &>(machine().options());
 	for (index = 0; index < video_config.numscreens; index++)
 	{
 		sdl_window_config conf;
 		memset(&conf, 0, sizeof(conf));
-		extract_window_config(machine, index, &conf);
-		conf.totalColors = tc;
-		if (sdlwindow_video_window_create(machine, index, pick_monitor(options, index), &conf))
-			return 1;
+		extract_window_config(machine(), index, &conf);
+		if (sdlwindow_video_window_create(machine(), index, pick_monitor(options, index), &conf))
+			return false;
 	}
 
-	return 0;
+	return true;
 }
 
 
@@ -143,7 +131,7 @@ int sdlvideo_init(running_machine &machine)
 //  video_exit
 //============================================================
 
-static void video_exit(running_machine &machine)
+void sdl_osd_interface::video_exit()
 {
 	// free all of our monitor information
 	while (sdl_monitor_list != NULL)
@@ -250,10 +238,10 @@ void sdlvideo_monitor_refresh(sdl_monitor_info *monitor)
 					}
 					if ((cw==0) || (ch==0))
 					{
-						mame_printf_warning("WARNING: SDL_GetVideoInfo() for driver <%s> is broken.\n", monitor->monitor_device);
-						mame_printf_warning("         You should set SDLMAME_DESKTOPDIM to your desktop size.\n");
-						mame_printf_warning("            e.g. export SDLMAME_DESKTOPDIM=800x600\n");
-						mame_printf_warning("         Assuming 1024x768 now!\n");
+						osd_printf_warning("WARNING: SDL_GetVideoInfo() for driver <%s> is broken.\n", monitor->monitor_device);
+						osd_printf_warning("         You should set SDLMAME_DESKTOPDIM to your desktop size.\n");
+						osd_printf_warning("            e.g. export SDLMAME_DESKTOPDIM=800x600\n");
+						osd_printf_warning("         Assuming 1024x768 now!\n");
 						cw=1024;
 						ch=768;
 					}
@@ -277,8 +265,8 @@ void sdlvideo_monitor_refresh(sdl_monitor_info *monitor)
 		static int info_shown=0;
 		if (!info_shown)
 		{
-			mame_printf_verbose("SDL Device Driver     : %s\n", monitor->monitor_device);
-			mame_printf_verbose("SDL Monitor Dimensions: %d x %d\n", monitor->monitor_width, monitor->monitor_height);
+			osd_printf_verbose("SDL Device Driver     : %s\n", monitor->monitor_device);
+			osd_printf_verbose("SDL Monitor Dimensions: %d x %d\n", monitor->monitor_width, monitor->monitor_height);
 			info_shown = 1;
 		}
 	}
@@ -344,10 +332,8 @@ void sdl_osd_interface::update(bool skip_redraw)
 	sdlinput_poll(machine());
 	check_osd_inputs(machine());
 
-#if !defined(NO_DEBUGGER)
 	if ((machine().debug_flags & DEBUG_FLAG_OSD_ENABLED) != 0)
-		debugwin_update_during_game(machine());
-#endif
+		debugger_update();
 }
 
 
@@ -451,7 +437,7 @@ static void init_monitors(void)
 	{
 		int i;
 
-		mame_printf_verbose("Enter init_monitors\n");
+		osd_printf_verbose("Enter init_monitors\n");
 
 		for (i = 0; i < SDL_GetNumVideoDisplays(); i++)
 		{
@@ -461,7 +447,7 @@ static void init_monitors(void)
 			// allocate a new monitor info
 			monitor = global_alloc_clear(sdl_monitor_info);
 
-			snprintf(monitor->monitor_device, sizeof(monitor->monitor_device)-1, "%s%d", SDLOPTION_SCREEN,i);
+			snprintf(monitor->monitor_device, sizeof(monitor->monitor_device)-1, "%s%d", OSDOPTION_SCREEN,i);
 
 			SDL_GetDesktopDisplayMode(i, &dmode);
 			monitor->monitor_width = dmode.w;
@@ -471,7 +457,7 @@ static void init_monitors(void)
 			monitor->handle = i;
 			// guess the aspect ratio assuming square pixels
 			monitor->aspect = (float)(dmode.w) / (float)(dmode.h);
-			mame_printf_verbose("Adding monitor %s (%d x %d)\n", monitor->monitor_device, dmode.w, dmode.h);
+			osd_printf_verbose("Adding monitor %s (%d x %d)\n", monitor->monitor_device, dmode.w, dmode.h);
 
 			// save the primary monitor handle
 			if (i == 0)
@@ -482,7 +468,7 @@ static void init_monitors(void)
 			tailptr = &monitor->next;
 		}
 	}
-	mame_printf_verbose("Leave init_monitors\n");
+	osd_printf_verbose("Leave init_monitors\n");
 	#elif defined(SDLMAME_WIN32)
 	EnumDisplayMonitors(NULL, NULL, monitor_enum_callback, (LPARAM)&tailptr);
 	#else
@@ -571,25 +557,24 @@ static void check_osd_inputs(running_machine &machine)
 	{
 		//FIXME: on a per window basis
 		video_config.fullstretch = !video_config.fullstretch;
-		ui_popup_time(1, "Uneven stretch %s", video_config.fullstretch? "enabled":"disabled");
+		machine.ui().popup_time(1, "Uneven stretch %s", video_config.fullstretch? "enabled":"disabled");
 	}
 
 	if (ui_input_pressed(machine, IPT_OSD_4))
 	{
 		//FIXME: on a per window basis
 		video_config.keepaspect = !video_config.keepaspect;
-		ui_popup_time(1, "Keepaspect %s", video_config.keepaspect? "enabled":"disabled");
+		machine.ui().popup_time(1, "Keepaspect %s", video_config.keepaspect? "enabled":"disabled");
 	}
 
-	if (USE_OPENGL || SDLMAME_SDL2)
-	{
+	#if (USE_OPENGL || SDLMAME_SDL2)
 		//FIXME: on a per window basis
 		if (ui_input_pressed(machine, IPT_OSD_5))
 		{
 			video_config.filter = !video_config.filter;
-			ui_popup_time(1, "Filter %s", video_config.filter? "enabled":"disabled");
+			machine.ui().popup_time(1, "Filter %s", video_config.filter? "enabled":"disabled");
 		}
-	}
+	#endif
 
 	if (ui_input_pressed(machine, IPT_OSD_6))
 		sdlwindow_modify_prescale(machine, window, -1);
@@ -638,6 +623,14 @@ static void extract_video_config(running_machine &machine)
 
 	// d3d options: extract the data
 	stemp = options.video();
+	if (strcmp(stemp, "auto") == 0)
+	{
+#ifdef SDLMAME_MACOSX
+		stemp = "opengl";
+#else
+		stemp = "soft";
+#endif
+	}
 	if (strcmp(stemp, SDLOPTVAL_SOFT) == 0)
 		video_config.mode = VIDEO_MODE_SOFT;
 	else if (strcmp(stemp, SDLOPTVAL_NONE) == 0)
@@ -646,7 +639,7 @@ static void extract_video_config(running_machine &machine)
 		video_config.novideo = 1;
 
 		if (options.seconds_to_run() == 0)
-			mame_printf_warning("Warning: -video none doesn't make much sense without -seconds_to_run\n");
+			osd_printf_warning("Warning: -video none doesn't make much sense without -seconds_to_run\n");
 	}
 	else if (USE_OPENGL && (strcmp(stemp, SDLOPTVAL_OPENGL) == 0))
 		video_config.mode = VIDEO_MODE_OPENGL;
@@ -662,7 +655,7 @@ static void extract_video_config(running_machine &machine)
 	}
 	else
 	{
-		mame_printf_warning("Invalid video value %s; reverting to software\n", stemp);
+		osd_printf_warning("Invalid video value %s; reverting to software\n", stemp);
 		video_config.mode = VIDEO_MODE_SOFT;
 	}
 
@@ -673,21 +666,19 @@ static void extract_video_config(running_machine &machine)
 	video_config.syncrefresh   = options.sync_refresh();
 	if (!video_config.waitvsync && video_config.syncrefresh)
 	{
-		mame_printf_warning("-syncrefresh specified without -waitsync. Reverting to -nosyncrefresh\n");
+		osd_printf_warning("-syncrefresh specified without -waitsync. Reverting to -nosyncrefresh\n");
 		video_config.syncrefresh = 0;
 	}
 
-	if (USE_OPENGL || SDLMAME_SDL2)
-	{
+	#if (USE_OPENGL || SDLMAME_SDL2)
 		video_config.filter        = options.filter();
-	}
+	#endif
 
-	if (USE_OPENGL)
-	{
+	#if (USE_OPENGL)
 		video_config.prescale      = options.prescale();
 		if (video_config.prescale < 1 || video_config.prescale > 3)
 		{
-			mame_printf_warning("Invalid prescale option, reverting to '1'\n");
+			osd_printf_warning("Invalid prescale option, reverting to '1'\n");
 			video_config.prescale = 1;
 		}
 		// default to working video please
@@ -732,20 +723,6 @@ static void extract_video_config(running_machine &machine)
 					video_config.glsl_shader_scrn[i] = NULL;
 				}
 			}
-
-			video_config.glsl_vid_attributes = options.glsl_vid_attr();
-			{
-				// Disable feature: glsl_vid_attributes, as long we have the gamma calculation
-				// disabled within the direct shaders .. -> too slow.
-				// IMHO the gamma setting should be done global anyways, and for the whole system,
-				// not just MAME ..
-				float gamma = options.gamma();
-				if (gamma != 1.0 && video_config.glsl_vid_attributes && video_config.glsl)
-				{
-					video_config.glsl_vid_attributes = FALSE;
-					mame_printf_warning("OpenGL: GLSL - disable handling of brightness and contrast, gamma is set to %f\n", gamma);
-				}
-			}
 		} else {
 			int i;
 			video_config.glsl_filter = 0;
@@ -759,23 +736,22 @@ static void extract_video_config(running_machine &machine)
 			{
 				video_config.glsl_shader_scrn[i] = NULL;
 			}
-			video_config.glsl_vid_attributes = 0;
 		}
 
-	}
+	#endif /* USE_OPENGL */
 	// misc options: sanity check values
 
 	// global options: sanity check values
 #if (!SDLMAME_SDL2)
 	if (video_config.numscreens < 1 || video_config.numscreens > 1) //MAX_VIDEO_WINDOWS)
 	{
-		mame_printf_warning("Invalid numscreens value %d; reverting to 1\n", video_config.numscreens);
+		osd_printf_warning("Invalid numscreens value %d; reverting to 1\n", video_config.numscreens);
 		video_config.numscreens = 1;
 	}
 #else
 	if (video_config.numscreens < 1 || video_config.numscreens > MAX_VIDEO_WINDOWS)
 	{
-		mame_printf_warning("Invalid numscreens value %d; reverting to 1\n", video_config.numscreens);
+		osd_printf_warning("Invalid numscreens value %d; reverting to 1\n", video_config.numscreens);
 		video_config.numscreens = 1;
 	}
 #endif
@@ -784,12 +760,12 @@ static void extract_video_config(running_machine &machine)
 	video_config.scale_mode = drawsdl_scale_mode(stemp);
 	if (video_config.scale_mode < 0)
 	{
-		mame_printf_warning("Invalid yuvmode value %s; reverting to none\n", stemp);
+		osd_printf_warning("Invalid yuvmode value %s; reverting to none\n", stemp);
 		video_config.scale_mode = VIDEO_SCALE_MODE_NONE;
 	}
 	if ( (video_config.mode != VIDEO_MODE_SOFT) && (video_config.scale_mode != VIDEO_SCALE_MODE_NONE) )
 	{
-		mame_printf_warning("scalemode is only for -video soft, overriding\n");
+		osd_printf_warning("scalemode is only for -video soft, overriding\n");
 		video_config.scale_mode = VIDEO_SCALE_MODE_NONE;
 	}
 }
@@ -810,7 +786,7 @@ static float get_aspect(const char *defdata, const char *data, int report_error)
 		data = defdata;
 	}
 	if (sscanf(data, "%d:%d", &num, &den) != 2 && report_error)
-		mame_printf_error("Illegal aspect ratio value = %s\n", data);
+		osd_printf_error("Illegal aspect ratio value = %s\n", data);
 	return (float)num / (float)den;
 }
 
@@ -833,5 +809,5 @@ static void get_resolution(const char *defdata, const char *data, sdl_window_con
 	}
 
 	if (sscanf(data, "%dx%dx%d@%d", &config->width, &config->height, &config->depth, &config->refresh) < 2 && report_error)
-		mame_printf_error("Illegal resolution value = %s\n", data);
+		osd_printf_error("Illegal resolution value = %s\n", data);
 }
