@@ -18,7 +18,7 @@
 #include "render.h"
 #include "rendutil.h"
 #include "options.h"
-#include "rendersw.c"
+#include "rendersw.inc"
 
 // MAMEOS headers
 #include "winmain.h"
@@ -61,7 +61,7 @@ struct dd_info
 	DDCAPS                  ddcaps;                     // capabilities of the device
 	DDCAPS                  helcaps;                    // capabilities of the hardware
 
-	void *                  membuffer;                  // memory buffer for complex rendering
+	UINT8 *                 membuffer;                  // memory buffer for complex rendering
 	UINT32                  membuffersize;              // current size of the memory buffer
 };
 
@@ -159,7 +159,7 @@ int drawdd_init(running_machine &machine, win_draw_callbacks *callbacks)
 	dllhandle = LoadLibrary(TEXT("ddraw.dll"));
 	if (dllhandle == NULL)
 	{
-		mame_printf_verbose("DirectDraw: Unable to access ddraw.dll\n");
+		osd_printf_verbose("DirectDraw: Unable to access ddraw.dll\n");
 		return 1;
 	}
 
@@ -167,7 +167,7 @@ int drawdd_init(running_machine &machine, win_draw_callbacks *callbacks)
 	directdrawcreateex = (directdrawcreateex_ptr)GetProcAddress(dllhandle, "DirectDrawCreateEx");
 	if (directdrawcreateex == NULL)
 	{
-		mame_printf_verbose("DirectDraw: Unable to find DirectDrawCreateEx\n");
+		osd_printf_verbose("DirectDraw: Unable to find DirectDrawCreateEx\n");
 		FreeLibrary(dllhandle);
 		dllhandle = NULL;
 		return 1;
@@ -177,23 +177,21 @@ int drawdd_init(running_machine &machine, win_draw_callbacks *callbacks)
 	directdrawenumerateex = (directdrawenumerateex_ptr)GetProcAddress(dllhandle, "DirectDrawEnumerateExA");
 	if (directdrawenumerateex == NULL)
 	{
-		mame_printf_verbose("DirectDraw: Unable to find DirectDrawEnumerateExA\n");
+		osd_printf_verbose("DirectDraw: Unable to find DirectDrawEnumerateExA\n");
 		FreeLibrary(dllhandle);
 		dllhandle = NULL;
 		return 1;
 	}
 
 	// fill in the callbacks
+	memset(callbacks, 0, sizeof(*callbacks));
 	callbacks->exit = drawdd_exit;
 	callbacks->window_init = drawdd_window_init;
 	callbacks->window_get_primitives = drawdd_window_get_primitives;
 	callbacks->window_draw = drawdd_window_draw;
-	callbacks->window_save = NULL;
-	callbacks->window_record = NULL;
-	callbacks->window_toggle_fsfx = NULL;
 	callbacks->window_destroy = drawdd_window_destroy;
 
-	mame_printf_verbose("DirectDraw: Using DirectDraw 7\n");
+	osd_printf_verbose("DirectDraw: Using DirectDraw 7\n");
 	return 0;
 }
 
@@ -235,7 +233,7 @@ static int drawdd_window_init(win_window_info *window)
 
 error:
 	drawdd_window_destroy(window);
-	mame_printf_error("Unable to initialize DirectDraw.\n");
+	osd_printf_error("Unable to initialize DirectDraw.\n");
 	return 1;
 }
 
@@ -315,13 +313,13 @@ static int drawdd_window_draw(win_window_info *window, HDC dc, int update)
 	result = IDirectDrawSurface7_Lock(dd->blit, NULL, &dd->blitdesc, DDLOCK_WAIT, NULL);
 	if (result == DDERR_SURFACELOST)
 	{
-		mame_printf_verbose("DirectDraw: Lost surfaces; deleting and retrying next frame\n");
+		osd_printf_verbose("DirectDraw: Lost surfaces; deleting and retrying next frame\n");
 		ddraw_delete_surfaces(window);
 		return 1;
 	}
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X locking blit surface\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X locking blit surface\n", (int)result);
 		return 1;
 	}
 
@@ -350,7 +348,7 @@ static int drawdd_window_draw(win_window_info *window, HDC dc, int update)
 			case 0xf800:        software_renderer<UINT16, 3,2,3, 11,5,0>::draw_primitives(*window->primlist, dd->membuffer, dd->blitwidth, dd->blitheight, dd->blitwidth);  break;
 			case 0x7c00:        software_renderer<UINT16, 3,3,3, 10,5,0>::draw_primitives(*window->primlist, dd->membuffer, dd->blitwidth, dd->blitheight, dd->blitwidth);  break;
 			default:
-				mame_printf_verbose("DirectDraw: Unknown target mode: R=%08X G=%08X B=%08X\n", (int)dd->blitdesc.ddpfPixelFormat.dwRBitMask, (int)dd->blitdesc.ddpfPixelFormat.dwGBitMask, (int)dd->blitdesc.ddpfPixelFormat.dwBBitMask);
+				osd_printf_verbose("DirectDraw: Unknown target mode: R=%08X G=%08X B=%08X\n", (int)dd->blitdesc.ddpfPixelFormat.dwRBitMask, (int)dd->blitdesc.ddpfPixelFormat.dwGBitMask, (int)dd->blitdesc.ddpfPixelFormat.dwBBitMask);
 				break;
 		}
 
@@ -386,7 +384,7 @@ static int drawdd_window_draw(win_window_info *window, HDC dc, int update)
 			case 0xf800:        software_renderer<UINT16, 3,2,3, 11,5,0, true>::draw_primitives(*window->primlist, dd->blitdesc.lpSurface, dd->blitwidth, dd->blitheight, dd->blitdesc.lPitch / 2); break;
 			case 0x7c00:        software_renderer<UINT16, 3,3,3, 10,5,0, true>::draw_primitives(*window->primlist, dd->blitdesc.lpSurface, dd->blitwidth, dd->blitheight, dd->blitdesc.lPitch / 2); break;
 			default:
-				mame_printf_verbose("DirectDraw: Unknown target mode: R=%08X G=%08X B=%08X\n", (int)dd->blitdesc.ddpfPixelFormat.dwRBitMask, (int)dd->blitdesc.ddpfPixelFormat.dwGBitMask, (int)dd->blitdesc.ddpfPixelFormat.dwBBitMask);
+				osd_printf_verbose("DirectDraw: Unknown target mode: R=%08X G=%08X B=%08X\n", (int)dd->blitdesc.ddpfPixelFormat.dwRBitMask, (int)dd->blitdesc.ddpfPixelFormat.dwGBitMask, (int)dd->blitdesc.ddpfPixelFormat.dwBBitMask);
 				break;
 		}
 	}
@@ -394,13 +392,13 @@ static int drawdd_window_draw(win_window_info *window, HDC dc, int update)
 
 	// unlock and blit
 	result = IDirectDrawSurface7_Unlock(dd->blit, NULL);
-	if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X unlocking blit surface\n", (int)result);
+	if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X unlocking blit surface\n", (int)result);
 
 	// sync to VBLANK
 	if ((video_config.waitvsync || video_config.syncrefresh) && window->machine().video().throttled() && (!window->fullscreen || dd->back == NULL))
 	{
 		result = IDirectDraw7_WaitForVerticalBlank(dd->ddraw, DDWAITVB_BLOCKBEGIN, NULL);
-		if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X waiting for VBLANK\n", (int)result);
+		if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X waiting for VBLANK\n", (int)result);
 	}
 
 	// complete the blitting
@@ -428,7 +426,7 @@ static int ddraw_create(win_window_info *window)
 	result = (*directdrawcreateex)(dd->adapter_ptr, (LPVOID *)&dd->ddraw, WRAP_REFIID(IID_IDirectDraw7), NULL);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X during DirectDrawCreateEx call\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X during DirectDrawCreateEx call\n", (int)result);
 		goto error;
 	}
 
@@ -436,24 +434,24 @@ static int ddraw_create(win_window_info *window)
 	verify = ddraw_verify_caps(dd);
 	if (verify == 2)
 	{
-		mame_printf_error("DirectDraw: Error - Device does not meet minimum requirements for DirectDraw rendering\n");
+		osd_printf_error("DirectDraw: Error - Device does not meet minimum requirements for DirectDraw rendering\n");
 		goto error;
 	}
 	if (verify == 1)
-		mame_printf_verbose("DirectDraw: Warning - Device may not perform well for DirectDraw rendering\n");
+		osd_printf_verbose("DirectDraw: Warning - Device may not perform well for DirectDraw rendering\n");
 
 	// set the cooperative level
 	// for non-window modes, we will use full screen here
 	result = IDirectDraw7_SetCooperativeLevel(dd->ddraw, win_window_list->hwnd, DDSCL_SETFOCUSWINDOW);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X during IDirectDraw7_SetCooperativeLevel(FOCUSWINDOW) call\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X during IDirectDraw7_SetCooperativeLevel(FOCUSWINDOW) call\n", (int)result);
 		goto error;
 	}
 	result = IDirectDraw7_SetCooperativeLevel(dd->ddraw, window->hwnd, DDSCL_SETDEVICEWINDOW | (window->fullscreen ? DDSCL_FULLSCREEN | DDSCL_EXCLUSIVE : DDSCL_NORMAL));
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X during IDirectDraw7_SetCooperativeLevel(DEVICEWINDOW) call\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X during IDirectDraw7_SetCooperativeLevel(DEVICEWINDOW) call\n", (int)result);
 		goto error;
 	}
 
@@ -463,7 +461,7 @@ static int ddraw_create(win_window_info *window)
 		result = IDirectDraw7_SetDisplayMode(dd->ddraw, dd->width, dd->height, 32, dd->refresh, 0);
 		if (result != DD_OK)
 		{
-			mame_printf_verbose("DirectDraw: Error %08X attempting to set video mode %dx%d@%d call\n", (int)result, dd->width, dd->height, dd->refresh);
+			osd_printf_verbose("DirectDraw: Error %08X attempting to set video mode %dx%d@%d call\n", (int)result, dd->width, dd->height, dd->refresh);
 			goto error;
 		}
 	}
@@ -512,7 +510,7 @@ static int ddraw_create_surfaces(win_window_info *window)
 		result = IDirectDrawSurface7_GetAttachedSurface(dd->primary, &caps, &dd->back);
 		if (result != DD_OK)
 		{
-			mame_printf_verbose("DirectDraw: Error %08X getting attached back surface\n", (int)result);
+			osd_printf_verbose("DirectDraw: Error %08X getting attached back surface\n", (int)result);
 			goto error;
 		}
 	}
@@ -539,7 +537,7 @@ static int ddraw_create_surfaces(win_window_info *window)
 	if (dd->membuffersize < dd->blitwidth * dd->blitheight * 4)
 	{
 		dd->membuffersize = dd->blitwidth * dd->blitheight * 4;
-		global_free(dd->membuffer);
+		global_free_array(dd->membuffer);
 		dd->membuffer = global_alloc_array(UINT8, dd->membuffersize);
 	}
 	if (dd->membuffer == NULL)
@@ -563,7 +561,7 @@ static int ddraw_create_surfaces(win_window_info *window)
 			result = IDirectDrawSurface_QueryInterface(dd->primary, WRAP_REFIID(IID_IDirectDrawGammaControl), (void **)&dd->gamma);
 			if (result != DD_OK)
 			{
-				mame_printf_warning("DirectDraw: Warning - device does not support full screen gamma correction.\n");
+				osd_printf_warning("DirectDraw: Warning - device does not support full screen gamma correction.\n");
 				dd->gamma = NULL;
 			}
 
@@ -580,7 +578,7 @@ static int ddraw_create_surfaces(win_window_info *window)
 				// attempt to set it
 				result = IDirectDrawGammaControl_SetGammaRamp(dd->gamma, 0, &ramp);
 				if (result != DD_OK)
-					mame_printf_verbose("DirectDraw: Error %08X attempting to set gamma correction.\n", (int)result);
+					osd_printf_verbose("DirectDraw: Error %08X attempting to set gamma correction.\n", (int)result);
 			}
 		}
 	}
@@ -642,7 +640,7 @@ static void ddraw_delete_surfaces(win_window_info *window)
 	dd->clipper = NULL;
 
 	// free the memory buffer
-	global_free(dd->membuffer);
+	global_free_array(dd->membuffer);
 	dd->membuffer = NULL;
 	dd->membuffersize = 0;
 
@@ -679,14 +677,14 @@ static int ddraw_verify_caps(dd_info *dd)
 	result = IDirectDraw7_GetCaps(dd->ddraw, &dd->ddcaps, &dd->helcaps);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X during IDirectDraw7_GetCaps call\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X during IDirectDraw7_GetCaps call\n", (int)result);
 		return 1;
 	}
 
 	// determine if hardware stretching is available
 	if ((dd->ddcaps.dwCaps & DDCAPS_BLTSTRETCH) == 0)
 	{
-		mame_printf_verbose("DirectDraw: Warning - Device does not support hardware stretching\n");
+		osd_printf_verbose("DirectDraw: Warning - Device does not support hardware stretching\n");
 		retval = 1;
 	}
 
@@ -737,7 +735,7 @@ static HRESULT create_surface(dd_info *dd, DDSURFACEDESC2 *desc, IDirectDrawSurf
 	result = IDirectDraw7_CreateSurface(dd->ddraw, desc, surface, NULL);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X creating %s surface\n", (int)result, type);
+		osd_printf_verbose("DirectDraw: Error %08X creating %s surface\n", (int)result, type);
 		return result;
 	}
 
@@ -745,14 +743,14 @@ static HRESULT create_surface(dd_info *dd, DDSURFACEDESC2 *desc, IDirectDrawSurf
 	result = IDirectDrawSurface7_GetSurfaceDesc(*surface, desc);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X getting %s surface desciption\n", (int)result, type);
+		osd_printf_verbose("DirectDraw: Error %08X getting %s surface desciption\n", (int)result, type);
 		IDirectDrawSurface7_Release(*surface);
 		*surface = NULL;
 		return result;
 	}
 
 	// print out the good stuff
-	mame_printf_verbose("DirectDraw: %s surface created: %dx%dx%d (R=%08X G=%08X B=%08X)\n",
+	osd_printf_verbose("DirectDraw: %s surface created: %dx%dx%d (R=%08X G=%08X B=%08X)\n",
 				type,
 				(int)desc->dwWidth,
 				(int)desc->dwHeight,
@@ -778,7 +776,7 @@ static int create_clipper(win_window_info *window)
 	result = IDirectDraw7_CreateClipper(dd->ddraw, 0, &dd->clipper, NULL);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X creating clipper\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X creating clipper\n", (int)result);
 		return 1;
 	}
 
@@ -786,7 +784,7 @@ static int create_clipper(win_window_info *window)
 	result = IDirectDrawClipper_SetHWnd(dd->clipper, 0, window->hwnd);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X setting clipper hwnd\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X setting clipper hwnd\n", (int)result);
 		return 1;
 	}
 
@@ -794,7 +792,7 @@ static int create_clipper(win_window_info *window)
 	result = IDirectDrawSurface7_SetClipper(dd->primary, dd->clipper);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X setting clipper on primary surface\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X setting clipper on primary surface\n", (int)result);
 		return 1;
 	}
 	return 0;
@@ -890,7 +888,7 @@ static void compute_blit_surface_size(win_window_info *window)
 	{
 		// force some updates
 		update_outer_rects(dd);
-		mame_printf_verbose("DirectDraw: New blit size = %dx%d\n", newwidth, newheight);
+		osd_printf_verbose("DirectDraw: New blit size = %dx%d\n", newwidth, newheight);
 	}
 	dd->blitwidth = newwidth;
 	dd->blitheight = newheight;
@@ -1016,7 +1014,7 @@ static void blit_to_primary(win_window_info *window, int srcwidth, int srcheight
 			clear = outer;
 			clear.right = dest.left;
 			result = IDirectDrawSurface_Blt(target, &clear, NULL, NULL, DDBLT_COLORFILL | DDBLT_WAIT, &blitfx);
-			if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X clearing the screen\n", (int)result);
+			if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X clearing the screen\n", (int)result);
 		}
 
 		// clear the right edge
@@ -1025,7 +1023,7 @@ static void blit_to_primary(win_window_info *window, int srcwidth, int srcheight
 			clear = outer;
 			clear.left = dest.right;
 			result = IDirectDrawSurface_Blt(target, &clear, NULL, NULL, DDBLT_COLORFILL | DDBLT_WAIT, &blitfx);
-			if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X clearing the screen\n", (int)result);
+			if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X clearing the screen\n", (int)result);
 		}
 
 		// clear the top edge
@@ -1034,7 +1032,7 @@ static void blit_to_primary(win_window_info *window, int srcwidth, int srcheight
 			clear = outer;
 			clear.bottom = dest.top;
 			result = IDirectDrawSurface_Blt(target, &clear, NULL, NULL, DDBLT_COLORFILL | DDBLT_WAIT, &blitfx);
-			if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X clearing the screen\n", (int)result);
+			if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X clearing the screen\n", (int)result);
 		}
 
 		// clear the bottom edge
@@ -1043,19 +1041,19 @@ static void blit_to_primary(win_window_info *window, int srcwidth, int srcheight
 			clear = outer;
 			clear.top = dest.bottom;
 			result = IDirectDrawSurface_Blt(target, &clear, NULL, NULL, DDBLT_COLORFILL | DDBLT_WAIT, &blitfx);
-			if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X clearing the screen\n", (int)result);
+			if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X clearing the screen\n", (int)result);
 		}
 	}
 
 	// do the blit
 	result = IDirectDrawSurface7_Blt(target, &dest, dd->blit, &source, DDBLT_WAIT, NULL);
-	if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X blitting to the screen\n", (int)result);
+	if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X blitting to the screen\n", (int)result);
 
 	// page flip if triple buffered
 	if (window->fullscreen && dd->back != NULL)
 	{
 		result = IDirectDrawSurface7_Flip(dd->primary, NULL, DDFLIP_WAIT);
-		if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X waiting for VBLANK\n", (int)result);
+		if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X waiting for VBLANK\n", (int)result);
 	}
 }
 
@@ -1078,7 +1076,7 @@ static int config_adapter_mode(win_window_info *window)
 	result = (*directdrawcreateex)(dd->adapter_ptr, (LPVOID *)&dd->ddraw, WRAP_REFIID(IID_IDirectDraw7), NULL);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X during DirectDrawCreateEx call\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X during DirectDrawCreateEx call\n", (int)result);
 		return 1;
 	}
 
@@ -1086,10 +1084,10 @@ static int config_adapter_mode(win_window_info *window)
 	result = IDirectDraw7_GetDeviceIdentifier(dd->ddraw, &identifier, 0);
 	if (result != DD_OK)
 	{
-		mame_printf_error("Error getting identifier for device\n");
+		osd_printf_error("Error getting identifier for device\n");
 		return 1;
 	}
-	mame_printf_verbose("DirectDraw: Configuring device %s\n", identifier.szDescription);
+	osd_printf_verbose("DirectDraw: Configuring device %s\n", identifier.szDescription);
 
 	// get the current display mode
 	memset(&dd->origmode, 0, sizeof(dd->origmode));
@@ -1097,7 +1095,7 @@ static int config_adapter_mode(win_window_info *window)
 	result = IDirectDraw7_GetDisplayMode(dd->ddraw, &dd->origmode);
 	if (result != DD_OK)
 	{
-		mame_printf_verbose("DirectDraw: Error %08X getting current display mode\n", (int)result);
+		osd_printf_verbose("DirectDraw: Error %08X getting current display mode\n", (int)result);
 		IDirectDraw7_Release(dd->ddraw);
 		return 1;
 	}
@@ -1131,7 +1129,7 @@ static int config_adapter_mode(win_window_info *window)
 				break;
 
 			default:
-				mame_printf_verbose("DirectDraw: Unknown target mode: R=%08X G=%08X B=%08X\n", (int)dd->origmode.ddpfPixelFormat.dwRBitMask, (int)dd->origmode.ddpfPixelFormat.dwGBitMask, (int)dd->origmode.ddpfPixelFormat.dwBBitMask);
+				osd_printf_verbose("DirectDraw: Unknown target mode: R=%08X G=%08X B=%08X\n", (int)dd->origmode.ddpfPixelFormat.dwRBitMask, (int)dd->origmode.ddpfPixelFormat.dwGBitMask, (int)dd->origmode.ddpfPixelFormat.dwBBitMask);
 				return 1;
 		}
 	}
@@ -1175,7 +1173,7 @@ static void get_adapter_for_monitor(dd_info *dd, win_monitor_info *monitor)
 	memset(&einfo, 0, sizeof(einfo));
 	einfo.monitor = monitor;
 	result = (*directdrawenumerateex)(monitor_enum_callback, &einfo, DDENUM_ATTACHEDSECONDARYDEVICES);
-	if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X during DirectDrawEnumerateEx call\n", (int)result);
+	if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X during DirectDrawEnumerateEx call\n", (int)result);
 
 	// set up the adapter
 	if (einfo.foundit && einfo.guid_ptr != NULL)
@@ -1233,7 +1231,7 @@ static HRESULT WINAPI enum_modes_callback(LPDDSURFACEDESC2 desc, LPVOID context)
 	final_score = size_score + refresh_score;
 
 	// best so far?
-	mame_printf_verbose("  %4dx%4d@%3dHz -> %f\n", (int)desc->dwWidth, (int)desc->dwHeight, (int)desc->dwRefreshRate, final_score * 1000.0f);
+	osd_printf_verbose("  %4dx%4d@%3dHz -> %f\n", (int)desc->dwWidth, (int)desc->dwHeight, (int)desc->dwRefreshRate, final_score * 1000.0f);
 	if (final_score > einfo->best_score)
 	{
 		einfo->best_score = final_score;
@@ -1292,8 +1290,8 @@ static void pick_best_mode(win_window_info *window)
 	einfo.best_score = 0.0f;
 
 	// enumerate the modes
-	mame_printf_verbose("DirectDraw: Selecting video mode...\n");
+	osd_printf_verbose("DirectDraw: Selecting video mode...\n");
 	result = IDirectDraw7_EnumDisplayModes(dd->ddraw, DDEDM_REFRESHRATES, NULL, &einfo, enum_modes_callback);
-	if (result != DD_OK) mame_printf_verbose("DirectDraw: Error %08X during EnumDisplayModes call\n", (int)result);
-	mame_printf_verbose("DirectDraw: Mode selected = %4dx%4d@%3dHz\n", dd->width, dd->height, dd->refresh);
+	if (result != DD_OK) osd_printf_verbose("DirectDraw: Error %08X during EnumDisplayModes call\n", (int)result);
+	osd_printf_verbose("DirectDraw: Mode selected = %4dx%4d@%3dHz\n", dd->width, dd->height, dd->refresh);
 }
