@@ -28,13 +28,12 @@
 // MAME headers
 #include "emu.h"
 #include "osdepend.h"
-#include "ui.h"
+#include "ui/ui.h"
 
 // MAMEOS headers
 #include "winmain.h"
 #include "window.h"
 #include "input.h"
-#include "debugwin.h"
 #include "video.h"
 #include "strconv.h"
 #include "config.h"
@@ -169,9 +168,9 @@ typedef /*WINUSERAPI*/ BOOL (WINAPI *register_rawinput_devices_ptr)(IN PCRAWINPU
 //============================================================
 
 // global states
-static UINT8                input_enabled;
+static bool                 input_enabled;
 static osd_lock *           input_lock;
-static UINT8                input_paused;
+static bool                 input_paused;
 static DWORD                last_poll;
 
 // DirectInput variables
@@ -185,16 +184,16 @@ static get_rawinput_device_info_ptr     get_rawinput_device_info;
 static register_rawinput_devices_ptr    register_rawinput_devices;
 
 // keyboard states
-static UINT8                keyboard_win32_reported_key_down;
+static bool                 keyboard_win32_reported_key_down;
 static device_info *        keyboard_list;
 
 // mouse states
-static UINT8                mouse_enabled;
+static bool                 mouse_enabled;
 static device_info *        mouse_list;
 
 // lightgun states
 static UINT8                lightgun_shared_axis_mode;
-static UINT8                lightgun_enabled;
+static bool                 lightgun_enabled;
 static device_info *        lightgun_list;
 
 // joystick states
@@ -213,10 +212,6 @@ static const TCHAR *const default_axis_name[] =
 //  PROTOTYPES
 //============================================================
 
-static void wininput_pause(running_machine &machine);
-static void wininput_resume(running_machine &machine);
-static void wininput_exit(running_machine &machine);
-
 // device list management
 static void device_list_poll_devices(device_info *devlist_head);
 static void device_list_reset_devices(device_info *devlist_head);
@@ -463,31 +458,27 @@ INLINE INT32 normalize_absolute_axis(INT32 raw, INT32 rawmin, INT32 rawmax)
 
 
 //============================================================
-//  wininput_init
+//  input_init
 //============================================================
 
-void wininput_init(running_machine &machine)
+bool windows_osd_interface::input_init()
 {
-	// we need pause and exit callbacks
-	machine.add_notifier(MACHINE_NOTIFY_PAUSE, machine_notify_delegate(FUNC(wininput_pause), &machine));
-	machine.add_notifier(MACHINE_NOTIFY_RESUME, machine_notify_delegate(FUNC(wininput_resume), &machine));
-	machine.add_notifier(MACHINE_NOTIFY_EXIT, machine_notify_delegate(FUNC(wininput_exit), &machine));
-
 	// allocate a lock for input synchronizations, since messages sometimes come from another thread
 	input_lock = osd_lock_alloc();
 	assert_always(input_lock != NULL, "Failed to allocate input_lock");
 
 	// decode the options
-	lightgun_shared_axis_mode = downcast<windows_options &>(machine.options()).dual_lightgun();
+	lightgun_shared_axis_mode = downcast<windows_options &>(machine().options()).dual_lightgun();
 
 	// initialize RawInput and DirectInput (RawInput first so we can fall back)
-	rawinput_init(machine);
-	dinput_init(machine);
-	win32_init(machine);
+	rawinput_init(machine());
+	dinput_init(machine());
+	win32_init(machine());
 
 	// poll once to get the initial states
-	input_enabled = TRUE;
-	wininput_poll(machine);
+	input_enabled = true;
+	wininput_poll(machine());
+	return true;
 }
 
 
@@ -495,13 +486,13 @@ void wininput_init(running_machine &machine)
 //  wininput_pause
 //============================================================
 
-static void wininput_pause(running_machine &machine)
+void windows_osd_interface::input_pause()
 {
 	// keep track of the paused state
 	input_paused = true;
 }
 
-static void wininput_resume(running_machine &machine)
+void windows_osd_interface::input_resume()
 {
 	// keep track of the paused state
 	input_paused = false;
@@ -512,11 +503,11 @@ static void wininput_resume(running_machine &machine)
 //  wininput_exit
 //============================================================
 
-static void wininput_exit(running_machine &machine)
+void windows_osd_interface::input_exit()
 {
 	// acquire the lock and turn off input (this ensures everyone is done)
 	osd_lock_acquire(input_lock);
-	input_enabled = FALSE;
+	input_enabled = false;
 	osd_lock_release(input_lock);
 
 	// free the lock
@@ -530,7 +521,7 @@ static void wininput_exit(running_machine &machine)
 
 void wininput_poll(running_machine &machine)
 {
-	int hasfocus = winwindow_has_focus() && input_enabled;
+	bool hasfocus = winwindow_has_focus() && input_enabled;
 
 	// ignore if not enabled
 	if (input_enabled)
@@ -569,22 +560,22 @@ void wininput_poll(running_machine &machine)
 //  wininput_should_hide_mouse
 //============================================================
 
-int wininput_should_hide_mouse(void)
+bool wininput_should_hide_mouse(void)
 {
 	// if we are paused or disabled, no
 	if (input_paused || !input_enabled)
-		return FALSE;
+		return false;
 
 	// if neither mice nor lightguns enabled in the core, then no
 	if (!mouse_enabled && !lightgun_enabled)
-		return FALSE;
+		return false;
 
 	// if the window has a menu, no
 	if (win_window_list != NULL && win_has_menu(win_window_list))
-		return FALSE;
+		return false;
 
 	// otherwise, yes
-	return TRUE;
+	return true;
 }
 
 
@@ -693,7 +684,7 @@ BOOL wininput_handle_raw(HANDLE device)
 
 	// free the temporary buffer and return the result
 	if (data != small_buffer)
-		global_free(data);
+		global_free_array(data);
 	return result;
 }
 
@@ -1008,7 +999,7 @@ static void win32_keyboard_poll(device_info *devinfo)
 	int keynum;
 
 	// clear the flag that says we detected a key down via win32
-	keyboard_win32_reported_key_down = FALSE;
+	keyboard_win32_reported_key_down = false;
 
 	// reset the keyboard state and then repopulate
 	memset(devinfo->keyboard.state, 0, sizeof(devinfo->keyboard.state));
@@ -1026,7 +1017,7 @@ static void win32_keyboard_poll(device_info *devinfo)
 				devinfo->keyboard.state[dik] = 0x80;
 
 			// set this flag so that we continue to use win32 until all keys are up
-			keyboard_win32_reported_key_down = TRUE;
+			keyboard_win32_reported_key_down = true;
 		}
 	}
 }
@@ -1112,7 +1103,7 @@ static void dinput_init(running_machine &machine)
 	}
 #endif
 
-	mame_printf_verbose("DirectInput: Using DirectInput %d\n", dinput_version >> 8);
+	osd_printf_verbose("DirectInput: Using DirectInput %d\n", dinput_version >> 8);
 
 	// we need an exit callback
 	machine.add_notifier(MACHINE_NOTIFY_EXIT, machine_notify_delegate(FUNC(dinput_exit), &machine));
@@ -1295,7 +1286,7 @@ static char *dinput_device_item_name(device_info *devinfo, int offset, const TCH
 
 	// convert to UTF8, free the temporary string, and return
 	utf8 = utf8_from_tstring(combined);
-	global_free(combined);
+	global_free_array(combined);
 	return utf8;
 }
 
@@ -1409,7 +1400,7 @@ static BOOL CALLBACK dinput_mouse_enum(LPCDIDEVICEINSTANCE instance, LPVOID ref)
 	result = dinput_set_dword_property(devinfo->dinput.device, DIPROP_AXISMODE, 0, DIPH_DEVICE, DIPROPAXISMODE_REL);
 	if (result != DI_OK && result != DI_PROPNOEFFECT)
 	{
-		mame_printf_error("DirectInput: Unable to set relative mode for mouse %d (%s)\n", generic_device_index(mouse_list, devinfo), devinfo->name);
+		osd_printf_error("DirectInput: Unable to set relative mode for mouse %d (%s)\n", generic_device_index(mouse_list, devinfo), devinfo->name);
 		goto error;
 	}
 
@@ -1505,17 +1496,17 @@ static BOOL CALLBACK dinput_joystick_enum(LPCDIDEVICEINSTANCE instance, LPVOID r
 	// set absolute mode
 	result = dinput_set_dword_property(devinfo->dinput.device, DIPROP_AXISMODE, 0, DIPH_DEVICE, DIPROPAXISMODE_ABS);
 	if (result != DI_OK && result != DI_PROPNOEFFECT)
-		mame_printf_warning("DirectInput: Unable to set absolute mode for joystick %d (%s)\n", generic_device_index(joystick_list, devinfo), devinfo->name);
+		osd_printf_warning("DirectInput: Unable to set absolute mode for joystick %d (%s)\n", generic_device_index(joystick_list, devinfo), devinfo->name);
 
 	// turn off deadzone; we do our own calculations
 	result = dinput_set_dword_property(devinfo->dinput.device, DIPROP_DEADZONE, 0, DIPH_DEVICE, 0);
 	if (result != DI_OK && result != DI_PROPNOEFFECT)
-		mame_printf_warning("DirectInput: Unable to reset deadzone for joystick %d (%s)\n", generic_device_index(joystick_list, devinfo), devinfo->name);
+		osd_printf_warning("DirectInput: Unable to reset deadzone for joystick %d (%s)\n", generic_device_index(joystick_list, devinfo), devinfo->name);
 
 	// turn off saturation; we do our own calculations
 	result = dinput_set_dword_property(devinfo->dinput.device, DIPROP_SATURATION, 0, DIPH_DEVICE, 10000);
 	if (result != DI_OK && result != DI_PROPNOEFFECT)
-		mame_printf_warning("DirectInput: Unable to reset saturation for joystick %d (%s)\n", generic_device_index(joystick_list, devinfo), devinfo->name);
+		osd_printf_warning("DirectInput: Unable to reset saturation for joystick %d (%s)\n", generic_device_index(joystick_list, devinfo), devinfo->name);
 
 	// cap the number of axes, POVs, and buttons based on the format
 	devinfo->dinput.caps.dwAxes = MIN(devinfo->dinput.caps.dwAxes, 8);
@@ -1679,7 +1670,7 @@ static void rawinput_init(running_machine &machine)
 	get_rawinput_data = (get_rawinput_data_ptr)GetProcAddress(user32, "GetRawInputData");
 	if (register_rawinput_devices == NULL || get_rawinput_device_list == NULL || get_rawinput_device_info == NULL || get_rawinput_data == NULL)
 		goto error;
-	mame_printf_verbose("RawInput: APIs detected\n");
+	osd_printf_verbose("RawInput: APIs detected\n");
 
 	// get the number of devices, allocate a device list, and fetch it
 	if ((*get_rawinput_device_list)(NULL, &device_count, sizeof(*devlist)) != 0)
@@ -1696,11 +1687,11 @@ static void rawinput_init(running_machine &machine)
 		RAWINPUTDEVICELIST *device = &devlist[devnum];
 
 		// handle keyboards
-		if (device->dwType == RIM_TYPEKEYBOARD && !FORCE_DIRECTINPUT)
+		if (!FORCE_DIRECTINPUT && device->dwType == RIM_TYPEKEYBOARD)
 			rawinput_keyboard_enum(machine, device);
 
 		// handle mice
-		else if (device->dwType == RIM_TYPEMOUSE && !FORCE_DIRECTINPUT)
+		else if (!FORCE_DIRECTINPUT && device->dwType == RIM_TYPEMOUSE)
 			rawinput_mouse_enum(machine, device);
 	}
 
@@ -1728,12 +1719,12 @@ static void rawinput_init(running_machine &machine)
 		if (!(*register_rawinput_devices)(reglist, regcount, sizeof(reglist[0])))
 			goto error;
 
-	global_free(devlist);
+	global_free_array(devlist);
 	return;
 
 error:
 	if (devlist != NULL)
-		global_free(devlist);
+		global_free_array(devlist);
 }
 
 
@@ -1777,7 +1768,7 @@ static device_info *rawinput_device_create(running_machine &machine, device_info
 	// improve the name and then allocate a device
 	tname = rawinput_device_improve_name(tname);
 	devinfo = generic_device_alloc(machine, devlist_head_ptr, tname);
-	global_free(tname);
+	global_free_array(tname);
 
 	// copy the handle
 	devinfo->rawinput.device = device->hDevice;
@@ -1785,7 +1776,7 @@ static device_info *rawinput_device_create(running_machine &machine, device_info
 
 error:
 	if (tname != NULL)
-		global_free(tname);
+		global_free_array(tname);
 	if (devinfo != NULL)
 		rawinput_device_release(devinfo);
 	return NULL;
@@ -1918,7 +1909,7 @@ static TCHAR *rawinput_device_improve_name(TCHAR *name)
 
 					// free memory and close the key
 					if (endparentid != NULL)
-						global_free(endparentid);
+						global_free_array(endparentid);
 					RegCloseKey(endkey);
 				}
 			}
@@ -1934,7 +1925,7 @@ static TCHAR *rawinput_device_improve_name(TCHAR *name)
 
 convert:
 	// replace the name with the nicer one
-	global_free(name);
+	global_free_array(name);
 
 	// remove anything prior to the final semicolon
 	chsrc = _tcsrchr(regstring, ';');
@@ -1947,9 +1938,9 @@ convert:
 
 exit:
 	if (regstring != NULL)
-		global_free(regstring);
+		global_free_array(regstring);
 	if (regpath != NULL)
-		global_free(regpath);
+		global_free_array(regpath);
 	if (regkey != NULL)
 		RegCloseKey(regkey);
 
@@ -2172,7 +2163,7 @@ static TCHAR *reg_query_string(HKEY key, const TCHAR *path)
 		return buffer;
 
 	// otherwise return a NULL buffer
-	global_free(buffer);
+	global_free_array(buffer);
 	return NULL;
 }
 
