@@ -59,7 +59,7 @@ static const translation_info gcc_translate[] =
 	{ 0,        "-O0",                      "/Od" },
 	{ 0,        "-O1",                      "/O2" },
 	{ 0,        "-O2",                      "/O2" },
-	{ 0,        "-O3",                      "/O2" },
+	{ 0,        "-O3",                      "/Ox" },
 	{ 0,        "-Os",                      "/O1" },
 	{ 0,        "-g*",                      "/Zi" },
 	{ VS2005,   "-fno-strict-aliasing",     "" },       // deprecated in VS2005
@@ -68,10 +68,10 @@ static const translation_info gcc_translate[] =
 	{ 0,        "-fomit-frame-pointer",     "" },
 	{ 0,        "-Werror",                  "/WX" },
 	//{ VS7,        "-Wall",                    "/Wall /W3 /wd4003 /wd4018 /wd4146 /wd4242 /wd4244 /wd4619 /wd4702 /wd4706 /wd4710 /wd4711 /wd4738 /wd4826" },
-	{ VS7,      "-Wall",                    "/Wall /W4 /wd4003 /wd4018 /wd4146 /wd4242 /wd4244 /wd4619 /wd4702 /wd4706 /wd4710 /wd4711 /wd4738 /wd4826 /wd4820 /wd4514 /wd4668 /wd4127 /wd4625 /wd4626 /wd4512 /wd4100 /wd4310 /wd4571 /wd4061 /wd4131 /wd4255 /wd4510 /wd4610 /wd4505 /wd4324 /wd4611 /wd4201 /wd4189 /wd4296 /wd4986 /wd4347 /wd4987 /wd4250 /wd4435" },
+	{ VS7,      "-Wall",                    "/Wall /W4 /wd4003 /wd4018 /wd4146 /wd4242 /wd4244 /wd4619 /wd4702 /wd4706 /wd4710 /wd4711 /wd4738 /wd4826 /wd4820 /wd4514 /wd4668 /wd4127 /wd4625 /wd4626 /wd4512 /wd4100 /wd4310 /wd4571 /wd4061 /wd4131 /wd4255 /wd4510 /wd4610 /wd4505 /wd4324 /wd4611 /wd4201 /wd4189 /wd4296 /wd4986 /wd4347 /wd4987 /wd4250 /wd4435 /wd4150 /wd4805 /wd4141" },
 	{ 0,        "-Wall",                    "/W0" },
 	{ VS7,      "-Wno-unused",              "/wd4100 /wd4101 /wd4102 /wd4505" },
-	{ 0,        "-Wno-sign-compare",        "/wd4365 /wd4389 /wd4245" },
+	{ 0,        "-Wno-sign-compare",        "/wd4365 /wd4389 /wd4245 /wd4388" },
 	{ 0,        "-W*",                      "" },
 	{ VS2005,   "-march=*",                 "" },       // deprecated in VS2005
 	{ 0,        "-march=pentium",           "/G5" },
@@ -81,10 +81,15 @@ static const translation_info gcc_translate[] =
 	{ 0,        "-march=athlon",            "/G7" },
 	{ 0,        "-march=pentium4",          "/G7" },
 	{ 0,        "-march=athlon64",          "/G7" },
+	// TODO: the x64 compiler doesn't have the /arch:SSE*
+	{ VS71,     "-msse",                   "/arch:SSE" },
+	{ 0,        "-msse",                   "" },
 	{ VS71,     "-msse2",                   "/arch:SSE2" },
 	{ 0,        "-msse2",                   "" },
 	{ 0,        "-msse3",                   "" },
 	{ VS2010,   "-mavx",                    "/arch:AVX" },
+	// TODO: introduced in Visual Studio 2013 Update 2, version 12.0.34567.1
+	//{ 0,   "-mavx2",                    "/arch:AVX2" },
 	{ 0,        "-mwindows",                "" },
 	{ 0,        "-mno-cygwin",              "" },
 	{ 0,        "-std=gnu89",               "" },
@@ -93,6 +98,7 @@ static const translation_info gcc_translate[] =
 	{ 0,        "-x",                       "" },
 	{ 0,        "c++",                      "" },
 	{ 0,        "-flto",                    "/GL" },
+	{ 0,        "-fno-optimize-sibling-calls", "" },
 	{ 0 }
 };
 
@@ -222,6 +228,7 @@ static DWORD get_exe_version(const char *executable)
 //  build_command_line
 //============================================================
 
+// TODO: VS2012 and up enable SSE2 instructions by default for x86 - we should make older versions consistent with this
 static void build_command_line(int argc, char *argv[])
 {
 	const translation_info *transtable;
@@ -341,12 +348,19 @@ static void build_command_line(int argc, char *argv[])
 	}
 
 	// identify the version number of the EXE
-	if (!icl_compile) exe_version = get_exe_version(executable);
-	else exe_version = 0x00110000; // assume this for ICL
+	if (!icl_compile)
+		exe_version = get_exe_version(executable);
+	else
+		exe_version = 0x00110000; // assume this for ICL
 
-	// special case
-	if (!strcmp(executable, "cl.exe") && (exe_version >= 0x00070000))
-		dst += sprintf(dst, "/wd4025 ");
+	// special cases
+	if (!icl_compile && !strcmp(executable, "cl.exe")) {
+		if (exe_version >= 0x00070000)
+			dst += sprintf(dst, "/wd4025 ");
+		// fixes -j compiles with VS2013
+		if (exe_version >= 0x000C0000)
+			dst += sprintf(dst, "/FS ");
+	}
 
 	// iterate over parameters
 	for (param = parampos; param < argc; param++)
