@@ -31,7 +31,6 @@
 #include "window.h"
 #include "video.h"
 #include "input.h"
-#include "debugwin.h"
 #include "strconv.h"
 #include "config.h"
 #include "winutf8.h"
@@ -344,10 +343,6 @@ void winwindow_process_events(running_machine &machine, int ingame, bool nodispa
 
 	assert(GetCurrentThreadId() == main_threadid);
 
-	// if we're running, disable some parts of the debugger
-	if (ingame && (machine.debug_flags & DEBUG_FLAG_OSD_ENABLED) != 0)
-		debugwin_update_during_game(machine);
-
 	// remember the last time we did this
 	last_event_check = GetTickCount();
 
@@ -1901,7 +1896,7 @@ static void set_fullscreen(win_window_info *window, int fullscreen)
 	adjust_window_position_after_major_change(window);
 }
 
-#ifdef USE_QTDEBUG
+#if (USE_QTDEBUG)
 bool winwindow_qt_filter(void *message)
 {
 	MSG *msg = (MSG *)message;
